# -*- coding': utf-8 -*
#!/usr/bin/env python3

data = {
  'Latin': {
    'spa': ' de|de |os | la| a |la | y |ón |ión|es |ere|rec|ien|o a|der|ció|a p|cho|ech|en |ent|a l|aci|e d|el |ona|na | co|as |al |da | to|ene|e l| en| el| pe|nte|tod|ho | su|per|ad | ti|a t|ers|tie| se|rso| pr|son|e s|te |oda|cia|n d|o d|dad|ida| in|ne | es|ion|cio|s d|con|est|a e| po|men| li|res|nci|su |to |tra| re|n e| lo|tad| na|los|a s| o |ia |que| pa|rá |pro| un|s y|ual|s e|lib|nac|do |ra |er |nal|ue | qu|e e|a d|ar |nes|ica|a c|sta|ser|or |ter|se |por|cci|io |des|ado|les|one|a a|del|l d|ndi| so| cu|s p|ale|s n|ame|par|ici|oci|una|ber|s t|rta|com| di|e a|imi|o s|e c|ert|o e|dos|las|o p|ant|dic|nto| al|ara|ibe|enc|cas| as|e p|ten|ali|o t|soc|y l|n c|s l|l t|pre|nta|so |tos|y a|ria|n t|die|a u| fu|no |l p|ial|qui|dis|s o|hos|gua|igu| ig| ca|sar| ma|l e| ac|tiv|s a|re |nad|vid|era| tr|ier|cua|n p|cla|ade|bre|s s|esa|ntr|ecc|a i| le|lid|das|d d|ido|ari|ind|ada|nda|fun|mie|ca |tic|eli|ta |y d|nid|e i|n l|ios|o y|esp|iva|y e|mat|bli|r a|drá|tri|cti|tal|rim|ont|erá|us |sus|end|pen|tor|ito|ond|ori|uie|lig|n a|ist|rac|lar|rse|tar|mo |omo|ibr|odo|edi|med| me|nio|a y|eda|isf|lo |aso|l m|ias|ico|lic|ple|ste|act|tec|ote|rot|ele|ura| ni|ie |adi|u p|seg|s i|un |und|a n|lqu|alq|o i|inc|sti| si|n s|ern',
    'eng': 'the| th| an|he |nd |ion|and| to|to |tio| of|on |of | in|al |ati|or |ght|igh|rig| ri|ne |ent|one|ll |is |as |ver|ed | be|e r|in |t t|all|eve|ht | or|ery|s t|ty | ev|e h|yon| ha|ryo|e a|be |his| fr|ng |d t|has| sh|ing| hi|sha| pr| co| re|hal|nal|y a|s a|n t|ce |men|ree|fre|e s|l b|nat|for|ts |nt |n a|ity|ry |her|nce|ect|d i| pe|pro|n o|cti| fo|e e|ly |es | no|ona|ny |any|er |re |f t|e o| de|s o| wi|ter|nte|e i|ons| en| ar|res|ers|y t|per|d f| a | on|ith|l a|e t|oci|soc|lit| as| se|dom|edo|eed|nti|s e|t o|oth|wit| di|equ|t a|ted|st |y o|int|e p| ma| so| na|l o|e c|ch |d a|enc|th |are|ns |ic | un| fu|tat|ial|cia| ac|hts|nit|qua| eq| al|om |e w|d o|f h|ali|ote|n e| wh|r t|sta|ge |thi|o a|tit|ual|an |te |ess| ch|le |ary|e f|by | by|y i|tec|uni|o t|o o| li|no | la|s r| su|inc|led|rot|con| pu| he|ere|imi|r a|ntr| st| ot|eli|age|dis|s d|tle|itl|hou|son|duc|edu| wo|ate|ble|ces|at | at| fa|com|ive|o s|eme|o e|aw |law|tra|und|pen|nde|unt|oun|n s|s f|f a|tho|ms | is|act|cie|cat|uca| ed|anc|wor|ral|t i| me|o f|ily|pri|ren|ose|s c|en |d n|l c|ful|rar|nta|nst| ag|l p|min|din|sec|y e| tr|rso|ich|hic|whi|cou|ern|uri|r o|tic|iti|igi|lig|rat|rth|t f|oms|rit|d r|ee |e b|era|rou|se |ay |rs | ho|abl|e u',
    'por': 'de | de| se|ão |os |to |em | e |do |o d| di|er |ito|eit|ser|ent|ção| a |dir|ire|rei|o s|ade|dad|uma|as |no |e d| to|nte| co|o t|tod| ou|men|que|s e|man| pr| in| qu|es | te|hum|odo|e a|da | hu|ano|te |al |tem|o e|s d|ida|m d| pe| re|o a|ou |r h|e s|cia|a e| li|o p| es|res| do| da| à |ual| em| su|açã|dos|a p|tra|est|ia |con|pro|ar |e p|is | na|rá |qua|a d| pa|com|ais|o c|ame|erá| po|uer|sta|ber|ter| o |ess|ra |e e|das|o à|nto|nal|o o|a c|ido|rda|erd| as|nci|sua|ona|des|ibe|lib|e t|ado|s n|ua |s t|ue | so|ica|ma |lqu|alq|tos|m s|a l|per|ada|oci|soc|cio|a n|par|aci|s a|pre|ont|m o|ura|a s| um|ion|e o|or |e r|pel|nta|ntr|a i|io |nac|ênc|str|ali|ria|nst| tr|a q|int|o n|a o|ca |ela|uçã|lid|e l| at|sen|ese|r d|s p|egu|seg|vid|pri|sso|ém |ime|tic|dis|raç|eci|ara| ca|nid|tru|ões|ass|seu|por|a a|m p| ex|so |r i|eçã|teç|ote|rot| le| ma|ing|a t|ran|era|rio|l d|eli|ça |sti| ne|cid|ern|utr|out|r e|e c|tad|gua|igu| ig| os|s o|ruç|ins|çõe|ios| fa|e n|sse| no|re |art|r p|rar|u p|inc|lei|cas|ico|uém|gué|ngu|nin| ni|gur|la |pen|nça|na |içã|ião|cie|ist|sem|ta |ele|e f|om |tro| ao|rel|m a|s s|tar|eda|ied|uni|e m|s i|a f|ias| cu| ac|r a|á a|rem|ei |omo|rec|for|s f|esc|ant|à s| vi|o q|ver|a u|nda|und|fun',
    'ind': 'an |ang|ng | da|ak | pe|ata| se| ke| me|dan| di| be|ber|kan|ran|hak|per|yan| ya|nga|nya|gan| at|ara| ha|eng|asa|ora|men|n p|n k|erh|rha|n d|ya |ap |at |as |tan|n b|ala|a d| or|a s|san|tas|eti|uk |pen|g b|set|ntu|n y|tia|iap|k m|eba|aan| un|n s|tuk|k a|p o|am |lam| ma|unt| de|ter|bas|beb|dak|end|i d|pun|mem|tau|dal|ama|keb|aka|ika|n m| ba|di |ma | sa|den|au |nda|n h|eri| ti|ela|k d|un |n a|ebe|ana|ah |ra |ida|uka| te|al |ada|ri |ole|tid|ngg|lak|leh|dap|a p|dil|g d|ena|eh |gar|na |ert|apa|um |tu |atu|a m|sam|ila|har|n t|asi|ban|erl|t d|bat|uat|ta |lan|adi|h d|neg| ne|kum|mas|nan|pat|aha| in|l d|emp|sem|rus|sua|ser|uan|era|ari|erb|kat|man|a b|g s|rta|ai |nny|n u|ung|ndi|han|uku|huk| hu|sa |ers|in | la|ka | su|ann|car|kes|aku|dip|i s|a a|erk|n i|lai|rga|aru|k h|i m|rka|a u|us |nak|emb|gga|nta|iba| pu|ind|s p|ent|mel|ina|min|ian|dar|ni |rma|lua|rik|ndu|lin|sia|rbu|g p|k s|da |aya|ese|u d|ega|nas|ar |ipe|yar|sya|ik |aga| ta|ain|ua |arg|uar|iny|pem|ut |si |dun|eor|seo|rak|ngs|ami|kel|ini|g t|dik|mer|emu|aks|rat|uru|ewa|il |enu|any|kep|pel|asu|rli|ia |dir|jam|mba|mat|pan|g m|ses|sar|das|kuk|bol|ili|u k|gsa|u p|a k|ern|ant|raa|t p|ema|mua|idi|did|t s|i k|rin|erm|esu|ger|elu|nja|enj|ga |dit',
    'fra': ' de|es |de |ion|nt |tio|et |ne |on | et|ent|le |oit|e d| la|e p|la |it | à |t d|roi|dro| dr| le|té |e s|ati|te |re | to|s d|men|tou|e l|ns | pe| co|son|que| au| so|e a|onn|out| un| qu| sa| pr|ute|eme| l’|t à| a |e e|con|des| pa|ue |ers|e c| li|a d|per|ont|s e|t l|les|ts |tre|s l|ant| ou|cti|rso|ou |ce |ux |à l|nne|ons|ité|en |un | en|er |une|n d|sa |lle| in|nte|e t| se|lib|res|a l|ire| d’| re|é d|nat|iqu|ur |r l|t a|s s|aux|par|nal|a p|ans|dan|qui|t p| dé|pro|s p|air| ne| fo|ert|s a|nce|au |ui |ect|du |ond|ale|lit| po|san| ch|és | na|us |com|our|ali|tra| ce|al |e o|e n|rté|ber|ibe|tes|r d|e r|its| di|êtr|pou|été|s c|à u|ell|int|fon|oci|soc|ut |ter| da|aut|ien|rai| do|iss|s n| ma|bli|ge |est|s o| du|ona|n p|pri|rs |éga| êt|ous|ens|ar |age|s t| su|cia|u d|cun|rat| es|ir |n c|e m| ét|t ê|a c| ac|ote|n t|ein| tr|a s|ndi|e q|sur|ée |ser|l n| pl|anc|lig|t s|n e|s i|t e| ég|ain|omm|act|ntr|tec|gal|ul | nu| vi|me |nda|ind|soi|st | te|pay|tat|era|il |rel|n a|dis|n s|pré|peu|rit|é e|t é|bre|sen|ill|l’a|d’a| mo|ass|lic|art| pu|abl|nta|t c|rot| on| lo|ure|l’e|ava|ten|nul|ivi|t i|ess|ys |ays| fa|ine|eur|rés|cla|tés|oir|eut|e f|utr|doi|ibr|ais|ins|éra|’en|iét|l e|s é|nté| ré|ssi| as|nse|ces|é a',
    'deu': 'en |er |der|ein| un|nd |und|ung|cht|ich| de|sch|ng | ge|ine|ech|gen|rec|che|ie | re|eit| au|ht |die| di| ha|ch | da|ver| zu|lic|t d|in |auf| ei| in| be|hen|nde|n d|uf |ede| ve|it |ten|n s|sei|at |jed| je| se|and|rei|s r|den|ter|ne |hat|t a|r h|zu |das|ode| od|as |es | an|fre|nge| we|n u|run| fr|ere|e u|lle|ner|nte|hei|ese| so|rde|wer|ige| al|ers|n g|hte|d d| st|n j|lei|all|n a|nen|ege|ent|bei|g d|erd|t u|ren|nsc|chu| gr|kei|ens|le |ben|aft|haf|cha|tli|ges|e s| si|men| vo|lun|em |r s|ion|te |len|gru|gun|tig|unt|uch|spr|n e|ft |ei |e f| wi| sc|r d|n n|geh|r g|dar|sta|erk| er|r e|sen|eic|gle| gl|lie|e e|tz |fen|n i|nie|f g|t w|des|chl|ite|ihe|eih|ies|ruc|st |ist|n w|h a|n z|e a| ni|ang|rf |arf|gem|ale|ati|on |he |t s|ach| na|end|n o|pru|ans|sse|ern|aat|taa|ehe|e d|hli|hre|int|tio|her|nsp|de |mei| ar|r a|ffe|e b|wie|erf|abe|hab|ndl|n v|sic|t i|han|ema|nat|ber|ied|geg|d s|nun|d f|ind| me|gke|igk|ieß| fa|igu|hul|r v|dig|rch|urc|dur| du|utz|hut|tra|aus|alt|bes|str|ell|ste|ger|r o|esc|e g|rbe|arb|ohn|r b|mit|d g|r w|ntl|sow|n h|nne|etz|raf|dlu| ih|lte|man|iem|erh|eru| is|dem|lan|rt |son|isc|eli|rel|n r|e i|rli|r i| mi|e m|ild|bil| bi|eme| en|ins|für| fü|gel|öff| öf|owi|ill|wil|e v|ric|f e',
    'jav': 'ng |an | ka|ang|ing|kan| sa|ak |lan| la|hak| pa| ha|ara|ne |abe| in|n k|ngg|ong|ane|nga|ant|won|uwo| an| uw|nin|ata|n u|en |ra |tan| da|ran|ana| ma|nth|ake|ben|beb|hi |ke |sab|nda| ng|adi|thi|nan|a k| ba|san|asa|ni |e h|e k|g k| ut|pan|awa| be|eba|gan|g p|dan| wa|bas|aka|dha|yan|sa |arb|man| di|wa |g d| na|g n|ban| tu|n s|ung|wen|g s|rbe|dar|dak|di |g u|ora|aya|be |ah |a s|eni| or|han|as | pr|a n|na |iya|a a|kar|at |a l|mar|uwe|duw|uta|und|n p|asi|pa | si|ala|n n| un|kab|oni|ya |i h|gar|g b|yat|tum|ta |n m|i k|apa|taw| li|ani| ke|al |ka |kal|ngk|ega| ne|nal|n i|g a|ggo|ina|we |ena|dad|iba|awi|aga|a p| ta|sar|adh|awe|and|uju|ind|min|sin|ndu|uwa|gge|n l|ggu|ngs|n b|a b|pra|iji|n a|ha | bi|kat|go | ku|e p|ron|kak|ngu|a u|gsa|war|nya|g t|pad|bis|k b|i w|ae |wae| nd|ali|a m|er |sak|e s|ku |liy|ama|i l|eh |isa|arg|n t|a d|kap|i s|ayo|gay| pe|ndh|bad|pri|neg|tow|uto|eda|bed|il |ih | ik|ur |k k|rta|art|i p|rga|lak|ami|ro |aro|yom|r k|e d|a w|kon|rib|eng|ger|g l|ras|dil| ti|k l|rap|mra|uma| pi|k h|n d|gaw|wat|ga |k n|ar |per| we|oma|k p|jro|ajr|saj|ase|ini|ken|saw|ona|nas|kas|h k|i t| um|tin|wo | me|aba|rak|pag|yar|sya|t k| te| mu|ngl| ni|i b|men|ate|a i|aku|ebu|a t| du|g m|owo|mat| lu|amp',
    'vie': 'ng |̣c |́c | qu|à | th|nh | ng|̣i |̀n |và| va| nh|uyê| ph|quy| ca|ền|yề|̀nh|̀i |̣t | ch|ó | tr|ngư|i n| gi|gươ|ời|ườ|́t | co|ượ| cu|ác|ự |ợc| kh| đư|đươ| tư|có| ha|ông|c t| đê|n t|i đ|ìn|̀u |cá|gia|́i |ọi|mọ| mo|ều|iệ|đề|u c|như|pha| ba| bi|ất|̉a |ủa|củ|hôn| đô|g t|́ q|̃ng| ti|tự|t c|̣n | la|n đ|n c|n n|hiê|ch |ay |hay| vi|ân | đi| na|bả| ho|do | do| tô| hi|ội|há|ị |nà|̀ t|ới|hân| mô|́p |àn|̣ d|́ch|̣p |̀o |ào|khô|́n |ột|mộ| hô|ia |ốc|c h|hữ|i v|g n|́ng|uố|quô|h t|ôn |ên |n v|nhâ|̣ t| bâ|i c|g v|̉ng|iế|c c|ật|thư|hư |ướ|̉n | vơ| cô|c đ| đo| sư|t t|ộc|ữn|vớ| vê|ả |̣ng|g đ|̉o |ảo|uậ| đa|bị|là|sự|bấ|hà|hộ|i t|ản|hươ|̀ng|tro|̉m |o v| mi|ể |ục|i h|ức|áp|g c|̃ h|iá|n b|̉i |a m|h c|côn|ện|ớc|hạ|độ| du| cư|a c|n h|tha|ã | xa|́o |áo|ín|̀y |g b| hư|g h|ong|ron|̀ c|cho|̀ n|mì|ực|h v|c b| lu|i b|ệ |ai |ế |̣ c|xã|kha|c q|iể|tộ|ối|đố|á |hoa|o h|h đ|cả|n l|họ|tiê|y t|̉ c|ại|án|̀ đ|oà|y đ|chi|̉ n|phâ|ề |thu|iên|dụ|o c|i m|luâ|c p|ốn|c l|́ c|ũn|cũ|c g|c n|qua|n g|c m|o n|ải|hả|́ t|ho |về| tâ| hơ|o t|ở |hứ|hì|viê|̀m |̉ t|đó|thô|ứ |cứ|hí|́nh|ày|ởn|ưở| bă|tri| ta|m v|c v|ợp|hợ|h m| nư|ết|thi|ặc|ngh|uy ',
    'ita': ' di|to | in|ion|la | de|di |re |e d|ne | e |zio|rit|a d|one|o d|ni |le |lla|itt|ess| al|iri|dir|tto|ent|ell|i i|del|ndi|ere|ind|o a| co|te |tà |ti |a s|uo |e e|gni|azi| pr|idu|ivi|duo|vid|div|ogn| og| es|i e| ha|all|ale|nte|e a|men|ser| su| ne|e l|za |i d|per|a p|ha | pe| un|con|no |sse|li |e i| o | so| li| la|pro|ia |o i|e p|o s|i s|in |ato|o h|na |e s|a l|e o|nza|ali|tti|o p|ta |so |ber|ibe|lib|o e|un | a | ri|ua |il | il|nto|pri|el | po|una|are|ame| qu|a c|ro |oni|nel|e n| ad|ual|gli|sua|ond| re|a a|i c|ri |o o|sta|ita|i o| le|ad |i a|ers|enz|ssi|à e|ità|gua|i p|e c|io | pa|ter|soc|nal|ona|naz|ist|cia|rso|ver|a e|i r|tat|lle|sia| si|rio|tra|che| se|rtà|ert|anz|eri|tut|à d|he | da|al |ant|qua|on |ari|o c| st|oci|er |dis|tri|si |ed | ed|ono| tu|ei |dei|uzi|com|att|a n|opr|rop|par|nes|i l|zza|ese|res|ien|son| eg|n c|ont|nti|pos|int|ico|rà |sun|ial|lit|sen|pre|tta|dev|nit|era|eve|ll |l i| l |nda|ina|non| no|o n|ria|str|d a|art|se |ssu|ica|raz|ett|sci|gio|ati|egu| na|i u|utt|ve | ma|do |e r|ssa|sa |a f|n p|fon| ch|d u|rim| fo|a t| sc|trà|otr|pot|n i| cu|l p|ra |ezz|a o|ini|sso|dic|ltr|uni|cie| ra|i n|ruz|tru|ste| is|der|l m|a r|pie|lia|est|dal|nta| at|tal|ntr| pu|nno|ann|ten|vit|a v',
    'tur': ' ve| ha|ve |ir |ler|hak| he|her|in |lar|r h|bir|ya |er |ak |kkı|akk|eti| ka| bi|eya|an |eri|iye|yet|ara|ek | ol|de |vey|ın |ır |nda|arı|esi|ını|dır| ta|tle|e h|ası|etl|e k| va|ı v|sın|ile|ne |rke|erk|ard|ine| sa|ınd|ini|k h|kın|ama|le |tin|rdı|var|a v| me|e m|na |sin|ere|k v| şa| bu|lan|kes|dir|rin|dan| ma|kı |mak|şah|da | te|mek| ge|nı | hi|nin|en |n h| se|lik|rle|ana|lma|e a|ı h|r ş|ill|si | de|aya|zdi|izd|aiz|hai|ret|hiç|ına| iş|e b| ba|kla|et | hü|rın|n k|ola|nma|e t| ya|eme|riy|n v|e i|a h|li |mil|eli|ket|ik |kar|irl|hür|im |evl|mes|e d|ahs|ma |rak|ala|let|lle|un | ed|rri|ürr|bu | mi|i v|dil| il| eş|n i|la |el |mal| mü| ko|e g|se | ki|mas|lek|mle|mem|n b|ili|e e|ser| iç|n s|din| di|es |mel|eke|tir|şit|eşi|r b|akl|yla|n m|len| ke|edi|oru|nde|re |ele|ni |tür|a k|eye|ık |ken|uğu| uy|eml|erd|ede|ame| gö|e s|i m|tim|i b|rde|rşı|arş|a s|it |t v|siy|ar |rme|est|bes|rbe|erb|te |alı| an|ndi|end|hsı|unm|rı |kor|nın| ce|maz|mse|ims|kim|iç | ay|a m|lam|ri |sız|a b|ade|n t|nam|lme|ilm|k g|il |tme|etm|r v|e v|n e|ğre|öğr| öğ|al |ıyl|olm|vle|şma|i s|ger|me | da|ind|lem|i o|may|cak|çin|içi|nun|kan|ye |e y|r t|az |ç k|ece|sı |eni| mu|ulu|und|den|lun| fa|şı |ahi|l v|r a|san|kat| so|enm| ev|iş ',
    'pol': ' pr|nie|pra| i |nia|ie |go |ani|raw|ia | po|ego| do|wie|iek|awo| ni|owi|ch |ek |do | ma|wo |a p|ści|ci |ej | cz| za| w |ych|ośc|rze|prz| ka|wa |eni| na| je|ażd|każ|ma |zło|czł|noś|o d|łow|y c|dy |żdy|i p|wol| lu|ny |oln| wy|stw| wo|ub |lub|lno|rod|k m|twa|dzi|na | sw|rzy|ają|ecz|czn|sta| sp|owa|o p|spo|i w|kie|a w|zys|obo|est|neg|ać |mi |cze|e w|nyc|nic|jak| ja|wsz| z |jeg|wan|ńst|o s|a i|awa|e p|yst|pos|pow| ró|o o|jąc|ony|nej|owo|dow|ów | ko|kol|aki|bez|rac|sze|iej| in|zen|pod|i i|ni | ro|cy |o w|zan|eńs|no |zne|a s|lwi|olw|ez |odn|rów|odz|o u|ne |i n|i k|czy| be|acj|wob|inn| ob|ówn|zie| ws|aln|orz|nik|o n|icz|zyn|łec|ołe|poł|aro|nar|a j|i z|tęp|stę|ien|cza|o z|ym |zec|ron|i l|ami| os|kra| kr|owe| od|ji |cji|mie|a z|bod|swo|dni|zes|ełn|peł|iu |edn|iko|a n|raj| st|odo|zna|wyc|em |lni|szy|wia|nym|ą p|ją |zeń|iec|pie|st |jes| to|sob|któ|ale|y w|ieg|och|du |ini|war|zaw|nny|roz|i o|wej|ię |się| si|nau| or|o r|kor|e s|pop|zas|niu|z p|owy|w k|ywa| ta|ymi|hro|chr| oc|jed|ki |o t|ogo|oby|ran|any|oso|a o|tór| kt|w z|dne|to |tan|h i|nan|ejs|ada|a k|iem|aw |h p|wni|ucz|ora|a d| wł|ian| dz| mo|e m|awi|ć s|gan|zez|mu |taw|dst|wią|w c|y p|kow|o j|i m|y s|bow|kog|by |j o|ier|mow|sza|b o|ju |yna',
    'swh': 'a k| ya|na |wa |ya | ku|a m| na| ha|i y| wa|a h|a n|ana|aki|ki |la |hak| ka|kwa|tu | kw| ma|li |a a|ila|i k| ki|ni |a w|ali|a u| an| mt|ke |mtu|a y|ake|ati|kil|ka |ika|kat|ili|te |ote|we |a s|e k|ia |zi |u a|za |azi|ifa|ma |yak|yo |i n|ama| yo|au | au|e a|kut|amb|o y|ha |asi|fa |u w|hal|ara|sha|ish|ata|ayo| as|tik|u k| za|i z|ina|u n|mba|uhu|hi |hur|cha|yot|ru |uru|wat| ch|eri|ngi|e y|u y|i a|aif|tai| sh|nay|chi|ra |ani| bi| uh|sa | hi|i h|awa|iwa|a j|ti |mu |o k|ja |kan|uli|iwe|any|i w| am|e n|end|atu|kaz|o h|ria|her|she|shi|nch| nc|uta|ye |wak|ii |ele|ami|adh|eza| wo|iki|oja|moj|jam| ja|aka|bu |kam|kul|mat|fan|a l|agu|ind|ne |iri|lim|wen|da |kup|uto|i m|a b|ini|wan|bil| ta|sta|dha| sa| ni|ao | hu|e w|wot| zi|rik|kuf|aji|ta |wez|nya|har| ye|e m|si |lin| ut|ine|gin|ing| la|a t|zim|imu|ima|tak|e b|uni|ibu|azo|kos|yan|nye|uba|ari|ahi|nde|asa|ri |ham|dhi|eli|hir|ush|pat| nd|kus|maa|di |nda|oa |bar|bo |mbo|oka|tok|ndw|ala|wal| si|uzi|hii|tah|i s|o n|liw| el|upa|zin|hag|a c|ndi|ais|mai|eny|mwe|aa |ewe| al|ndo|e h|lo |umi|kuh|jib|osa|mam|a z|ufu|dwa|u i| in|iyo|nyi| ny|u m|sil|ang|o w|guz|zwa|uwa|kuw|hil|saw|uch|ufa|laz|und|aha|ua | mw|bal| lo|o l|a i|del|nun|anu|nji| ba|lik|le |uku|i i',
    'sun': 'an |na |eun|ng | ka|ana| sa| di|ang|ung|un |nga|ak | ha|keu| ba|a b| an|nu |hak| bo|anu|ata|nan|a h|ina| je|aha|ga |ah |awa|jeu| na|ara|ing|oga|bog|gan| ng|asa|kan|a s|ha |ae |bae|n k|a k| pa|a p|sah|g s|sar| si|sin|a n|din|n s|ma | at|aga|a a|tan| ku| ma|n a|san|man|wa |lah|pan|taw|u d|ra |ari|eu | pi|gar| pe|kat| te|n p|sa |per|a d|a m|e b|aan|ban|ran|ala|ike|n n|kum| ti|ama|a j|pik|ima|n d|al |at | ja|ila|ta |nda|bas|rim|teu|n b|eba|beb|udu|aya|ika|ngg|nag|kab|rta|art| me|ola|k n|uma|atu|aba|g k|adi|aca| po|ngt|nar|una|ate|oh |boh|awe|di |tin|asi|uku|n h|dan|aka|iba|car|sac|gaw|are|ent|um |jen|abe|u s|dil|pol|ar |ku |kud|u m|upa|han| hu|ake|bar|ur |hna|aru|h s|a t|sak|wat|kaw| so|n t|pa |mpa|du |ngk|g d|ena|huk| mi|mas|ngs|ti |n j|ka |aku|ren|n m| ta|law|isa| tu|und|a u|h a|tay|ula|aja|ali|nte|gsa|en |gam| wa|ieu|ere|k h|jal|h b|il |dit|ngu|lan|asu|yun|ayu|gta|k d|a r|g n|mah|uda|dip|kas|rup|geu| be|ter|sej|min|ri |ern|u p|k k|amp|ura|kal|e a|k a|ut |g b|nak|bis| bi|k p|tes|end|we |h k|tun|uan| un| de|u n|h t|ksa|u k|ian|wil|u b|ona|nas|uka|rak|eje| se|ami| ke|war| ra| ie|k j|eh |ya |lma|alm|pen|tur|wan|lak|h j|g a|ean|up |rga|arg|r k|u t| ne|deu|gal|gke|e t|h p| ge|g t| da|i n',
    'ron': ' de|re | în|și |are|de | și|te |ul | sa|rep|e d|ea |ept|dre|tul|e a| dr|ie |în |ptu|le |ate|la |e p| la| pe|ori| pr|ce |e s| or|au |tat| ar|ice|ii |or |a s| fi| a |ric|ale|per| co|nă |ă a|rea|ers|i s| li|sau| ca|rso|ent|lor|ați|al |a d|e o|men|l l|ei |e c|pri|ană| ac| re|uri|ber|ibe|lib|a p|oan|soa| in|i l|ter| al| să|tea|lă |car|tăț|să |tur|i a|i d|nal| ni|ri |ita|e î|e ș|se |ilo|in |ia |ție|pre|fie|ții|ăți|con|ere|e f|a o|eni|nte| nu| se|ace|ire|ici| cu|i î|a c|i n|a l|pen|ui |nu |ări|ală|ona|l d|ră |ert|ril| su|ntr|n c|rin| as|ni |i o|eri|tă |că |ile|ă d|i c|e n|ele|sa | mo|i p|fi |sal|tor|va |oci|soc|nic|pro| un| tr|est|inț|a î|uni|n m|a a| di|ecu|lui|sta|lit| po|tre|gal|ega|oat|ra |act|ă î|leg|u d|e l|nde|int|a f|n a| so|naț|ara|i f|uie|iun| to|tar|ste|ces|rar|at | ce|eme|i ș|rec|dep| că| o | îm|bui|ebu|reb| eg| na|mân|ntu|ili|văț|ând|iei|r ș|bil|pli|od |mod|res|din|e e|cți| au|ali|ă p|ă f|împ|ial|cia|ion|ă c|dec|nta| om|ită| fa|ță |cu |tra|ăță|nvă|înv|ât |ite|i i|lic| pu| ex|riv|tri|rot|ța |ți |l c|rta|imi|ulu|țio|ică|lig|rel|ta |cla|t î|nt |nit|e m|ânt|ămâ|țăm|ger|nța|ru |tru|gur|u c|bli|abi|ată|art|par|ar |rim|iva|l ș| sc|ime|nim|era|sup|ind|u a|dic|ic | st| va|ini|igi|e r',
    'hau': 'da | da|in |a k|ya |a d| ya|an |a a| ko| wa|na | a |sa | ha|kin|wan|ta | ba|a s| ta|a y|a h|wa |ko | na|n d|a t|ba |ma |n a| ma|iya|hak|asa| sa|ar |ata|yan| za|akk|a w|ama| ka|i d|iki|a m|owa|a b| ci| mu| sh|anc|nci|kow|a z|ai |nsa|a c|shi| ƙa|cik|ne |ana|i k|ci |kki|e d|a ƙ| ku|su |n y|uma|ka |uwa|kum|hi |a n|utu| yi|ani| ga| ra|aka|ali|mut|‘ya|tar| do|ɗan|ars| ‘y|sam|ƙas|nda|ane|man|tum|i a|yi |ni | du|ada| su|and|a g|cin| ad|a i|ke | ɗa|n k|yin|um |e m| ab|ins|nan|ki |mi |ami|yar|min|oka|re |i b|kam|mas|i y|mat|za |ann|en |aɗa| ja|m n|li |duk|dai|e s|n s|ra |n w|n h|aik| ai|ida|ga |san|rsa|aba|sar|ce |nin| la|o n|ban|nna|kan|abi|una|dam|me |ara|i m|hal|a r|add|are|n j|abu| ne|zai|a ɗ|wat|ari| ƙu|on |ans|waɗ|ame|ake|kar|din|zam| fa|a l|ƙun|buw|r d| hu|oki|kok|a ‘|u d|n t|abb|aur| id|rin|yak|dok|kiy|ray|jam|n b|ubu|bub|n m|i s| an|am |ili|bba|omi|dan|gam|ayu|ash|nce|tsa|ayi|har|yya|ika|bin|han|kko|rsu|aif|imi|fa | am|i i|dom| ki|yuw|dun|o a|fan|n ƙ|aya|fi |n r|she|uni|bay|riy|n ‘|sab| iy|bat|tab|aga| ir|mar|o w|i w|sha|awa| ak|uns|unc|tun|u k| il|ɗin|mfa|amf|aci|ewa|kas|lin|n n|don|n i|ure|ifi|lai|dda| ts|iri|aye|un |tan|wad|gwa|afi| ay|ace|mba|amb|aid|nta|ant|war|lim|kya| al|aɗi',
    'fuv': 'de | e |e n| ha|nde|la | wa|ina| ka|akk| nd|ɗo |na | in|e e|hak|al |di |i h|kke|ii |um |ko |ala|ndi| mu| ne|lla| jo|wal|eɗɗ|neɗ|all|mum| fo|kal|jog|ke |aaw|taa| ko|eed|ɗɗo|aa | le|ji |ade|aad|laa|o k| ng|e h| ta|re |ogi|a j|e w|e m|nnd|gii|e l|ley|awa|aag|ede|waa|e k|gu |e d| go|gal|ɓe |ti |fot|aan|eyd|ydi|ɗe |ee | re|ol |oto|i e|oti|m e|taw|nga|a i|kee|to |ann|eji|am |ni | wo|een|goo|eej|e f| he|enn|gol|agu|pot| po|dee|ay | fa|ka |a k|ond|oot| de|a f|o f|a n|wa |maa|ota|le |hay|i k|o n|ngo|e j|o t| ja|ñaa|hee|nka|i w|awi|a w|ngu|der| to|e t|dim|i n|fof|i f|e g|tee|naa|aak| do|too|a e|ndo|ren|dii|oor|er |o e|i m|of | sa| so|gaa|ani|kam| ma| ña|o w|i l|u m|kaa|ima|dir| ba|igg|lig| li|aar| ɓe|o i|e s| o |e r|so |ooj| nj| la|won|awo|dow|woo|faw|and|e i|ore|nge|nan|are|a t|tin|aam| mo|ɗee|ita|ira|aaɗ|e p|nng|ma |ank|yan|nda|oo |e ɓ|njo|ude|nee|e y|e a|je | ya|en |ine|iin| di|ral| na|ɗi |und| hu|inn|ŋde|aŋd|jaŋ|a d|den| fe| te|go | su|a h|haa|tal|eɗe|e b|y g|baa|tde| yi|ɗɗa|o h|iiɗ|ow | da|do |l n|alt| ho|l e|aga|mii| aa|a a|ama|nna|m t| ke|edd|oga|m w|l m|o j|aɗe|ree|oje|yee| no|ele|ne |ago| pa| al|guu|wi |ge |aaɓ|daa|ind|dew|i j|jey| je|ent|tan|o ɗ|geɗ| ge|ñee|a l| ɗu|kko|mak|a s| ga',
    'bos': ' pr| i |je |rav|na |ma |pra| na|ima| sv|a s|da |a p|vo |nje|ko |ako|anj|o i| po|avo|ja |e s|a i|ti | im| da| u |sva|no |ju | za|o n|va |i p|ili|vak|li | ko|ne | il|koj| ne|nja| dr|ost| sl|van|im |i s|u s|i i|a n|ava|ije|a u| bi|stv|se |a d|om |jed|bod|obo|lob|slo| se| ra|ih |sti| ob| je|pri|enj|dru|u i|o d|iti|voj|raz|ova|dje| os|e i|lo |e p| nj|uje|i d|bra|tre| tr| su|jeg|i n|u z|a k|og |u p|oje|cij|reb|a o|a b|lju|i u|ran|mij|ni |nos|jen|ba |edn|svo| iz|jel|pro|e d|žav|bit| ni|i o|sta|a z|avn|vje| ka|bil|ovo|a j|aju|ist|nih|tu |red|gov| od|e o|oji| sm|lje|o k|ilo|ji |aci|e u|e n|pre|o p|eba|u o|su |vim|ičn| sa|u n| dj|a t|ija|čno|jem|rža|drž|elj|stu|dna|odn|eni|za |iva|olj|šti|nom|em |du |vno|smi|jer|e b|de |pos|m i| do|u d|nak|a r|obr| mo|lja|nim|ego| kr|tit|kri|ve |nju|an |iko|nik|nu |i m|nog|eno|sno| st|e k|tup|rug|ka |oda|riv|vol|aln|m s|itu|ašt|zaš|ani|sam|akv|ovi|osn|rod|aro| mi|tva|dno|nst|jan|ak |ite|vič|rad|u m| ta|dst|tiv|nac|rim|kon|ku |odu|živ|amo|tvo|tel|pod|g p|nov|ina|nar| vj|o s|i b|oj | ov|ave|vu |ans|oja|zov|azo|ude|bud| bu|e t|i v|din|edi|nic|tan|nap|mje| is|jal|slu|pun|eds|o o|zak|jav|i k|m p|tno|ivo|ere|nič|m n|jim|kak|ada|vni|ugi| ro|mov|ven|pol|to |te | vr',
    'hrv': ' pr| i |ma |rav|ima|pra|je |na | sv|ti | na|a p|vo |vat|ko |a s|nje| po|anj|avo|o i|tko| im|a i|sva|no |i p|e s|ja |o n| za|ju |ili| u |va |li | bi|ne |i s|atk| il|iti|da | ne| ko| dr| sl|van|nja|koj|ije| ra|ova| os|u s|i i|ost|bod|obo|lob|slo|pri|a n|om |jed|ati|ih |im |voj|ava| ob|stv|se | mo|i u|bit|dru| je| se|dje|i o|enj| ka|i n|sti|lo |u i|svo|mij|ni |e i|raz|a o|e n|bra|o p| su|a b|u p|ran|a k|og |i d|bil|ako|e p|a d|edn|aju|mor|eni| nj|iva|jel|žav| ni|a z|avn|ovi|eno|ra |oje|a j| da|a u|ora|jeg| iz|nih|rža|drž|oji|sno|nit|jen|vje|ilo|cij|oda|nim| dj|pro|tit|u z|e d|red|nom|jem| od|nos|sta|nov|osn| sm|lje|o s|ji |ovo|stu|pos|vim| do|odn|rad|ist| sa|e o|tu |nju|em |gov|o d|rod|i m|jer|aci|oj |pre|m i|nak|dna|a r|lju|uje|e m|obr|za |olj|ve |o o|m s|an |nu |du |aro|vno|smi|aln|e k|o k|i b|e u|tva|u u|tup|rug|dno|u o|su |u d|ka |vol| ta|ija|itu|šti|ašt|zaš|itk|živ|ani|sam|elj| st|sob|oso|nar|akv|ada| mi|te |ona|nst|jan|lja|i v|ite|ego|elo|rim|ku |odu|amo|tvo|tel|jim|pod|nog|vi |ina| vj|to |e b|ans|zov|azo|ak | sk|edi|tan|oju|pun|pot|oti|kon|zak|i k|m p|tno|ivo|ere|nič|kak|vni|ugi| ro|mov|ven|štv| be|ara|kla|ave|u b|avi|oja|jal|u m|dni|mje|rak|din|ći |juč|klj|nic|u k|nap|obi|atn',
    'nld': 'en |an |de | de| he|ing|cht| en|der|van| va|ng |een|et |ech| ge| ee|n e|rec| re|n v|n d|nde|ver| be|er |ede|den| op|het|n i| te|lij|gen|zij| zi|ht |ijk|eli| in|t o| ve|op |and|ten|ke |ijn|e v|jn |ied| on|eft| ie|sch|n z|n o|aan|ft |eid|te |oor| we|ond|eef|ere|hee|id |in |rde|n w|t r|aar|rij|ord|wor|ens|of | of|hei|n g| vr| vo| aa|r h|hte| wo|n h|al |nd |vri|e o|ren|le |or |n a|jke|lle|eni|n b|ij |e e|g v| st|ige|die|e g|men|nge|t h|e b| za|e s|om |t e|ati|wel|erk|sta|ers| al| om|n t|zal|dig| me|ste|voo|ter|gin|re |ege|ge |g e|bes|nat| na|eke|che|ig |gel|nie|nst|e a|nig|est|e w|erw|r d|end|ona|d v|jhe|ijh|d e|ele| di|ie | do|del|n n|at |it | da|tie|e r|elk|ich|jk |vol|ijd|tel|min|len|str|lin|n s|per|t d|han| zo|hap|cha|wet| to|ven| ni|aat|ion|tio|taa|lke|eze|met|ard|waa|uit|sti|e n|doo|pen|eve|el |toe|ale|ien|ach|st |ns | wa|eme|nin|e d|bij| gr|n m|p v|esc|t w|ont|ite|man|ema| ma|nal|g o|rin|hed|t a|t v|beg|all|ijs|wij|rwi|e h| bi|gro|p d|rmi|erm|her|oon| pe|eit|kin|t z|iet|iem|e i|gem|igi| an|d o|r e|ete|e m|js | hu|oep|g z|edi|arb|zen|tin|ron|daa|teg|g t|raf|tra|eri|soo|nsc|t b| er|lan| la|ern|ar |lit|zon|d z|ze |dez|eho|d m|tig|loo|mee|ger|ali|gev|ije|ezi|gez|nli|l v|tij|eer| ar',
    'srp': ' pr| i |rav|na |pra| na|ma | sv|ima|da |ja |a p|vo |je |ko |ti |avo| po|a i|ako|a s| za| u |ju |o i| im|nje|i p|va |sva|anj|vak| da|o n|nja|e s|ost| ko|a n|li |ili|ne |om | ne|i s| sl| il| dr|no |koj|u s|ava| ra|og |slo|im |enj|sti|bod|obo|lob|iti|a o|stv|i u|a d|ni |jed|u p|pri|edn| bi|i i|a k|o d|sta|ih |dru|a u| je| os| ni|nos|pro|aju|i o|ran| de| su|u i|se |van|ova|i d|cij| ob|uje|red|žav|e i|i n|voj|e p|a j|dna| se| od|ve | ka|eni|rža|drž|a z|avn|aci|ovo|u u|m i|oja| iz|lja| nj|ija|u z|e o|rod|jen|lje|e b|raz|jan|lju|svo|za |gov|ičn| st|nov|sno|osn|du |ji |pre| tr|su |vu |odn|a b|jeg|nim|nih|tu |tit|šti|ku |nom|bit|e d|me |iko|čno|oji|lo |vno|nik|e n|đen|ika|bez|ara|de |u o|vim|nak| sa|u n|riv|ave|an |olj|vol| kr|o p|sme|e k|nog| ov|e u|tva|bra|rug|reb|tre|u d|oda| mo| vr|vlj|avl|ego|jav|del|m s|kri|o k|ašt|zaš|nju| sm|ani| li|dno|eđu|aln|la |akv|oj |šen|kom|stu|ugi|avi|a r|ka |rad|oju|tan|odi|vič|tav|itu|ude|bud| bu|pot|odu|živ|ere|m n|tvo|ilo|bil|aro|ovi|por|eno|štv|nac|ove|m p|tup|pos|rem|dni|ba |nst|a t|ast|iva|e m|vre|nu |beđ|ist|pun|en |te |dst|rot|zak|ao |kao|i k|juć|o s|st |sam|ter|nar| me|i m|kol|e r|ušt|ruš|ver|kak| be|i b|kla|ada|eba|ena|ona| on|tvu|ans| do|rak|slu',
    'ckb': ' he| û |ên | bi| ma|na |in |maf| di|an |xwe| xw|ku | ku|kes| de| ji|her|kir|iya|ya |rin|iri|ji |bi |es | ne|ye |yên|e b|er |afê|tin|ke | an|iyê|eye|rke|erk|we | be|e h|de | we|hey|fê |i b|yê |ina| bê| li|diy|ber|li |re |î û|nê |ê d| se| ci|eke|di |wî | na|î y|af |ete|hem| wî|sti| ki|rî |kî |î a|yek|n d|kar| te|ne |yî |i h|e k|tî |tê |a w|e d|î b|s m|ast|n b|be |yan|ser|tew|net| tu| ew|hev|aza|ara|û b|n k|adi|ev |zad| az|ras|est|anê| ya|n h|n û|wed| tê|wek|bat|bo | bo| yê|st |n n|ê k|dan|ê h|ema|ê b|iye|î h|din|bûn|r k|ekî| me|par|ûna|ta |wle|ewl|î m| ke|nav|ewe|man|ê t|dî |û m|mû |emû|a m|ika|e û|n w|a x|ê m|e n| ta|ela|n j|eyê|n x|civ|wey|ana| re|khe|ekh|bik|kê |jî |f h|erî| pa|îna|bin|erb|vak|iva|a s| ni|cih|vê |e j|ari| pê|î d|nên|ike|e t|a k|ê x| ye|n a|eyî|n e|ama|bê |ar |ewa|atê|bes|rbe|av |ibe|ist|mî |tem|awa|are|hî |geh|nge|ing|nek|nûn|anû|qan| qa|vî |rti|uke|tuk| şe|eza| da|u d|û a|f û|edi| ra|tu |tiy|tên| mi|xeb| ge|hîn| hî|etê|î j|stî|mal|bib|ra |i d|e m|mam|i a|nik|i m|î k| wi|ûn | ko|a ş|ê j|riy|lat|wel|e e|ine|ane|û h|în |a d|siy|end|aye| za|ija|a n|î n|ek |tek|yet|mbe|emb|û d|rov|iro|mir|eba| xe|mên| ên| hu|nîn|anî|t û|ten|n m|dem|ê û|enê|te |art|i r| jî|u j|ekê|dew',
    'yor': ' ní|ti |ó̩ |ní | lá| è̩| e̩|̩n |àn |é̩ |kan|tí | tí|o̩n|an |è̩ |e̩n| kò|tó̩|ò̩ |wo̩|̩tó|bí |áti|lát|è̩t| gb| ló| àt| àw|í è|̩nì|gbo|n l|àti| a |lè̩| ó |kò̩|ì k|sí |ò̩k|ra |ni | tó|àbí|tàb| tà|s̩e| s̩|nì | sí|̩ka|n t|àwo|ó n|̩ò̩|ò̩ò|ílè|orí|ló |tó |̩ l|dè |ìyà|ún |̩‐è| or|í ì|èdè|o̩ |̩ t|kò |‐èd|è̩‐|ríl|í ó|rè̩|̩ à|í à|̩ s|̩ni| sì|yàn|̩e |í a| rè|jo̩|n e| wo|sì | bá|ràn|wó̩|nìy|fún| fú|n à|ba |n n|gbà|jé̩|un |ìí | kí|gba|ènì| èn|bá |a k| ka|í ò|dò̩|̩dò|o̩d|kí | òm|in | fi|bò |n è|fi |e̩ |bé̩|bo̩| jé|hun|nú |nín|̩ n|wà |ira|nir|òmì|ìgb| ìg|ínú|ó s|i l|ìni|mìn|bà |̩wó|áà |̩ o|n o|i ì|ohu| oh|í i|gbé|̩ ì|ara| ti|̩ k|bo |̩ e|ò l| pé|rú |írà|̩ a| ò̩|ogb|kó̩|pò̩|ó b|à t|i n|ló̩|é̩n| ìb|í e|yìí| o̩|gé̩|n s|bog|óò |yóò| yó|n k|̩ ò|pé |dá |àbò|ó̩w|à l|í k| wà| ir|̩ y|ò̩r|ú ì|mo̩|i t|̩é̩|s̩é|í t|yé |̩ p|lè | lè|fin|à n|ùjo|wùj|irú|ó j|ìké|i ò|̩ b| ar|í w|a w|̩kó| ìm|ú à|̩è̩|òfi| òf|̩ f| àà|fé̩|àwù|wù |ìír|mìí| mì|̩ m|láì| yì|í g|í o|ó̩n|̩gb|è̩k|je̩|àgb|ígb|níg|a n| kú|láà|náà| ná|ké̩|i o|ípa|níp|ìn | ìk|bé |i g|̩mo|o̩m|i è|i à|is̩|n a|n f|yí |ó d|á è| dá| mú|ààb|ábé|láb|ìbá|i s|ò g|jú |lú | èt|è̩s|tò̩|de | ìy|kàn| bí| is|mò̩| fà|̩ j|̩ i|èyí| èy| ìd|mó̩|ú è|dé |ò t|mú | fé|s̩à| ìj|rí |nìk|ìní',
    'uzn': 'ish|an |lar|ga |ir | bi|ar | va|da |iga| hu|va |bir|sh |uqu|quq|huq| ha|shi| bo|r b|gan|a e|ida| ta|ini|lis|adi|ng |dir|lik|iy |ili|oʻl|har|ari| oʻ|uqi|ins|lan|hi |ing|dan|nin|kin| yo|son|nso| in| mu|on |qig| ma|ega|r i|boʻ| eg|oʻz|ni |gad|ash|i b|ki |oki|ila|yok|a b|n b|osh|ala|at |in |r h|erk| er|lga| qa|rki|h h| sh|i h|ara|n m| ba|nis|ik |igi|lig|bos|ri |qil|a t|bil|las|eti| et|n o|ani|nli|kla|i v|a q|a h|a o|yat| qo|im |a s|i m|iya|atl|oli|osi|siy|qla|cha|til| ol|ati|a y|mas|qar|inl|lat| qi|taʼ|ham|gi |ib |ʻli|mla|h v|ʻz |hun|n e|mum| da| bu| to|un |mki|umk|sha|tla|ris|iro|ha |rch|bar|iri|oya|ali| be|i o|asi|aro| ke|i t|rla| te|arc|hda|shu|tis|n h|tga| sa| xa|rak|lin|ada|ola|imo|hqa|shq|li | tu|aml|lla|sid| as|nid|a i| ki|ch |n t|nda|k b|era|siz|or |hla|a m|r v|eng|ten|mat|mda|amd|lim|miy|y t|ayo|i a|ino|ilg|tni| is|ana|as |ema| em|ech|a a|tar|kat|aka|ak |rat| de|aza|ill| si| so|gʻi|uql|n q|oda|ʼli|aʼl|nik| ni|tda|uch|gin|a u|him|uni|sit|ay |qon| ja|atn|kim|h k|hec| he|ʻzi|lak|ker|ikl| ch|liy|lli|chi|ur |zar|shl|rig|irl|dam|koh|iko|a d|am |n v|rti|tib|yot|tal|chu| uc|sla|rin|sos|aso| un|na | ka|muh|dig|asl|lma|ra |bu |ush|xal|ʻlg|i k|ekl|r d|qat|aga|i q|oiy|mil| mi|qa |i s|jin',
    'zlm': 'an |ang| ke|ng | se| da|ada|ara|dan| pe|ran| be|ak |ber|hak|ata|ala|a s|ah |nya| me|da |per|n s|ya | di|kan|lah|n k|aan|gan|dal|pad|kep|a p|n d|erh|eba|nga|yan|rha| ya|nda|ora|tia|asa| ha|ama|epa| or|iap|ap |a b| at| ma|eti|ra |tau|n a|set|au | ba|pa | ad|n p|tan|p o|eng|a d|men|apa|h b|h d|dak|man|a a|ter| te|k k| sa|n b|ana|g a|end|leh|ole|a k|am |n y|aka|eh |lam|bas|beb|n m| un|pen|sa |keb|sam|n t| ti|ela|san|car|uan|ma |di |han|ega|ban|eri|at |sia|a m|ika|kes|ian|gar|seb|ta |mas|und|neg|nan|ngs|i d|erl|na |epe|emb|bar| la|atu|kla|pem|mem|emu|eca|sec|ngg|nny|any|bol|al |aha|gsa|ebe|ind|akl|n h|erk|ung|ena| bo|a t| ap|ers| de|in |tu |pun|as |agi|ann|g b|bag| ne|ain|hen| he|era|rat|sem| su|adi|lan|g s|dia|mat|ses|iad| ta|iha|g t|tin|k m|k h|i k|gi |i s|ing|uka|enu|den|lai|k d|ert|ti |rka|aja|rga|lua|ker|mel|dun|ndu|lin|rli|nak|ntu|esi|aya|un |uat|jua| in|rma|erm|ai |emp|kem|ri |dil|ua |uk |h m|l d|g m|mba|kat|ese|tik|ni |ini| an|mpu|ka |dar|mar|rja|erj|arg|u k|sua| ol|esa|dap|ar |g u|si |ent|g d| pu|awa|iri|dir|sal|gam|mbe|n i|har|a h|raa|ema|tar|i a|saa|ira|ari|pel|jar|laj|uju|tuj|rak|ura|uar|elu|t d|unt|il |wen|asi|gga|ipa|ksa|tuk|ula|sek|sas|ibu|rta|sep|rsa|nta|ati|ila|mua|yar',
    'ibo': 'a n|e n|ke | na| ọ |na | bụ|ọ b|nwe|nye|ere|re | n |ya |la | nk|ye | nw| ma|e ọ| ya| ik|a o|a ọ|ma |ụla|bụl|ike| on|nke|e i|a m|ony|ụ n|kik|iki|bụ | a |ka |wer|ta |i n|do |di | nd| ga|a a|e a|a i|he |kwa| ok| ob|e o|hi |any|ga‐|ha |dụ | mm|ndi|ọ n|wa |rụ |e m|che|a e|oke|wu |aka|ite|o n|a g|odo|bod|obo| dị| ez|ara|we | ih|a‐e|hị |ri |n o|zi |mma|chi|dị |ghi|ụta|iri|ihe| an| oh|a y|gba|ụ ọ| ọz| ak| iw|nya|te |iwu| nt|ro |oro|e ị|zọ |ezi|me |e e|u n|her|ohe| si|a‐a|i m|ala|ụ i| ka|akw| in|ghị|kpe|n e|pụt| e |i i|i o|ide|inw|ụ o|hụ |ahụ|weg|ra |o i|kpa|adụ|mad|si |sit|a s| me|sor|i ọ|gid|edo|u o|e y|n a| en|tar|ozu|toz|bi |be |ụ m|ụrụ|ọrụ| ọr|mak|uso|ama|de |ị o| ọn|ọzọ|chị|egh|enw|apụ|ru | to|i a|a ụ|osi|rị |wet|hed|nch| nc| eb| al|nọd|ọnọ|uru|sir| kw|yer|ji |eny| mk|ịrị|eta| us|tu |ọ d|u ọ| o |ba | mb|ọdụ|ịch| ch|a d|pa | ag|kwe| ha|a u|e s|mkp|n u|nta|ebe|n ọ|o m|kwu|nkw|nwa|obi| ịk|esi|i e|nha| nh|le |ile|nil| ni|eme| og|e k|n i|chọ|o y|asị|otu| ot|ram|u m|ịgh|dịg|zu |nọ |mba| gb|e g|ị m|ọch|ich|pe |agb|i ị|uch|zụz|uny|wun|ọrọ| nn|na‐| di|ge |oge|iji| ij|ọha| ọh|ikp|egi|meg|o o|ụhụ|hụh|mah|n ụ|ọ g|ọta|ekọ|ị n|kwụ|agh|ụmụ|ban|kpu|okp| ah|ịkp|a k|ime| im|zụ |ụzụ|ọzụ| ụz|lit|ali|nat',
    'ceb': 'sa | sa|ng |ang| ka| pa|an |ga |nga| ma|pag| ng|on |a p|od |kat|ay | an|g m|a k|ug |ana| ug|ung|ata|ngo|atu|n s|ala|san|d s|tun|ag |a m|god|g s|a a|a s|g k|g p|yon|n u|ong|tag|usa|pan|ing|una|mat|g u|mga| mg|y k| us|ali|syo| o |aga|tan|iya|kin|dun|nay|man|nan|a i| na|ina|nsa|isa|bis|a b|adu| ad|n n| bi|asy|asa|lay|awa|lan|non|a n|nas|o s|al |agp|lin|nal|wal| wa|ili|was|gaw|han| iy| ki|nah|ban|nag|yan|ahi|n k|gan| gi|him| di|a u| ba| un|ini|ama|ya |kas|asu|n a|g a|gka|agk|kan|ags|agt|l n|a g|kag| ta|imo|uns|sam| su|g n|n o|gal|kal|og |taw|aho|uka|gpa|ipo|ika|o p|a t| og| si|gsa|g t|aba|ano|gla|y s|o a|aki|hat|kau|sud|gpi|a w|g i|aha|ot |ran|i s|n m|bal|lip|gon|ud | ga|li |uba|ig |ara|g d|na |kab|aka|gba|ngl|ayo| la| hu|a h|ati|d a|d n| pu| in|uga|ok |ihi|d u|ma |may|awo|agb|ami|say|apa|pod|uha|t n|agh|buh|ins|ad | ub| bu|at |iin|a d|ip |uta|sal|hon|wo |ho |tra|lak|iko|as |aod|bah|mo |aug|ona|dil|gik|sos|lih|pin| pi|k s|nin|oon|abu|la |rab|hun| ti|mah|tar|t s|ngb|uma|hin|bat|lao|mak|it | at|s s|sno|asn|ni |aan|ahu| hi|agi|n p|inu|ulo|y p| ni|iha|mag|o n|duk|edu| ed|a e|til|ura|tin|kip|agl|gay|g h|g b|ato|ghi|nab|kon|in |ter|o u|o o|yal|sya|osy| so|tik| re| tr|hig|a o|ha |but|pak|aya',
    'tgl': 'ng |ang| pa|an |sa | ka| sa|at | ma| ng|apa|ala|ata|g p|pan|pag|ay | an| na|ara| at|tan|a p|pat|n a| ba|ga |awa|rap|kar|g k|aya|lan|g m|n n|g b|nga|mga| mg|a k|na |ama|n s|a a|gan|yan|gka| ta|may|tao|agk|asa|man|aka|ao |y m|ana|g a|nan|aha|kan|y k|baw|kal|a m|g n|ing|wat| y |t t|pam|a n|o y|ban| la|ali|san|wal|mag| o |g i|aga|lay|any|g s|in |nya|yon|kas|a s|isa|una|ong|aan|kat|t p| wa|ina|tay|ya |on |o m|ila|ag |nta|t n|aba|ili| ay|o a| ga|no |a i|gal|ant|han|t s|kap|kak|lah|ari|agt|agp|ran|g l|lin|as |lal|gaw|ans|to |ito| it|hay|wa |t m| is|pap|mam|nsa|ahi|nag|bat|lip|gta| di|gay|gpa|pin| si|ngk|ung|aki|y n|iti|tat|ano|yaa|y s|mal|hat|kai|sal|hin|uma|mak|di |agi|pun|ihi|a l|i a|ira|gga|nah|s n|ap | ha|usa|nin|o p|gin|ipu|ika|ngi|i n|lag|la |y p|ini|g t|uka|nap| tu|a g|tas|aru|ipa| ip|li |al |n o|a o|t k|alo| pi|sin|syo|asy|ita|aho|nar|par|o s|pak|t a|uha|sas|gsa|ags|kin|a h|iba|lit|ula|o n|nak|a t| bu|duk|kab|sam|g e|ain|ami|mas|lab|ani|kil|it | al|agb|buh|a b|g g|ba | ib|iyo|ri |yag|ad | da|edu| ed|anl|ma |ais|iga|mba|tun|ipi| ki|od |ayu| li|lih|sar|gi |g w|pah|wir|oob|loo|agg|nli|bay|map|git|mil|ok |hon|ngg|sah|iya|pas|g h|agl|tar|ngu|amb|uku|ayo|s a|p n|n m|rus|i m|l a|abu| aa',
    'hun': 'en | sz| va| a |és |min|ek | és| mi|jog| jo|an |ind|nek|sze|ság|nde|a v|den|oga|sza|val|ga |mél|ala|emé|gy |n a|van|zem|ele| me|egy|ély| eg|zab|tás| az|n s|bad|aba|ni |az |gye| el|ak | se|meg|sen|ény|ség|k j|yne|lyn| ne|ben|lam|tt |t a|et |agy|oz |hoz|vag|zet| te|n m|ez |nak|int|re |eté|tet|mel|tel|s a|em |ely|let|hez| al|s s| ki|ete|atá|z a| le|yen|es |ra |tés|ell|nt |sem|t s|len|nem|a s|ese|nki|enk|a m|ásá|i m|ban|kin|k m|szt| ál|ame|köz|k a|dsá|ads|ló | kö|ás |ly |on |ébe|tat|a t|n v|áll|mén| vé|nye|kül|lő |a n| cs|i é|ok |ész|ért|lla|lap|ágo|gok|nyi|tek| ke|nd |éte|ami|zés|yes|szo|t m|a a|het|fel|lat|lem|lle|el |z e|s e|k é|mbe|emb|elé|ot |lis|vet|kor|ág |olg| am|szá|ehe|leh|ogo|ott|ül |nte|éle|i v|ogy|hog| ho|kel|n k|tes|nlő|enl|ssá|áza|ház|ég |vel|ába|lek|ége| ha|a h|rés| fe|ány|del|elő|át |alá|art|tar|zto|zás|tő |yil|koz|tko|aló|s k|i e|árs|tár|mze|emz| ny|más|ett|ny |fej|ass|zas| há|d a|t é|is |ésé|ezé|téb| mu|áso|sít|lye|elm|éde|véd|ine|t k|os |it |izt|biz| bi|y a|m l|tot|a j|atk|nél|t n|ti | má|ai |lás|eve|nev|zte| bá|sel|ll |al |ere|n e|unk|mun|t e| ak|ife|kif|ako|s é| ér|ána| es|s t|got|sül| be|vál|csa|se |ése|ad |ges|tos|ja | gy|asz|ten|lmé| tá|eze|árm|bár|ess|l s|üle',
    'azj': ' və|və |ər |ir | hə| bi| hü| ol|üqu|hüq|quq|na |in |lar|hər|də | şə|bir|lər|lik|mal|r b|lma|r h| tə|əxs|şəx|ən |dir|uqu|una|an |ali|a m| ma|ikd|ini|r ş|dən|ar |ilə|qun|aq |ası| ya|mək|yət| mə| mü|kdi|əsi|ək |ilm|nin|ndə|olm|əti|ə y|sin|xs |nda|lmə|yyə|i v| qa| az|olu|iyy|ya |ind|zad|qla|ün |ni |lə |tin|n m|aza|arı|ət |n t|maq|lun|lıq|ə b|un |nun|q v|n h|dan|ın | et|tmə|ərə| öz|da |ə v| on|ə a|ına|ını|bil|a b|sı |il |əmi|ara|si | di|ə m|əri|rlə| va|ə h|etm|ığı|ama|dlı|adl|rin|bər|rın|n i|müd|nın| he|mas|ik |n a|dil|alı|irl|ələ|üda|sın|ınd|xsi|li |ə d|nə | bə|əya| in|ə i|lət| sə|nı | iş|anı|eç |heç|q h|eyn|ə e|dır| da|asi|rı |iş |ifa|lığ|i s|fiə|afi|daf| ed|məz|u v|kil| ha|ola|n v|əni|ır |uq |unm| bu| as|sia|osi|sos|ili|ıdı|lıd|nma|ıq |inə|əra|sil|xil|axi|dax|adə|man|a h|ə o|onu|a q|əz | ki|seç| se|ı h|min|lan|ədə|bu |raq|lı |ılı|al |ə q|r v|nla|hsi|əhs|təh|öz |ist| is|məs| əs|ina|ə t|ətl|a v|iə |n b|tər| ta| cə|edi|ala|kim|qu |i t|ulm|məh|n o|aya|ı o|ial| so|ill|siy| də|var|ins|mi |ğı |nik|r i|aql|k h|təm|tam|çün|üçü| üç|ğın|sas|əsa|z h|əmə|zam| za|sti|rəf|n e|r a|ild|həm|ıql|yan|may|n ə|mən|mil| mi|əqi|din|n d|tün| dö|miy|kah|ika| ni|fad|tif|l o|sər|yni| ey|ana|lən|am |ril|ayə|aşı',
    'ces': ' pr|ní | a | ne|prá|ráv|na |ost| po|ho | sv|o n| na|vo |neb|ávo|bo |ebo|nos|má | má|ažd|kaž| ka| ro|ch |dý |ždý|ti |ou |a s| př| za|ání|á p| je| v |svo|ého| st|ý m|sti|ně | by|obo|vob|ter|pro|ení|bod| zá| sp|í a|rod|kte|by |mu |u p|o p| ná|ván|jak| ja|a p|o v|í n|ová|oli|ví |spo|roz| kt|mi |í p|ny | ma|ím |i a|do | so|odn|áro|nár|li |né |tví|at |ých|a z| vy|byl|vol|en |ýt |být| bý|t s|tní|stn|o s|í b|to | do|své|vé |ran|ejn|zák|eho|jeh|nes|pří|mí |čin|kol|ají|sou| vš|ích|it |ným|ým |nu |hra|nou|u s|ému| k |du |žen|pod| ze|kla|a v|stv|pol|dní|eré|m p|stá|je |ci |ečn| ni|néh|a n|aké|áva|maj|em |rov|í m|ké |ole|nýc|ova| ve|ako| ta|i k|chr|och| oc|kon|i p|í v|smí|esm|kdo|st |i n|o z|ave|odu|bez| to|sta|ech|jí |o d|sob|se | se|í s|ými|i s| i |i v| vz|ním|pra|lně|při|tát|ste|a j|aby| ab| s |oln|a o|m n|čen|slu|řís| os|zem|mez| či|lní|áln|oci|jin| ji|y b|í z|y s|va |vše|t v|ovn|chn|děl|níc|leč| pl|vat| vo|vin|rav|vou|lad|inn|é v|anu|tej|u k|stu|est| tr|ky |ikd|nik|ivo|nit|zen|u o|ném|nez|iál|ího|len|ens|ože|oko|kéh|rac|ven|í k|e s|lán|ělá|zdě|vzd|t k|din|odi|tí | od|ré |tup|pov|pln|ště|ákl|nno|tak|erá|řed|o a|a t|res|jíc| mu|u z|rok| ob|čno|u a|y k|i j|é n|luš|ísl|oso|ciá|soc|níh|o j|cké',
    'run': 'ra |we |wa |e a| mu|a k|se | n | um| ku|ira|ash|tu |ntu|a i|mu |umu|mun|unt|ere|zwa|ege|ye |ora|teg|a n|a a|ing|ko | bi|sho|iri| ar| we|shi|aba|e n|ese|go |a m|o a|gu |uba|ngo|nga|hir| ca|ugu|obo|hob|za |ndi|ish|gih| at|ara|wes| kw|ger|ate|a b| ba| gu|e k|can|ama|ung|bor|u w|mwe|di | ab|nke|ke |kwi|ka |ank|yo |ezw|n u|na |iwe|e m|rez|ri |a g|gir| am|igi|e i|ro |a u|ngi|e b|ban| ak| in|ari|n i|hug|ihu|e u|riz|ang|nta| vy|ata| ub|and|aka|rwa| nt|kur|ta |iki|kan|iza|u b|ran|sha|o n|i n| ig|ivy| iv|ahi|bah|u n|ana| bu| as|aku|ga |uko|o u|ho | ka|ose|ubu|ako|guk|ite|o y|ba |i b|any|kir|o k|aho|iye|kub|amw|nye|aha| ng|o m|nya| it|re | im|o b|izw|kun|hin|e c|vyo|o i|vyi|ngu|uri|imi|imw|gin|ene|u m|zi |ha |kug|bur|uru|jwe| zi|u g|era|aga|ron|abi| y |e y| uk|gek|ani| gi|eye|ind|wo |u a|i a| ib|i i|ras|bat|gan|amb|n a|onk|rik|ne |ihe|agi|kor| ic|ze |tun|ibi|wub|nge|o z|tse|nka|he |rek|twa|gen|eko|mat|ber| ah|ni |ush|umw| bw|mak|bik|ury|yiw|bwo| nk|ma |no |kiz|uro|gis|aro|ika| ya|gus|y i|wir|ugi|uki| ki|a c|ryo|bir| ma| yi|iro|bwa|mur|eng|ukw|hat|tan|utu|wit|w i| mw|y a|mbe| ha|uza|ham|rah| is|irw|o v|umv|ura|eny|him|eka|bak|bun| ny|bo |yig|kuv|wab|key|eke|yer|vye|i y|ita|ya |a r| ko|kwa|o c',
    'plt': 'ny |na |ana| ny|a n|sy |y f|a a|aha|ra | ma|nan|n n|any|y n|a m|y m|y a| fi|an |tra|han|ara| fa| am|ka | ts| na|in |ami| mi|a t|olo|min|man|iza|lon| iz|fan| ol| ha| sy|aka|a i|reh|ay |ian|tsy|ina| ar|on |o a|etr|het|ona|y o|o h|zan|y t|a h|ala| hi|a f|y h|ehe|ira|a s|zo |y i|ndr|jo | jo|n j| an| az|ran|dia| dr|y s|fah|ena|ire|tan|dre| zo|mba| ka|m p|afa| di|n d|and|azo|zy |amp|ia |ren|iny|rah|y z|ry |ika|oan|ao |amb|lal|ho | ho|isy|ony|tsa|asa|a d|ha |fia|mis|ava|ray| pi|am |dra| to|rin| ta|ant|eo |zay|rai|tsi|itr|sa | fo| ra|van|ova|nen|azy| vo|mpi|ari|o f|tok|a k| ir|kan|oto|mah|ly |sia| la|n i|voa|haf|a r|ito|y k|oka|y r|y l|ano|ita|ene|its|ial|zon|aza|ain| re| as|fot|aro|fit|nat|nin|aly|har| ko|ham| no|fa |ary|atr|ila|ata|iha|nam|kon|oko| sa|elo|nja|anj|ive|isa|oa |dy |y d|o m|nto|ank|o n|otr|pan|fir|air|sir|ty |a v|sam|o s|tov|mit|rak|reo|o t|pia|tao| ao|no |y v|iar|a e|a z|hit|hoa| it|to |za |ton|eha|end|vy |idi|tin|ati|adi|lna|aln|rov|ban| za|nga|hah|oni|osi|sos|vah|ino|ity| at|hia|pir|ifa|omb|ame|era|vel|kar|va |tso|jak|fid|ifi|ais|o i|idy|la |ama|ba | pa|tot|ani|rar|mpa|haz|kam| eo| il|iva|aho|nao|n k|ato|lah|ovy| te|dro|lan|ela| mo| si|fin|miv|san|koa| he|aso| mb|sak|kav',
    'qug': 'ta | ka|ka |na |una|cha|ash|ari|a k|ana|pak|ish|ach|hka|shk|mi |kta|hay|man| ch|apa|ak |rin|ata|kun|har|akt|ita| ha|ami|lla| pa|ama|pas|shp| ma|tak|ayñ|yñi|in |sh |ina|uku|nka|chi|aka|a c|yta|kuy|all|tap|a h|kan| tu|ñit|tuk| ru|run|chu|an |pay|ayt|ris| ki|aku|hpa|ank|a p|kam| sh|nam|a s|uy |i k|ayp|nak|pi |nta|a m| li|ay |lia|hin|kaw|nap|ant|tam|a t|iri|nat| wa|y r|kay|aws| ya|n t|ypa|wsa|pa |lak|shi|a a|lli|iku|hu |n k|iak|yay|kis| al|shu|a w|ipa| sa| il|api|kas|yku|yac|kat|a r|huk|i c|wan|hik|a i|ill|ush| ti|ayk|hpi| ku|kac|say|hun|uya|ila|ika|yuy|pir|ich|mac|ima|a y|yll|ayl|i p|kin|a l| wi|kus| yu|lan|tan|llu|kpi| ta| pi|aya|la |yan|awa| ni|kak|lat|rik|war|ull|kll|li |ink|nch|un |akp|n s|may| ay|uch|i s|nac|sha|iki|kik|h m|ukt|pip|tin|n p|iya|nal|aki| ri|ura|tik|mak|ypi|i m|i w|n m|his|k i|riy|iwa|y h| hu|han|akl|k t|mas|pik|kap| ña|u t|nmi|nis|k a|i y|k l|kar| im|i i|wil|yma|aym|ksi|iks|uma| su|h k|has| ak|unk|huc|kir|anc|k m|pal|k k|ik |iñi| iñ|ma |n y|mun| mu|mam|tac|a n|i t|k r|sam|ian|asi|k h|was|ywa|iyt|llp|san|sum|ray|si |pan|nki|tar| ii|u k|ñik|uk |iña|kuk|wpa|awp|akk|a u|wat|uri| mi|yar|uyk|ayw|h c|ha |tay|rmi|arm|uta|las|yka|llk|kul|wiñ|ati|ska| ll|kit|n h|uti|kic|mat',
    'mad': 'an |eng|ng |ban| sa| ka|dha|ren| se| ba|ak | ha|adh|hak| dh|ang|se | pa|aba|a s|na |aga|ha | or|n s|ore|ara| ag|gad|are|ana|n o|ngg|ale|gan|a k|ala|dhu|tab|sar|ota|asa|eba| ot| ke|sab|ba |wi |uwi|abb|i h|huw|aan|n k|a b|bba| ta| ma|pan|hal|bas|ako|dhi|ra |kab|em |beb|ka |lak|gi |lem|g a|eka|n b|ama|nga|san|at |ong|ran|nge|a o|ggu|sa |a d|ane|n p|ken|par|aja|man|gar|ata|nek|apa| na|agi|abe| ga|e e|sal|a a|tan|g s|al |kal|gen|ta |i s|aka|e a|a p|a e| la| pe|nan| an|era|e d| e | be|n a| al|ena|uy |guy|n n|ate| bi|mas|e k|kat|uan|oan|kon|k k|a m|i d|g e|n t|g k|ada|koa|lan|ela| da|bad|ma |ne |as |lab|ega| mo|ar |car|one|i p|bi |kaa|bat|ri |on |pon| so|e b|le |ah |abi|ase|adi|epa| ep|k h|and|pam|te |ok |ste|aon|om |oko|aha|ari|ona|asi|ter| di|di |pad|e s|sad|yar|neg|ton|set|rga|ost|mos|gap|nda|a l|har|i k|ina| a | ng|kom|isa|si |a t|a h| kl|jan|daj|iga|hig|idh|hid|ndh|n m|ngs|tto|ett|arg|la |k b|ler|k d|nna| to|nao|n d|mat| ca|tad|bis|aya|epo|aen| po|bin|nya|kas|k s|n h|sya|nta|gsa|en |ant|n g|kar|i e|das|e t|e p|iba| pr|g p| ho| el|i a|hi |os |sao|uwa|tes| ja|nag|nas|lae|sia|t s|k o|nto|int|yat|arn|m p|duw|adu|eta| ko|i b|ni |g n|kla|rak|ame|mpo|jua|sok|aso|ggi|eja|pel|jam|ele| et|dil',
    'nya': 'ali|ndi|a m|a k| nd|wa |na | al|yen| ku|nth|ra |di |se |nse| mu|a n|thu|hu |nga| wa|la |mun|u a|unt|iye| ka|ce |ace| lo|a l|ang|e a| la| pa|liy|a u|ens| ma|idw|ons|dwa|e m|i n|ala|kha|lo |li |ira|era|ene|ga |ana|za |o m| mo|yo |o w| ci|we |dzi|ko |o l|and|dan|hal|zik|chi|oyo|pa |ner|ulu|ena|moy| um|a p| da|ape|kap|ka |iko| an|pen|a c|to |ito|hit|nch| nc|iri|lir|wac|umo|e k|lu |a a|aye| dz|kuk|a z|dwe|tha|mal| za|ing|ufu|mu |ro |ful| uf|o c|i d|lin|e l|zo |edw| zo|o a|mwa|u w|iro|o n|lan|amu|ere| mw|nzi|dza|alo|ri | li|fun|lid|gan|so | ca|kul|ofu|nso|o z|ulo|unz|o k|mul|lam|i c|san|a b|kwa| na|a d| a |una|u k|i l|nkh|ant|aku|ca |cit|oli|ipo|dip|ama|lac|wir|han|yan|osa|uli|tsa|i m|pon|kup|u d|ti |gwi|ukh|ung|hun|lon|ank|nda|iki|ina| ko|ao |diz|phu|ati|oma|i a|tsi|pat|iya|siy|kut| ya|zid|eze|ma |i k|mer|ome|mol|u n|u o|aph|ogw|izo|mba|sid|ku |sam|awi|adz| ad|izi|ula|say|e n|khu| kh|rez|vom|bvo|okh|lok|win|akh|o o| am| on|zir|map| zi|eza|ja |go |ngo|ika|its|ats|osi|gwe| co|isa|ya |haw|ani|o p|zi |ndu|kho|ezo|kir|uni|i u| ay|lal|gal|sa |bom| bo|ola|amb|wak|ha |ba |nja|anj|ban| ba|iza| bu|udz|ngw|bun|oye|o d|nal|kus|i p|i o|i y|wi | nt|e p| si|aka|ne |men|jir|nji|sed|ets|end|eka|uma|du ',
    'zyb': 'bou|iz |aeu|enz|eng|uz | bo|ih |oux|nz | di|ing|z g|ux |uq |dih|ngh| ca|ng |gen|ung|z c| mi|miz|ij |cae|z d| gi| de| ge|euq|you| ci|ngz|ouj|aen|uj | yi|ien|gya| gu|ngj|mbo| mb|zli|dae|gij|cin|ang|j d|nae| se| ba|z y|euz| cu|de |x m|oz |j g|ouz|x b|li |z b|h g| da| yo|nj |xna|oxn|rox| ro|h c|nzl|vei|yau|wz |z m|ix | si|i c|iq |gh |j b| cw|nda|yin| hi| nd|dan|vun|inh| ga|can|ei |cun|yie|q g|hoz|bau| li| gy|wyo|cwy|z h|gue|gz |gun|faz|unz|yen|uh |den|ciz| go|q c|gj | bi|ej |aej| fa|hin|zci| wn|j n|goz|gai|au |z s|q d| vu|h m|gva|hu |auj|ouq|az |h d|ya |uek|ci |nh |u d|ou |sou|jso|gjs|din|awz|enj| do|h s|eve|sev|z r|nq |sin|nhy|g g|g b|liz|kgy|ekg|sen|eix|wng|lij|ngq|bin|i d|ghc| ha|bae|hix|h y|j c|ghg|i b|ouh|en |n d|h f|j s|z v|j y|law|hci|anh|inz|q y|nei|anj|ozc|ez |enh|q s|aiq|uen|zsi|zda|hye|ujc|e c|siz|eiz|anz|g y|i g|q n|bie| ne| ae|giz|u c|hgy|g d|gda|ngd|cou| la|z l|auy|ai |in |iuz|zdi|jhu|ujh|yuz| du|j m| fu|cuz|eiq|g c|gzd| co|uyu|coz|zbi|biu| dw|i s|i n|aw |dun|yun|izy|daw| he|nho| ho|enq|x l|cie|q b|cij|uzl|x d|iuj|awj| ya|eij|dei|nde|sae|izc|wnq|wnh|sei|h b|aih|gzs|bwn|a d|u g|ngg|jca|e b|ran| ra|hcu| me|iet|van| bu|guh|hen|si |wnj| ve|u b|azl|inj|gak|gan|ozg|siu|yaw|i m',
    'kin': 'ra | ku|se | mu|a k|ntu|tu |nga|umu|ye | um|unt|mun|e n| gu|we |ira|a n| n |wa |ere|mu |ko |gom|a b|e a| ab|li |e k|mba|a a|e b|aba|ga |e u|ba |omb|o k| ba|a u|ose|u b|o a| cy|ash|eng| ag|kwi| bu|za |gih|ren|ndi| ub|ang|yo |aka|gu |igi| ib|a g|a m| nt|uli|o b|ama|ihu|e i|nta| ak|ago|ro |ora| ka|ugu|hug|di |iye|ban| am|cya|ku |ta | bw|and|sha|re | ig|gan|ubu|na | kw|obo| by| bi|a i|yan|ka |sho|kub|era|ese| we|kan|aga|hob|bor|ana|byo|ura|uru|ibi|rwa|wes|u w|no |uko|i m|mo |u a|ure|ili|uba|o n|uha|uga|n a| im|ish|bwa|bwo|wiy|ali|ber|ze |ne |ush|are|o i|u m|ger|bur|ran| ki| no|ane|bye| y |ege|teg|guh| uk|n i|rag|i a|ya |u g|e m|anz|bo |abo|gar|wo |y i|ho |age|ind|o m|eke|a s|ara|zir|ite|kug|kim|aci| as|u n|ani|kir|mbe| gi|yos|kur|ugo|gir|e c|iza|aho|i b|tur|ata|o u| se|u u|zo |i i|aha|nge|mwe|iro|akw|any|eza|uki|imi|o y|ate|u k|iki|atu|bat| in|go |tan|n u|bos| bo| na|hak|iby| at|ihe|ung|ha |bul|kar|eye|eko|gek|nya|o g|shy|e y|awe|ngo|bit|mul|nzi|rer|bag|ge |imw|bah|cir|gac|bak|je |gez|imu|eze|tse|ets|mat| ru|irw|he | ni| ur| yi|ako|ngi| ng|i n|rez|ubi|gus|fit|afi|ugi|uka|amb|o c|utu|ufa|ruk|mug|bas|bis|uku|hin|e g|ige|amo|ing| af|yem|ni | ry|a r|gaz|te |erw|bwe|ubw|hwa|iko| al|ant|zi ',
    'zul': 'nge|oku| ng|a n|lo |ung|nga|la |le | no|elo|lun| um|e n|wa |we |gel|e u|ele|nel|thi|ke |nom|ezi|ma |ntu|oma|hi |o n|ngo|tu |nke|onk|o l|uth|ni |a u|lek|unt| wo|o e| lo|mun|umu|pha| ku|ang|ho |kwe|ulu| ne|won|une|lul|elu| un|a i|gok|kul|ath|hla|lok|khe|eni|tho|ela|zwe|akh|kel|a k|enz|ana|ban|aka|u u|ing|ule|elw|kho|uku|ala|lwa|gen| uk|wen|ama|na |e k|ko |gan|a e|he |zin|enk|o y| ez|kat| kw|lan|eth|het|o o| ok|okw|i n|nzi|aba|e a|hak|lel|lwe|eko|ane|ka |so |yo |ayo|o a|uhl|nku|nye| na|thu|mph|do |ben|ise|kut|ike|kun| is| im|hol|obu|fan|i k|e w|nhl|nok|ini|and|kuh|ukh|kuk| ak|e i|isi|aph|zi |ile|eki|ekh| ba|eka|the|a a| le| ye|kwa|e e|fut| fu|za |mal| ab|ebe|isa| em|o w|kub|mth|i w|ndl|emp|any|olo|ga | ko|nen|nis|alu|ith|eli|ndo|seb|nda| ya|i i|eke|vik|ake|uba|abe|ezw|yok|ba |ale|zo |olu|ume|ye |esi|kil|khu|yen|emi|nez|hlo|a l|ase|ula|kek|a o|iph|o u|no |azw|kan|mel|uny|ne |ufa|ahl|lin|hul|ant|und|sa |enh|kus|kuv|lak| in|o i|din|kom|amb|zis|ind|ola|uph|wez|eng|yez|phe|phi|mba|nya|han|kuf|nem|isw|ani|iyo| iy|fun| yo|uvi|i a|ene|izi| el|cal|i e|eze|ano|nay|hwe|kup|lal|uyo|ubu|kol|oko|ulo| la|e l|tha|nan|mfu|hon|nza|hin| ey|omp|da |bo |ilu|wak|lon|iso|kug|nka|ink|i l|sek|eku| ek|thw|gez',
    'swe': 'ar |er |tt |ch |och| oc|ing|ätt|ill|rät|en | ti|til|för|ll | rä|nde| fö|var|et |and| en|ell| ha|om |het|lle|lig|de |nin| de|ng | in| fr|as |ler| el|gen|nva|und|att|env|r h| i |r r|ska|fri| so|har|der| at|ör |ter|all|t t| ut|den|ka |lla|som|av |sam|ghe|ga | sk| vi| av|ete|la |ens|t a| si|r s|iga|igh|tig| va|ig |a s| st|ion|ra |tti|a o| är|ten|ns |t e|na | be|han| un| an| sa|a f| la| gr| må|nge|n s|vis|lan|må |ati|nat| åt|an |nna| li| al|t f|ans|nsk|sni|gru|äll|tio|ad | me|isk|kli|s f|t i|stä|t s|ri |med|sta|h r|lik|da |dig|ta |r o|run|on | re|lag|tta|är |kap|a i|a r|änd|erv|n e|kte|n f|rvi|nom|itt|id | mo|sky|r e|ver|äns|vil|gt |igt| na|tan|uta|dra|t o|ro |isn| fa|kal|ihe|rih|erk|r u|e s|per|l v|vid|one|rel|ber|ran|ot |mot|ndl|d f|ed |ika|män|l s|bet|t b|dd |ydd|kyd|n o|s s|str|n m|tet|sin|r f| om|rna|int|r i|end|nad|l a|ap |ers|nda|t v|ent|rbe|arb| hä|ets|häl|amh|ckl|gar|nga|r m|je |rje|arj|n i|s e|lin|r t|i s|rän| pe|ilk|t l|ern|på | på|täl|d e|dom|ege|g e|tni|r a|lit|ras| så|lln|kil|ski|enn|i o|a d|erä|n a|ara| ge|äro|a m| ar|t d|ilj|els|yck| ve|g o|frå|nas|tra|ess|del|m s|liv|l l|in |v s|g a|ast|e e|val|son|rso|e t|age|nd | eg|ial|cia|oci|soc|upp|igi|eli|g s|rkl|gad|ndr|nte|öra',
    'lin': 'na | na| ya|ya |a m| mo|to | ko|li |a b| li|o n| bo|i n|a y|a n|ki |a l|kok|la | ma|zal|i y|oki| pe|ngo|ali|pe |so |nso|oto|ons| ba|ala|mot|a k|eng|nyo|eko|o e|nge|yon| ny|kol|lik|iko|a e|o y|ang|ye | ye|oko|ma |o a|go | ek|ko |e m|aza|te |olo|sal|ama|si | az|mak|e b|lo | te|ta |isa|ako|amb|sen|ong|e n|ela|oyo|i k|ani| es|o m|ni |osa| to|ban|bat|a t|mba|ing|yo | oy|eli|a p|mbo|o p|mi | mi| nd|ba |i m|bok|i p|isi|mok|lis|nga|ge |nde|koz|bo |gel|ato|o t|mos|aka|oba|ese|lam|kop| ez|lon|den|omb|o b|ota|sa |ga |e a|e y|eza|kos|lin|esa|e e|kob|e k|sam|kot|kan|bot|ika|ngi|kam|ka | po|gom|oli|ope|yan|elo| lo|ata| el|bon|oka|po |bik|ate| bi|a s|i t|i b|omi|pes|wa | se|oza|lok|bom|oke|som|zwa|mis|i e|bek|iki| at|ola|ti |ozw|lib|o l|osu|oso|e t|nda|ase|ele|kel|omo|bos|su |usu|sus|bal|i l|ami|o o|bak| nz|pon|tel|mob|mu | ep|nza|asi|mbi|ati|kat|le |gi |ana|oti|ndi|tan|a o|wan|obe|kum|nya|mab|bis|nis|opo|tal|mat| ka|bol|and|aye|baz|u y|eta| ta|ne |ene|emb|sem|e l|gis|ben| ak| en|mal|obo|gob|ike|se |ibo|’te| ’t|umb| so|mik|oku|be |mbe|bi |i a|eni|i o| mb|tey|san| et|abo|ebe|geb|eba|yeb|bu | as|ote|sik|ema|eya|ibe|mib|ai |pai|mwa|kes|da |may|boz|amu|a a|kom|mel|ona|ebi|ia |ina|tin| ti|bwa|sol|son',
    'som': ' ka|ka |ay |uu |an |yo |oo |aan|aha| wa|da | qo| in| u |sha| xa|a i|ada|iyo| iy|ma |ama| ah| la|qof|aa |hay|ga |a a|a w|ah | dh|a s| da|in |xaq| oo|a d|aad|yah|eey| le|isa|lee|u l|q u|aq | si|taa|eya|ast|la |of |iya|sa |y i|u x|sta|kas|xuu|uxu|wux| wu|iis|nuu|inu|ro | am| ma|a q|wax|dha|ala|kal|nay|f k|a k|le |ku | ku| sh|o i|a l|ta |maa|a u|dii|loo| lo|o a|ale|ara|ana|iga|o d| uu|ha |lo |o m|o x|doo|aro|kar|yaa|gu |si |ima|na | xo| fa|adk|do |a x|ad |aas| qa| so|a o| ba|lag| aa| he|dka|adi|soo|o k|aqa| is|ash|u d|had| ga|eed|san|u k|a m|iin|i k| ca|u s|n l|yad|rka|axa|elo|hel|aga|hii|o h|o q| ha|id |n k| mi|baa| xu|har|xor|aar|ax |mad|add|nta|mid|aal|waa|haa|ina|qaa|daa|agu|ark|o w|nka|u h|dad|ihi| bu| ho|naa|n a|ays|haq|a h|o l| gu|o s|aya|saa|lka| ee| sa|dda|ab |nim|quu|gga|ank|kii|rci|arc|n s|a g| ji|gel| ge|eli|ysa|a f|siy|int|laa|uuq|uqu|xuq| mu|i a|uur|mar|ra |iri|o u| ci|riy|ya |ado|alk|dal|ee |al |rri|ayn|asa| di|ooc|aam|ofk|oon|to |ayo|dar| xi|dhi|jee|a c| ay|yih|a j|ban|caa|lad|sho|d k|ida|uqd|agg|sag|ras|bar|ar | ko| ra|o f|gaa|gal|fal|u a| de| ya|o c|ii |xay|eel|aab|sig|aba|orr|hoo|u q|y d|ed |ho |sad|qda|h q|fka|n i|xag|n x|qay|lsh|uls|bul|u w|jin| do|raa| ug|ido|ood',
    'hms': 'ang|gd |ngd|ib | na|nan|ex | ji|eb |id |d n|b n|ud | li|nl |ad | le|jid|leb|l l| ga|ot | me|x n|anl|aot|mex|d g|b l|d d|ob |gs |ngs|jan| ne|ul | ni|nja| nj|lib|ong|nd | zh|jex| je|b j| sh|ngb| gh|gb | gu|gao|l n|han| ad|gan| da|t n| wu|il |x g|nb |b m| nh|she|is |l j|d l|nha|l g|d j|b g|el |end|wud|nex|gho|d s|d z|oul|hob|ub |nis| ch| ya|it |b y|eib| gi|s g|lie| yo| zi|oud|s j|d b|nx | de|es |d y| hu|uel|gue|ies|aob|you| ba|d m|chu|gia|dao|b d|s n|zib| go|zha|eit|hei|al |hud| do|nt |ol | fa|t g|hen|ut |gx |ngx|ab |fal|x j|b z|ian|d h|don|b w|t j|iad|nen| xi|gou|d c|b h|hao|x z|nib|anx|ant|gua| mi|s z|dan|ox |inl|hib|lil|uan|and| xa|b x| se|x m|uib|hui|d x|anb|enl| we|od |enb| du|at |ix |s m|bao| ho|hub| ng|zhi|jil|l s|yad|t m|t l|yan| ze| ju|heb|had|os |aos|t h|l d|nga| he|b a|xan|b s|sen|xin|dud|jul|d a|lou| lo|dei|d w| bi|b c| di|zhe|gt |ngt|x l|bad|x b| ja|hon|zho|blo| bl|d k| ma|deb|l z|wei| yi| qi|b b|x d|d p|eud| ge|x a|can| ca|t w|lol| si|hol|s w|aod|pao| pa|ren| re|x s|eut|pud| pu|aox|mis|gl |ngl|x w|zei|gon|enx|gha|s a|b f|l y|oub|eab|hea| to|did| ko|unb|ghu|t p|x c|geu|t s|x x|jao|ed |t c|l m|l h|jib|ax |l c|d f|nia| pi|eul|d r| no|min|l t|heu|ux |tou|ns |s y|iel|s l|hun',
    'hnj': 'it | zh| ni|ab |at |ang| sh|nit| do|uat|os |ax |ox |ol |nx |ob | nd|t d|zhi|nf |x n|if |uax| mu|d n|tab| ta| cu|mua|cua|as |ad |ef |uf |id |dos|gd |ngd|hit|ib |us |enx|f n|she|s d|t l|nb |ux |x z|ed |inf|b n|l n|t n|aob|b z| lo|ong|ix |dol| go|zhe|f g| ho| yi|t z|d z|b d| le|euf|d s|ut |yao| yo| zi|gb |ngb|ndo|enb|len| dr|zha|uab|dro|hox| ge|nen| ne|han| ja|das|x d|x c|x j|f z|shi|f h|il | da|oux|nda|s n|nd |s z|b g| ny|heu| de|gf |ngf| du|od |gox| na|uad| gu|inx|b c| ya|uef| xa| ji|ous| ua| hu|xan|hen|zhu|nil|jai|rou|t g|f d| la|enf|ged|ik | bu|nya|you|f y|lob|af |bua|uk |is |yin|out|of |l m|ud |hua| qi|ot |t s| ba|ait| kh|s s|nad| di|aib|x l|lol| id|dou|ex |aod|bao| re| ga|d d|b y|las|hed|b h|b s|f b|t y|jua| ju| dl|x s|hue|b l| xi|zif|dus|b b|x g|hif|x y|hai| nz|sha| li|x t| be|d j|und|hun|ren|d y|hef|xin| ib|b t|l d|aos|s l| ha|gai|nzh|gx |ngx| ao|s b|s x|el |gt |ngt|hik|aid|s t|x m|f l|f t| pi|aof|t r|eb | gh|s y|d l|gua| bi| za| fu|t h| zu|hou|deu|lb | lb|d g| mo|b k| bo|iao|ros|gon|eut|x h|al |uaf|hab|t t|k n|f x|hix|pin|yua| no|t b|ak | zo|s m| nb| we|d b|gha|f s|mol|euk|dax|l b|nof| ko|lou|guk|end|uas|t k|dis|dan|yol|uan|d t|x b|lan|t m| ch|jix|x x| hl|aox|zis|x i|et | ro',
    'ilo': 'ti |iti|an |nga|ga | ng| it| pa|en | ma| ka| a | ke| ti|ana|pan|ken|ang|a n|agi|a k|n a|gan|a m|a a|lin|ali|aya|man|int|teg|n t|i p|nte| na|awa|a p|na |kal|ng |dag|git|ega|sa |da |add|way|n i|n n|no |ysa|al |dda|n k|ada|aba|nag|nna|ngg|eys| me|a i|i a|mey|ann|pag|wen|i k|gal|gga| tu|enn| da| sa|nno| we|ung| ad|tun|mai| ba|l m| ag|ya |i s|i n|yan|nan|ata|nak| si|aka|kad|aan|kas|asa|wan|ami|aki|ay |li |i m|apa|yaw|a t|mak| an|i t|g k|a s|ina|eng|ala|ika|ama|ong|ara|ili|dad| aw|gpa|nai|et |yon|ani|aik|on |at |oma|sin|bal|ipa|n d|uma|g i|ket|ag |in |aen|n p|ram|sab|aga|nom|ino|lya|ily|syo|i b| ki|nia|agp|gim|kab|asi|kin|iam|ags|bab|oy |toy|n m|agt| ta|bag|sia|g a|gil|mil| um|o p|ngi|n w|i i|pad|pap|daa|iwa|naa|eg |ias|ed |nat|bae|o k|saa|san|pam|gsa|ta |kit|ma |dum|yto|tan|i e|t n|uka|t k|apu|lan|sta|sal| li|a b|ari|g n|den|mid|ad |o i|y a|ida|ar |aar|y n|dey| de| wa|a d|ak |bia|ao |tao|min|asy|mon|imo| gi|maa|sap|abi|i u|aib|kni|i l|gin|ged|o a| ar|kap|pul|eyt|abs|ibi| am|akn|i g|kip|isu|g t|bas|nay|ing|i d|kar|ban|iba|nib|t i|as |d n|y i|ura|a w|nal|aad|i w|lak|adu|kai|bsa|duk|edu| ed|may|agb|agk|tra|gge|sol|aso|agr|ngs|ian|ila|dde|edd|tal|aip|kua|umi|pay|sas|ita|pak|g d|ulo|inn|aw ',
    'uig': 'ish| he|ini|gha|in |ili| bo|sh |bol| we|ing|nin|we |shq|quq|oqu|hoq| ho|ush|ng |qa |ni |qil|hqa|en |lis|n b|dem|shi| ad|lik|ade|hem| qi|nda|ki |em |e a|iy |din|qan|igh|uq |ge |et |han|and| bi|ige|her|tin|olu|aq |ash|idi|luq|daq|erq|ha | te|let| ya|iti|liq|kin|me |mme|emm|rqa|lus|iki| qa|de | ba|aki|yak|uql|a h|men|rim|an | er|qlu| be|shk|du |döl| dö|hri|ile|lgh|esh|q h|rki|erk|i w|uqi| me|öle|ime|ehr|nli|iq |ara|ar |lar|a b| öz|da |ik |i b|beh|hi |len|h h|ila|ayd|may|ke | ar|che|shl|nis|ydu|lin| ké|bil| mu|e q| ig|er |olm|éli|inl|tni|yet|lma|q a|ek |asi|hli|e b| as| sh|u h|hke|ali|ari|siy|shu|a i|e h| qo|rli|bir|emd| tu|ler|iye| is|ett|qi |i k|mde|he |bar|özi|etl|lid|tur|e t| al|nun|kil|tis|mni|qig|uru| je|ima|bas| ji|rek|ére|kér|r b|raw|awa| ma|a a|anu|éti|ida|emn| bu|iqi|i y|jin| sa|e e| xi|mus|k h|iri|tes|ayi|nay|ina|dil|adi|i h|zin| él|she|i q|n h|hek|n w|min|n q|tti|ti | ch|ip |iya|éri|tid|his|alg|pal|apa|les|sas|asa|e m|p q|uch|niy|qti|siz|isi|n a|il |rni|uni|chi|tim| ij|ris|i s| xa|ir |ghu|met|n i|m i| ta|atn| pa|tle|lim|gen| de|ich|kap| ka|g h|q b|i a|ün |hün|chü|üch|q q|und|sht|sit|rus|lig| to| iy|ale|y m|e d|aiy|mai|jti|ijt|eli|i d|i t|si |rqi|e i|arl|hu |ami|rin| hö|etn',
    'hat': ' li|ou |an |wa |li |on | po|pou|yon|te | yo|oun| mo|un |mou|en |ak | na|n p|nan| dw|dwa| ki| fè|tou| pa| to| ak|ki |syo|se |yo |i p| ko|gen| ge|èt | sa| la| se|out|n d|ut |pa |u l|n s|ite|n n| ch|n k| de|t p|n l|cha|kon|e l|e d| re|asy|nn |fè |a a|i s|ans|fèt| a |a p|sa |swa|ni | ka|òt |n y|t m|n a|i k|hak|pi |n m|ote|men| me| so|i l|a l|lit|epi| pe| si|enn|e p|e s| ep|nm |i t|yen|k m|t l|eyi| an| ni|e n| lò|a f| ap|yi |pey|i a|son|lòt|ns |san|e k|n e|ay |n t|man|ali| os|a s|e a| pr|al |e m|osw|n f|enm|sou| ma|ap |e y| ba|ran|a k| tr|lwa|n g|aso|lib|i d| pè|ant|i g|la | ta|sos|i m|i n|ka |a c|a y|nal|anm| di|pwo| pw|ye |e t|je |k l|de | vi|ksy|t k|nen|ons|a t|alw|lal|ete| le|ta |res|ava|he |che|ati| fa|ken|oke| ok|tan|osy| pi|bli|le |tis|a g|kal|nas|a d|sye|lè |lek|a m|a n|u y|eks|re |è l|o p|tra|i f|onn|aye|way| en|ik |ze |kla|kou| sw|a r| za|ide|di |a b|vay|rav|pès|wot|ont|kot|k k|jan|o t|ona|ras|isy|sya|van|ib |è a| tè|k a|pòt| ne|pre|esp|òl |èso|ach|i o|it |ist|e r|is |s k|n o|ète|u f|nsa|t a|dev|las|u t|nte| lè|i r|l k| kò|sip|tek|ri |pas|pra|k p|nt | ja| te|ond|yal|pan|fas|iti|fan|si | ra|u d|ife|dek|bèt|ibè|u k|ret|kòl|ekò|lon|wen|s a|vle| vl|ent| aj|ibl|ini|npò|enp| as|è s',
    'hil': 'nga|ang| ka|ng | sa|ga |an |sa | ng| pa| ma|ag |on |pag| an|a p|san|n s|ata|a k|ung|kag|n n|a m|kat| ta|gan|ags|ay |tar|gsa|tag|g p|run|aru|a s|ala|g k|kon|g m|man|a t|ing|agp|n k| si|may|y k|g t|mga| mg|g s|a i|a n|mag|ya |gpa|sin|n a|uko|yon|la |hil| uk|od |gin|ina|ahi|g i|kas|syo|ili|g a|iya| gi|pan|ban|way|ana|tan| pu| in|lwa|ilw|in |asa|lin|n p|gka|aya|nan|han| iy|at |g n|wal|aha|apa|o m|al |a g|lan|aba|gba| wa|kah| na|o s|a a|kab|agk|pat|ong|no |ano|ngs|pun|yan|aki|isa|o n|ali|ini|agb|nag|aga|a d|a h|ngk|i s|asy|abu|dap| hi| da|aho|agt|n m|di |n u|sal|til|sod|gso|ni |uga|mat|bah|bat|asu|a b|ato|ati| la|iba|sil|ngo|uha| su|nah|ulo|na | ba|pas| pr|ida| di|ngb|aka| ko|gay|lal|paa|o a|d s|ton|agh|pro|y n|uan|bis|ot |asi|i m|ka | is|ksy|atu|him|ila|y s|tao|gi |agi|aag|aan|o k|non|k s|ula|sul|tek|sug|gua| bi|gon|yo |n d| ib|uli| du|duk|ho |iko|hin| ed|a e|bot|ind|do |ron|aro|i a|abi|lab|eks|ote|rot|ugu|to |mak|as |s n|n b| o |n o|ad |m s|gal|una| hu| tu|but|kal|ika|a l|yag|hay|pah|nta|int|ama|pam|hat| al|uka|edu|ko |g e|ghi|lik|ami|ndi|sta|ok |tok|tra|os |abo|om |alo|dal|kin|n t|hi |a w|i n|da |kda|akd|tak|lig|inu|t n|d k|ao |kaa|par|aay|rab|awa|kau|mo |gla|gko|d a|ado|g o|lo |lon',
    'sna': 'wa |a k|ana|na | mu|ro | ku|a m| zv|nhu|mun|hu |dze|oku|a n|aka|che|zer|unh| ch|chi|ero|kan|ka |odz|kod| ne|zvi|rwa| pa| an|se |ra |e a|nek|va |ane|o y| we|kut| ka|ke |ake|iri|dzi|eko| yo|cha|ese|ach|ika| no|zva|ngu|ano|yok|ri |wes|u w|ang|yik|nyi|eku|ung|idz|ech|uva| dz|ipi|a z|irw|van| va|nge|iro|wan|o i|ani|nga|ich|wo |eng|ti |udz|o n|tan|ira|a y|a c|dza|sun|vak|nok| ya|a p|kwa|i p|e k|ita|rir|ko |ga |hip|unu|hec|edz| ma|ara|bat|guk|nun|sha|zwa|dzw|hen|o m|zve|o c|mo |kuv|a d|eny|ema|uta|uti| rw|ta |ino|twa|o a|pac|dzo|yak|wak| kw|i z|kus|zir|kur|rus|ere|nem|e z|emo|tem|gar| ha| ak|o k|rwo|uko|mwe|ata|e n|we |o r|and|za |zo |a i|yo |da |pan|erw|ezv|pi |asi|rud|usu|hak|uka|han| ic|guv|pir|a a|ari|isi|emu|aan|uch|re |hur|kwe|ura| in|uru|oru|kub|fan|anh|ush|hek| ye|ute|ran| ac| iy|ong|mut|i m|a r|ina|sin|pas|ait|nor|uye| uy|a u|sa |asa|i i|era|nen|omu|uit|kui|u a| ny|kud|kuc|e m|aru|uwa|uba|nir|a s|cho|enz|ndi|aga|kun|i a|sva|ge |vin|get|hap|o z| wa|sar|o p|no |muk|itw|uri|mat|ama| ko|kuw|usa|ofa|nof|kuz|vo |a v|uma|mag|wen|e p|yor|pam|emh|swa| hu|ne |ye |ete|vic|uzv|ava|ose|si |ayo|mir|apa|ton|vem|nez|do |i h|adz|azv|zan|nza|zid|mum|imb|bas|mba|mus|iki|e c|osv|hos|mho|vis|ngo|ite',
    'xho': 'lo |nge|lun|oku|elo|ye |ung|nye| ng|nga|e n|la |tu |ntu| ku|a n|o l|ele|e u|lek|yo |gel|o n|nel|ho | na|ke |wa |a k| um| lo|ko |ulu|o e| ne|nke|onk|elu|any|mnt|we |ama|lul| kw|umn| wo|kub|ngo|une| no|eko|won|enz|ule| un|a u|ela|le |kun|kan|ba |a i| ok|ang|lwa|eyo|oka|alu|uba|lok|lel|ukh|kuk|aku|ala|aph|akh|kwe|ley|eth|the|u u|khe|het|nok|pha|ezi|ile|uny|use|ath|eki|khu|zwe|kul|kho|e k|wen|gok|na |o y|sel|a e| ez| uk|o o|ane|ana|hul|e a|tho| in|enk|o k|nam|o w|uku|kil|he | yo|unt|ent|ni |obu|nku|esi|ing|o z|ayo|ya |hi |lwe|phi|ban|fun|ben|elw|o a|uhl|ndl|nzi|gan|eli|olu|eni|hus|kwa|aba|ha |und|gen|uth|lal|ntl|e o|ink|hla|ise|iph|seb|ebe|isw|thi| zo|ume|kut|a a|isa|kel|izw|e i|za | ba| ab|sha|tya|een|yal|mth|i k|uph|sa | lw|alo|lan|dle|tha|lin|zi |ase|nay|i n|pho| ak|man|mal|wak|zo |bel| im|mfu|int|swa|ngu|do |nee|ene|ulo|o u|a o|tla|ezo|ga |wan|han|sen|kuh|kus|ety| es| ya| le|eng| el|kup|azi|ka |e e|olo|ubu|bal|and| se|o s|fan|okw|ant|o i|tsh|li |lis|sis|ale| en|phu| ol|ham|iso|lak|bo |mny|okh|nte|mel|ziz|sek| am|zin| ul| ub|nen|e w|ong|zel|emf|nan|ndo|yok|ube|nya|yen|len|gal|ili|e l|be |abe|ali| ph|a y|wam|aka|amn|men|lum|rhu|urh|eka|dla|u k|oli|iba| ko|thw|imf| wa|nda| is|nza| be',
    'min': 'an |ak |ang| ma| ka| da|yo |ara|nyo| sa| ha|ran|ng |nan|hak| pa| ba|dan| di|ata| pu|ura|pun|kan| na|man|ok |nda|ala|o h|uak|asa|k m|ntu|k u| ti|uny|ah | ur|n k| un|tua|n d|n b|and|n s|unt|ek |g p|iok|tio|jo |n p|tau| at|dak| ta|aka|pan|au |ind|ama|pek|dap|aan|ape|nga|k d|n m|uan|tan|lia|sua|gan|amo|bas|kat|gar|o p| in|n n| jo|mo |at |mar|ado|o t|ari|di |k s|n a|am |lam| su|o d|iah|par|ban|tu |sam|adi|o s|ika|lak|ian|ko |dal|um |san| la|ai |ega|neg| ne|k k|uka|al |asi|ant|aga|bat|dek|o m|mas|eba|beb|asu|mal|n u|tar|aku|ri |kal|ana|in |atu|ti |ato|sar|ngg|lan|alu|rad|aro|ali|un |ami|o u|k h|ro |car|o b|amp|mam| bu|dok|dia|aha|n t|to |rat|ka |ila|a d|sia|anu|yar|sya|i d|sur|sas|kum|as |pam|aca|k t|ati|kar|eka|dil|any|lo |i m|h d|iba|k b|u d|kab|u p|o a|o k|kam|lai|aba|ard|dua|ndu|lin|k p|ajo|raj|han|bai|ra |n i|uku|huk|itu|dar|aya|uli|mpa|amb|i k|ain|rde|abe|did|ili| li|sac|sti| mu|bul|n h|i p|nny|k a| ko|ras|bad|k n|ndi|rga|arg|iko|tam|a n|kaw|i j|ga | an|nta|k l|apa|ida|jam|alo|sal|l d|u k| hu|das|tik|mat|dik|ia |idi|uju|lua|pul|kuk| pi|ann|il |iny|i t|bak|ust|mus|uah|pri|aja| ja|n j|h p|sio|ar |ada|oka|ngk|sa |gam|min|ik |mbe| ad|si |m d|kaa|sat|i n|i a|usi|rak|asy|aki|rik|kny|ulo',
    'afr': 'ie |die|en | di| en|an |ing|ng |van| re| va|reg|te |e r|et |e v|een|e e| ge| be| te|eg |n d|le |ens|n h| he|het|ver|t d|lke|nie| in|ke |lik|of | el|e o|nde| ve|al | to|elk| op| ni| of|g t|der|id |and|eid|aan|kee|ge |ot |tot|de |hei|e b| vr| we|om | sa| aa|ord|er |e w|ige|g v|n v|ers|in |sal|nd |erk|e s| vo|dig|vry|wor|n s|asi|eni| wa| om| de|bes|rd | wo|’n | ’n| on|ond|at |ska|ede|esk|sy |nig|e t|oor|ns |men|g o|aak|eli|kap| me|lle|vol|n a|edi|din|g e|uit|op |e g|gte|rdi|aar|ik |erd|el |ak |sta| st|ap |egt|se | sy|ele|gin|sie|min|ker|ere|is | so|yhe|ryh|es |ike|wat|e n|e d|del|wer|end|ale|n o|ur |eur|s o|per| hu|re |gel|ten|deu|e k| as|it |ema|gem|nas|ger|d s| is|rin|ewe|eme|ite|ter|as |n e|soo|oed|s v|ees|wet|red|e h|d v| al|ies| ma|nsk|ig |e i|ier|hie| hi|r d|t e|man|kin|nal|ona|d o|ske|ien|e a|eri|wee|ir |vir| vi| na|n w|iem|t v|s e|r e|ion|sio|nte|tel|eke| da|taa| gr|oon|rso| pe|tee|ort|n b|d e|lyk|ely|ese|e m|sia|ont|ans| ty|rde|ind|d t|nge|d d|g s|voe|n t|ndi|rmi|erm| sl|ren|maa|d w|lan|l g|hed|t a|n g|hul|n r|waa|t g|all|pvo|opv|ang|dee|nli|osi|sos|mee|wel|k o|kan| ka|raa|spr|nsp|nse|den|aat|gen|t s|g a|ste|est|str|lin|l v|sek|d n|ern|arb|daa|s d|ods|r m|t i|yke|met|rs |n i',
    'lua': 'wa |ne | mu| ne|a m|a k| ku|di | di| bu|e b|bwa|tu |udi| bw|a d|a b|ntu|e m|nga|i b|i n|shi|la |mun|yi | ba|adi|unt|u b| dy|nde|ung|ons|ya |mu |na |ga |end|nsu|a n|buk|e k| ma|any|u m|nyi|esh|de |lu |idi|ika|u n|su |ku |yon|i m| ka| mw| yo|u y|we | ud|wen|ken|dya|ji | kw|u d|mwa| an| bi|dik|sha|tun| ci|ha |hi |kes|oke|kok|bwe|kwa|dit|nji|kan|ka |mwe|ibw|yen|itu|ba |u u|ena|ang|le |ban|ala|enj|a a|e n|uko|uke|ans|u a|ana|bul| wa|nda|did|umw|ish| a |ila|bad|e d|mbu|kal|du |ndu|hin|kum|aka|nso|nan|a c|ele|ela|kwi|bu |nsh|ind|i k|sun|i d|i a|ula|ye | na|dye|u w|mba|alu|mak|ant| pa|lon| by|kus| mi|amb|gan|dil|dim|mud| cy| ns|kub|lel|u k|da |bud|enz|ond|ako|ile|e c|umb|diy|mus|abu|ja |dis|aku|bid|mal|umu|kad|dib|imu|cya|kuk|kud|so | me|ilu|ulu|ngu|ta |bak|akw|u c|iba|ush| ke|wik|eng|uba|wil|elu|und|kwe| mo|a p|omb|nza|iye|pa |mum|man|bya|kup|wu |muk|aci|a u|som|atu|ukw|upe|uka|e a|bis|kak|ngi|nge|pet|ilo|ama|iko|iku|mik|utu|ong|ulo|iki|and| um|mat|kul|uja|isu|gil|ale|nka|ata| mb|san|dif|ifu|ole|lwi|ulw|za |cik|lam|bel|awu| ya|wab|lum|ubi|sam|isa|aa | aa|fun|kon|bum| lu|eta|mbe|wel|kol| be|ane|ame| ad| tu|men|upa|tup|uku|omu|mom| my|mul|ing|ma |o u|pik|kab|cil|aji|me |uyi|kuy|o b|bon| bo',
    'fin': 'en |ise|on |ais|ja |ta |an | ja|sta|n o|ist|keu|ike|oik|ell|lla|een| oi|n t| on| va|n j|aan|kai|la | ta|lis| jo|sen|lli|a o|uks|sel|tai|a j| ka|us |in |n k|a t|eus|sa |ksi|n s|ään|än |kse|nen|jok|see|oka|ai |tta|ssa|taa|mis|aa |nsa|ses|apa|tä | se|ans|den|est|ttä|all|kan|tää| yh|lai|sia|ill|ä o|a v|itt|ett|vap|aik|ia |hän| hä|ast|a k| tu|n e|ust|kun|eis|ess|ti |sti|per|ä j|n v|ain|n y|kä |n p|n m| tä|ine|isi|äne|yks|ude|ä t|a m| pe|tei|tee| mi|a s|a p|val|unn|tuk|sä |a h|sek|utt|llä|ste|yht|ava|lta|ien| sa|lä |oll| ei|ssä|n a|n h|stä| ke|alt|suu|isu|sal|tet|ois|tav|a a|ikk|sty|ekä|a y|etu| ku|vaa| te|hte| mu|pau|stu|iin|toi| to|lle| he| ri|muk| la|n l|ää | ra| ol|nno| ma|ei |uut|iit| su|oma|ami|tam|ten|att|dis|tur|aut|mää|n r|ämä|maa|oon|jul| ju|ute|iaa|et |kki|tie|ide|ä m|kaa|suo| si|saa|i s|rva|urv|väl|lin|tus|rus|eru|nna|sku|isk|lii|oli|uol|a r|sii|ite|a e|hen| ko|sil|euk| sy| ty|työ|pet|ope|ali|avi|paa|si |iss|voi|tyk|ä v|oja|vat|vas| yk|joi|vai|täm|kil|enk|mai|mie|tti|iel|rii|nkä|min|hmi|yhd|lit|ens| pu|uka|ita|ka |omi|aas|kka|jaa|uoj| ed|ala|oit|täy|i t|int|ilö|nki|eel|ä s| al|eli|lee|un |kää|oht|koh|va |eid|tun|ttu|le |na |ihm| ih|aal| av|aat|i v|non|tte|ytt|yyt|ulk|eud|van',
    'slk': ' pr| a |prá|ráv| po|ho |vo |na | na|ost| ro| ne|ie |nos|ch |ávo|kto|ebo|má | má|ažd|kaž| ka|bo |leb|ale| al|o n|ani|dý |ždý|ia |ne |om |ti |ého| v | je|ova| za|á p|ý m|mi |eni|to |né | sl|tor|van|a p|sti|voj|o v| kt|nia|lob|slo| sv|mu |rov|rod|ých|svo| zá| by|o p| ná|ať | ma|nie| sp|e s|ej |nu |je |néh|o a|áva|bod|obo|a s|e a|by |a n|oci| vy|o s|odn|a z|ný |ený|mie|áro|roz|ovn|spo|u p|eho|nes|u a|nár|kla|a v|i a| sa|jeh|yť |byť|e v|stn|va |a m|sa |nýc|ným| k |ran|och|pre|a o|ému|a k|iť |ajú| do| vš|ov |čin|hra|zák|tre| ni|sť |u s|prí|stv|pod| ob| sú|a r|vše|ými|oje|ým |pri|kon|i p|vna|est|e b|smi|esm|osť| či|oré|lad| in|pol|žen|bez|áci|a a|u k|maj|šet| vo|e z|ť s|tát|i k|pro|chr| oc|nak|bol| bo| tr|i s|iu |čen|ny |du | ho|ť v|jú |del|ami|dov|vať|ko | vz|rav|pra|lne|ré |štá| ta|anu|nom|aby| ab|res|voľ|ikt|nú |niu|slu|kra|edz|e p|odu|áln| so|ože| de|é v|etk|ní |ok | pl|kým|ako| št|vin|str|ou |é p|m p|inn|rís|kej|stu|nik|med|tvo|por| to| kr|de |sta|pov|iál|ens|aké|hoc|rác|o d|ené|m a|lan|ela|zde|vzd|očn|olo| ak|loč| st|iný|ím |ast|dne|ju |oju| od|aní|tup|i n|rej| ve|pln|adn|tak|ú p|júc| s |oľn|čno|ivo|obe|luš|sob|oso| os|jin|aji|raj|iná|ade| ži|ven|vod|ciá|soc|dno|bož|ábo|náb|o r|kéh',
    'tuk': 'lar| bi| we|we |da | he|ada| ha|dyr|er |an |r b|ir |ydy| ýa|bir|yň |yna|na |yr | ad|ary|dam|lyd|de |kly|yny| öz|lan|r a|her|hak|akl|aga|kla|iň |am |ara|mag|ili|r h|ga |ala|ler|dan|en |a h|öz |ar |nyň|gyn|ini|ne |bil|li |len|atl|nda| ed| ga|‐da|ygy|a‐d|ine| de|uku|huk|e h|lyg|edi|a g|ýa‐|dil| bo|kuk|lma|eri|tly|ryn|asy|a d|eti|ny |ly |niň|dir| hu|‐de|aza|ge |ýan|ile|aýy|e d|zat| az|hem| gö|ama|lyk|ýet|den|nde|any|ynd|ykl|ukl|äge|mäg|im | du|a w|a ý|gin|m‐d|em‐|in | je|n e|bol| hi| di|e a| be|p b|ra |e ö|mak| go|ni |mez|ilm|aly|ril|n b|sy |syn|rla|esi|ryň|gal| ma|etm|nma|ede| sa|lme|iç |hiç|e g|a b|lin|igi|ele|rin|iri|deň| do|ak |lik|anm|dal| ka|mal|n h|kan| ba| ýe|iýa|gat| ge|al |y b|yýe|tiň|let|ard|tle|n ý|ere|agy|ora|gor|nme|inm| gu| ki|sas|esa| es|r e|bu | bu|gar|tla|ill|ýle|lig|sin|ň ý|mel|e b|end|n a|ýar|ň h|rda|y w| et|tyn| dö| iş|çin| ar|z h|r d|ýda|ň g|nun|ünd|yly|ň w|ez |yp |kim|ýaş|olm| çä|gör|dur| äh|siý|and|daý|eli|mil|eýl|beý|erk| er|aýa|kin|ek |ndi| yn|ola|ry |r w|lim|aýl|gyý|et |e m|i ý|agt|wag| se|dol|a ö|n w|i b|eň |n p|anu|zün|özü|m ö|i g|ç k|aşa|rma|ana|ldi|my |hal|ähl|asi|ram|kda|ýyn|gda|agd|şyn|ip |lip|gel| mi|din|rle| me|at |jün|pjü|üpj| üp|ýla|mgy|emg|jem|gur',
    'dan': 'er |og | og|til|et | ti|der|en | de|for|il | re| fo|ret|ing| ha|lig|de |nde| en|lle|hed|els|ver|ar |und|ed |har|ell|den|ge |ler|lse|and|r h|t t|se |ng |hve| el|enh| fr|at |e e|e o|ig |nhv| i |gen|ede|ska|ige| at|es |le |ghe|r r| in|e f|fri| me|nge|al |igh|nne|nin|l a| be| sk| af|r e|ion|af |re |han| st|om | so|r s|e s| an|eli|ne |r o| på|tig|esk|or |del|ati|på |r f| er|enn| al|ens| un| he|tio|ndl|med| si|end|kal|nat|g f|ske|ns |tte|ent|ter|det|ke |lin|som|e r| ud|ett|g o|sky|e a| ve|nte|n s|r d|tti|sni|t s|lde|vil|ale|ind|ans|r a|kel| hv|dig| li|men|ren|old|hol| na| gr|ihe|rih|sam|vær|e i|e m|s f|age| vi|d d|g h|str|ære|te |ilk|g t|r i|nal|ona|e n|rel|run|gru|d e|nd |ers| sa|r u|ere|ger|e t|tel|bes| må|t i|per|lan|isk|dli|ors|rin|e d|kab| mo| væ|all|ejd|bej|rbe|arb|gte|mme|ved|e h|må |n m|igt|res|kke|l h|sig|ld |l e| fa| ar|n f|r k|ets|rsk|t o|t f|it |t d|t v|g i|ytt|kyt|ven|ove|g e|ste|r t|eri|tet|lke| om|øre|e g|fun|orm|d a|oge|nog| no|g a|erk|kra| kr|d h|od |mod|g d|g s|ie |erv|ene|em |sta|nst| ku|isn|vis|rvi|g m|t a|ner|tes|ræn|s s|n h|int| la|ikk|el | op|lit|n a|g u|av |rav|ts |dre|t m|e u|s o|ore|l f|rit|ndi|lag|l t|ffe|rli|n e| fu|yld|dan|n o|rke|ive|raf|tra|dom| tr|i s|l l',
    'nob': 'er |og | og|en |til| ha| ti| re|ett| de|ing|ret|il |tt |et |lle|for|ar | en|ver|ell|om | fo|ng |har|r h|het|ler|lig| so|hve|t t| el|ter|nne|som|enh|and|de |av |nhv|ska| å | i |le |r r|den|e e| fr|ig |r s|nde|els|se |e o| er|enn| me| st|lse|al |re |fri|tte| sk|han|or | be| in|ke | av| ut|ghe|r e|esk|nge|te |es | på|ete|der|nin|ten|på |igh|ed |l å|kal|ge |unn| sa|ent|e s|eli|n s|rin|ne |g f|itt|sam|lik|gen|t s|end|jon|sjo|asj| an|r o|g s|t o|men| al| si|lin|mme|med|g o|ner|dig|n m|ren|nte|ige|inn|e f| gr|e r|r f| ve|sni|sky|g e|del|ens|und|res|det|isk|gru|ihe|rih|tig|tti|kte|ans|g t|tel| li| un|lan|nas|t i|m e|r u|ske|e m|ns |ekt|str|t e|ers|per|ale|kke| he|rel|run| ar|kap|mot| mo|all|eid|bei|rbe|arb|e t| vi|bes|g r|ven|s f|eri| må|n e|e g| na|nn |e d|kra| kr|ot |ndl|ere|erd|rit|ære|vis|ger|ffe|id |e a|ytt|kyt|g h| et|tes| sl|i s|må | la|dom|l e|n o| fa|rav|r k|t f|nes|vær|ta |sta|ste|å d|ndi|g d|bar|l f|isn|rvi|g a|vil|nnl|r m|t d|jen|dli|e b|gre|e h|ikk|el |l o|nal|ona|opp|r a|on |n a|noe| no|ute|erk|v p|ts |e i|dre|g m|ie |gan|erv|org|ser|tat|ang|at |t v|s o|tli|fen|an |e n|ik |g i|å s|lov| lo|r l|t a|lt |ove|aff|rdi|m s|l l|nse|r t|n h| pe|sli| gj| ik|d d|old|hol|ial|sia|osi|sos',
    'suk': 'na | mu| bu|we | na|hu |a n|ya | gu|a b|nhu|wa |a g|a m|unh| ya|mun|li |ili|ali|bul|i m|ilw| ba| bo|uli|han|mu |lil| al|e n|u a|bo |la |ose|kwe|ang|ulu|lwe|kil| wi|i b| se|ga |ina|le |ge |kge|ekg|sek|bi |e b|e y|lo |and|i n|yo |ila|se |lu |a s|lin|gil|ngi|akw|aki|abi| gw|si |nsi| ns|dak| nu|ng’|gan|u b|o g|ilo|nul|e g|ka |nga|ile|a w|ada|u m|gwi| ka| ad|ubi|lwa|ani|ban|o a| ly|ndi|a l| ng|jo |g’w|a i|ho |ayo|ika|dik|e k| ma|anh|gul|u n|o b| ji|o n|yab|iya|wiy|lag|ula|yak|o l|ma |ing|gi |gub|biz|lan|shi|iwa|ja | li|iha|mo |o j|wen|o s|lya|a a|ola| ku|jil|win| ga| sh|agi|ha |iga|uga|a k|iti|oma| nd|uyo|iza|za |i a|a y|yos| ha| mi| lu|iko|ndu|pan|ji |nil|ala|bos|ene|a u|ele|nhy|u g|nik|o w|iki| mh|nda|uhu|duh|hay|aji|ana| ja|gwa|nay|i y|ong|aya|mil|o m|da |lug|man|e i|abo|aga|okw| ab|nek|ngh|dul|e m|aha|uma|ubu|bus|sol|wig|ki |nya|ung|iji| gi|wit|iso|som|twa|udu|imo|eki|’we|hya|gut|iku|e u|uso|u l| il|but|mha|any| um|bal|ujo|kuj|aka|tum|waj| we|ko |ugu|bud|lon|a h|utu| uy| is|jiw|ale|e a|a j|sha|ita|lit|ibi|lyo|u w|g’h| ij|upa|tog|ida|omb|yom|ajo|atw|mat|bok|ulo|gup|lik| ul|ize| at|uto|ze |kan|ulw|u u|sho|ish|hil|ike|kal|mah|umu|je |ule|mbi| ih|kaj| lo|ti |wik|’ha|eni|yiw|umo|ito|ba ',
    'als': 'të | të|dhe|he | dh|ë d|në |et |ë t|imi|për|ejt|rej|dre|e t| dr|it | e | pë| në|gji|ë p|sht|jit| gj|jtë|ër |het|ith|ve | ve| li|ush| sh| ka| i |t t|a t|kus|hku|jë |sh | ku|e p|ka |se | pa|me |e n|mit|së | nj|ë n|thk|ën |ë k|e d|ë s|in |ose|lir|h k|etë| os| si|ara|n e|një|t d|tet| ba|jer|ohe|jet|ë m|rim| nd|ë b|e k|e s|eve|eti| du|ndë|rë |ë g|tën|vet|eri|ra | me| që|t n|do |es |iri|e l|duh|dër|shk|und|si | as|re |end| ng|uhe|ndi|ësi|ga |nga|min|që |hte|ime|ash|mi |tje|i n|jes|ris|ë v|ri | ar|nje|r n| pe|ë i|ur |uk |nuk| nu|tar|i p|at |en |anë|ta |jta|e m| pu|e v|ar |sim|isë|gje|art|ë l| ma|ë r| së|ht |ish|i d|or | mb| je|lim|e a| ko|uar|ë e|cil|bar|mar|tës|edh|ëm |shë|ave|shm|nal|t a|ë j|ari|htë| ci|k d|im |snj|asn|kom|igj|t p|ës |ërk| de| kë|a n|ë a|irë|bas|esë| pr|tim|hme|ke |per|pri|vep|mun|roh|t s|ojë|ë c|tit|lli|omb|lit|par|i s| tj|s s|ij |tij|shi| fa|le |ale| ti|roj|bro|mbr|ali|ë q|nim| mu| t |n k|ti |t i|ven|uri|qër|inë|ik |esi| ra|atë|ras|t m|ëri|je |hë |pun|i i|e b|nd |jen|mev|a g|ë f|n p|ona|son|rso|ers|epr|tes|ësh| ës|ftë|oft|ore|ror|oqë|hoq|sho|ëta|zim|arë|kur|rat|kët|ëzo|i t|ill|ars|ite|ind|r d|rin| pl|ie |ërf|ë z|a p|rte|hëm|r p|tyr|bli|res|ike|te |kun|m t|lig|a d|ia ',
    'sag': 'tî | tî|na | na| ng|ngb|a n|lo | lo|nga|gö |ngö|gbi|bi |nî |zo |ang|la |î l| wa| sô|sô |gan| zo|a t|îng|o n|i t|lîn| al|gü |ngü|wal|ala|ö t|alî|a l| kû| nd|î k|ô a| lê|â t|î n|ë t|ûê |kûê|ê t| mb|î m|äng|ko | te|o k|örö|e n|o a|gë |lêg|gâ |ngâ|î b|ëpë|pëp| pë|ôko|a â|î â|êgë|mû |î s|dör|ödö|köd|ï n|a k|ëe |pëe|ü t| kö| ôk|ter|a z|kua|ke |eke|yek| ay|î t|ê n|ua |bên|o t|tï |ra | am|aye|î d|û n|ê a|rê |erê|â n|ênî|mbê|rö |âng|amû|a y|a m|ga | du| ku|î g| yâ|a s|ro |oro|dut| âl|yâ |ngô|ä t| nî| âm|utï|rä |arä|âla|bê |ö n|lï |öng|o s|a p|î z|önî|ten|i n|gba|ne |ene| sê|ba |e t| gb|ndo|iä |diä|ndi|ö k|ndö| gï|ara|ïng|î w|lë |do |ï t|a w|ûng|war| ân|a a|yê | âk| da|î a|ban|o w|tën| të|âra|sâr|në |dö |î p|o ô|zön|nzö| mä|ông|se |da |ndâ|sên|tön| tö|e a|ënë|ë s|üng| nz|o p|kân| kâ|a g|bâ | ko|o l|rös| bê|ôi |gôi|îrî|ênd|ana|ta |î f| po| sâ|mbâ|âmb| sï|ëng|mba|zar| za|ibê| mû|ëtï|bët|mbë|i p| as|fa |tän|e z|lê |sor|mar| ma|sï |i s|a b|amb|odë|kod|bûn|ë n|êse|sês|ösê|o m|du | af|dë |bor| bo|ê s|gê |ngê|ô n|ä s|ätä|bät|ü n|ë ô|ata|bat|älë|päl|kpä| kp|ö w|pë |rän|ärä|sär| sä|gï | âz| ad|ö m|gî |ïgî|bîr|mbî|afa|rë |erë|ûe |kûe| âs|ön |gbâ|e l| mo|âlï|wâl|ê w|ä w|i ô|ä a|pä |ü s|yam| ya|âzo| âb',
    'nno': ' de| og|og | ha|er |lle|en |ar |til| ti|il | re|ett|et |ret|om |le |har|tt | al|all|re |ing| å |ell|and| sk|ska| i |det| fr|t t|an | ei| so|enn|ne |ler| el|den|e s|ver| me|l å|leg|e h| ve| på|al | fo|dom|for|på |av |ein| sa|ten|n s|som|sam|fri|nne|r r|ei |ere|men|gje| st|de |e o| gj|je |nde|kal|dei|st |eg |tte| in|han|i s|ast|r s|ski|t o|med|rid|or |lan|ter|t e| an|ed |r f|te |t s|kje|ge | sl| av|r k|ido|e t| er|ke |jon|sjo|asj|nas|unn| ut|g f|g s|n o|g o|nga|å f|e a|der|ng |e f| gr|kil| få|r d|ske|esk| si|lik|e i|n m|ste|at |ern|ona|n e|lag|kra| kr|e n|in |t a|ren| la|nte|e d|nin|e k|nn |tan|na |seg|v p|rav|nsk|ins|me |ame|nes|e m|bei|å v|itt|eid|a s|ege|få |e r|år |e v|lov|r a| fa|gru|sla|ld |rbe|arb|ome|kap|jen|n t|jel| mo|r l|sta|ane| tr| li| må| at|kkj|ikk| ik|kan| ka| lo| na|n a|dre|ndr|ha |g g| ar|n d|eld| se|id |ot |mot|å s|va |t i|gen|nle|t d|n i|ale|ige|nal|rel|run|ag |oko|nok| no|d a|nad|frå|l d|å a|ild|var| kv|ve |erd|e e|inn|e u|g i|r h|kte|dig|gar|lin|god| vi|str|i e|l h|nge|end|t h|r o|r g|bli| bl|int|eig|nna|on |se |uta|t f|l f|e g|nom|amf|sin|pet|kår|vil|ga |mål|ene|ent|ig |fer|are|d d|g a|rn |ova|ele|g e|ik |g t|per|ens|gre| om|rt |und| un|rna|øve|høv|l e|ial|sia',
    'mos': ' n | a |ẽn| se|a t| ne|a s|̃n |sẽ| ye|e n| ta| pa|n t| tɩ| so|tɩ | la|nin| ni|ãa |fãa| fã| tõ| bu|ng |tõe| b |ye |a n|or | te|a a|la |õe |tar|ẽ | ya|ne |pa | to|ed |ned|sor|e t|tẽ|aan|uud|buu|g n|r n| ma|maa|n y|ud |a y|n m|ra |ã n|paa|n p|ara|em |a b| wa|d f|n b|n d|̃ng|sã | tʊ|eng|bã |n w|an |gã |og |me |ins| na|e b|bɩ | bɩ| ka|ɩ b|am |g a|d b|aam|gẽ|taa|mb |ore|ɩ n|yel|ʊʊm|ãmb|ab |a m|tʊʊ|wa |a l| bã| ba|tog|ga |m n|re |ba |ngã|nd |aab|aa |yaa| sã|na | tũ| sõ| da|aoo|n n| yɩ|ã y|ame| me|aal|dat|n s|b s|ing|ãng|d n|ɩ y|ã t|ã s| kã|lg |m t|oor|r s|d s|̃nd|nge|el |neb|b y|nga|ar |gr |kao| bʊ|dã |to |vɩɩ| vɩ|egd|seg|men|saa|nsa| le|a k|at |ngr|n k|wã | wã|g t|oog|bũm| bũ|a p|dɩ |ʊm |ren|ɩɩm|ãad|ʊmd|da |b t|ũmb|yɩ |bãm|b n|d a|ya |g s|eb |l s| yi|kẽ| ke|rã | sɩ|m s| ti| yã| we|oab|soa| f | zĩ|b k|m b|oga|go |gdɩ|a z|õng|sõn|aor|tũ |ɩm |b p|ã p|ilg| mi|in | ko|al |ka | no|ɩ s|pʊg| pʊ|gam|̃ n|lem|ĩnd|b b|ã f|le |te |iid|uii|bui|ell|wil| wi|s a|oa |r t|e y|a g|aas|e s|ɩ t|ik |wẽ| ra|g b|tũu|e p| yõ|oy |noy|a r| zã|aba|ull|ũ n|mã |kãa|eem|kat|aka|wak|s n|nda|ll |gre|kog|loa|alo|lal|ã k|mbã|md |ẽe|k n|ag |r b|o t|eg | gã|n g|seb|ʊge|ebã|o a|bãn|sul| su|m y|bao|n z|ate|ã w|kam|mik',
    'cat': ' de| i | a |la | la|es | se|de | pe|per|tat|ió |ent|ret|dre|at |a p| dr|a l|ona|nt |men|ció|ts |na |aci|al |en |t a|ls | el| to|et |tot|a s|el | co|s d|ers|er |a t|que| en|s i|ta |e l| pr|t d|rso| qu| o | ll|son|ion|té | té|ns |é d|sev|ita|als|ota| in| l’|est|cio| re| al| un|cia|ons|ame|del|res|ar |ual|lli|s e|va |nal|ia |con|ser|les|i a|rà | no|pro|els|eva|nac|a c|s p|i l|nci| le|ue |no | so| ca|a d|sta|r a|s l|l’e|ert|s a|a i|re | d’|l d|una|ues|ter|rta|e c|ats|t i|n d|s n|a u|cci|s o| pa| es| na|l p|vol|sen|ber|ibe|lib|s t|t e|ure|l i|lit|erà|ant|da |ici|oci|soc|ra |tra|ens| di|gua|igu| ma|nta|ali|ene|tes| ni|a a|nte|a e|és |o s|tre|alt|r s|com|ets|i e|par|cti|ect|ten|cte|ote|us |eta|mit|ial|om |se |i d|s s|e d|i p|pre|un |ntr|r l|ecc| tr|seg|l t|ada|dic|eme|qua|ica|eli|ó d|aqu| aq|ènc| ig|ir |iva|ssi|lic|t t|des|o p| ac|ont|act|ing|egu|ria| te|int|ndi| fo|a m| po|lig|lle|inc|ist|nse|cla|hom|ltr|i i|cie|ess|ura|ass|a f|e t|bli|seu|tal|tec|rot|ú n|gú |ngú|nin|tac|pen|nde|t s|ic |s f|ó a|ol |evo|lse|tic|dis|cap|rac|mat|iur|liu|man|ll |itj| mi|olu|e i|art|uni|rti|esp|l s|le |ble|eri|os |sos|ies| as| ob|e p|n e|s q|tri|tiu|i c| ar|ni |tur|t n|gur|vid| vi|a v|ran|àri|ind| si|’es| fa',
    'sot': ' le|le |ng |ho | mo| e | ho|a l|e m|ya | bo|a h|lo | ya|ong|ba | ba| ka|na | ts|e t|tho|a b|mon|o y|o e|a m|elo|la |ets|olo|sa |oth|g l|oke|eng|kel|a k|ka | na| di|ang|mot|tla|a t|tsa|tok| se| ha|e b|o t| o |wa | tl|o l|e e|o b| to|pa |e k|lok|ha |aba|apa| a |e h|o n|so |tse|a e|hab|jha|tjh|tso|tsh|kap|se |ana|oko|ela|g o|a s|o m|let|loh|a d|e l|kol|set| ma|a a|bol|ohi|tsw|ele|hi |dit|eth| ke|lan| kg|o s|o h|eo |bo |g m|ke |ala|phe| me|etj|ola|o k| ph|aha| mm|ohl|ebe|lwa|a n|g k|swa|e d|bot| th|di | sa|atl|ena|hle|mol|tlo|ae |hae|abe|g y|ats|lat|i b|seb|to |otl|ane|g b|moh|mel|edi|lek|a f|the|wan|efe|nan|g t|e s|o a|han|ito|me |hlo| hl|shi|rel|ire|lao|kgo|hel|g h| en|g e|nah|ona|bet|man| fu|ell|kga|eha|a p|its|get|kge|mme|swe|si |thu|mat|uma|fum| ef|bel|len|ume|lal|hat|ban|kan|we |bat|tsi|ing|ato|e n|ao |o f|lel|hir|hla|sen| eo|she|pha|ano|eka|ile|fen|i k|tlh|lap|ots|fet|hal|din| ko|hen| fe|heo|got|hwa|elw|a y|i m|o o|bon|hol|son|dis|o p|alo| lo|boh|uto|hut|ben|nya|tha|abo|ita|aka|ama|ose|mab|iso|shw|e y|i l|het|oho|o d|tum| tu|llo|oll| wa|hil|ath|mos|oka|mmo|ikg|mo |uso|hah|emo|adi|boi|llw|dik|nts|lle|non|sel|all| yo|tle|e i|ike|rab|wen|meh|ame|lho|mee|ken| si|eny|oph|yal|pan|g s',
    'bcl': 'an | sa|in | na|ng |sa |na | pa|nin|ang| ni| ka| ma|pag| an|n s|ion|sin|asi| as|on |cio|n n|a m| de|n a|ban|a n|a p|kan|rec|ere|der|aro|cho|ech|aci|ga |a s|n d|o n| la|mga| mg|g s|n p|o s|man|sar| o |ho |n l|asa|n k|ay |n m|wa |gwa|igw|al | ig|mba|amb|kat|o i|sai|ong|lam|ata|ro |os |iya|a a|ara|o a|agk|apa|kas|tal|a k|yan|aiy|gka|nac|ali|may|g p|san|ina|aba|a d|lin| ba| da|ag |nka|ink|o m|yo |a i|iba|aka| in|ad |ing| ga|ent|no |ayo|nta|par| pr|ano|ini|hay|aha|iri|dap|ida|abo|han|sta|nal|kai|og |agt|at |pat| co|a g|ant|pro|g n|nte|n i|t n|ia |cia|con| si|dad|do |o k|a b|tan|ron|l n|s a|mag|ran|g m|aki|s n|men|es |g d|y n|tra| so|ona|a l|ra |min|agp|uha|n b|g o|a o|n o|a c|g k|mak|aya|hos|as |ado|o p|ter|bas|ags|i n|lan|ba |g i|bos|gab|bah|li |ico|l a|kap|cci|ecc|tec|ami|isa|imi|ton|ial| re|en |g a|tay|pin|n e|ili|rab|bal|hon|ote|rot|rim|cri|ast|gpa|y m|say|iis|sii|pan|sad|nag| se|ala|gan|bil|n c|nda|d a| di|nga|taw|gta|i a|ios| es|pak|bo |aan|res| pu|a e|sab|ey |ley| le|atu|buh|mit|om |abi|e s|kab|ika|rin|ici|gsa|ale|ica|ni |ipa|nci|ind|nan| ip|cac|waa|nwa|anw| ed|lid|nes|ura|le |ibo|uli| hu|sal| gi|awe|gaw|agi|y p|to |air| bu|rar|int|ito|ndi|kam|dir|agh|oci|soc|lig| li|aen|lar| bi',
    'glg': ' de|de |os |ión| a | e |to |da |en |ció|ón |der|n d|ere|ito| se|a p|eit|rei|ent|as | co|ade| pe|dad|aci|per| te|do |o d|nte|e a|ten|men| to|e d|al | pr|rso|ers|s e|a t|tod|que|soa| ou|ida| da|te | in| po|s d|oa |cia|es |o a|est| á |ra |oda| do| li|a e| es|a s|ou |con|e e|res|tra| re|nci| o |súa| sú|pro|a d|o e| pa|ar |e c|tos|lib|ue | qu|rá | na|ser|a a|er |úa | ca|ter|ia |dos| en|erá|e s|ica|a c|sta|s p|ber|nac|s n|s s| no|e o|a o| ni|ns | un|ado|e p|o á|io |cci|era|nin|des|nal|is |óns|ame|nto| so|or |se |com|pre|par|no |o t|o p|ona|e n|sen|s t|por|ais|das| as|cto|á s|eme|cio|ha |nha|unh|ara|rda|erd|ant|ici|n p|n s|ibe|n e| di|cas|nta| ac|ont|n t|dic|ndi|oci|soc|ion|ing|s o|enc|tiv|so |ali| ma|o s|a u|ngu|tad|e i|ese| me|lic|seu|ect|n c|lid|vid|ria| tr|e t|eli|e l|gua|igu| ig|l e|o m|r a|re |cti|act|ntr|ecc|ual|rec|a l|ido|nde|ind|o n|a n|cal|dis|ta | os|o ó|r d|iva|ada|mat|ste|fun| fu|tri| ó |á p|tor|nda|pen|na |on |n a|o o|ori|uer|lqu|alq|ca |rac|n o|tar|nid|bre|ibr|lo |aso|esp|a v|a i|ode|pod|und|s a|tec|ote|rot|tes|ena|ura|ín |uín|guí|egu|seg|ita|ome|ari|s i|ase| fa|ond|ial|tic|ixi|inc|sti|ist|cla|cie|e r|omo|s c|man|bal|spe|ati|edi|med|uni|ios|isf| sa|ias|ren| mo|lle|co |ico',
    'lit': 'as |ir | ir|eis|tei| te|uri|ti |s t|iek|is |os |us | ki|vie|ri |tur|ai | tu| pa|ien| vi|ali|i t|žmo|sę |isę| žm|mog|ena|ais| ne|ini|kvi|kie| la|gus|ekv|lai|ogu|nas| į | jo|ės | bū|s ž|vis|mą | ar|būt|s i| pr| su|mas|pri|ant|mo |ių | ka|s s|isv|ūti|oki|s k|s a|ar | sa| ta|tin|kai| ti|ę į| ap|ama|i b|s v|inė|sav|isi|s n|val|jo |aci|gal|imą| nu|imo|s p|rin|men|i p| ku|dar|cij|sta|ina|kur|nim|je |li |i k|ms |i i|arb|sin|jos| na|tas|mis|lyg|i v|i s|asi|tik|ijo|oti|eik|vo |mok|tie| mo| va|išk|iam|tai|aut|ma |s b|lin| be|i n|kit|r t| ly|si |ntu|tuo|sty|ą i|tų |r p|aik|ega|neg| įs| re|s j|isė|ybė|jim| iš|din|įst|sva|tat|aus|es |kia|ima|i a|ara|oje| ga| at|tis|avo|r l|nės|suo|isu|ek |tyb|ą k|am |mos|pag|aug|aty|ieš|rie|tu |nt |gyv|nti| da|o n|kal|mų | sk|kla|omi|aud|iai|ip |aip|o a|ito|r j|avi|ų i|ven|yve|als|jų |kim|alt|agr|nuo|ymo|kio|tym|int|min|ška|nam| ve|eka| as|ava|uti|tar|lie|šal| ša|oma|nac|kin|iki|tok| ji|s g|s l|ksl|ink|ome|pat|o l|rei|ika|o p|o t|ios|sau|io |san|nių|uo |nie| ni|vę |ver|o k|ikl|cia|oci|soc|r k|eli|yti| to|ų t|irt|kių|pas|u k| or|uom|uok|eno|vai|sla|ati|tą |a t|lst|ran|ėji|ary|tim|usi|a k|lti|gas|uot|tos|ist|ndi|ėms|ją |psa|aps|gą |ygi|nki|kan|s d|kas|ę i|svę|eni',
    'umb': 'kwe| om|e o|oku| ok|a o|a k|nda| kw|ko | ly|da |wen|la |end|nu |unu|mun|omu|wa |oko|ka |o l| ko|kwa|omo|mok|iwa|le |we |o y|i o|okw|te |eka|mwe|olo| vy|a v|osi|o k|ali|ete| ey|lyo|wet|si |yok| yo|lo |vo |ang|ong|kut|sok|iso|u e|u o|a e|a l|ye |oci|gi |eye|oka|fek|ofe|nde|iñg|nga|o o|ata|ñgi| li|eci| nd|i k|ngi|wat|kal|ilo|ovo|vyo| va|pan| oc|li |so |a y|owi|ci |kuk|e k|nge|wiñ| al|avo|kul|lon|ga |ing|ili|e l|ale|lom|ala|ge |ovi|ta |ngo|ati| ya|imw|go |eli|vya|a a|uli| ol|he |ahe|iha|ele|ika| wo| ku|lil|isa|a u|ti |yo |alo|kol|o v| ov|lis|i v|lya|lin|cih|uti| yi|yal|ako|ukw| lo|wav|ung|akw|ikw|yos|val|tiw|upa| ye|onj|i l|lim|and|uka| vo| el|gol|sa |su |kok|aka|e y|lyu|ñgo| ka|yov|vik|e v|eko|yah|gis|omw| wa| la|lik|e u|ava|tav|olw|ila|e e|vak|kov|omb|aso|a c|tis| ce|tat|iyo|epa|dec|a n|va |u c|eso|ela|ama|kat| ek|kup| ha|o e|co |ekw|asu|has|yon|asi|yow| ke|i c|upi| ci|wil|cit|ole|eyo| co|liw| yu| ca|kas| ec|uta|yim|wal|yol|kiy|e w|yuk|lye| of|o w|o c|i a|ita|ola|lwi|uva|lit|iti|njo| on|apo|ipa|sil| um|lof|wam|kun|i e|anj|cel|del|han| ak|u y|añg| up|o a|tun|atu|kak|yik|yof|iki|eti|fet|oñg|loñ|ulo|koc|yi |wiw|kwi| ow| os|kuv|ndu| es|vos|yel|uyu|mak|san|mbo|jon|i w|ngu|oco|lok|yas|e n',
    'tsn': ' le|le | mo|ng |go | ts|we |gwe| go|ya |ong| ya|lo |ngw| bo| e | di|a l|tsh|sa |e t|elo|a g|tlh|tsa|e m|olo|a b|wa |na |e l|o y|o t|a t|wan| kg|eng|kgo|o n| tl|a k|mon|la | na|ets|ane|mo | o |hwa|shw|tse| ba|e e|nel|a m|ka | ga|tla|ots|o m| ka|ele|o l|ba |e d|dit|e g|got|di | a |se | se|ang|a d|otl|bot|e o|lho|o e|ga |lol|e b| nn|a n|lha|so |lel|tso|o b|seg|ose|let|ola|ego|gol|o o|g l|kan|eka|nng|e k| ma|aka|atl|mol|sen|o g|aba|ela|its|los|tho|ano|gat|oth|yo |agi|tsw|e n|e y|len| yo|hab|o k|to | th|o s| nt|lhe|ho |agw|gag|g y|kga|mel|rel|ire|tlo|o a|ana|lek|iwa|aga|bon|g m|tir|edi|šha|tšh|lao|g k|i k|tle|ntl| te|dir|ao |e s|lwa|hir|shi|a e|pe |o d|any|a a|i l|a s|ale|alo|a y|g t|jwa| jw|hol|mot|gi |kwa|dik|lon|etl|tet| wa|mai|swe|set|thu|ko |non|ats| me|han|ume|ala| mm|nya|iti|he |bat|hut|nna|ira|itl|no | ne|ro |iro|nan|elw|she|ona|i b|hot|oag|log|a p|wen|i t|ikg|adi| ti|o i|lat|g g|ame|mog|bo |okg|hel|tha| sa|nag|bod|emo|nyo|isi|ile|hok|ogo|uto|si |pa | it| ko|the|diw|ope| op|tek|itš|odi|rwa|sep| ph| kw|pol|gis|bok|me |o j|aag|baa|hop|yal|opa|are|kar|ing|oke|ato|lam|bak|leb|ke | ke|amo|eny|gwa|mok|g n|nye|swa|boa|tum| ja|gan|g a|hag|gon|lan|net|mme| la|ban| fe|ika|rag|ne |g e|nen',
    'vec': ' de|de | ła|ła |el | el|ion|ar | e |sio|on |to |e ł|o d|rit| in|par| pa| co|a ł|eri|łe |ga |der|tà |a d| ga|un | a |a s|asi|n e| i |ito|e i|a e| on|te |onj|e d|ti |’l |ent|con|int|l d| re|nte|só | só|l g|o a|he | da|a p|e a| łe| pr|jun|nju|da |che| o |e c|sar|e e| ch|ałe|n c|na |e o|ità| na|e’l|art|ta |ens|èsa| ès|e p|men| po| se|tar|a c|sa |bar|ałi|o e|ona|e n| so| łi|i d|i e|pro|dar|e s|à d|nas|nał|sta|i i|sia|rà |ars|osi|ze |rso|n d|a n|eze|nji|se |ro |esi|nta|ara|iba|łib|nsa|tut| l’|tri|ame|o o|arà|ist|a g|usi|i s| cu|io |ita|nes| ne|rtà| tu|r ł| un|nto| ma| si|l p|ond|sos|tra|so |nsi|sun|esu|à p|e r|iti|ji |onp|ren|ont|tes|ste|in |ia |de’|l s|rio|isi|ra |dis|ras|ghe|łi |e f|sie|r d|i p|man|r e|nda|res|ca |nca|anc|a a|str|a i|o i|go | st| fa|n o|iał|sen|’st| ’s|i c|ntr|ien| di|o c|ver|est|r a|o p|nti|l m|pie|nde|son|ego|ega|ari|r i|var| an|rim|a’l|i o|e m|pod|imi| al|n p|pre|o s|co |ani|ri |uti|rus|tru|l’i|età|e l| ca|ato| fo|ó d|łit| a’|ant|dez| cr| me|ten|à è|oda|ó p|à o|den|en | vi|a v|o n|ne |rte|ltr|teg|nio|ini|or |sti|una|ełi|i g| ze|à e|npa|ni |ers|a r|a è| su|com| vo|ans|ja |à i| ar|fon|esp|tro|ote|rot|ura|re |o ł|cia|r t|à c|min|ene|alt|opi|eso|oło|n s|ute|e t|rse|anj',
    'nso': 'go | le|le | go|a g|lo |ba |o y|ng | ma|ka | di|ya | ya| ka| mo|a m|etš|a l|elo| tš|a k|ang|e m|o l|na |e t|man|wa |o t| bo|tok| a |e g|la |a b| ga|a t|we |oke| se|gwe|kel| ba|ša |o a|o m|tša| na|e l|o k|tše|a s| to| o |ele|a d|o b|ago|ego|dit|tšh|o g|oba|gob|e d|tho| e |šo |ngw| ye|ong|g l|di |o n| tl|ga |swa|let|olo|tla|tšw|mo |ane|ho |še |oko|aba|šha| kg|tšo|wan|ela|hab| sw| th|g o|ola|ye |e b|a n|kgo|šwa|eo |set|ito|e s|ona|log|mol| wa|se |oth|ao |eth|ogo|thu|to |eng|a y|o d|hut|e k|o s|net|kol|lok|a a|gag|rel|ire|e e|nag|agw| wo|ana|o w| yo|hlo|lel| bj|šwe|alo|aga|leg|wag| ph|yo |lwa|mel|pha|wo |get|kge|ano|aka|ato|lat|din|o o|hir|šeg|o e|ala|mok|šom| la|mog|nya|e y|lao| ts|mot|i g|ke | ke|kan|iti| me|kar|g y|gwa|eba|ohl|šhi|hel|phe|oph|bo |bot|ume|pol|a w|sa | sa|gon| lo| am|are|gel|ale|a p|len|e n|atš|itš|rwa|o f|emo|edi|bon|bja|ta |tle|ban|no |ušo|tlh|amo|wel|išo|ing|ge | ge|the|leb|o š|ko |hla|bop|dir|e a|ahl|aem|mae|ntl|šon| mm|mon| fi|lek|oka|uto|omo|i b|ret|ape|oge|lal| nn|ošo|pel|okg|abo|gab|lon|lag|yeo|a f|ile|moš|kga|dik|ši |yal|i l|tlo|a e|tsh|otl|elw|odi|i t| fe|med|dum|mal|ora|oll|hol| nt|jo |boi|lwe|i s|bat|hom|lho|ikg|tha|nel|muš|mmu|ha |apa|ne |adi|eny|iri|šal',
    'ban': 'ng |an | sa|ang|ing|san| ma|rin|ane| pa|ne |n s|ak | ka| ke| ha|hak| ri|nga|ma | ng| ja|in |sal|lan| pe|n k|uwe|iri|g s|ara|alu|lui|gan|uir|duw|adu|mad|adi|yan|nma|anm|jan|asa|n p|we |g p|g j|pun|a s|a m|man|e h|nge|tan|n m|awi| la|kan|nin|ra |uta| ne|pan|ur | tu|ih |ala|aya|n n|wan|eng|nte|un |ngg|tur|ah | da|en | ut|ana|bas|beb|nan|lih| wi|apa| ta|are|aha|ent|iad|wia|eba|han|ian|ani|ten|din|wi |taw|aan|a n|gar|asi|n w|pen|ebe|da |ika|ngk|a p|keb|ama|ata|aje|n r|aka|ipu|kal|e s|saj|g n|nen|g k|ado|oni|ron|ero|jer|ela|dan|ate|ka |anu|dos|dad|nya|al |aki|i k|a t| wa|ami|ren|ksa|ega|sak|gka|nay|ewa|mar|nik|ep |e p|aks|ndi|sar|iwa|upa|era|neg|oli|ina|uni| pu| se|h s|pat|ban|lak|h p|rep|os |ran|a k|ali|ngs|aga|sa |ar |e m|ung|atu|arg|n l|usa|sam|ngu|ewe|tat|nip|swa| sw|n t| pi|n d|i n|a u|kat|osa|eda| mu|ena|e k| me|r n|lah|k r|nda|ayo|ida|um |uku|k p|gsa|kew| ba|ras|r p|wen|par|pak|k h|eka| ny|i m|end|ari|yom|gay|kab|uan|pa |gi |kin|kum|huk| hu|n u|h r|war|dik|mal|g t|ta |ti |sti|sap| su|s k|per| in|ntu|pol| po|car|rga|pin|eh |r m|tah|ant|nus|mi |idi|did|rya|ary| pr|ngi|kar|pag|gew|ha |k k|min|uru|ut |tut|ita|eta|dil|oma|ri |ust|mus|ira|g d|sio|gam| ag|as |abi|i p|g h|g r|il |awa|lar',
    'bug': 'na |ng | na|eng| ri|ang|nge|nna|ngn|gng|ge |sen| ma|app| si| ta|nap|ase|a r| pa|ddi|a n|ri |tau|a t|ale|edd|au |ega|ria| ha|ai |hak|len|e n|ias|ak |ga |a a|pun|inn|ing|ass|a s|nai|pa |nin|sin|ppu|ini|are|gen| ru|ngi|upa|g r|una|rup|ana|ye | ye|gi |ama|i h|lal|man|asa|enn|ara|le |i r|ila| de| ke|ssa|g n|ae | as|e a|san|a m|din|a p|di |sed|ane| se|e r|u n|ada|ann|ala|ren|e p| la|da |lan| we|nas|aga|ipa|i a|e s|pan| ad|wed|reg| ar|sal|pad|ole|i n|g a|lai|asi|pas|a k|i s|ung|rip|g s|ena|jam|ola| pe|ran|ppa|e m|i l|akk|gan|ngk|ong|map|ril|aji|ttu|kan|gar|neg| ne|gka|att|g m|ain| ja|nar|ett| e |k r|i p|nan|i t|ra |e d|ban|gag|bas|eba|beb|ata|sib|nen|i m|unn|iba| mo| wa|ebe|keb|uwe|de | te| sa|par|kel|g p| ba|kun|ura|a d|uru|mas|aka|bol| al|u r|ko |we |kol|tu |add|o r|e y| hu|pol| po|mak|deg| at|bbi|ian|elo|kko|ell|auw|nga|cen|iga|nat|g t|dan| di| tu|apa|uku|huk|ro |tte|ma |ngs|atu|leb|iko|sik|ssi|rga|arg|ekk|rel|uan|la |an |ece|pat|gau| to|ele|a w|e w|a y|lu |a b|gsa|sil|rus|ie |ire|ebb|oe |wet|rek|llu|ppi|tun|dec|wa |awa|baw|u w|ten|ter|ka |per|mat|g y|pak| an|lua|sse|pig|dde|nre|anr|ton|olo| ia|caj|nca|ona|nro|onr|sa |tur|k n|e h|u p|bir|lin|a e|eri|mae|e k|si |elu|a l|tam|ru |ntu|ade',
    'knc': 'nzə|ro | a |be |ye | kə|zə |mbe| ka|a k| ha|akk|abe|kki|hak|ndu| nd|a n|a a| ya| la|adə|ben|aye|en |inz|kin|yay|əbe|ji | mb|lan|ma |də |eji|bej|ə a|o a|aro|əla|du |e m|kəl|əna|kən| ba| ga|ga |lar|e a|u y|an |rdə| ad|anz|shi| sh|ard|əga| ku|au | au|e h|n k|a s|uro|wa | na| ye|so |obe| sa|ara|iya|kal|ama| nə| su|amb|n n|in |ənd|ndo|kur|inb|dəg|u a|kam|na | fa| nz|and|ida|ba |ə k|awa|la |nyi|a b| fu|dəb|a l|nəm|sur|e s|aso|ana|gan| ci| ab|a d|tə |a g|kar|dən|uru|a y|baa|ə n|ru | da|wo |əra|ndi|ya | sə|tən|ade|gad|asa|ta |aar|aa |al | as|aya|i k| du|e n| ta|uwu|din| tə|nam|ata|e k|o k|am |a f|o n|təg|i a|əmk|ə s|nba|awu|iga|nga|wu |ala|utu|o w|da |nza|zəg|əli|gin|ima|zən|u k|adi|owu|cid|əwa| wa|san|əgi|laa|awo|de |bem|fut|n a|wan|rad|do |ali|i n|mka|e l|u s|zəb|o s|ayi|wur|n y|ibe|iwa|əgə|za |mar|a t|wal|mər| mə|tu |ndə|azə|wum|fuw|kun|gən|uma| ng|o g|ema|yir|gay|o h|on |tam|kat|ada|lmu|ilm| il|jam| ja|dob| ny|dəw|yaw| ay|ən |hir|i s|liw|ela|bel|how| ho|atə|nat|iro|aid|zəl|ltə|hi |tin|dum|nbe|o t|ə f|irt|rta|n d|kiw|a h| wo|mu |sad|ə h|ədə|taw|lil|dal|sha|n f|iwo|o f|enz|diy|ədi|səd|yi |əny|ang|nab|nya|wob|unz| aw| ra| ji|lam| al|nad|wow|ram|ə y|dar|a i|utə| yi|u n|di |kas|fan|ənz|təb',
    'kng': ' ya|na |ya |a k| na|a y|a m| ku|a n|u y|and|a b| mu|wan| ba| lu|yin|tu |ve |yan| ki|ka | yi|nda| mp|a l|di |ndi|la |ana|ntu|si |so |da |ons|e n|mpe|nso|aka| ke|pe |mun|unt|lu |i y|alu|sal| ma|o m|luv|ta |ina|nza|ke |u m|e y|uve|ndu|ala|u n|i m|za |ban|amb|u k|isa|fwa| ko|to |kon|ayi|ma |du |kim|ulu|o y|kan| me|wa |usa|kus|anz|ama|ang|end| ve|yon|nyo| ny|a v|a d| to|i k|nsi|ins|i n|sa |mos| mo|mbu|e k|und| bi|osi| fw|ika|kuz|len|uti|imp|mab|uka|ata| le|ind|vwa|tin|pwa|mpw|kuk|ba | at|kis|adi|mba|olo|ngu|bu | di|uta|mut|lo |sam| sa|sik|isi|e m|su |ila|ula|e l|mu |usu|abu|nga| nz|lus|yi |yay|ngi|but|o n|ni | nt| ka|dya|kak|dil|esa|amu|ti |imv|o k| bu|bal|e b|wu |awu|kul|ant|gu |ngo|inz|bun|a t|mpa|utu|dis| dy|nka|ank|mvu|kin|u f|iku|ong|uzi|zwa|i l|bim|sad| mb|vuk|dik|uzw|lam|tan|mef|idi|kat|lwa|fun|kuv|ga |ken|bak|ing|luz|baw|bis|yal|uya|luy|bay|nsa|mak|usi|mus|nta|ibu|kub|a a|atu|ufu|uvw|i a|ani|swa|uza| ni|ela|tuk|kol|lak|uso|ola| ns|twa|uko|pam|kut|bam|i s|eng|ku |umb|don|ndo|yak|i t|iti|mbi|eta| nk|iki|gi |uku|a s|luk|sol|nzo|te |nak|oko|mam|tal|efw|pes|dib|u b|ati|gid|uke|nu | nd|umu| vw|ilw|dus|luf|zo |u t|mvw|met|bum| ng|sul|ima|wel|kwe|ukw|zol|yam|ota|kot|lan|zit|i b|i v|kun',
    'ibb': ' nd|ke |e u| mm|ndi| ke|me |de |e n| em|o e|en |nye|mme|owo| en| ow|wo |yen|ene|mi |emi|ye |i e|e e|eny| un|nen|eke|une|edi| ek|e o| uk|et |n n|ne |e i|n e|e m| ed|e k| ye| es|ana|em | id|ede|esi| mb|un |di | nk|iet|kpo|na |ukp|sie|kem|kpu| in|kie|eme|did|ie |idu| nt|nam|am |ndo|o u|o o|mo |o n|mmo|yun|t e|din|dib|kpe| uf|o m|ked|nyu|no |ded|o k|an |on |nkp|e a|du |m e|iny|kpa|po |ho | kp|ade|om |ina|dut|ono| ub|m u|uke|bo |ikp|i o| ki|ini|bet|mbe|ida|t m|ode|in |oho|wem|uwe| uw|bio|ut | ot|ru |uru|pur|uto|ni |i m|do |fen|omo|dom|u u|ok | us|to |dik|iso| ut|mde|tom|ibo| is|n i|ri |o i|oki|mok|edu|ide| et|a n| on| ak|diy|ak |nek|a e|n o|i u|man|u o|puk|akp|pan|idi|m n| ob|ara| or|a m|op |a k|t k| ny|ema| as|io |kar|pon|nwa| ik|oto|boh|ubo|n k|ufo| an|i k|m k|k n|pem|uka|o a|i n|uk |ed |wed|nwe| nw|usu|uan|te |mad|ti |e y|a u|asa| mi|obi| ef|n m|m m|dud|sun|n y|ka |o y| ey|t i|ro |oro|ond| of|ra |aba|tod|fin|re |nte|nde|ko |efe| ab|k u|dis|n u| eb|ony|pa |nti|pe |med|da |ndu|mbo|eye|dem|aha|ban|ena|nka|san|i a|sop|ibi|sin|ion|eko|se |he |ruk|oru|eto|sua|d e|odu| od|a o|mba|ama|fok|iok|a a|anw|mek|so |ufe|m o|kon|k m|ha | se|si |asi|bas|ufi|ito|dit|ere|ike|son|ori|pep|fon|u n|a y|bon',
    'lug': 'a o| ok| mu|wa |oku|nga|mu |ga | ob|a e|tu |ntu|bwa|na |a a|ba |ang|ra |a m| ng|wan|aba| n |a n|li |oba|a k|unt|la | ab|era|a b|ibw|mun|u n|ka |ali|tee|ate|i m|uli|bul|obu|eek|u a| bu|dde|za | ku|ana|ban|sa |edd|ala| eb|mbe|iri|ye |gwa|emb|omu| om| ek|u b|ant|ira|e o|n o|be |amu| en|eki|kwa| er|dem| ed| ki|nna|okw|ama|kuk|eer| ye|eri|kus| ba|ggw|kol| wa| em|usa|ula| am|inz| ly|eka|any|ola|i e|ina|kwe|o e| eg| ky|ekw|u m|mus| bw|kir|ere|ebi|u e|ri |n e|uyi|a y|y o|a l|onn|uso|u k|ger|e e|bal|egg|o o|mat|zib|izi|aan| at|awa|no |ko |yo |bwe|yin|kul|bir|zes|wal|aga|nge|ako|gan|ebw|nza|lin|esa|e m|oze| ma|riz| te|nyi|kut|ya |ufu|kub|sin|we |ngi|obo|kan|nka|yen|eby|y e|gir|eta|una|aka|lye|tuu|wo |bee|u o|ku |i y|ino|kin|e b|a w|isa|o b|sob|zi |e n|wam|imu|e l|uku|bon|de |san| by|ata|wat|iko|kuy| ag|boz| al|ngo|lwa|umu|ulu|utu|uki|ewa|taa|o n|ong|si |nsi|by |e k|muk|usi|rwa|ne |i o|i n|enk|bye|rir|ma |kug|mbi|iza|lal|uko|kis|enn| og|ole|kye|a g|asa|add|ani|nya|sib|ens|ni |ini|uka|i k| aw|uga|gi |yam|n a|tab|uma|umb|kyo|wen|uwa|bib|wee|ing|a z| ey|ze |emu|ete| et|tew|a t|yiz|mul|awo|u g|nzi| kw|tal|o a|o k|fun|afu|and|i b|ibi|ung|ro |amb|igi|aku|saa|baa|nyu|yig|ayi|gya|wet|kik|go |a s|ti ',
    'ace': 'an |ng |eun| ha|ang|oe |peu|ak |on |ngo|gon|ah |nya| ta|na | ny|ung| ng|reu|yan| na| pe|ure|meu|roe| ke|eut|hak|keu| me| ba| ur|at |teu|ee |han|a h|dro|ban| di|ara| be|ata|g n|iep|tie|am |eur| sa|nan|jeu|ut |n n|ep |eug|tap|seu| la| te| ti|uga|e n|euk| da|ala| at|a n|eba|beb|awa|ong|ra |tan|n t|eum|eh |n b|p u|ih | se|nda|h n|a t|a b|h t|ape|eu | pi|oh |eub|e p|lam|e t|ai | ma|um | si|dan|eul|asa|t n|und|neu|ana|n p| wa|n a|bah|lah|and|lan|wa |euh|n k|nyo|n h|eus|ula| bu|k t| je| dr|anj| pa|ma |g s|n m|h p|eng|nga|ran|n d|om |hai|a s|yoe|e b|mas|san|ngg| ra|ta |beu|g d|nje|taw|uka|ek |a k|una|a m|ura|yar|sya|gan|soe|n s| li|sid|ya |sab|aka|k n|ka |dum|ndu|har|ot |di |idr|aya| ka|kat|e u|e d|ok |a p|bat|aba|euj|gah|adi|lak|pat|et |n j| ja|kom|uko|kan|en |asi|ari|t t|aan|un |h d|sa |ame|ate|ama|sia|oih|usa|h h|g k|i n|sal|ila|bue|dee|lin|h b|ieh|g p|bak|aja|huk|ade|k m|dip| in|lee|uny|uh |rak|dar|uta| so|gar| ne|nto|ant|rat|uja|h s|aro| le|g h|nta|ep‐|ina|k a|uma|t b| ji|don|gro| hu|k h|ile|t h|t s|ngs|gam|aga| ag|m p|n l|heu|e s|ahe|a l|ane|e a|ggr|‐ti|p‐t|g b|ue |toe|jam|oe‐|eud|k k|ngk|ika|ino|ute|ie |wah|ham|n u|taa|yat|k b|tam|sam|a d|ia |man|use|t l|uk | an|aso|ga |g m| ya|ri ',
    'bam': ' ka|ka |ni |a k|an | ni|kan| bɛ| la|i k|la |ya |n k|ye | ye|ɔgɔ|na |li |ɛɛ |bɛɛ|ɛ k|ali| ma| i |man|sir|ra | da|en |ama|gɔ |wal| wa|ira|n n| kɛ|mɔg| ja|a n|a b| mi|ma |a d|ana| mɔ| ba|’i |ɔrɔ|min| o |iya| si| sa|in |ara| na| kɔ|i m|i j|dan| k’|i d|a s|len| jo|bɛ |jam|a m|ɛrɛ|i n| n’|a l|a y|kɔn| fɛ|kɛ | tɛ|iri|ari|’a |aw |ɛ s|a i|ɔnɔ|i t|ɛ b|n b|ani| an|riy|sar|ɛ m|tɛ |rɔ |ko |a w|i b|si |asi|a t|k’i|ɛn |o j|a f|a j| fa|den|aya|nɔ |n y|i s|ale| de|ang|aar|baa|ila|ala|kal| di|inn|tig|o b|ɛ j|ɲa |i f|olo|nu |nnu|osi|jos|raw|kun|ati|e k|w n|ɛ n|aga| se|ɔ m|nɛ |inɛ|nti| ta|lan|bɔ |i y|ɔ b|don|ga |ugu|a a|fɛn|da | jɛ|igɛ|ɔn |ɲɔg| ɲɔ|nɲa|u k|ada|bil|abi|rɛ |n’i|o l|ɔ k| fo| a | ti|aba|nw |jo |n i|a ɲ|go |ɔ s|iɲɛ|o m|yɔr|n o|n’a|ri |hɔr|i h|gɔn|afa|kab|un | ko|i l|aka|lak|on |e m|igi|a o| bɔ|o f| sɔ|n f| fi|ant| hɔ| cɛ|ɛ l|dam| ha|aay|maa|fur| fu| ku| tɔ|ti |ile|gu |mɛn|riw|e b|’o |e f|iwa|ɛ y|uya|nna|n m| do|ago|nga|kar|nka| du|o k|ɲɛ |n w| jɔ|iir|n d|fan|oma|lom|wol|nin|n j|cɛ |u b|ili|a h|nen|ɲɛn|ade|ɛɛr|u d|nba|ru |uru|tɔn|ɛku|jɛ |dil|gan|i i|sug| su|w l|ɛmɛ|w k|uma|ew |fɛ |aju|ɔ o|diɲ|ɛ i|ɔ n|sɔr|isi|ɛya|ank| t’|ɔnɲ|rɔn|i ɲ|wa | b’|taa|anb|mad|had|lu |yir| yi|amu|aam|lad|ɛna| ɲɛ|sag',
    'tzm': 'en | ye| d |an | n |ur | s |ad | ad|ḥe|lḥ| lh| gh|agh|n i| i |̣eq|d y|n t|eqq| ta|ett|qq |s l|dan| is|gh |la |hur|ell|ra |d t|r s|ghu|is | na| am|nag|i t|mda|ll |n g|a y|yet|t i| te| ti|di |n a|l a| di|akk|in |ara|a d|n d| ar|ma |ghe|n l|ull|it |edd|dd |kul| ku|amd| ur| id| wa| we| ma|a n|q a|li |rt | yi| ak|d a|as |a t|lla|men|es |d i|a i| le|sen|lli|lel|a a|n s|t t|ar |na |n n|eg | tm|n y| dd|tta|t a| as|r a|ken|kw |kkw|twa|i w|n u|d u|deg|mur|t n| tu|s d| ag|at |wen|gar|i l|win|ttu|wak|n w| tl| de|s t|ḍe|i n|hel|d l|tam| se|rfa|wan|w d|urt|er |h d|iya|gi |sse|yes|erf|zer| tt| ik|ddu|q i|ḥu| in|tle|nt |hed|r i|wa |arw|mga|idd|sef|fan|ize|n m| im|ya |udd|ttw|i u|uḥ|mad|tim|s n|i d|emd|wem|tmu|ef |ame|rwa|i g|̣en|iḍ|ddi|iḥ|ili|ess| u |el |t d|awa|msa|lan|a l|kke|tte|ikh|em |wad|way|̣ud|s y|mma|s k|i i|ant| ya|siy|̣ṛ|un |agi|dda|til|khe|med|tes|ana|taw|l n|d n|chu|all|yek|am |g w|aḥ|r d| iz| ne|nun|anu|qan|lqa| lq|t l|iwi| ss|den|gha|ert|der|nes|man|tag|s u|hwa|ehw|yeh|ala|ila|lna|eln| la|ṛr|ray|ṣe|yed|iwe|n k| lâ|yen|ile| il|ha |ski|esk|lt |hul|ekh|del|i a|kra| kr|yn |ayn|a s|h a|ir |ezm|net|eḥ|awi|ki |u a|leq|fel| fe|ssi|use|ine|il |r t|tem|edm|hef|ail|aw |naw|yas|asi',
    'kmb': 'a k|la | ku|ya |ala| mu| ki|a m|kal| o |u k|o k|ni | ni| ky|mu | dy|dya|a o|lu |ang| ya|tok|kya|nga|na |so |oso|a n|oka|nge|mba|i k|a d|kut|xi | wa|kwa| ka|mut|hu |elu|thu|ba |uth| kw|uka|gel|ka |a i|wal|wa |uto|ene|ban|ga |i m|kuk|ku | mb|e k|u m|ne |ana|kik|u n|a y|ngu|iji| ng|u y|ela|u w|i y|ixi| mw|kit|kel|ye |ika|wen|isa|nda|ji |oke|u i| ji|ena|and|und|kil|ilu|ung|ke |iba|ila|aka|a w|o w|yos|ten|kus|ulu|kub|e m|ta |alu|sa |oxi|mox|amb|olo|kum|gu |wos| wo|wat|ate|muk|gan|lo |tun|du |ndu| it|mwe|kan|san|kis|ita|o m|luk|imo|ong| ph|kye|a t|i d| ye|di |ato|nji|kij|sok|idi| ix|u d|kud|u u|ula|tes|we |e o| ke|a s|o i| di|uku|da |udi|ma |lun|lak|eng|ele|wij|yat| we|nu |wan|uba|e n|hal|pha| se|e y|yen|kib|a j|uke|ki |o n| yo|ito|itu|a u|i n|jin|kwe| im|lon|u o|uta|su |i w|ja | ja|utu|kat|iki|fol|ute| ut|kul|i u| en|kim|adi|ikw|tal|esa|nde|dal|yan|ngo|fun| ko|jil|eny|i o|uki|nen| ik|umu|lel|atu| uf|ing|uso|vwa|o y|esu|u j|ge |ufu|lan|o d|nyo|jya|uma|i j|jix|ukw|usa|unj|ite|o a|kuz|sak|dib|kyo|mun| os|mbo|imb|go |kos|u p|ijy| ib| tu|te |i i| a |han|xil|exi| il|kam|dit| un|a a|ilo|gam|kwi|tul|ivw|ubu|lul|a p| so|iku|uni|se |oko|o o|mwi|ote| to|kex| uk| bh|ufo|e a|ind|bul|sen|inu|ngh|kiv',
    'lun': 'ng | mu|la | ku|a k|di |aku|tu |chi|g a| a |ntu|mun|ma | ch|a n|unt|a m|ndi|ela| we| na|aka|ima|ind|jim|eji| ni|i m| in|u w|a i|wu |i k|a w|shi|awu|hi |lon|u m|wej|sha|ing|kul|wa |nak|i n|ala| ja|na |ung| kw|muk|ulo|kum|ka |a c|hak|cha|iku|ewa|wen|a h| wa|g o|u j|kut| ha|ana|vu |ovu| ov|yi |idi|u c|him|nik|ong|adi|mbi|kwa|jak|kuk| an|ang|tun|bi |nsh|tel|ha |esh|amu|han|kus|kwi|ate|ila| he|uch|ula|imb|ilu|a a|kew|enk|uku|mu |u a|hin|a y|zat|nke|u n|kal|hel|ond|i a|ham|eka|eng|mwi|a d|itu|and|del|nde|wak|ins|nin|i c| ya|ona|mon|ina|nji|i h|ach| yi|ama| ak|nat| mw|nyi|kin|umo|lu |ata|uma|sak|ku |udi|ta |ati|uza|kuz|mul|wes|ich|i y|awa|u k|uta|muc|i j|wal|uka|kuy|uke|wit| di|yid|naw|kam|bul|ayi|wan| ko|i i|kad|waw|akw|ni |ken|ji |uki|iha|dik|u y|g e|ush|mbu|si |osi|kos|ahi|ika|ish|kud|ash|twe|atw|any|dil|hih| ye|da |eni|kwe|wil|imu|dim|li |ya |kun|yin|g i|nan|yan|win|iwa|din|tam|etu|ant|amb|mwe|his|nda|hik|til|ule|umu|was|inj|jin|hu |nam|mpi|iki|wah|hiw|kuh|jil| da|eyi|ney| ne|isa|hid|usa|jaw|wat|wun|tan|umb| ma|uya|una|end|lun|pin| ji|ahu|nka|omw| om| ny| i |hen|che|yej|wik|u h|eta|tal|kuc|ulu|sem|wet|fwe|twa|utw|uyi| hi|iji|iwu|mpe|omp|ilo|yil|nic| en|a e|iyi| at|haw|lek|mba|emb| ew',
    'war': 'an |nga|ga | ng| pa| ha| ka|han|pag| hi|in | ma| an|ata|mga|hin| mg|kat|ay |ya |a m|a p|gan|on |da |n n|n h|ug |n p|n k|ung| ug|iya|a h|a k|ha |n i|adu|n m|dun|tad|ada| iy|sa | o |ara|may|a n| ta| di|a t|n a| na|y k|o h|pan|kad|tag|n u|yon|ags|ud |o n|ang|al |a s|ana|gsa|gad|a u|o p|man|syo|asa|ala| ba|ag | in|a i|g h|n b|agp|asy|awo|ray|war| wa|to |a d|wo |a a|usa| us|g a|nas|ina|was|taw|nal|ing|gpa|ali|iri|dir|agt|i h|ra |ng |aha|ri |bal|san|ad |kas|aka|g p|o a|a b|ida|awa|hat|no |g m|ini|uga|ahi|y h|o m|tan|ili| bu|uha|buh|gka|agi|bah|aba|i n| su|tal|him|at |pin| pi|hiy|kan|int|mo |n t|did|a o|aya|sya| ko| tu|nah|nan|iba| bi|n o|od |agb|la |kon|lwa|alw|gba|aho|tra|uro|o u|l n|ona|yo |ho |pam|o k|agk|ano|d a|sud|asu|gin|ngo|ni | la|hi |as |rab|uma|ton|os |par| sa|sal|ati|ko |iko|upa|lin|ami|gar|ban|n d|ern|gi |aag|abu|a g|kal|d h|aga|yan|n e|yal|d m|gtu|ak |mil|rin|ba |lip|mah|aud|lau|ka | so| ig|lig|ama| ki|ihi|tik|ras|aso|mag|gud|g i|tun|g k|duk|osy|sos|kau|uka| un|hon|n s| pu| ib|ro |imo|tub|mak|pak|ila|n w|yer|bye|ent|ito|ika|amo|it |sug|n g|dad|ira|edu| ed|tum|aup|ngb|til|non|anu|pod|upo|sak|sam|ari| pr|agh|alu|ato|ta |nta|gon|lik|bli|s h|d i|k h|uyo|ig |uli|bul|dto|adt|isa',
    'dyu': 'a’ | ká| kà|ye | ye|kà | à |ni |án |la | bɛ|kán| la|ya’| ni|ɔgɔ| i |ká |ya |mɔg| mɔ|a k|á k|bɛɛ|ɛɛ |na |ɔrɔ|n k| mí|’ y|mín|ín |’ k| be|’ l| kɛ|be | ya|ma |à k|i y|’ m| wá|te |n n| jà| te|nya|ɛ k|a b|i’ |wál|ɛrɛ|áli|ima| ní|àma| ò |ra |jàm| mà|e k|ɔ’ |lim|gɔ |ní |n’ |ɛn | kɔ|iya|à à|e b| lá|o’ |rɔ |à l| há|e à| sà|rɛ |ana|man|n b|ɛ y|i k|à m|kɛ |li’|à b|ɔnɔ|kɔn|hák|e s| dí|gbɛ| bá|n y|ara|’ s|mà | bɔ|’ n| kó|bɛn| sɔ|riy|a m|nɔ |aw |’ b|sàr|à y|a j| sí| fà|ɔ k|e m|à s|yɛr| yɛ| fɛ| gb|gɔ’|n m|báa| tá|sɔr|àni|àri|na’|e w|yɔr|i m|kɛr|ákɛ| là|áar| sì|dí |à i|ɔ s|’ t|ali|en | cɛ|a s|bɔ |an’| dà|a n|yaw|ólo|’ f| sé|ána|ógo|a f|a d| ó |w n|a y|ɔn |lá |dén|ìgi|sìg|à t|i à|à d|si |ɛ l|se | se| àn|’ d| a | ɲá| tɔ|cóg| có|sí |i b|bɛr|a t|àra| má|ɛya|ra’|lan|kàl|á d|e i|i t|ɔ à|nga|àng|aya|li |a à|ɛra|ɛ’ |à n|fɛn|ko | dɔ|gɔn|tá |í i|àla| na| dò|so’|n s|a w|u’ |rɔ’|a g|ina|kan|nin|a h| í |kó | ù |e ò|ili|ɔ b|kɛy|e n|den|ama|fúr| fú|i n|w l|úny|dún| dú|ma’|òn |dòn|i l|ga |nna|go |ò k|i s|í y|e’ |len|kél| ké|í t|ɔny| nà|i f|ɛnn|dàn| lɔ|dɔ |tig|áki|hɔr| wó|ɲɔg| ɲɔ| dé|la’|úru|ow |i ɲ| fá|kùn| kù|e d|ɛ t| yɔ|jɔn|ìna|mìn| mì|ɲán|a c|e j|in |a i|éle|ból|àga|íin|díi|ɛ n|ika|lik|igɛ|n d|í à|ò l|gi |kil',
    'wol': 'am | ci|ci | sa|sañ|añ | na|it | ak| am| mb|lu |ak |aa |ñ s|mu |na |m n|ne | ko|al | ku|baa|mba|te | mu|ko | wa|a s|ñu | ni|u n| te| ne|nit|u a|e a| lu|t k|i a|oo |u m|ar |ku |ay | it|pp |u k|gu | do|u y|éew|rée| ré|war| ta| ñu|i w| bu|xal|llu|épp|oom| li|u c|on | xa|ul |àll|wàl| wà|loo| yo| di|kk | ya| aa|u d| gu|yoo|oon|i d|i b|mën| më|fee|doo|bu |nn | bo|ew |e m|o c|r n| xe|eex|i m|boo| yi|nam|aay|m a| nj|ara| du|ju |xee|yu |en |een|naa|uy |ana|enn|aar|aju| bi|taa|ama|igg|oot| lé|yi | pa|di | aj|ti |ën |okk|k s|taw|lig|gée|ral|ee |u l|i l|m m|und|dun| de|li |u j|n w|an |w m|ala| me|eet| se|axa|ata| ba| so|n t|a a| dë|m c|yam|mi |éey|ggé|ota| gi|ir |ewa| an|a m|aam| ja| ke|ngu|om | su|a d|see|amu| ay|ax |ex |wfe|awf|dam| mi| ng|ey |p l|i n|o n|u t|a n|ool|jaa|ken|une| ye|la |n m|k l|kan|a l|et | yu|bok|mbo|u x|i t|àng|jàn| së|k i|nee|i j|e b|men|ok |em |ndi|i k|ñ ñ| lo|m g|nda|ñoo|kun|opp|ali| ti|laa|j a|l x|n n|lee|nd | da|ada|aad|are|njà|eem|y d| fe| jo|y a|lép|tee|aw |l c|wam|k c|n a|l l|nja|ëng|le |a b| mo|aan| fa|e n|m r|oxa|dox|n c|l a|ska|ask| as|aat|a c|mul|l b|aax|u s|y t|eg | jë|k n|ng |g m|gi |gir|k t|ëy |sëy|ëra|góo|kku|uñu| bé|tax|ba |e s|m s|i r|i c|k b|añu|t a|u w',
    'nds': 'en |at |un | da|n d| de|een|dat| un|de |t d| ee| he|cht|n s|n e|sch|ht |er |ech| wa|rec|tt | si| to|vun| vu|ett|ten| re| ge|n h|ver|nne|k u|elk| el|t w|ien|lk |sie|to |het|gen|n u|t u|n w|orr| an|n v|r d| in| ve|ch |war|ann| or|ör |t r|rn | fö|it |rer|ner|för| st|rre|den|t g|n f|up | up|eit|t a|t e|rie| fr|aar|nd |ich| sc|chu|wat|n g|fri|nn |ege|on |oon|rrn|daa|t h| bi|is | is|rt |ell| se|hte|len|n o|n k| ma|kee|in |ik |lt |e s| mi|n i|aat| we| na|ven|hei|t s|t t|hn |lle|n t|n m| dr|ok | ok|doo|ers| ke|se |lie| sü|nsc|ken|n a|arr|sta|ünn|gel|r s|ren|rd |che|ll |ill|he |e a|nen|ene|men|ie |ins|ahn| gr| wi|ede|kt |öff|röf|drö|raa|sik|llt|n b|an |kan|ard|und|e g|gru|dee|ff |s d|sse|sün|all| ka|run| dö|eke|st | do|ere| ün|ehe|ebb|heb| gl|min|e e|ens|taa|rch|örc|dör|ig |nee|maa| so|al |aal|cho|tsc|e f|ieh|e v|t v|ünd|iet|t m|enn|p s|el |hör| wo|t o|t n| fa|iht|eih|hen| al| ar|bei|rbe|arb|pp |upp|hup|e w|ehr| eh|utt| be| ut|na |inn|nre|lan|nst|ats|huu|as |weg|t f|e r|öve|eel|et | ni|mut| mu|pen|t b|a d|wen|ul |uul|e d| ah|str|eve|lic|ert|aak|hee|t k|ste|erk|üss|düs| dü|t i|der|iek|e m|mit|d d|nic|ent|gt |anr|set| as|aaf|tra|art|oot|r t| eg|ach|t l|l s|ter|akt|and|ame|hon|nat|n ü|r e|ite',
    'fuf': ' e | ka| ha|ndi|al |de |di |and| no|han|no | ma|o h|nde|e d|aa |e n|dyi|he |i e|un |a n|ala|dhi|yi |la |gol|re |dho|ka |eed|ho | wo|kal| dy|maa|dhe|o k| bh| ne|ko |ann|ni |hi | dh|bhe| nd|edd|won|ol |e e|ddh| mu|haa|ned|mun|e m| le| sa|i m| go|nnd|taa|aan|e h| fo|ede|eyd|ley|dan|e k|gal|aad|ii |i k|o n|sar|ond| fa|en |dya| ko|e b|tta|a k| he|ow |ana|uud|adh|iya|riy|yaa|bha|aak|ani|ett|het|ngu|aar|ydi|ari|i d|e f|i n|tal|le |ral|ira|ita|oni|ya |oo |na |nga|goo|dir|ndh|nda|ee |ydh| ta|e l|are|e g|ina|n n| wa|faa|fow| hu|i w| fi|akk|naa|ree|e w|udh|yan|ugo|i h|to |oto|nan| ng|oot|dyo|udy|oll|ore|fii|kko|mak|e s| da|a d|l m|on |dhu|dii|iid|ude|aam|i f|a e|o f|ady|den|n m|yee| on|e t|laa| la| na|l d|e a|idy|l n|l e|fot|ke |awt|lle|oor|in |o e| do|ubh|n k|a h|a b|a o|tan| ya|yng|att| ho|an |ake|nya|hen|a l|ewa|hun|i s|i t|mo |amu|te |n e|huu|taw|tor| o | ad|lli|onn|bon| bo|dee|bhu| an|ere|hoo|n h| ny|woo|iin|o w| mo|ku |er |der|ota|n f|dha|ant|l h|wti|tin| ke|tit|l l|yam|o b|aal|l s|a f|guu|ell|edy| se|und|n d| ga|ago|a t|eyn| ku|l g|gur|ama|a w|a m|oon|ndu|rew|waa|u m|nee|mu |tii|ri |nta|hin|wal|kaw|bhi| de|tug|dud|ure|uur|hey| fe|wad|do | si|too|o s|ing| te|tay|eta|o t|adu|ang|rda|urd',
    'vmw': 'tth|la |thu|a e|na |a m|ana|we |hu |kha| mu|a o|awe|ela|wa | ed|to |ire|ala|hal|dir|edi|ito|eit|rei|ni |mut|aan| wa|a w|u o|akh| on|a n|haa|ya | ni|o y|a a| yo|wak|utt|nla| ot| oh|iwa|ka |okh|att|oha| n’|the|oth|mwa|mul|ari|ne | si|iya|aku|apo|lap|unl|kun|aka| el| wi|tha|ott| ok|ha |oni|e m|e a| at|ale|le | sa|e n| va|ene|ihi| aw|owa|o o|ett|e s|ele|hen|hav|oot|lel|ta |moo|ula|amu|iha| kh| en|e o|han|o n| ak|o a|ota| mo|i a|e w|po | mw|row|nro|ara|’we|anl|i m|e e|de |ade|aya|a s|waw|ihe|ra |hel|eli|dad|a i|o s|ina|vo |a’w|nak| ah|lan|i e|i o|ika|sin| et|wi |eri|n’a|onr| ya|ri |var|ona|liw|hiy|nna|aa |wal|u a|a v|kan|oli| so|ko |huk|her|hiw|riw|avo|u e|wan|thi|aha|kel| an|eko|tek|hwa|sa |yot|itt|e k|uku|laa|riy|una|hun|ntt|yar|khw|ane|ath|pon|e y|o e|iwe|lei|ali|kho|wih| ep|n’e| es|ida|ani| a |nih|n’h|vih|avi|him|ei |lo | ma|aki|kum|i n|i w|nkh|uth| nn|a y|ahi|ile|rda|erd|ber|ibe|lib|i v|ia |ute|ole| it|som|i s|yok| na|ola|nuw|nnu| eh| yi|va |mih|saa|lih|hop|’at|man|hik|a k|ikh|iri|nin|mu |elo|’el|yaw|tte|mur|ont|ila|lik|hol|u s|uma|ma |uwi|inn|ehi|u y|nal|kin|saw|enk|in’|nan| wo|tti|ena|mak| ek|pel|ope|oma|sik|epo|ulu|ro |ira|wir|nli|pwe|mpw|emp|lem|sil|pot|tel| oo|iko|esi|n’o|era',
    'ewe': 'me |le |ame|e a|wo |kpɔ|ƒe | am| si|ɖe | me| wo| le|si |sia|e d|aɖe|esi|be |pɔ |e l|la |e w| ɖe| la| ƒe| kp|na |e e| mɔ| du| be|a a| aɖ|nye| dz|e s| ŋu|ukɔ|duk| na|e n|ome|ye |dzi|e m|kpl|e b|nya|ɔkp|pɔk|ɔ a|ple|ke |ɔ l|ɔnu|woa| o |iwo| nu|ɔ m| al|evi|u a|awo|mes|ɖek|nu |ŋu |o a|ɔwɔ|e ɖ|nɔ |ekp|gbe|mɔn|kɔ |ɔme|eƒe|eke|lo |alo| eƒ|i n| ny|o n|o m|ya |dze| ab|ia |e ŋ|e k|siw|iam|o d|ubu|bub| bu|o k|zi |ukp|li |a m|wɔ |nuk|mek| ha|i s|kpe|e ƒ|eny|any|ɔ s| go|e g| li|mev|ŋut|eme|akp|ã |anɔ|gom| ey|blɔ|dɔw|mɔ | wò|enɔ|tso|iny|ɔɖe|bɔ |oma|ɔna|a k| ta|e t|to |nɔn| gb|iaɖ|ɖes|ɔe |bu |egb|a s|vi | ƒo| dɔ| he| to|a ƒ|o e|ɖo | ɖo|ele|wɔw|awɔ|i l| an|lɔɖ|abl|ƒom|e h|i w|a n|wɔn|i d|ene|oto|yen|ɔ ɖ|meg|i a|ɔ ƒ|xɔ |ti | ts|afi|wom|agb| ag|nan|so |uwo|o g|ɔnɔ| vo|eɖo|tɔ |a l|etɔ| at|o ƒ| ad|ee |se | se|ne | xɔ|gbɔ|uti| ma|ovo|vov|vin|ɔwo|wòa|i b|i t|a ŋ|a d| af|ats|eŋu|e x|ɖok|o l| ne|ado|e v|de |ɔ b|ta |eye| ka|gɔm| gɔ|te |a e|ben| es|ana|a t|i ɖ|rɔ̃|mee|o t| ak|ewo|ɔ k|sɔ |i o|ɔ e|i m|ema|ded|ẽ |man| el|yi |ɖev|ata|odz|eɖe|u s|kɔm|ate|da | xe|axɔ| en| aw|edz|ui |buw|heh|uny|peɖ|o s|ze |i e| sɔ|bet|a g|udɔ|ehe|ada|o ŋ|o h|abe|he |o w|tsɔ|u ɖ|ku |isi|kui|oku|ɔ n| ke|ma |e o| tɔ|men|ade|dzɔ|oɖo',
    'slv': ' pr|in |rav| in|do |pra|ti |avi|anj| do|nje|vic|je |o d|no |li |ih |a p|ega| vs|o i|ost| za|ne | po|ga |ja | dr|co |ico|ako|vsa| v |kdo|sak| ka|ali|ima| im|e s|sti| na|van|i s| ne|akd|svo| sv| al|nja|nih|ma |pri|i d|stv|nos|o p|dru|i p|o s|pre|e n|jo | iz|red|iti| de|i i|neg|o v|ki |avn|vo |ni |em |i v|oli|a v|a i| so| nj|jan|obo|vob|ova|na | ki|ati| bi| ob|ko |ego|i z|tva|gov|rža|drž|i n|kol|i k|e v|kak| ra|bod|se |eva|ruž|jeg|e i|vlj| sk|žen| mo|e p|sto|nak|ena| se|del|n p|ter|žav|jem|kon|sme|a d|voj|lja| ni|enj|pol| en|ovo| te| ta|va |imi|zak| st|bit| sm|var|a n|i o| z |mi |ve |kat|di |pos|lov|nsk|me |krš|aro| sp|o k|n s|en | je|tvo|odn|vat|ate|a z|vol|ri |ed |ju |sta|a s| va|ji |sam|a k|o a| s |ene|uži|rug|ora|mor|jen|ans|elo|avl|itv|e m|eja|dej|rst|vne|nan|ove|e b| me|lje|ršn|akr|nar|čin|živ|čen|i m|o z|so |eni|rod|pno|za |oln|dol|h i|olj|tak|ars|nju|ebn|mu |o o|ičn|cij|aci|šči|h p|vič| ve|raz|nst|ajo|ode|kup|sku|e d|v n|u s|otr|nim|jav|šne|vi |vni|rim|kaz|ta |ovi|ski|n n|če |ose|v s|o t|da |ev |nik|rem| ko|ara|n d|bra|e o|ijo|si |i u|ra |žev|raž|vez|dov|ons|zni|obr| ja| sa|ljn|elj|dst|dis|bre|i b|m v|zna|sod|nem|šni|ina|an |seb|pro|ere|oji|mej|amo|skr| bo|edn|med|iko|ust|mož',
    'ayr': 'apa|nak| ja|aka|ata| ma|aki|asi|aña|ana|aqe|ñap|cha|aw |mar|ti |jha|iw |paw|pat|spa|ark|tak|ama| ch|ani| ta|una|jh |hat|kap|kan|a j|jaq|rka| uk|a m|aru|ki |kis|jan|taq| ar|pa |qe | wa|na |a a|niw|may|kas|iti|ach|i j| kh|ayn|ina|pan| mu| ya|ati|a u|yni|ha | am|amp|w k|as |uka|iña|sa |mun|at |hit|isp|t a|is |ch |ka |khi|ñan|e m|an |isi|oqa|ru |asp|siñ|ejh|ta |qha|kam|h a|ajh|pjh|atä| uñ|han|mpi|sis|sti| in|ita|qen|ham|ñat|äña|täñ|sin|rus| sa|ma |iri|ara|sit|yas|ñja|ska| ut|yat| ku|arj|qat|tis|tap|kha|pas| ji|ura|uñj|jam|a y|nin|nch|kañ| ju|hañ|ukh|nañ|kat|qas|i t|noq|rjh|lir|ili|ña |kun|tas| ka|ans|tha|kak|utj|w m|aya|pi | as|i u|nka|us |aqa|kiw|a t|has|jil| lu|tat|sna|tan|tay|w u|ino|i m|in |w j|rak|s a|apj|jas|nsa|asn|pis|i a|mas|wak| ay|w t|i c|njh|ipa| a |s j|s m|chi|kaj|sip|rañ|lur|mp |tañ|a k|uki|rin|upa|iru|hac|ena|uya|muy|amu|wa |a i|llu|yll|ayl|api|hap|nip|ak |aqh|yaq|n m|a c|tja|eqa|uch|ayk|isa|ank|asa|sap|k a|anq|awa|s u|lan|h j|pam|i y| pa|ask|h u|a w|ap |juc|anc|run|nap|ri |ali|auk|inc|nir| aj|tir|ast|ink|anj|isk|kar|jac|ist|ni |usk|khu|yan|mat|a s| ap|pka|en |ñas|sir|qer|i k|kit|heq|che|mä | mä|s k|e j|yt |ayt|way|qañ|naq|nas|n j|sar|war|s w|s c|ika|hik|a l|t u|hus|h k',
    'bem': ' uk|uku|la |wa |a i|kwa|a u|ali|ta | mu|a n| na|ya |amb| ya| in|ata|sam|shi|ula|nsa|nga|ang| ku|bu |mbu|wat|se |nse| pa|ins|ons|kul| ba|li | no|aku|lo |ngu|nan|a m|gu | al|ala|mo |a a|fya|a k|ntu|yak| ca|ikw|ing|u u|lik|na |e a|ili|alo|nok| on|u y| um|tu |a p|ga |o n|mu |lwa|lin|sha|i n|ka |ila| ci|ku |uli|oku|ika|and|ulu|ukw|ana|kup|akw|ko |ama|we |cal|a c|amo|umu|aka|a b|aba|kus|lil|o u|cit|kan|yal|mbi|ndu|mul|pa |o a|ish|le |ile|o b|hi |u m|bal|kub|u c|kal|u a|uci|ba |ne |unt|e u|any|ton|kwe| sh|po |ha |yo |bul| fi| if|nsh| ab|du |kuc| fy|e n|abu|ung|u n|cil|nka| ne|kum|a l|fwa|o c|lan|o i|i u|a f|kut| am|und|ush|nda|kuk|afw|no |gan|pan|upo|a o|win|aya|ale|bi | ta|ify|utu| ng| ka|tun| bu|int|wil|fwi|u b|pam|lam|apo|way|ako| ic|bil|ans|uko|apa|wab|mun|ma |nya|cin|ban|tan|wal|ela|o y|ine| af|imi|lul|kap|ngw| li|ubu|e b|mas|nta| ma|ilw|ti |iti|gil|ngi|eka|imb| im|twa|e k|uma|umw|i k|tul|pat| ak|gwa|u k|ita|onk|ant|bom|usa|a s|but|eng|e p|iwa|umo|ici|o f|afu|sa |da |atu| ns| is| wa|mut|o m|nto|ont|uka|baf|ilo|min|mba|kuf|ini|u s|pok|ye |ily|men|kwi|hiw|pal|ind|ute|cak|mak|tak| at|ash|u i|lel|ina|alw|lu |asa|asu|kat|o o|aik|ubo|suk|ule|ufy|upe|e i|til|lya|pak|nam|mwi|efw|lef|ate|tek',
    'emk': ' ka|a k|ka | a |an |la | la| ma|kan|na |a l|a a|n k|ya |ni |ama|a m|ma |ɛɛ | di|lu | ja| bɛ|ana|aka|man|di |a b|bɛɛ|iya|dɔ |a d|ara|jam| si|a s|mɔɔ| mɔ| sa| dɔ|en |ɔɔ | tɛ|alu|i s|da |tɛ |sar|den|a j|riy|ila| ye|ani| kɛ| i |i a|ye |ari| ni|n d|kak|ɛ k|ɛn |a t| ba| al|i d|ra |nna|len|ɲa |aar|n m| se| bo|olo|ɔn |sil|ele|ɔdɔ|n n| kɔ|i k|ank|ɔ a|baa|e k|a ɲ|se |bol|ɛ d|lo |u d|kel| sɔ| na| da|n s| ke|ɔnɔ|fan|a f| fa| de|nda|a i|ɛ s|ade|ada|mɛn|ala|i b| mi|and|ɔ s|lak|ɛ m|ɛ y|li | ha|dɔn|sɔd|nu | ko|ɔ b|kɔn|ina| su|ɛda|kɛd| wo|han| mɛ|kar|ko |aya|a n|ɔ m|i m|nɔ |ɔ k|ɲɔɔ|n a|ata|ɔya|nɲa|nnu| wa|n b|in |nka|kɛ |olu|a h|i l|dan| an|mad|le | le|ran| gb|a g|u l|e m|i j|si |kun| ku|u m|ɛnɛ|ii |suu|lat|enn|nad|nin|on |don| ɲa|ɛ l|aji|ɛ b|mak|u k|yan|a w|u s|ɛnn|i t|sii|n t| ɲɔ|wo |dam| ad|awa|law|u t|ɔnn|ɛdɛ|nba|enb|bɔ |ibi|jib|waj|gbɛ|ɲin| ɲi|o m|nan| lɔ|fɛ | fɛ|bɛn|din|kol|fɛn|afɛ|maf|su |usu|uus|taa|u y|e a|ta | ta|aba|ɔrɔ| dɛ|dɛɛ|asa|iri|mir|ba |udu|fud| fu|ini|bɛd|aha|dah|du | bɔ|ɔ j|tan|dal|te |ida|lan|biy|ant| do| te|i w|kɔd|ɲɛ |lɔn|ɔɔy|min|ɛ j|nal|nɛn|ɔɔn|aam|e b|ili|kil|nki|enɲ| du|nni|wan|tii|was|dɛ |a y|o s|ɛbɛ|bay|ali|lɔ |fɔl| fɔ|ɛ a|ɔ n| tɔ|bil| bi|e i|nfa|anf|iil|e f|ɔ l|san|ɔ d',
    'bci': 'an | ɔ |be | be|un | i |wla|ran|kwl|la |sra| sr|in |n b| kw|n s|kɛ | kɛ|n k|le |a k|n n| nu| ng|lɛ |nun| a |n i|man|n ɔ|ɛ n|n m|kun|a b|e k|i s| ku|ɛn |nga| su|mun| n | ti| fa| mu|su |ga |ti | ni|e n|e a|ɔ f| li|ɛ ɔ|nin|a n|e s|a s|i n|ɔ n|a ɔ| le|tin| at|ɔ k|wa |ati|ɔ l|ɛ i| sɔ|ta |ata|fat|ɛ b| ma| mɔ| sa|mɔ |sɔ |a a|iɛ |akw|di | sɛ|vle|nvl| nv|lak| kl|ɛ m|i b|i k|liɛ|dɛ |ndɛ| nd|sɛ | wu| yo|lik|ɔ ɔ|n a| ka|ɔ t|ɛ s| mm|e w|yo | di|i a|ba |ngb|ke | an|und|sa |a m|mɛn|e t|uma| fi|ike| ju|e y| mɛ|mla|mml|ɔ b| ny|i i| bo| ye| si| aw| yɛ|e m|bo |e b|fa |n f|ndi|ɔ i|i f|e i|o n| tr|jum|ɛ a|a w|kan|i w|wie|wun|a y|n l|yɛ |awa|ɔ y|ge |nge|ing|uɛ |ie |ka | fɔ|b a| b | fl| o | wl| wi|fin|tra|klu|i m|lo | uf|a i|ang|ɔun|fɔu|n t|gba| wa|ua |uwa|luw|flu|o i|bɔ |wuk|uan|flɛ|e l|ye |n y|nan|n w| ba|ɔbɔ|bɔb|ɔ d|o ɔ|ufl|nzɛ|anz|kpa| kp|ɛ k|alɛ|dan| ak|e ɔ|sie|te | af| bɔ|lun|nyi|kle|nua|u m|lu | na|u i|ilɛ|i t|zɛ |fuɛ|ɛ w|a t|ika|u b|ɔ s|anm|bɛn|gbɛ| bl|ci |aci|i ɔ|n u|o m|wlɛ|i l| bu|se | se|e f|iɛn|wo | wo|bu |elɛ| yi|afi|uka|a j|i j|ian|nma|san|u n|aka|anu|u s|a l|unm|ɔ w|nda|ote|vot| vo|fiɛ|e j|wan| kɔ| ja|o b|usu|ɔn |n j|anw|ɔlɛ| jɔ|w a| w |kac|o s| ya|i y|ngu| e |u ɔ|dil|tua|yi |yan|nya|ja ',
    'bum': 'e a|od |an | mo|e n|mod|ne |am |se | ab|e m| me| os|ai | ai| ng| ak|ose| y | an|e e|y a| nn|le |d o|nna|a a| be| en| dz|nam|ele|ane|i n|nde|i a|n a|de |a m|iñ |end| a |ie |na | na|a n|bel|abe|e d| as|nyi|ki |a b|ngu| ya| ay|ven|mve|ge |m a|ul |gul|da |li |ya | ki|asu|be | bo| e |su | et|oe |l y|i m|yiñ|dzi|ebe|yia|eny|ene| mv|i e|ian|ala|e b|nge|en |og | mb|ili|e y| mi|ege|bod|tob| ma|nda|ayi| at|e k|la |abo|ñ m|ban|bog|ñ a|ve |om |eti| to|bo | ny|fe | bi|e v|o a|g a|d m|fil| fi|dzo|mem|ben| se|abi| si|beb| nd|n e|woe| wo| fe| ek|zie|aye|oan| nt|emv|ia |bia|ato|e f| ad| da|ga |nga|n m|u m| ve|mbo|a e| te|ial|sie|me |ond|ug |lug|m e|obo| al|do |n b|uan|ae |n k|di |k m|e s|eñ |zia|e t|d b|to | ba|alu|ako|o m|si |a s| di|oba|ma |edz|man|ama|n y|m w| vo|n n|d a|bi |aka|m y|min|ōk |kōk|akō|zen|em | nk|ñ d|mis|tie|i b|ali|kom| es|eku| ze|ii |mam|ziñ| zi|ndo|o e|s a|i d|ye |añ |ake|vom|a f| ev| eb|m m|fam| fa|men|lu |ulu|ñ e| mf|dze|boa|gan|sog|tso|s m|is |sal|esa|ses|teg|ese|yeg|mon|u a|kua|any|ela|ad |lad|ete|und|kun|nku|uma|aku|o n|e o|bon|ui |dza|ó m|ñ n|adi|e z|die|tii|us |ebo|meb|a d|zo |u n|med|nye|kam|l a|voe|deg|dañ|ol |ke |l n|yae|kya|aky|m s|eki|d e|kal|m o|te |oga|nts|i s|omo',
    'epo': 'aj | la|la |kaj| ka|oj |on | de|iu |raj| ra|as |ajt|de | ĉi|aŭ | li|j k|eco|ĉiu|ia |jn | pr|o k|e l| al|est| aŭ| ki| es|jto|co |kon| ko|en |tas|n k|an | en|pro| po|a p|ta |io |ere|ber|ibe|lib|j p|n a| ne| se|o d|to |aci|kiu| in|o e|a k|ajn|j l|ton| pe|do |o a|cio|j e|jta|iaj|eni|ro | ha|taj|ita|rec|lia|toj|ado|vas|hav|per| re|a a|o ĉ|sta|iuj| si|a l|stu|cia|j r|ala|n p| ri|ekt|je | je|ter|tu |nac|al |j d| di|tra|sia|ava|nta|a s| so| aj|sen| ti|ali|uj |a r|nec|int|n d|s r|ent|kto|oci|soc|por|ega|j a|n l|rim|ojn|u h|e s|s l|or |a e|u a|j ĉ|pri|ntr|ont|evi|u r|n j|re |nte|ata| fa| pl| na|ika|igi|tiu|laj|gal| eg|raŭ|cev|ice|ric|ne | ku|ĝi |lan| ju|nen|j s|n s|no |era|pre| el|ian|bla|ebl|vi |tek|e a| pu|don|u s|u e|ers|art| su|iĝo|j n|o p|igo|ren|e p|ons|li |j i|ena|er |len|ple|n r|ote|rot|sti|s e|for|n ĉ|niu|imi|son|tat|o n|o r|u l|con|ili|duk|bor|abo|lab|edu| ed|tan|iĝi|ioj|is |ni |uzi|lo | ek|res|men|un |dis|e e|el | ma|erv|i e|ern|ato|ĝo |a d|lig|go |ĉi |coj|unu|ti |laŭ|moj|hom| ho|kad|kun|edz| ce|ŝta| ŝt|i k|zo | ar|n i|u k|ra |kri| ag| kr|j f| vi|ura|nda|ono|rso|par|ndo|and|jur|far|ven|ŭ s|ka |eli|sek|ĉu | ĉu|kia|kla|ini|uka|r l|ele|rto| pa|i l|ora|edo|le | ge|l l|opr|ive|ziv|luz',
    'pam': 'ng |ing|ang|an | ka| pa|g k| at|ala|at | ma|g p| ki|apa|kin|lan|g m|ata|yan|pam|kar|ara|pat|tan| in| ba|pan|n a|aya|ung| a |g a|g b|rap|ama|man| ni|nin|n k|tin|ati|n i|tun|a a|iya|bal| me|ami| la| di| iy|asa| o |etu|nga|mag|met|ban|in |din|a k|nan|a i|ya |mak| na|ari| mi|kay|aka|yun|ipa| sa|sa | al|rin|a m|na |kal|ant|g s|par|ana|al |ali|ika| da|t k|san|gan|ran|lay|u m|nu |g l|un |a n|atu|kat|awa|a p|t m|ti |iti|syu|mip|ila|aba|n n|la |kas|as |ili|nsa|wa |kap|mal|ra |n d|aki|g n|t p|g i|anu|t a|tas|ans|ita|iwa|uli|i a|mil|a d|bat|sal|ira|li |una|lal| it| pr|dap|ral|ad |usa|o p|kab| an|mik|tul|e p|nte|iba|tau|be |ag |s a|aga| e |lit|mas|wan|lir| ta|abe|g e|abi|n o|n p|lip| li|lam|pro|n l|te |au |kan|g g|ap | ar|ani|alu|e k|it |sab|ale|a b|t i|eng|tek|uri|lab|ail|l a|nti|mam|i i|gaw| tu|ily|ian|liw|inu|da |g d|g t|bra|obr|u i|mba|ina|aru|abu|ie |bie|mit|am |o k|lya|pun|o a|a o|asy|gga|lub|pag|gal|bla|abl|en |len|lat| bi|pak|tur|lin|ksy|eks|ote|rot|e m|ril|sar|u a|u n|tu |gpa|agp|n m| ke| pi|ipu|ka |wal| re|ta |tik|ngg|nap|rti|art|ema|gam|ko |kia|kai|aun|d a|tad|nta|amb|a l|rus|g o| ya|lak|bus| ga|gob|dan|sas|ags|nun| nu|sak| ag|e d|a e|agl|are|bil|ndi|and| pe|iyu|rel|kul|i k|upa|isa',
    'tiv': 'an | u | na|nan| sh|en | a |shi|ha | i |sha|a i|or | er|er | ma|u n|n i|han|ar |n s|gh |r n|n u|a m|in |yô |n a|na |n n|hin| ha|u a|a u|a k|mba|n m|a n|nge| lu|kwa|man|n k|ana| ke| ve|r u| kw| mb| ga|ren|lu |a t|agh|ir |ga |aor|mao| yô|a s|nma|anm|ang|wag| ia|gen|a a|ba |ma | ci| ng| gb|i n|ken|ere|ian| or|aa | kp|e u| ta|ve |r i|ii |gu |ngu| la|ity| he|om |a h|hen|n g|ge |la | ts|n t|e n|oo |gba|kpa|u i|ese|se |aha|cii|r m|tar|r s| ka|ol | ne|tom|u k|ugh|ish| ku|ev | it|doo|ior|n e|on |ene|u s|hi | de|n h| te|yol|oug|a v| to|igh|u t|tyô|ind|i u|i d|ima|iyo|h u|paa|a l|ua |ndi|o u|him| is|r k|i m|ie |hie|tes|u e|yan|hir|ker|di |e s|uma|r a|a e| do|m u|nen|era| io|e a| ya|un | as|ne |tin|ee |mak|u h|tse|n y| za|a g| in|bar| mi|ka |i a|ron|ôro| iy|men|ase|e e|de |ô i|a o|nah|ave| zu|gbe|ran| ti|i v|io |u l| ik|r t|n l| ig| mk|nja|inj|eng|ant| wa|e h|mi |a d|ra |kur| ij|a y|end|hio|lun|l i|r l|av | fa|u z|h s|e i|do |ndo|i k|i i|ta |nta|ake|ash|uan|zua|u m|e m|i l|a w|ura|ôm |môm|vou| vo|i e|iji|e k| hi|da |nda|ghi|kig|iky|see|v s|a f|n c|was|ce |ace|mac|soo| so|r c| mt|vir|ivi|civ|zou|mzo| mz|a c|nev|ves|emb|sen|jir| mô|e l|e g|i y|een|uer|lue|alu| al|u u|ô u|zan| im|ônd|n z|e y|em ',
    'tpi': 'ng |ong|lon| lo|im | ol| na|la |ela|pel| ma| yu|at |ait|gat|ri | ra|na | bi|ol |t l|it |rai| ka| o |mi |umi|bil|yum|ilo|man|t r| i |eri|ing|iga| ig|mer|ara| wa|i o|rap|tin|ta |eta|get|lge|olg| sa|wan|ap |ain|ape|nar|in |a m|ini|ant| no|i i|em |m o|g k|n o|sim|an |as |mas|i n| wo|yu |nme|anm|wok|g y| me|kai| ga|ok |tri| pa| ha|ntr|kan|g o|m n|a l| st|g s|i b|a i|g w|a k|g l|i m|g n|gut|ama|isi|o m|l n|sam|kim| in|lo |pim|aim|kam|p l|sin|amt|a s| gu|i l|tai|mti| ko|t w| la| ki|m l|en |g b|tpe|no |nog|m k|a t|utp|tap|sta|m y|nim|nap|api|g p|tu |ts |a p|nem|i y| tu|kis|lai|oga|tim|spe|isp|its|a o|a n|nka|map|nta|l i|usi|g g|o i|s b|sem|lse|ols| sk|n s|t n|m s|g t| ti|luk| lu|ni |iki|o b|sen|o l|os |et |iti|kin|dis| di|a y|asi|pas|ane|ari| pi|ili|ina|o k|aus|s i|ot |a h| ba|npe|anp|nin|aun|yet| ye|ik |lim|gti|ngt|m g|i g|pik|aik|u y|sai|kot|ut |k b|uti|aut|kau|pos|sap|un |a g|s o| ta|am |ve |ave|sav|i s|s n|t o|ank|a w| fr|ul |kul|sku|ti |m b|go | go|u n|g h|n i|ese|i w| ne|ati|vim|ivi|ali|t m|n b|gav|o n|apo|rau|n m|l m|hap|o w|oli|s l|es |les|ple|m m| em|l s|a r|m i|fri|liv|hal| si|bun|pai|dau|nsa|ins|upe| hu|g r|kom|ana|san|n r|nis|gar|aga|bag|n n| pe|m p|m w|s s|avm|uka| as|g m|g e',
    'ven': 'na | na| mu|a m| vh| u |ha |we |a n|wa |tsh|hu |a u|ṅwe| ts| ya|lo |ya |ana|nga|vha|ho |o y|uṅw|a v|thu|ane|muṅ|shi|e n| dz|vhu| pf|elo| kh|nel|ga |a p|a t|fan|ne | zw| ng|pfa|sha|u n|uth|aho| a |a k|mut| ka| hu|a h|ele|kan|kha|o n|edz|wo |dza|zwa|la |u m|a z| mb|e u|dzi|hum|si |i n| wa|a d|mul|e a|zwi|u t|fho|ang|ḓo | ha|u s|o v|gan|olo|vho|ela| ḓo|lwa|o d|hol| i |ula|aka|o m|no |za |o k|hi |he |shu|han|o t|zo |ofh|lel|led|rel|low|u v|awe|tsi|hak| sh| ma|ka |mbo|ano|e k|yo |elw|a i|a s|bof|ngo|o i| te|nah|owo|iṅw|hil|its|o h|dzo|zi |dzw|mba|lan|e m|i k|sa | mi| si|ing|one|hon|and|ush|go |isa|li |het|e v|a l|swa|ire|sir|i h|i t|a ḓ| nd| lu|eth|umb|hat| fh|dzh| it|ine|wi |avh|khe|u k|ea |tea|unz|ni |ṱhe|ath|ndu|hen|ila|u a|mo |wah|kon|ulo|vhe|wan|o w|u w|mis|a a|a y|i ḓ|isw| an|iwa|hus|hel|e y| sa|alo|mbu| ḽa|oṱh|le |du |mus|o a|uts|ayo|tel|nda|amb|uvh| ho|vel|fun|i v|zan| ny|a w|zwo|o ḽ|pfu|u i|adz|hut| bv|kat|lay|hav|hit|afh| ḓi|evh|i m| ko| li|umi|aṅw|so |fha|ene|nyi|she| o |mal| iṅ|nḓa|mel|zhe|ivh|zit|hii|san|lis|ili|eli|ala|hul|u h|o u|ura|bul|nzo|umo|i i|mbi|haw|hin|o z|u ḓ| th|o f|oni|lus| yo|alu|lwo|ḓa |anḓ|fhe|zhi|u d|eah|usi|a ṱ| re|une|ite|ere|rer|hur|mbe|hal|lul|ule|thi',
    'ssw': 'nge|ntf|e n| le|tfu|eku| ng|a n|o l|la |lo |fu |khe| ku|nga|tsi| ne|le |unt| lo|he |mun|a l|nkh|ma |si |ele|elo|ung|nom|oma| no| um|wa |ni |ent|lel|lek|eli|lun|kut|ko |nel|gel|eni|pha| ba|onk| la|e l| em|ats|tfo|a k|e u|o n|e k|nye|hla|ela|umu|ban|oku|ulu|aka|akh|lil|won|ema|lok|lul|hul|a e|eti|ala|tse|khu|uts|ilu|i l| wo|ane|ye |nti|ndl|ang| na|ule|ve |we |esi|nek|na |ke |any|aph|ana|fo |set| li| ye| un|ale|lan|u u|hat|une|te |e b|eko|aba| ka|kwe|and|gan|lwa|ka |gen|tin|nem|phi|fan|wen|ben|mph|nal|kan|i n|ile|lal| ek|i k|gek|kel|o y|lab|ant|seb|u l|len|ahl|‐ke|let|e e|ako|ebe|lom|ive|be |ing|a b|kha|etf|uhl|ba |isw|kus|kho|ukh|yel|wo | kw|ikh|o k| im|uma|kat|kub|ne |ndz|sit|alo|ise|ini|omu|uph|abe|ngu|e i|alu|mal|nak|a i|kuv|sen|tis|kun|elw|lwe|e w|iph| in|fun|enk|sek|eke|dle|ti |lin|ase|a a|sa |use|hak|gab|a‐k|e a|les|kul|nen|kuh|ta |cal| ti|isa|tfw|ona|swa|ene|ma‐|hol|jen|ali|eki|bon| se|to |fol|utf|yen|ula|o e|lon|kuk|ike|liv|sel|ute|sik|lak|eng|hi |ume|kuf|alw|int|sha|nhl| ya|its|i e|fut|i a|und| bu|i u| ab|ebu|emb|dza|ndv|kil|emp|had|yak|ets|ifa|vik|emt|phe|emi|ite| si|tsa|kwa|u n|dla|a u|olo|imi|o m|han|gap|nan|ufa|ata|wem|mts|end|uvi|i w|ekh|owo|low|ind|i i|uba|mel|vum|dvo',
    'nyn': 'omu| om|a o| ku|tu |ntu|wa |ari| ob|ra |a k|obu|mun|uri|mu |unt|a n| mu|nga|ri | na|ho |e o|bwa|aba|rik|a e|gye|han|ga |ang|oku|a a|bur| bu|iku|re |ush|aha|iri|uga|ka |i m|ndi|sho|ain|kur|u a|we |ere|ira|ibw|ire|na |e n|ne |ine|iha|aho|ung|and|e k|ye | eb|a b|ban|eki|ing|bug| ni| ab|ba |kut|ura|uba|be |ro |u b|sa | kw|bir|ebi|u n|kwe|e b|gir| ok|i n|kir|zi |abe| bw| ah|o o|kub|i k|gab|ish|sha|era|o e| no| ai|u o|ate|tee| ek|di |rwa|ha |kuk|rin|mer|wah|kwa|i b|bwe| ba|ant|zib|u m|end|ngo|i a|ngi|bus|nib|ama|baa|kuh|iro|iki|eka|eek|i o|nar|o g|go |kug|ya |kan| ka|ngy|ana| ar|o b|agi| ti| or|hi |shi| gw|eme|ash|gan|bwo|o k|rag|uru|ute|ris|ja |mur|ora|tar| nk|she|o a|i e|oro|iba|yes|wee|tek|ara| en|bya|ija|mus| ha|kus|mwe|eir|hem| ne|obw| n |eih|rir|za | we|ekw|naa|yen|o n|uta|iho|rih|har| by|egy| er|e e|amb|da |nda|rei|gi |wen|kwi|aar|eby|rer|yam|a y|isa|yaa|nko| bi|aka|sib|aab|ind|riz|uku|irw|si |nsi|ens|iin|aij|mub|a r|ugi|oon|ata|ki |dii|nka|utu|bas|hob|aga|kor|uko|n o|eri|bye| am|amu|ika|ham|mut|umu|nok|aat|izi|uzi|o m|ebw|oba|emi| em|rim|azi|uka|rye|ona|okw|u k|e a|kum|tuu|ibi|ahu|gwa|bor|mo |aas| ya|ent|ete|u e|ori| ei|bo |ani|amw|aah| ky|uma|eer|der|nde|ugy|a z|ikw|tih|ong|yob',
    'yao': 'ndu|chi| wa|du |akw|aku|a m|kwe| ch|und|ni | mu|wak|mun|la |e m| ak|wa |wan|amb| ku|ulu|mbo|ali|u w|we |ila|kut|lu |bo | ma|kwa|a n|ful|ufu|le |se |a k| ni|hil|nga|ose|ete|e u|ang|jwa| jw| ga|na |kul| uf|lam|ne |amu|aka|son| na|e a| pa|oni|u j| so|ngo|wal|and|go |mwa| yi|te |wet|ana|uti|nda|yak|che|lij|gan|i a|a c|ele|cha|o s|e n|jos| ya|o c|ijo|i m|ti |pa |ga | mw|kam|ya |ula|asa|ala|ind|yin|e k|isy|ich|kas|ile|li | ka|ili|o m|ani|si |ach|u a|nam|ela|jil|ikw|a w|mul|yo |uch|aga|a u|hak|asi|kap|gal|kus|mbi|mba|mal|ma |ule|ape|o a|lan|i w|imb|pe |his| al|e w|end|a p|usi|ika|uli| ng|ope|sye|a j|aji|kum|ase|i k|ine|pen| ja|lem|him|u y|e c|mas|ka |och|ena|ekw|sya|ako|kup|a y|any|man|ane|ten|kol|hel|i y|ola|i u|wo |wam|e y| ul|kwi| kw|awo|gam|cho|gak|o n|eng|sen|pel| mp|iwa|da |gwa|sop|jo | ji|mch|ite|ama| li|ngw|hik|syo|u g|mpe|je |oso|ye |emw|ujo|duj|uwa|kuw|bom|ja |i g|mus|waj| mc|iga|tam|upi|jak|ong|dan|a s|sa |was|ole|nde|nji|ene|oma|nya|poc|ons|lo |apo|a l|i n|alo|mka|ale|one|o k|lil|uma|lic|ung|i j|ban| bo|mag|ata|usa|win|lik|hos|o g|sik|lig|lek|kan|anj|iku|pan|ing|u m|wu | aw| mm|eje|uku| yo|omb|pak|a a|he |hin|e s|esy|nag|muc|iji|lwa|mma|kal|ba |nil|uta| nd|awa|i p|ipa|no |ano',
    'lvs': 'as |ība|ies|tie|bas|ai |un | un| ti|sīb|esī|ien|ir | ir|vie| vi| va|bu |am |ību|iem|m i|em | ne|s u|r t|vai| uz| pa|uz |ena|ās |pie| pi| iz| sa|nam|dzī|šan|isk|ar | ar|kvi|ikv| ik|viņ|brī| br|es |rīv| ka| at|u u| ci|i i|s p|cij| no|edr|inā|āci|s v|iņa|drī|dar|s t|u p|u a|pār| pr|i a|ot |nu |s s| la|zīb|ska| ie|aiz|jas|ija|vīb| jā| ap|ībā|īgi|vis|arb|tīb|gu | st|kā |s i|val|īvī|ām |īdz|st |ied|bai|īgu|s b|ņa |t p|arī|lst|als|ana|s n|gi |līd|s l|mu |umu|kas|jum|ju |iju|kum|u i|ba |u n|izs|n p| ai|ā v| da|nīg|ama|u k|u v|i v|rdz|son| tā|kst|īks|rīk|ned| so|iec|s k|ajā|cit|sav|līt|stī|pil|u d|t v|per| pe|bā |nīb|i n|not|stā| dz|s d|m u|ras|tu |cie|n v|kat|ā a|mat|enā| li|evi|nev| kā|kur|aut|nas| pā|skā| re|a a|a v|kād|ebk|jeb| je|bez| be|jā |līb|i u|i p|bie|tik| ta|n i|pam|mie|ard|sar|zsa|nāc|iku|lik|iet|r j|būt|rso|ers|du |ikt|sta|ciā|oci|soc|cīb|tis|rīb|āda|tīt|ītī|glī|zgl|izg|abi|ulī|aul|lau|tra|atr| lī|ais|tot|atv|umi|nod|anu|t s|a u|ram|ier| ku|a p|tās|kt |klā|a s|ta |ant|iāl|ma | ve|n b|nāt|ekl|ret|pre|ā u|lvē|ilv|cil|jāb|sab|eja|oši|mēr|āti|roš|dro|pat|m k|kri|rie|ūt |m v|ēt |t t|zīv|īga|a i|kar|atk|nea|ts |ādu|āt |s m|lās|nāl| na|ecī|tas|iģi|liģ|eli|rel|uma|sas| ga|s g|et |m p',
    'quz': 'una|an |nan|as |pas|apa|ana|cha| ka|lla|man| ru| ll|sqa|run|qa |aq | ma|ach|ta |pa |paq|npa|mi |taq|na | ch|a r|kun|hay|anp|tin|nta|nch|yta|chu|asq|chi|aku|lap|ant|qan|kuy|in |ama|aqm| wa|qmi|a a|ay | ya|ata|nap|ati|ipa|wan| ju|ina|a k|aqa| at|may| ja|a l|aqt|ayt|a m|kan|ima| pi|n k|s m|nin|ank|tap|anc|qta|his|hu |pip| mu|n j|all|a c|spa|uku|ypa|qpa|iku|yac|pi | pa|ion|uch|naq|pan|n m|a p|kam|un |han|ayp|a j|aci|nac|awa|n r|laq|s k|nma|anm|usa|aus|kau|isq|k a|n l|cio|asp|lan|n c|ayk|yan|nak|oq |yoq|ayn|inc|nat|uy |n p|yku| im|mun|jin| ji| yu|i k|has|q j|tan|inp|tuk| tu|n y|ura|kay|uyt|kus|ña | na| sa|is |nmi|s t|s w| qa|mac|tun|atu|jat|asi|yni|uya|api|pac|nk | ay|kaq|tiy|waw|inm|ech| de|n t| ri|q k|a y|ma |hik|nti|sin|kas|lin|lli| al|ari|nku|juc|was|nal| aj|i m|pay|rmi|arm|war|a q|yay|yuy|q y|say|i p| ti|usq| an| as|qti|n a|npi|pap|hur|a w|rec|ere|der|ita|q c|rim|s p|aqp|s y|yqa|iyo|niy|ani|i l|unt|s j|juj|kin|iya|q a|huy|a s|ywa|nka|sap|u l|ras|int|sta|uma|kuk|piq|iqp|hak|tay| ta|qas|q r|ypi|maq| su|ash|y r|uj |qsi|lak|heq|che|min|a t| ni|yma|t a|s a| ki|uyp|q q| re|muc|nqa|cho|unc|yas|s l|ayo|y l|qha| qh|ist|pur| pu|la |ill|mas|nam|pis|isp|hap|q w|lat| si|mik|y k|y s|ayq|pat|ali',
    'src': ' de|de |e s| sa|os |tu | a | su|tzi|one|sa |ne |ent| in|ion| e |a s|su |der|zio|u d|ret|e d|as |ess|ere|es |men| pr| pe|et |ten|ade|etu|nte| cu|ale|er |re | so|s i|atz| te|in | un| s |ene|a p|zi |ida|e e| on|sos| es|e t|nzi|onz|are|chi| si|le |te |s d| is|dad|u s|a d|net|u a|e c|tad|sse|ame|sso|t d| ch| o |son|at |pro|e i|i p|e a|pes|e p|nt |ntu| co|na |a c|du |hi |u e| li|e o|s e|int|s a| at|sas|un |cun|nu |per| po|ter|n s|ber|ser|nes|tra|zia| di|res|ro |s c|si |adu|sta|nat|s p|unu|era|ia |t s|tos|t a|da |nal|pod|u c| re|s s|sua|ona|ica|ist|ibe|lib|rar|egu|ntr|s o|ua |a a|o s|pre|ntz|ant| ne|ust| da|ndi|una|rta| fa|ode|u p|a e| to|est|nta|a l| pa|u o|und|ra |ada|ert|iss| na|otu|con| ma|a u|ae |dae|o a|otz|dis|eru|cus|les|a i|pet|lid|ali|i s|iat|sia|u t|sot|rat|epe|s n|tot|ssi|t e|ime|unt| ca| as|a n|ind|sti|eto|st |etz|lic|ont|a b|a t|iu |fun|ta |ine|a o| se|nen|nid|suo|s f| tr|ass|e u|nda| fu|ial|ena|sen|das|ghe|e f|pen|ual|gua| eg|pri| fi|par|a f|ria|u i|for|t p|emo|seg|ner|icu|tut| no|eli|run|det|itu|dep|inn|man|tar|lu |dos|r p|art| pu| bo|cum|ina|i d|ura|u n|tes|mos|nem|gur| bi|idu|nde|cu |ata|us |o d|tic|e l|e r|cam|des|ènt|din|ral|cas|uni|ios|com|u l|ado|sio|fin|nsi|n a|ire',
    'rup': 'ri | sh|ari|i s|hi |shi| a | ca|ti |ea |i a|tsi|rea|i c|tu | s |ndr|dre|i n|a a|ptu|ept|rep|câ | nd| un| di|la | la|i l|i u|a s| tu|ear|di |ui |lui| li|are|a l| ar|un |â s|li |caf|ati|tat|afi|lje|fi | lu|ats|icâ|â t|ei |râ |bâ |nâ |ibâ|car|i t|jei|si |ali| câ|tul|hib| hi|s h|tâ |or |u c|n a|â c| in| cu|ul |i d|ilj| ti|â a|a p|a c|a n|lor|tea|u s| al|int| co|u a|cu |tur|ber|ibe|lib| ic|lu |i p|eas|tsâ|i i|u p|sea|lji|min|u l| nu|â n|nal| pi| pr|ii |url|rar|nu |sta|ots|alâ|ji | po|â p|sti| ts|sii| si|al |oat|can|til|ura|â l|anâ|its|i f|lâ |nat|ina|ist|ert|sâ |i m| st|sia| so|pri|â d|poa|ips| fa|sht|tut|tse| ac| ap|ând|t c|ita|nts|gur|a d|sot|ent|sh |lip| su| as|ate| lj|urâ|pur| ân|at |ili|uni|a i|ona|â i| de|âts|ash|zea|i e|ucr|luc|itâ|unâ| ma|act|bli| pu|nit| sc|con|tar|alt| mi|nde|ind|tât|hti|ntu|rli|ilo|ntr|par|r s|a t|apu|imi|rim|mlu| ni|com|igu|sig|rta|i b|ial| na|tic|l l|ica|est|tsl|âlj|art|pse|chi|iti|unt|sun| ea|r a|adz|l s|tlu|atâ|ter|sit|asi|pi |apt|ia |rlo|ârâ|fâr| fâ|oml|uts|scu| ba|na |lit|ndu|pis|dit|gal|ega| eg|fac|s f|ru |acâ|câr|ead|atl|ra | ta|arâ|cul|rti|nte| cr|iil|i v|lic|ubl|pub|vre| vr|s l|cri|nom|scâ|asc|nji|ire|ion|aes| ae| du|rtâ|idi|ini|sin|eal|uti|cru|vit',
    'sco': ' th|the|he |nd | an|and|al | o |ae | in|es |in |t t| ta|cht|or |tae|ich|ric| ri|ion| aw| be|is |s t|tio|ht |bod|dy |ody|s a|e a| he|e r|ent|on | co|his|hes| or| na|ati|wbo|awb|ty | fr| hi|be |e t|n t| sh|ts |sha|er |hal|nal| on|y h|ng |l b|ree|fre|ing|l a|e o|y a| pe|o t|it | ti|e s|ter|s o|air| ma|nat|for|n a|nt |il |til|aw | fo|ona|e c|ny |ony|tit|nti| a |men|ity|e w|at |d t|t o| wi|her|e f|dom|edo|eed|d f|d a|ce |con|an |e i|e e|r t|nte|ar |lit|oun| re|ic |n o|nae|t i| it|ont|sta|oci|soc| as|y i|r i|ith|ne |ane|ons|ed | di| so|ly | wa| fa| pr|y s|ers| ha| se|int|und|e g| st| de| fu| en|nce|hts|d o|o h|res|com| no|le |e h|nin|r a|ie |e p|ear|ial|r o| la|inc|ite|wi |re |ual|qua|equ| eq|ns | le|ess|ali| pu|en |per|e m|cia|as |thi|lt |elt|rit| is|d i| we|imi|din|ild|eil|nor|r h|t n|e b|tri|ntr|ir |iou|eli|ge |lan|s r|s f|ms |tel|cie| me|lea|fai|y t|hat|tha|l t|law|g a|om |y o|sec|e l|ver| tr|ds |r b|l o|iti|un |cti|dis|e d|s d|id |hei|ld |are|rou| un|omm|s c| at|ssi|war|n h|me | ac|ten|bei|t a|uni|eme|tho|rt | ga|s n|m o|hau| li|tie|g o|rni| wh|s w|rie|ern| gr|mai|tat|n n|ica|igi|age|n w|oms|s e|d s| ar|nit|ee |n f|man|arn|rk |ark|eri|ral|e u|k a|el |te |ose|pos|ak |ces|s h| ch|lic',
    'tso': ' ku|ku |ni |a k|hi |i n| ni|a n| a |ka |i k|wa | ya|na |ya |fan| ma|la | ti| hi|nel|iwa|a m|ane|hu |a t| sv|ela| na| ka|lo |svi|u n|mbe|nhu| à | mu|u k|a w|eli|ndz|li |vi |be |kum|ihi|umb|i l|wu |ele|elo|mun| wu|a h|a l|nfa|u l| fa|liw| va|aka|wih| wi|unh|nga|lan| nf|a s| wa|u y|u h|iku|tik| ng|i m|u t| xi|va |o y|le |i a|nu |yel|amb|e k| le|anu|han| ha|isa|ana|eni|a x|lel|ma | kh|a a| la|ga |ndl|i h| li| nt|irh| ko| è |a y|ti |ani|ta |sa |in |kwe|u a|i w|any|lek|u v|pfu| ye|van|yen|u w|i s|yi |tir|à n|and| nd|mel|e y|eke|i t|a v|n k| lo|à k|isi| kw|hin|we |ang|è k|wan|aye|ko |a f|mah|rhu|i y|end|ham|mba|u f|lul|ulu|hul|khu|kwa|nti|hla|ngo|kel| si|eka|dle|dzi|may|ule|aha|u s|u m|i à|ati|thx| th|dze|nth|anh|eki|oko|eyi|u à| lè|mat|n w|xi |fum|vu |nye|zis|i f|thl|lok|rhi|ava|a è|lak|o n|mbi|tà |mu |ke |tin|ond|o l|ngu|e n| dj|ong| mi|siw|a à|vik|lwe| ts|uma|naw| tà|hak|èli|à m| là|xa |ume|u p|sik|gan|e a|wak|xiw|ind|u d|esv|les|ike|wey| lw|e h|awu|mha| hà| ta|za |dza|i x|nyi|ths|fun|avu|wav|kot|ki |jon|djo|rha|umu|ba |sin|ha |xih|kar|lon|hxu|àwu| nh|to |ung|a u|ola|kol|ali|fu |int|akw|nan|àkw|gul|sun|wen|ikw|gom|kon|sva|kho|hel|sem|tse|sek| y |zen|ìhi|là |mi |e w|hlo|e m|exi|lex|nya',
    'men': ' ng|ɔɔ |a n|i n|ti | gb| ti| i |i l|ngi| ma|gi |aa | nu| kɔ|a k|ia |ma | na| ye| ta|kɔɔ|ɛɛ |ei | a |hu |bi |gbi|a m|na | hu|a t|i y| lɔ|u g|ya | nd|ii |i h|a h|i m|ɔny| kɛ|ɛ n|nya|lɔn|mia| mi|ɔ t|uu |ngɔ|ɔ i|ee |nga|lɔ |la |ao |tao| kp|i t|ye |nge|ɔ n|i g|gaa|gɔ |i k| le|hou|a y|ung|ni |ind| yɛ|e n|nuu|a l|nda| hi|umu|num|hin|mu |ugb|hug|oun|kɛɛ|eng|gba|a a|maa|a i| ɔɔ|da |ɔlɔ|ahu|le |i i| sa|ndɔ| ji|a w|ɔma|mah|yɛ |e t| lo|saw|o k| va|ta |gbɔ|u n|i w|li |va |u k|bat| ho| ya|sia|lei|ahi|e a|i j|nde|e m| ki|yei|isi| wo|kpa|dɔl|gbu|ɔ k|ge |awa| gu|wei|awe|e k|ila|ani| wa| ii|ji |aho|ale|ndu|kpɛ| ha|kɔl|a g|gbɛ|wa |nah|i b|yek|ein|yil|bua|atɛ| la| ny|tɛ |ɛ t|kpɔ|taa| ɛɛ|ɔ s|ie |ɛ k| we|bɔm|kpe|ekp|hei|nun|uni|ɛi |u t|ɛ y|ɛlɛ|gen|te |ote|wot|ɔ g|ama|i ɛ|ulɔ|gul|lee|kɛ |eke|pe |tii|ɔ y|pɛl|yen|bɛɛ|e y|ɛ g|ɔle|ga |a b| tɔ|u w|aah|baa|lek|o g|a v|bu | he|ili|kia|uvu|aal|jɔɔ|ajɔ|maj|nye| bɛ| sɔ|lɔl|ka |ɛmb| wi| ka|e h|iti|akp|ang|bɛm| ba|u m|u ɔ| yi|ɛ i|e g|lii|uah|nuv|lɛɛ|gua|yɛn|sɔɔ|ui | lɛ|dei| pe|i p|mbo|uam|ong|lon|ngo|oko|lok|a p|a s|haa|i v|ula|hii|yee|yan|u a|ati|wat|hi |ke |wee|e i|u i|ewɔ|ɔ h|wu |nyɛ|oi |ɔhu|ɛ h|u y|vuu|boi|paw|ɛng|wie|ɛ w| ga|lɛ |ɔɔh|bla|ɛ a|ɔli|ua |mɛi|amɛ|oma',
    'fon': ' e |na | na| ɖo|ɔn |ɖo |nu |o n|kpo| nu| ɔ | kp|mɛ | mɛ| gb| é |tɔn|po |do |yi | si| tɔ| al| to|gbɛ|wɛ |bo |e n|ɖe |lɛ | lɛ| do|lo |in | bo|e ɖ|ɛn |o a| wɛ|ɛtɔ|to |tɔ |ɔ e|sin|o e|a n|ɛ b|acɛ| ac|o t|nyi| ny|ɔ ɖ|okp|nɔ |ee |bɛt|ɖok|cɛ |ɛ ɔ|bɔ |an |ɛ n|a ɖ| ɖe|ɛ ɖ|o ɔ|n e|ji |ɔ n| bɔ| ǎ | en|mɔ | mɔ|n b| hw|i ɖ|alo|lin|n n|ɔ é|n a|nɛ |ɛ e|un |o ɖ|bi | bi|mɛɖ| yi|i n| ye|kpl| jl| wa|ɛɖe|enɛ| ji|u e|i e| ɖɔ|alɔ|a d|n m|ɔ b|é n|nun|hɛn| hɛ|e m|e e|ɔ m|e k|ɖɔ | nɔ|lɔ |ɛ é|é ɖ|odo|gbɔ|wa |n k|a y|kpa|sɛn|a s|ɖee|ɛ k|a t|jlo|ɔ w|ɔ t| sɛ|e j|kɔn|ɔ g|nnu|inu|pod|bɔn|o g|e s|ɔ s|unɔ|n ɖ|ɔ a|o s|a b|n t|hwɛ|o j|e w|o m|i t|bɛ |xu |ixu|six|eɖe|etɔ|ɔ k|lɔn|bǐ | bǐ| we| ka|nuk|o h|n ɔ|ba |zɔn|ukɔ|a m|ɛ a|n d|ma |o l|hwe|si |u k|azɔ| az|ema|wem|ogu|tog|nmɛ|o y|sɔ | sɔ|ali|ɛ l|jɛ |n l|ayi| ay|ɛ s|plɔ| zɔ|a z|ɖè |i k|onu|n w|u w|u a|u m|a e|hun|o b| lo|gun|n s|e ɔ|ka |dan|o d|gan| i |a g|i w|ɖó | ɖó|n g|wu |u t|yet|ɛ g|su | su|oko|a j|ɛ w| hu|ɛnn|obo|u l|kwɛ| ga|a w|i s| fi|a l| ee|pan|lee| le|ɛ t| ɛ |e b|evo|ɖev| wu|u g|i a| ma|ɖi | ɖi|ye |o w|isi|sis|zɔ |ǐ ɖ|o k|nú | nú| vi|ple|emɛ|we | ɖ |wɛn| ba|o é|nya| da|ɔ h|gba|ɛ m|fi |ya |kan| jɛ|e g|i m|jij|mɛt|ɔnu|u n|nuɖ| eɖ|e t|xo |ɔ y| li|enu|wen|ɔmɛ',
    'nhn': 'aj |tla| ti| tl|ej |j t| ma|li |a t|tij|an |i t|sej|kaj|eki|uan| to| no| te|ij |j m| ua|chi| se|noj| ki|ma |ika|laj|j k|j u|pa |tle|man|aka|oj |ka |lis|ech|tek|se |uaj|ano|ise|iaj|tec|amp|iua|ali|pia|j n|och| mo|pan|mpa|a k|kua| pa|n t|is |ya | am|uel| ue|eli|ual|ili|en |len|kit|ajt|a m|jto|j s|kin|ijp|amo|ia |jki|tim| ke|mo |hi |ant|ama|ani|noc|opa|oli|aua|j i|ase|tli|nek|itl| ik|ijk|tok|nij|imo|ati|kam|jpi|tik|ipa|one|tis| o |oua|tit|ra |ara|par|nop|tl |jya|a s|iti|lal|cht|ok |ojk| ku|o t|kiu| ka|maj|kej|lak|leu|alt|ijt|mej|lau|kia|ana|ki |kij| ak|jka|n n|lam|i m|mon|e t|til|s t|nti|j a|k t|ita|kip|kem|j p|lan|jtl|tep|lti|lat|ema|uat|ose|iki| ip|ats| ni|ntl|ajy|e a|stl|ach|tou|eua|tot|kat|uam|atl|eui|toj|ni |nau|nka|ist|epa|ite|ale|pal|oka|tia|ajk|ini|j o|tsa|n m|ipi|kui|eyi|uey|jua|a i|n k|mat|nit|i n|oju|a a|onk| on|o o|uik|uil|n s|ken|ijn|ank|a n|ote|i u|i k|otl| sa|kon|as |ino|hiu|xtl|tos|its|tsi|n a|oyo|eka|chp|san|mpo|uak|ko |a u|tol|oke|yek|yol| ya|uas|pam|nok|tin|aui|htl|o k|sij|yok| me|nem|las|jke|ejy|hti|jne|nko|jti| ax|mac|emi| in|i i|mot|oui|ame|yi |lit|i a|kol|jku|sek|epe|lte|pil|nan|axt|ami|ejk|ine|int|ojt|ate|ias|ela|mel|aku|ina|uis|etl|kis|mik|ito|ui |ak | ye|ona',
    'dip': ' ku|en |ic | bi|bi |ku | yi| ke|yic|an | ci|aan|raa| th|c b| ka|n e|n a| eb|ci | ra|c k|ŋ y|kua|i l|i k|ka |in |th |ben|ny |ebe|kem| ek| al|eme|men| ye|k e|höm|nhö| nh|öm |ai |alɛ|lɛ̈|i y| lo|n k|t k|c e|thi| la| er|ɛ̈ŋ|ɔc |̈ŋ |kɔc|ek |yen|ua |m k|de |t e|ŋ k|a l|ok |aci| te|n b|at |u l|ith|n t| ep| ac|k k|it |i r| lu| e |uat|ke |u k|aai|oŋ |te |cin|ken|e y|eŋ |ui |epi|baa|ath| lɛ|tho|ɛŋ |hin|era|n c|e w| mi|a c|hii|lau|h k|ekɔ|n y|el | ti|u t|l k|au |kek|nde|lɛŋ| pa|n r|n l| et|h e|a k|u b|nhi|a t|thö|pio|la |c t|e k|ot |rot| kɔ|iny|pin|ŋ e|ak |loo| le| pi|i e|eba|ëk |ik |im |iim|ŋ n|oi | ro| ny| tu|kak| el|i m| kö|hok|y k|pan| we| ba|i t|iic|m e|u n|ye |oc |ioc|loi|k a|lui|wic| wi|e c|and|e l|eu |pir|i p|wen|ɛt | lö| li|mit|ëŋ |eth|yit| ey|öŋ |u m|nyo| aw|e e|i b| ew|i d|den|any|iit|iek| aa|k t|uc |köu| ko|leu|ir |r e|t t|e r| dh|ök |uee|tue|y b|e t|eny|uny|ooŋ|i c|cit|u c|n w| ya|l e| ec|kic|höŋ|eeŋ|dhi|a p|uan|m b|ut | ak|yii|y e|ewe|wuc|awu| mɛ|pat|i n|ien| ed|h t|uk |tii|öun|lie|ɛ̈n|elo|am |cii|r k|t c|wel|löi| wɛ|bai|thë|u y|tha|eku| en|k c|thɛ|hök|ɛɛt|il |hil| cɔ|ieŋ|cie|öny|kön|aku|m r|tic|oui|lou|ale|t a|war| wa|eka|ynh|nyn|kue|eke|eri|oth|yoo|loŋ|p k|up |k y|m a|y r|die',
    'kde': 'na | na|la |nu | va| wa|a k| ku|ila|wa |a w|unu| mu|a v|chi|mun|e n|a m|a n|van|ya |ele|ana|le | ch|amb|ave|sa |lam|asa| vi|ohe|mbo|aka|u a|was|e v|bo | n’|ne |e m|ke |u v|vel| pa|ala|a u|ake| av|hil|ika|ng’|ing|ngo|he |a l|ve |ile|anu|ela|vak|any| ma|vil| li|a a|go |a i|wun|uku|ili|lan|bel|mbe|ene| mw|nda|kuw|ama|nya|ola|ali|kol|kan| di|g’a|au | au|emb|den|eng|lik|uni|wak|a d|’an|e a|lem|ong|o v|ulu|kuk|an’| ak|ach|a p|kal|ma |dya|n’n|lew|mad|aya|and|mwa|uwu|kum|ye |a c| vy|apa|va |ava|ane|hel|mbi|kut|o m|hi |we |ula|ole|u m|umi|din|ton|ji |nji|nil|ewa| il|voh|ade|und|ni |kul|dye|dan|kay|uko|idy|kav|tuk|nan|kam|ka |ia |lia|eli| dy| in|ndo|ond|hin| la|uva| ul|ani|vya|i n|o n|wen|mwe|da |e k|e u|o c|lel|pal|nje|yik|aha|uwa|lil|n’t|nga|ata| ka|she|pan|cho|ang|no |u i|lon|ulo|lim|uli|’ch|dil|hev|i w|u l|e w|mba|niw|mil|ba |yoh|uma| um| kw|u n|wal|vin|vyo| an|bi |a s| ya|dol|hoh|u c|awa|lin| al|ilo|’ni|e p|ale|n’c|mu |imu|lun|kup|yak|yac|’ma|n’m|mah|atu|wav|kuv|hon| lu|i v|hih|jel|utu|hap|uka|o l|u w|itu|ga |o a|i d|umb|a y|inj|taw|ita|lit|lek|val|e c|oko|aku|me |bu |paw|kuy|mak|e i|yen|iho|amw|woh| ih|iku|pil|kun|onj|tul|nah|awu|ahe|i a|kat|mat| wu|pac|ina|olo|uto|ech|kwa|i c|li |ngi',
    'snn': ' ba|ye |bai| ye|ai |e b| ca|ji |ai̱|ia |i̱ | go|goa| ne|sia| si|i y|a y|̱ b|e c|i n|a b|i j|aye|re |se |e g|hua|iye|oa |quë| ja|jë |yë |bay| ma| hu|e̱ |u̱i|ñe |je̱|e s|̱i |gu̱| gu|ayë|ne |beo| be|eo |mai| ji|to |hue|o y|i g|a i|i s|bi |e e|ajë|ja |ba | e |deo| ña|aij|cat|ë b| de|ato|e i| co|i t|i b|e y|uë |oji|eoj|je | ñe| ts|e t| iy| ti|ña |e j|e ñ| i |na | re|aiy|cha|̱je|eba|a ñ|i c|ni |reb|ue |cay|coa|a ë|ach|oye|ë t|oac|ja̱| qu|i d| ë |utu|tut| tu| to|uai|ua |a̱j| i̱|iji|ihu|ë c|tu |cai| sa|e n|ere|e m|asi|ca | yë|ija|a m|a h| se|a c|ani|ti |eje|equ|yeq|ase| ai|a a|e d|̱ t|ije| te|ebi|yeb|oas|caj| na|co̱|neñ|oya|toy|are|añe|ahu|ico|aca| da| do|e r|ese|eoy|ë g|a t|eñe| a | o |yer|i m|doi|o b|mac|aje|ibë|haj|i r|oi |a s|ë s|ë d|aja|i i|ues|̱ g|a o|yaj| me|ehu|ose|uaj|ëca|aqu|cas|jab|ëja|nij|nej|o h|teo|hay|eso|̱re|ë m|tsi|eye|yij|i h|aña|ë j|ned|bëa|rib|ari|dar|jay|tia|̱hu|i̱h|sic|o s|oja| ro|ë r| ëj|a g|̱ñe|o̱a|go̱|año|ñe̱|ea |oca|coc|̱ c|sos|cah|i̱r|ë y|̱ca|o̱c|sai|̱ni|nes|me |o t|eja|huë|sih|bë | yi|abë|cab|sëc|tsë|jai|u b|oe |car|a̱ñ|e h|tse|jar|oañ|yo | yo|aco|uej|e a| cu|ban|ire|osi| ju|a j|co |ë q|yey|o c|si |ë ë|ta | je|ñej|aoy|sao|a̱ |ëbi|ma | bi|ëhu|ore|soe|tso|ro |̱ q',
    'kbp': 'aa | pa|se | se|na |nɛ | nɛ| wa| yɔ|yʊ |ɖɛ |aɖɛ|a w|ɛwɛ|ɛna|ɛ s|ɩ ɛ|paa|a ɛ| ɛy| ɛw| ɛ |ɛ p|e ɛ|waɖ|ɛ ɛ|e p|a p|wɛn| pɩ|yɔ |yɩ |aɣ |ɛyʊ|ɔɔ |ʊʊ | ta|ala|yɔɔ|yɛ |ɔ p|a n| ɩ |yaa|taa|ʊ n|a a|ʊ ɛ| tɔ|ʊ w|zɩ |la |wɛɛ|nɩ | an|ɛ t| kɩ|anɩ|ɛ y|maɣ|ɛ n|nɔɔ| nɔ|ɛyɩ|ɔm |tɔm|ɩ t| we| pʊ|ɩ p|ɛ ɖ|ɩɣ | ŋg|ama|kpa|a t|ɩyɛ|ayɩ|a k| tʊ| kʊ| pɔ|daa| wɛ|pa |ʊ t|ʊ p|tʊ |ʊ y| ɛs|wal| pɛ| na|ɔɔy| ya|fɛy| ɖɩ|ɖɩ |ɔɖɔ|ɔ ɛ| ɛl|i ɛ|ɩ ɖ|wɛ |ɛ k|ɛɛ | tɩ|ɩ n|paɣ|ɩ s|ɛja| ɛj|ɖɔ | ɖɔ|ɔ s|ɛla| ɛk|a s| mb|ɩ y|ɛya|pal|a y|ʊma|ɔyʊ|a ɩ|jaɖ|ɖɔɖ|kpe|ɩzɩ|ɩna| ñɩ|yi |eyi|kɛ |bʊ |mbʊ|ʊ k|mɩy|tʊm|alɩ|ŋgb|ɛzɩ| fa|ʊyʊ|ɩ ɩ|ɩfɛ| ɛt|kɩ |wey|ma |lɩ |ɔɔl|nda|ɩma|gbɛ|sam| sa|li | lɛ|ɩsɩ|akp|pak|ɣtʊ|ya |lab|sɩ |ŋ p|pɩf|day|and|kan|ɣ ɛ|sɔɔ| ye|ɩm |kɩm| kp|uli|kul|ɛyɛ|ʊmɩ|laa|iya|ɩ k|e e| ɖo|ʊ s| ha|aʊ |maʊ| ɖe|aɣt|ɔ k|ɔ y|a l| ke|pɩz|ŋgʊ|ɣ p| kɛ|eki|ɔŋ |aŋ |tɩ |ɛhɛ|bɛy|ʊ ŋ|pʊ |ba | sɔ| ɛd|nʊm| nʊ| pe|ɖʊ |ada|pad|ɣna|le | le|ʊ ɖ|ñɩn|pe |zɩɣ|ɛpɩ|naa|gʊ |ñɩm|ɣ t|a ñ| la|hal|ɛda| ɛɖ|ndʊ|m n|zʊʊ|ɖe |ana|akɩ|bɩ |abɩ|lɛ |ɛɛn|m t|ɔyɔ|ekp| ɛp|dʊ |tɩŋ|ɛkɛ|ɖam| ɖa|ina|maŋ|alʊ|uku|suk| su|kʊ |ɛsɔ|ɛtɩ|lal|ɛ l|tɛ |e l|lʊ | kɔ|ɩlɩ|ɛɛk|i p|pan| tɛ|ŋŋ |aka|pɩw|bʊy|abʊ|nab|lak|ee |yee|e w|ʊna|m p|e t|ye |iye|uu |a ɖ|nɖɩ| nɖ|dɩ |eek|pee|ga |ŋga|yaɣ|a m',
    'tem': 'a ʌ|uni| ɔ |ni |wun| wu| tə|yi | ka| yi| ʌŋ|ka | kə| kʌ|tək|kə |ɔŋ |əkə| aŋ|mar|nɛ | ʌm|ma |i t| th|ri | ɔw| a |i k|a k| ma|i m|ari| ba|wa |tha| kɔ| mʌ|ɔwa|thɔ|ba |ɔm | o |lɔm|ʌma|kɔ |i ɔ|a y|‐e |o w|ŋ k|a a|alɔ|te |i o|hal|ɔ b|aŋ |ɔ y|a m|ŋth|ŋ y| rʌ| ʌt| mə|kom|ema|yem|mʌ |ɔ k|om | ye|hɔf|ɔf | mɔ|th |e ɔ|ɛ t|ʌnɛ| ŋa| sɔ| gb| ro|ʌŋt|ɔ t|ʌth|a ɔ|ar |yɛ |ʌte|m k|ʌŋ |m ʌ|hɔ |ank|wan|ŋa |anɛ|ŋ ɔ|ŋɔŋ| ŋɔ|nko|rʌw|kʌm|ki |kət| yɛ| te|a t|ʌwa|ɔ ʌ|ʌmʌ|e a|kʌt|thi|i r|əm |ra |kəl|a w|ə k| yɔ|ʌme|me |a r|mɔ |kəp|aŋf|əŋ |e t|pa |əth|fəm|a‐e|ələ|ləŋ|ɛ k|ʌ k|ŋe |yɔ |ro |rʌ |ɔ m|gba|thə|ŋfə|li |ə b| ʌk|ə t| rə|m r|ɛ ʌ|i ʌ|ʌŋe|ta | ta|e m|bot|əpa|nʌn|m a|ma‐|sɔŋ|kəs|e w| ra|təm|ŋ t| tʌ|ath|gbə|ʌkə|ə s|ɛth|ɔ a| bo|i a|ŋ a|ŋ b|ɛ ŋ| bɛ|ʌrʌ|nth|ant|əli|bəl|o ɔ|ɔkɔ| pə| tɔ|əs |e y|kar|nka|ran|r k|ʌlə|əyi|m t|ə y|sɔ |ɔ ɔ|ŋgb|tʌŋ|ɔth|sɔt|mʌy|t k|ot |ith|ɛ m|tɔŋ|tət|ləs|mɔŋ|rək|ɔ r|thɛ| po|tə |wop| wo|gbʌ|f ʌ|ʌyi|ʌ ʌ|e k|ɛ a|mʌs|ə g|ənʌ|hən|bɛ |ara|pan|hit| ʌr|kɔŋ|a ɛ| wa|iki|ɔ g|to | to|lɔk|o t|ɛ r|eŋ |mʌl|gbɛ|ʌgb|hi |pi |tho|mə |ŋʌn|ər |oŋ |roŋ|m ŋ|hɛ |po |i‐e|mʌt|ʌ t|ʌy |ti |‐o |f ŋ|op |ɔ w|na |shɔ|nsh|ekr|sek|ʌse|aŋk|bas|mət|raŋ|kʌr|ʌtʌ|wat| ɛm|h k|i y|han|ək | ya|kəb|kɔn|yik|ayi|yir|pəy|ʌ ɔ|ɛŋ |əte',
    'toi': ' ku|a k|wa |a m| mu|la |e k|a a|ula|ali|ya |i a|de |ang|aku|tu |kwa|aan|ntu|na |lim| al|ulu|lwa|mun|ngu|luk|ele|gul|mwi|wi |gwa|kub|imw|ons| oo|oon|se |nse|ant|zyi|unt|ela|si | ak| ba| an|and|a b|ala| ci|uki|isi|nyi|ide|kid|zya| lw|ba | kw|uny|eel|laa| ul|cis|yin|kun|uli| zy| ka|tel|nte|ina|kul|kuk| ma|ili|waa|uba|wee|kwe|ede|led|nda|we |mul|nga|kus|da |izy|kut|wab|ana|i m| ya|ukw|o k|amb|yan|ka |e a|lil| bu| am|uci|a l|ilw|a c|li |sal|ban|e m|e u|u o|ila|bwa|aka|bo |bul|akw|wak|ale|kal|o a|i k|amu|bil|umi|bel|mbu|lan|usa|egw|abi|lo |awo|kuy|kup|igw|ko |uko|kak|wo |law|aci|i b|u b|ati|o l|yig|asy|ubu|wii|ika| bw|le | mb|ga |ung|kum|kka|ku |ndi|aam|muk|cit|mal|bun|yo |ukk|ind| wa|i c|bi |aya|ne |ene|len|mo | ab|upe|a n|mbi|eya|kuc| lu|ndu|a y|syi|u z|uta|ile|abo|u a|a z|ita|uka|aba|bal|imo|ley|iin|yi |ti |u u|lik|du |asi|yak|o y|u k|ube|iko|cik|zum|muc|ani|ule|mil| mi|mbo|twa|e b|umu|was|di |o n|ngw|lwe|nzy|peg|zye|abu|buk|kwi|liz| nk|i n|bam|ta |kab|alw|eka|mas|u m|imb|onz|kon|sya|miz|gan|tal| we|uum|no |yil|int|lem|del|nde|end|mbe|uya|oba|azy|iyo|i z|lek| ng|o o|cii|i o|a u|mba|mu |a o|ako|yik|yeg|ezy|a w|mi |ni |omb|kom|o b|syo|iya|usi|min| ca|e c|aul|lau|uku| aa|yee|ama|yal|kam',
    'ekk': 'sel|le |se |ja | ja|use|ise|mis|õig| va|ele|ste|ust|gus|us |igu|st | võ| õi|dus| on|on |el |te |ma |al |iga|või|a v| in|nim|ini|da |e j| te|ist| ig|ime|l o|lik|mes|e k|õi |est| ko|l i| ka|end|iku|ese|adu|gal| se|e v|tus|lt |ami|n õ|ema|aba|vab|a k| ra|lis|val|a i|atu| ku|tsi|ud | mi|ada|ali|e t| ta|ta |stu|ast|ks |ole|tam|sta|nda|es |ell|tes| pe|e s|ik |a t|is |i v|ahe|rah|t v|ava|bad|kul|ine|ne |t k|vah|ei | ei|e e|ga | ol|lus|kon|s v|ida|s t|gi |a r|mat|ioo|tud|tel|kus|oma| om|dse|kõi|teg|ees|i t|aal|ndu|a s|a j|ing|a a|iel|s k|vas|tse| ee|tem|ul |igi|lle|s s|i s|ili|vus|uta|elt| sa|aja|e a|eks|min|its|asu|a p|s o|sus|sli|i m|oni|oon|sio|ses|e o|ete|abi|ühi|ega| ki|ari|emi|si |i e| ke|uma| ri|usl|ahv|ats|eva|lev|ab |pea|eis|nis|rds|õrd|võr|sed| kõ|töö| ni| ab| üh|rid|nna|saa|teo|sek|ni |kor|ale|imi|ait|t i|sik|isi|eli|e õ|dis|ots| so|ata|lem|eab|üks|tum|dam| mõ|a o|õik|idu|har| tö|e h|nin|alt|onn|ite|ult|e m|mal|isk|kai|ead|sea|koh|d k|as |jal|põh| põ|aks|rit|hvu|dum|een|e p| ük|s j|set|ed |ng |bie|a ü|uri|s a|kin|ald|e r|t m|eri|i k| al|eel|lli|eta|dad|ule|elu|s p|i p|rii|hel| to|ndi|lse|als|iaa|sia|sot|rat|ara| kä| ve|and|umi| su|de |etu| vä|na | sü| ha|a m|e i|lit|lu |per|nud',
    'snk': 'an | a |na | na|re |a n| su| ga|a k|ga | ka|a a|en |su | se|a s|ta |ma |e s| ta|ser|ere|ama| i |aan| ra|un |nta| ma|n s|do | ki| ja|a g|jam|ne |nan| do| nt|ana| da| ya|ane|wa |ŋa |n ŋ|ri |e k|u k|a d| ŋa|ndi|ni |ra |raa| ku|taq|maa| si| ba|a r|tan| ke|aaw| sa|ren|gan|and|a b| be|a i|awa|di |i s|oxo|aqu|oro|kit|me |lli| go|tta|ini|ya |a j|ari|a m| xa|iri|aar|oll|gol|a t|e m|i a|i k|xo |sir|n d|aax|lle|a y|be |on |baa|n g|ran|din|ara|u r|e d|u n|qu | so|axu|are|o a|a f|ke | wa| ko| an|man|xar|dan|kan|ron|sor|li |de |nu |fo | fo| no|kuu|n t|pa |nde|n k|i g|len| ña| du|n n|nme|aad|u b|ang|axa|e y| fa| mo|ppa|app|kap|o k|o s| fe|ell|a x|att|kat|ure|i x|xun|e n|aba|mox|ti |i t|n y|yan|enm|ada|n f| bo|n b|a ñ| yi|i m|u t| di|da |iti|qun|nga|u a|xu |itt| ha|le |i d|sel|i n| me|ill|e t|riy|o b|ro |u d|du |saa| re|dam|haa|ind|xa |n x|ono|i i|nen|lla| mu|ond| ro|o n|udo|uud|ant|aga|ku |la | wu|nma|eye| tu|edd|fed|nox|no |o d|uur|sar|gu |e g|kil|ñaa|ire| bi|inm|ken|e b|tey|ite|ira|yu |a w|ina|iin|yi | xo|n w|o t|taa|ka |u s|anŋ|uga|und|i r|ore|bur|i b|fan|iba|xib| xi|een|u m|ogu|bog|bag|oqu|noq|oor|e r|bir| ti|i j|ban|ye |dii|o m|anm|ene|kka| ye|ña |rey| le|iña|ita|mun|ura|kaf|ank|e i|liŋ| li',
    'cjk': ' ku|a k|yi |nyi| ny|la | ci|a n|a c|wa |we | mu| ha|nga|i k|ga |ana|uli|kul|a m|esw|ela|ze |mwe| ka|ha |sa |tel|a h|swe|ung|ci |a u|ate|ma | wa|u m|kwa|han|e m|kut| mw|uci|mbu|mut|nji|nat|ya |uth|e k|na |pwa|kup|thu| ma|wes| ca|ji |kan| ya|lit|hu |i m|aku|asa|i n|mu | ul|ca |ang|e a|ina|anj|ali|imb|cip|amb|mba|i c|li |e n|i u|ka |muk|a i|awa|naw| na|fuc|ifu|uta|upw|ing|ize|ula|lin| xi|ukw|lim|ong| kw| an|ite|xim|ta |ita|umw|ulo|umu|has|kuh|kha|u c|ala|nge| mb|wo |ila| ce|cif|a a|kus|ama|tam|mwi|ili|te |imw|bu |o k| ng|ba |ipw|lo |bun|ikh|wik|ulu|mo |ufu| ak|o m|utu|ngu|imo|mil| mi|ko |a w|kun|ciz|i y|a y|kuk|eny|aze|aci|pwe|aka|o n|yum|uha|uka|e w|o y|lon|kum|e u|cim|ku |swa|e h|e c|mbi|emu|no |nal|a x|was|fun| un|uma| ja|usa| li|wil|uze| ye|o w|isa|o c|nda|ngi| es|kat|e y| in|aha|waz|yul|esa|yes|una|wen|aco|i h|cik|ema|pem|nyu|ika|kal|bi | ik|mah|zan|aso|so | uf|ata| iz|apw|tum|tal|o l|wam|iku|sak|ja | up|kwo|umb|oze|yoz|uni|ges|cen|kuz|wak|mul|wan|ulw|o u|cyu| cy|u i|e i|tan|mun| um|kuc|ngw|cin|co |go |ngo|da |ipe|ge |lem| uk| yo|lwi|nin|ikw|u k|kuf|uso|i w|upi|lum|gwe|uki|upu|and|pha|ces|ond|i j|man|ile|ule|uku|gik|akw|ino|ele| if|hac|tha|cil|eka|za |vul|uvu|hel|lu | it|ke |lya',
    'ada': 'mi | e |nɛ | nɔ| nɛ|nɔ | he|he |ɔ n| a | ng|e n|a n|kɛ | kɛ|aa |ɛ e|blɔ| bl|i k|i n|gɛ |ngɛ|ɛ n|lɔ |e b| mi| ma| ko|ɛ h| ts|ko |ɛ a|e h| ni|hi |ɛɛ |ɔ k|a m|i h| ɔ |tsu|ma |ami|a k| ny|ɔ f|oo |loo|i a| be|ya |e m|be |ni | kp|o n| si|si |nya|emi|ɛ m|fɛɛ| fɛ|laa|a h|a b|e j|a t| hi|e k|umi| ka|kpa| je|ɔ h|e s| lo| ye|ɔ e|i t|pee|omi|mɛ | pe|mla|i m| wo|je | ha|ɔmi|ɔ m|maa|sum|ke |i b|o e|ɛ k|ɔ t|alo| ml|ee | sa|ɛ ɔ|ɔɔ |ha | na|lɛ | lɛ|a a|i l|ɔ́ |a s|ɛ s| hɛ| gb| su|nɔ́|e p| al|eɔ |ɛ b|ne |i s|ɛmi| fa|uaa|sua| bɔ|ɔ a| to| ji|o k|kaa|bɔ |a e|ihi|u n|e ɔ|o a|yem|ane|e w|suɔ|imi|e y| ke|ɛ y|ɛ t| hu|san| we| jɔ|ɔhi|lɔh|e e|ahi|i j| bu|ɛ j|pa | ja| ku|wom|ngɔ|a j|him| bi|ue |e a| ya|tom|ɔ b|gba|o m|jam|́ k|fa |ake|ɛ p|uu |ba |hla| hl|sa |ɔ s|hu |e f|hɛɛ|uɔ | tu|e t|ji |tsɔ|jɔm|i ɔ|kuu|kak|ɛ g|a l|wo | sɔ|tue|o h| gu|isi|ɔ y|sɛ |o b|sɔɔ|gɔ |ia | ju| kɔ|eem|e l|akp|pak|li |e g|sɔs|a p|uɛ | yi|ti |sis| sɛ|to |ɔ l|ɔ w|ɛ w|yɛm|na |hia| nu|ɔsɔ|ye | mɛ|sem|ase|kas|hiɔ|naa|íhi|níh| ní|kpe|usu|uam|onɛ|kon|nih|eeɔ|mah|o l|a w|lam|ɔɛ |sɔɛ| pu|hɛ | ba|gu |a g|a y|ɛti|pɛt|kpɛ|o s| fɔ|bi |nyu|o j|we |se |uo |suo|ade| ad|bua|su |ngm| fi|iɔ |u k|haa|oɔ |koj| am|ɔ ɔ|ɛpɛ|i p|i e|guɛ| wa|io |jio|bam|ɔ j|yo ',
    'quy': 'chi|nch|hik|anc| ka|una|man|aq |pas|ana|kun|as |paq|nan|kan|ikp|cha|sqa|qa |ik |apa|aku|ech|kpa| de|cho|rec|ere|der|spa| ma|asq|am |an |taq|pa |nam| ru| ch|yoq|ta |na |a k|ina|mi |qan|ima| ll|aqa|lli|oyo|hoy|ant|ach|run|nap| im|pi |nak|hay|asp|ayn|wan|q k|ipa|nta|hin|oq |cio| hi|iw |liw|inc|ion|aci|chu|lla|pip|nas|npa|nin|qmi|kay|kas|ota|a m|anp| hu|all|nac| na|yna| ya|ari|api|i k|w r|nku|iku|in |a c|ama| pi|may|hu |kuy|ay |nma|has|onc|hon| ot| wa|aqm|anm|a p|n h|ata| li|ikm|hwa|chw|ma |awa|a d|qta|ara|pan|m d|pap|yku|yni|a l|kma|q l|ich|kin|huk|a r| ha|yan|uwa| ca|nqa|kta|ikt|q m|a i|n k|kpi|mun| sa|cas|usp|q h|wsa|aws|kaw|bre|ibr|lib|lin| al|k c| mu|ask|kus|a h|s l|ank|q d|yta|e k|tap|q c|mpa|pak|ski|qaq|ien|i c| qa|tin|re |nni|uch|isq|a s|was|ern|s m|a a|ayk|onn|s y|oqm|aqt|ruw|qpa|aqp|par|amp| am|nmi|ley| le|ayp|nat|i h|yma|onk|law|ier|map|a f|war|ita| ni|naq|yac|tar|naw|ayt|sak|n a|anq| pa|a q|aya|val| va|ypi|sti|ast|ura|n c|m p|s o|w n|rno|bie|obi|gob| go|rma|qar|nit|m i| ta|say|haw|s i|k l|asa|k h|rur|pun|wac|onm|tan| fa|tam|kap|oqt|i d|s c|ici| ju|a t|ras|ran|uy |uku| tu|qay|k k|ku |q i|arm|uk |a y|nti|awk|um |igu|esq|k m|sap|ati|aw |a o|asi|n p|sic|isp|aru|ukl|ten|pti|qku',
    'rmn': 'aj | te|te |en | sa| le|el | si|si |aka|sar|pen|les|kaj|es |ipe|sav|qe |j t| ha| th|ja |hak| e |and| o |ave|i l|ar |ta |esq| an|a s|sqe| ma| ja|ia |nas| ta|imn|e t|as |mna|kas|e s|haj|tha|s s|ark|asq|e a|nd |i t|s h|rka| na| i | pe|mes|isa|vel|cia| bi|ne |bar|kan| aj| me|avo|utn|the|e k|lo |o s|est|qo |e p|n s|ard|hem|a a| av| so| ba| pr|õl |a t|mat|ima|l p|e r|e m|e o| ka|man|orr|e d| di|o t|rel|sqo|re | ov|ika| re|qi | ak|enq|ere|vor|e b|res|ove|avi|ve |ver|o a|n t|o m|akh|rak|rim|a p|no |ana| ra|sti|d o|len|aja|rre|but| va|sqi|ker|r s|de |ata|ren|ali|ara|ste|ti |e l|r t|vip| ke|na |i s|ang|àci|tim|nqe|kon| ph|n a|nip| de|j b|àlo|al | pa| bu|are|vi |dõl| ni|tar| ko|naś| pu|o k|n n|l a| po|śaj| śa|on |lim|er |ari|i a|ven|pe |śti|aśt|a l|o p|e n|dik|rdõ|nik|l s|tis|ast|tne|a m|a e|erd|ndi|ni |pes|rin|j s|e h|aba|rab|khe|tni|eme|uti|rip|uj |amu|ano|ćar|a j|ća |la |khl|l t|e z|do |o z|ri |mut|kri|alo|soc|i p|so |ran|del|kar|nuś|anu|pra|din|nge|nis|ută|rde|vo |muj|mam|i d|nća|enć|ate|uni| as|iko| zi|rdo|l o|j p|eri|emu|ane|i b|o j|oci|i r|a d|ing| je|iàl|e e|l l|ɵar| za|tes|ćha|pal| vi|l b|ɵe |l e|aća|one|kin|to |ziv|imi|a n|per|ter|ris| kr|s a| st|o b| ćh|a i|kla|da |nda|e j|ekh|jek',
    'bin': 'e o|ne | ne|an |en |be | o |e e|wan|mwa|n n|vbe|mwe|emw|evb|na |omw|e n| em|in | na|ie |gha|n e| gh|re | om|wen|e a|ha | ke|e i|n o|gie|bo | vb|wee| kh|win| ir|vbo| ev|o n|gbe|he |hia|nmw|o r|a r|o k| no|ogi|nog|kev|tin|eti| et| mw|e u|mwi|a g|ra | ya|een|ee |a n|a o|ke | re| we|rri|ghe|ogh| og|a e|n k| a |ia |ya |o g|ien| uh| rr|ye |khi|ran|ira|ere|a m|a k|ian| ot|ro |n i|ovb|o m| ye|egb| ra|hi |de |kpa| eg| hi|n y|o e|hae| ok|a y|eke|mie| mi| gb|o y|ba |oto|rhi|n m| iw| ru| er|arr| ar|unm|rro| ov|e k|okp|aen|n a|hek|khe|nna|inn|ugi|hie|a u|ru |ae |to |wun|mwu|hun|otu|i k|i n|a v|nde|and| do| or|uem|rue|dom|n w|oba|iob|rio|e r|tu |ze |ehe|pa |e v| ma|aya|iru|iwi|ma | rh|un |uhu|yan|mo |gba|e y|o h| la|a i|rie|irr|ai |uhi|ho |u o|ren|yi | ni|egh|u e|u a| ug|ugh| al| iy|beh|aan|a d|n g|gho|ue |onm|ghi|anm|iko| ai|ene|i r|a a|aze| az|khu|i e|bi |vbi| i |yaa| yi| ek|hin|bie|on | ay|emo| od|aro|obo|e d|rov|o w|e g|ii |nii|se |kom| ow|ron|kha|o v| se|a s|rre| de|lug|alu|owa|wu |a w|aa |e w| bi|a b|n h|dia|fue|ifu| if|ebe| eb|ode|sa | os|nug|anu|wa |oo |gue|uwu| uw|ese|bug|vbu| en|n r| lo|n l|ugb|kug|la |uyi| uy|i v|o o|i g|rra|aku| ab| es|abe|aik|oro|enr| eh|eha|o a|a l|we |n u|i o|okh',
    'gaa': 'mɔ | ni|ni |kɛ | ak|lɛ |ɛ a|ɛ m| mɔ|akɛ| ko| he|gbɛ|i a|ɛɛ | lɛ|ɔ n|ɛ e|ko |aa |bɛ |yɛ |i e| kɛ|ɔ k| yɛ|li |ɛ h| ml|egb|oo |fɛɛ| fɛ|shi|aŋ |heg|mli|ɔɔ |a a| es| gb|i n|loo|ɛ n|maŋ| ma|ɛ k|i k| nɔ|ɔ y|nɔ |ɔ f| al|he |esa| sh|alo| ek|ɔ m|ii |amɔ| eh| en|emɔ|ji |naa|bɔ |e n|fee|o a|oni|kon|o n|ee | hu|o e| bɔ|i m|hi | am|ɔ l|hu |tsu|umɔ|ɛi |aaa|na |nii|sum|sa |ɔmɔ|ena|i y|ɛji|nɛɛ| nɛ|ɛ g|baa|eem|ɔ e|a l|kwɛ|yɔɔ|eɔ |amɛ|tsɔ| sa|ana| ts|saa|kɛj|ɔ a|ehe|a m|toi|eli|yel|aji|i l| ah|mɛi| at|e e|gba|a n| an|ane|hiɛ| na|eko|eye| ey|o h|kom|mla| kr| ej| as|ŋ n|san| ay|i s|nit|ash|ekɛ|ha |e k|ne | hi|i h|ɛ t|esh|efe|iɔ |its|iaŋ|ku |o k|ats|kpa| kp|ome|gbɔ|ets| ab|ɔ b|ɛ b|ye | et|a e|shw|oko|a k| bɛ|ɔ h|ɛ y| af| ku|sɛ |tsɛ|ŋ h|uɔ |ŋŋ | to|ŋmɛ|ɛ s| mɛ|oi |mɔɔ|aye|hwe| ef|la |ehi|rok|kro| ji|ŋ k|o m|aka|akw|o y| lo|o s|jɛ | ny|e a|ŋmɔ| ba|bii|aan|ŋts|ɛŋt|iɛŋ|diɛ| di|ai |u k|o l|ŋ m| eb|ɔ s|aha|nyɔ|i j|a h|ɛ l|wɛ |usu| aw| ja|suɔ|eni|i f|agb| ag|bɔm|sem|bua|any|ɛ d|i b|maj|mɛb|a s|eŋm|awo|e b|afe|hik| yi|u e|e s|ish|nak|anɔ|hey|ŋ a|o g|jam|u m|o b|aŋm| yɔ|bɛi|yeɔ| su|nyɛ|hew|me |ɔ g|ɔse| ee|ilɛ|hil|ihi|hih|las|̃la|ãl|bã| ŋm|nyo|te |esu|kai|ate|ŋma|eee|ɛmɔ|ɛia| eg|alɛ|jia|ɔŋ |ala|wal|hiɔ|ɛ f|his',
    'ndo': 'na |oku| na|wa |a o|a n| om| uu| ok|e o|ong|ka |uth|mba| ne|ntu|ba |tu |omu|nge|he |a u|the|uut|emb|hem|o o|o n|ehe|unt|e n|a w|nga|kal| wo| ke|ang| iy|lon|mun|no |lo |la |o i|ku | no|oka|keh|ulu|u n|we |shi|a m|ala|ko |ga |a k|ge |eng|nen|u k|ilo|osh|ngo|han|a y|elo|gwa|ngu|ye |li |ano|hil| mo|gul|ana|luk|a e|tha|dhi|uka| pa|lwa|go |ath|ho |man|kwa|ta |oma| sh|a p|wan|thi|uko| ko|wok| ta|ha |mwe|ya |wo |e p| yo|gel|a i|e m| os|nka|ika|uun|hi | ka|o g|sho|ema| li|kuk|iya|o w|i n|ith|and|men|ame|gam|ele|pan|opa|ash|ndj|po |hik|yom| po|le |ing|alo| el|olo|sha|kul|nok|ilw|kug|o k|a a|adh|aka|lat|aa |pam| ye|kan|iyo|mbo| we|kut|nin|e e|umb|onk|ndu| go|ike|ond|non|gan|omo|una|a s| e |mon| ga|ela|und|waa| ng|yok|ne |ulo|amw|oye| oy|aan|a l|iil|okw|eta| a |wen| ku|i k| gw|aku|igw|ila|a t| nd|ina|yuu|ene|ke | on| dh|iye|mo |pau|bo |him|lyo|o s|ula|wat|ota|yon|e t|eko|yaa|o e| me|a g|yop|e g|lun|alu|ngw|omb|ane| th|yi |o y| ii|nom|ili|dho|ono|mok|uga|vet|eho|ome|kun|iyu|i m|ali|epa| ni|lwe|opo|lok|oko|hok|i o|lol|djo|ung|oon|i t| yi|alw| ot|ukw|uuk|uki|egu|mii|o m| wu| mb|awa|naw|edh|ani|kat|nwa|enw|e k|taa|ont|a h|u t|lel|uni|ndo|wom| mw|she|ola|pwa|dyo|ndy|nem|ndi|yeh|aye|fut|nek|udh|omi',
    'nym': 'a k|na | ku|ya | na|la | ya|a n|a m|ila|wa |hu | mu|le | ha|aki|a b| wi|hak|a h|nhu|i y|ki |we |unh|mun|a w|kil| ki|ga |i n| ba|ina|ele| kw| wa|win|nga| bu|ili|u n|ang|u w|kwe|mu |a i|gel|aga| bi|kwi|ja |lu |ulu|si |nsi| ns|akw|lya| ly|ige|gan|e n|yo |mo |ali|han|e k|i k|ini|lwa|and|e l|a y|ula| al|ngi| nu| ig|ban|ka |kub|u a|aya| ng|ule|li |gi |ing|yag|kul|iha|ba | lu|ile|lul|alu|iya| ma|ika|aba|wiy|o a|nul|lim|iwa|gal|ala|e b|u b| ga|kus|ung|ziw|nzi|ku |ubi|bi |yak|e i|lil|uli|o y|wan|imo|iwe|no |ng’|kwa|ndi|usa|ilw|e w|ani|bil|zil|se |ose| il|o g|uma|tum|gul|agu|bo |kut|i b|kup|uba|shi|lo |nil|lin|g’w|dik|sab|a u| sh|ana|o n|ngu|abo|o k|utu| nz|u m| yi| li|o l|umo|mil|nik|iga|u k|ha |da |uga|a l|kuk|kuj|iku|lag|imu|ayo|fay|afa|maf|mam|go |ngo|ye |bun|yi |uhu|ngw| mi| ul|yin|aka|hay|lek|ilo|ano|ni |nda|lug|eng|jo |biy|gwa|bya| bo|anh|yan|sun|wal|nin| ni|pan|upa|isu|ma |piw|bad|lab|wel|a s|iye|wis|kal|wik|ibi|sag|iyo|azi|niy|kay| ka|zi |duh|u l|sha|ezi|e m|wib|bul|atu|i m|kuz| ak|a a|o i|w’i| ja|i w| um|u u|lwe|’ih|din| di|i l|alw|bos|eyo|bal|u i|ans|say| sa|o b|bab|usu|ke |pwa|ipw|lip|ulw|o u|ama|e h|aha|mah|upi|nha|ole|tog|but|ami|iti| we|nja|gil|ayi|gu |ne |ene|kim|yil|uku|wig',
    'sus': 'axa|xa |ma |a a| ma|an | xa| na|ama| a |xan|un |ra | sa|ada| ax|a x|xi |ui |a m|di |a n|nun|ya |de | nu|iri| ad| bɛ|i n|nax|bɛ |a s|lan|in | bi|n a|a b|rin|bir| mu|a f|dam| ra|i b|mu |fe |nde|na |yi |nyi|dax| fe|kui| ku|ari| wa|ali|xun|ayi|ara| ɲa|i a|n n|amu|ɛtɛ|adi|ɛ a| la|n b|mad|li |ndi|e m|iya| xu|n m|ana|sar|wal|ɔtɔ|i m| nd|a k|a y| ba|sɔt|e x|n x|ɛ n|nam|man| da| fa|i k|nɛ | sɔ|aba|i s|kan|i x|una|yib|any| ki|ie | ya|ɲam|riy|tɛ | e |ixi|a l|era|fer|ala|nxi|aya|ibi|axi|en |ti |sab|ɛe |iyɛ|e n|ima|ɛ s|and|den|biy|way| bɔ|e s|n f| su|yɛt| yɛ|bar|e b|a w|tɔ |i d|ati|mak| di| mi| fi|a d| yi| nɔ|ank|inɛ|mal|afe|ɛ m|bun|ɔxi|e y|ta |und|mas| de|ira|awa|aka|aga|e k|nad|bɔx|mix|ant|gi |ɔma|nɔm|kim|ɛ k|ɛra|xin|gan|uga|sug|e a| gb|ind|ras|yɛ |n s|ri |a ɲ|ibu| ib|sa |rɛ |u n|ere| ke|ɛrɛ|i r|abu|yo |alu|mun|asa|u a|yam|anx|ga |yir|e f|mul|bɛt|gbɛ|ee | si|ren|ker|ide|o m| yo| an|e r|a t|nka|fan|eya|mui|i y|tɛr|n y|xɛ |sen|ase|ndɛ| ta| fu|ni |ɛ d|bat|nba|fin|rab|ba |tin| am|n l|a r|ɲax|lu | al|end|yɛe|ɛ b|a e|ɛ r| xi|nta|dɛ | so|uti|i g|bay|enb|i f|ɛ f|i ɲ|i w|o n|inx|xaf|axe|ban|may|yay|far| tɔ|tɔn|ula|n d|tan|din|ing|n k| ka|xam| fo|lui|ral|afa|ɲɛ |nni|ɔnn|lɔn| lɔ|raw|fut|nfe|ago|sag|u m',
    'tly': 'iyə|ən | bə|yən|on |əti| iy| hə|də |ti |lə |həx|bə |ədə|ard| ka| ha| şə|kar|e h|har|ar |de |yə |əxs| tə|rde|şəx|ılə|ə ş|ni | qı|ə i|si |qıl|te |ə h|ə m| be|n b|yət|hes| he|est|ış |ste|ş h| mə|xsi|r q|i i|əxı|nə |ştə|xış|i h|ku | sə| mı|ə b|əy |i b|əni| de|ıə |rə |ışt|tə |ə k|bıə|ya |nin|odə| ya|zod|ozo| oz|ərə| va|ne |ə d|tən|ə s| ış|in |həm|n d|niy|onə|mon|ə v|əmi| çı|n i|iku|co | co|bər|n h| ko|be |çı |dət|rdə|yo |mıd| kə|ə c|bey|ini|y h|ıda|i t|ə ə|kəs| hi|ıni|ə n|e i|sos|oni| bı|e ə|əyo|miy|təm|ət |ə t|daf| da|siy|lət|ine|n k|yon|osi| so|bən|asi|i d|von|son| in|əx |n t|afi| ni|çəy|hiç|i m|inə|min|u b|təd|ətə|dey| çə| cə|iç | bo|əkə| ma|omə|bəy|alə|sia|sti|əro|sil|hsi|əhs|təh|nik|i s|dax|ey |eyo| vı| də|fiə|tər|nun|ə y|əbı|məh|kət|n m|n o|yyə| və|kə |ial| di|rəf|ənə|n ç|dən|non|ins|mə |ifa|sər|eəd|o i|sə |əsə|bəs|liy|ion|tio|iə |zın|o b|ton|əto|emo|ə o|e b|bın|mət|ə ç|ıbə|nıb| nı|iyy|i ə|din|r k|əvo|rob|xon|əxo|mmə|əmm|o k|adə|tif|il |əsi|ist| is|oy |axt|vax| do|uni|anu| ğa|kon|ə j| hı|bo | əb|eyn|urə|cur| cu|nət|ida| ji|iyo|məd| mi|əğı|cin| ci|i c|ə r|ənd|var|obə|bəş|səy|vlə|evl|dev|cəm|əno|l b|di |i ı|ilə|xil|axi| ro|deə|ay |kay|diy|oət|səd| ta|əmə|itə|e m| əs|ino|x i|and|vıj',
    'srr': 'na |aa | a | o | wa| mb|a w|war| na|mba| ka|a a|baa| re|ref|and|at | ke|aat|a n|ke | no|waa|uu |um |fna|no |ax |jeg|a j|efn|a o| je|nd |ara|kaa|el |a f| te|u r| sa| fa| um|aag|en |e n|am |aax| ta|a t|te |saa| le| ox|in |een|xuu|oxu|oor| ni|ng |ta |le | fo|ni | ne|a k|ra |or |mbo|a d| an|ne |fa |a m|too|e m|o k|iin|kam|oo |aan|a p|e w|ang|oon|eg |eng|gna|o ñ|ga | de|ee | ma|len| ng|ñoo|rna|m n|t o|maa| nd|o l|una|tee|g o|o n|oow| ño|boo| bo| da| to| fi|raa|oox| la|n n|gee| ña|aga|a b|den| ca| nj|e a|are|a l|fi |o j|a s|bug|r n|ato|kat|m a|gaa|x l| ya|ena|a c| ja| mu|eer|a r|o x|t n|it |e t|uun|ñaa|op |a ñ|naa|t a|oka|an |gen|m o| al| pi|ona|g w|kii| ki|m m|e f| xa|ef |ay |o t|l n|nan|nee|egn|yee| ye|ow |o m|n o|pi |laa|nga|n a|fop|dna| we|i m|bok|i a|nda|d o| nu| i |ox |xoo| xo|aak|a x|o a|t k| aa|ir |fog|ala|du |bod|p m|we |ale|e x|re | ge|koo|arn|r k|d n|ern|ap |nuu|noo|il |ndi|doo| do|ina|lay|eet|iid|eeg|ugn| bu|og |u n|can|all|yaa|xe |axe|of |nge|i k|i n| xu|l k|ako|a y|uwa|luw| lu|d u| ga|jal|e o|o y| fe|ate|u t|g n|f a|as |et | xe|gni|e y|aru|aay|ag | ba|bar|iif|yii| yi|odu|g a|lel|lle|cal|al | ax|ngo|kee|paa| pa|goo| of|x o|m s|a g|aam|la |ṕa| ṕ|x n|o g|id |a ɓ| jo|ooy|aap',
    'kha': ' ka|ka |a k| ba| ki|ki |ing| ji|ng |jin|ei |an |ong| ïa|wei|ban|a j|ad |i k|ba |ha |ïa | ha|bad| la|ok |ne | sh|hok|don|on | ho|ah |ang|a h|sha| do| pa|a l|n k|i d|a b|g k|pyn| py|i p|lon|la |i b|awe|kaw| ne|k b|iñ |d k|uwe| uw|aiñ|am |oh |a s|da |kan|ait|pa |e k|no | kh|lan|id |h ï| ri|n ï|jon| jo| lo|ngï|d b|lui|lai|ew |hah|o k|ano|m k|m b| ai|ri | sa|ar |a ï|na | ma|ngl|i h|at |uid|tlu|itl|iew|h b|ai |h k|ngs|a r|em |gïa| da|rie|eh |kam|uh |i n|ynt| ky|or |n p|i j|ngp|dei|ïoh|kum|kyn| de|a m|a d|i l|ynr| na| ïo|n l|t k| ku|kha|aba|i s|sah|ngk| by|ïad|ym |kab|ada|non|m d|um |shi|yns|pyr|kat|byn|g b|mar|hla|g s|a n|r k|gpy|man|m j|ngt|it |sho|leh|r b|ane|d j|hon|n b|a p| ym|rai|im |bri| im|nia|g h|ap |yng|e b|ngb|aid| be|ta |h p|a a|n s|har|syn|glo|ahl|mla|iml| ni|yll|khl|lem|om |e a|be |i u| hi|h h| tr|nsh| no|a i|hei| ja|k k|rei|tre|nge| bu|t h|ryn|lah|gsh|m ï|iba|kib|nta|aw |pat| sy|alo|n j|i r|a t|ynï|gla|ti |bor|gka|eng| le|up |lad|bah| se|ot |ian|ngm|rsh|yrs|n u| pu|hap|hi |rim|sai|the|nth|jai|hle|ynb|nra|d h|t b|w b|g j|ngn|uk |ïin|ia | ly|e j|h n|p k| ta|ñ k|dba|idb|pai|et |bha|khe|mat|thu|h j|iwe|kiw|g t|lor|hal|h s|huh|shu|ngd| ru|iam|en |ra |bar|le |ule|pul|d p|anb|un ',
    'oci': ' de|de | a |ion| la|la |as | e |on |ent|a l|cio| pe|rec|tat|per|at |dre|a d|ech|na | dr| lo| qu|men|es |nt |a p|s d|son|e l| to|ona|e s|tot|ch |a a| se| co|que|aci|e d|s e|ame|ns |ers| pa|ta | un|ue |ota|rso|lo | d | pr| so|ita|e p| li|s l|er |ar |al | l |t d|un |e c|a s|s a|cia|ons| en| sa| re|las|con| di|ls |res|sa | in| es|a e|os | o |se |sen|ts |n d|h a|nal|o d| ca|s p|t e|ica|da |ser|los| ma|ida|l e| si|tra|n p|rta|en |del| al|est|pas|ala|ert|nci|ali|egu|e a|sta|rà |nac|lit|nta|pro|r l|ont|s t|iá |com|s s|als| na|sse|lic|a c|cci|t l|siá|una|ra |ens|ote|bli|t a| ac|ntr|ada|ber|ibe|lib|r d| au|n e|ats|re |a u| fo|oci|soc| me|ca |nse|t p|ter|ins|din|aut|e r|hes|n l|ari|tge|atg|erà|ndi|eta|n a|ond|ina|n s|e t|pre|che|e e|tes|par|s q|h d|an |s i|ura|a t|vid|a q|ind|el |qui|a m|d a|ia |ene|pri|l a|mai|te |ria|act|aus|ge |deg|dic|int|fon|ial|t t|s n|rs |s m|ici| as|abl|cte|ecc|s c|seg|qu |rid|end|pen|l d|à p|lig|eli|rac|e f|esp|tre|utr|tar|gal|ega|ure|iss|èss|els|is |ir |àri|r a|n t|tec|ant|d e| tr|gun| vi|ivi|imi|ri |s o|ís |nte|nda|tan| ta| fa|ena|tic| po| le|ist|dis|cla| pò|amb|énc| eg|iur|liu|s u|tis|vol|art|nha|ral|mar|r p|uni|cas|usi|ai |ssi|ass|das|ren| el|ubl|pub| pu|cau| ar',
    'hea': 'it |ix |aix|ib |ang|ong|if |aib|id | la| li|lai|ot | do|f l| ye|ef |ait| ba|t d| di| da| no|ol |aif|et |non|of |t y|uai|gb |ngb|mai| ma|nx |lit| qu|enx|hai|qua|ax | go|dol| hu| ja|gf |ngf|b d| se| ha| ax|t n|x d|dai|f j|t h| ai|il | zi|ban|t g|ail|gd |ngd|x q|nen| ne| gh|x l| de|nt |dio|x m| na|nf |d n|yen|ul |eet| xi| ni|yef|gt |ngt|ian|t l|ns |ens| id|zit|ab |hul|nai|t z| ji|ent|x b| za| xe|f d|b g|nia|gof|b z|l n|ut |gx |ngx|f g|is |s d|eef|t j|dot| je|gid| gi| fa|aot|dei|af |d d|ox |l d|gl |ngl|t x|jab|b j|x n| ho|x s|f h|iee|nb |gha| si|x j|t a|eix|uf |xid|ud |enb|uit| mo|bao|f b|f z|eis|t b| ju|gon|mon|aox|f s|d h|as | ga|os |iot|jao|ios|b n|x g|faf|b h|s h|gai|d a|d g| xa|f x| vu|xen|inf| ze|x z|ob | yi|enf|ghe|gs |ngs|xan|x x|b l| pi|f n|see|ad |b f|t s|d m| zo|l h|zen| bi|t f|x a| du|die|hui|b s|zas|hof| fu|f y|l x| be|iao|x y|lif|l a|l g|set|xit|el | ya| lo|aob|b b|xee|b x|cai| ca|ux |sen|at |zai|jee|sei|ub |x h|jif| zu| wi|b a|s n|f a|l j|hei|s g|ex |d l|eb |us |lol|hot|yit|fut|sit|dad| gu|zon|l z|jib|ben|t i|den|iel|jus| ti|f t|jub|t m|aid|s l| ib|jan|f q|f m|d b| ge| hv|pin|b y|f c| ci|t c|b w|jef|x f|b q|f i|jit|l q|dud|lie|lix|l m|yan|aof|sif|jen|lia|wie|t v|s b| qi',
    'gkp': 'aa | ma|a k|maa| ə | nu| a | kɛ|la |i h|ala|a n| hu|ei |kɛ |ɛli| hw| lɔ|li | ka|le |pɛl|i k| di|aal|ɔn | mɛ|ɛni|mɛn|kaa| yi|ni |di |ɓa | da|ə k|ele| kp|i l|hu |da |i ə|ɛi |a p|laa| ye|ɔi |lə |an | pɛ|a h|kel|nuk|ti | la|ɔɔ |yei|ɓo |nu |ələ|a l|lɔi|a m|ɔlɔ|ə m| yɛ|pəl|i m|a y|ma |ai |hwə|wə |ii | ti| ŋɔ|hwa|n n|u m|i a|i y|lɛ |e y|n m|uke|yii| ɲe| pə|olo|kpɔ|aan|u y|ɛ a|ɛ ə|yɛ |ulo| ɓa|i d|ŋɔɔ|i n|wa |gbɔ|ɔpe|a ə|a ɲ|kol|ɔ l| lo|yi |lon|lɔp|ɲei|u k|ili|ee |aak|nɛ |lo |i ɲ|a d| ni|ɔɓo|ju | ɲɛ|a ɓ| ga|a t| ko|i t|kpɛ|əlɛ| əl|nii| gb|u d|lɔɓ| gɛ|gaa|ə p| ta|iiɓ|naa| lɛ| nɔ| ju|ɛn |na | kɔ|ɲɛi|ŋaa| ŋa|i g| tɔ|iɓa|ɔma|ui |nui|i ŋ|a a| ke|ɛlɛ|kul|ɛ d|ta |ɔŋɔ|ɛ k|un |bɔɔ|ɛ l| ki| ɲa|ɔ k|wai|ə l|ə g|lɔ | na|mak|wal|anɛ|ɛ m|kɛn| dɔ|wɛl|ɛnɛ|uka|pɔn| ya|ə h|owa|nua|kɛi|pee|a ŋ|akɛ|a w|nna| ku|ŋɔ | hɔ|nɔi|lan| mə|a g| jɔ|i ɓ|pe | gu|woo|n ɲ|kɛm|n d|əle|n g|kan|gɛ |lok|o m|e l|ə n|ɔwɔ|ɛ y|ama|low|akw|ɛti|aam|on |ɔ m|ila|lɔn|uta|nut|kɔŋ|hɔl|əla|mun|a j|ɔɓa|lu |pɔ | ɓo|e h|kil|oo |ɓə | ɓə|n ŋ|yɛn|kəl| kə|nɔn|tɔ |okɛ| wa|ə t|wɔ |pɔm|ɔ g|ilo|o d|ilə|iə |uaa|ŋɔn|ə ŋ|ya |iya| ŋu|iti| li|mɛi|tɔn|onn|oi |ɔ n|ini|ɛ g|ɛgb|lɛg| mu|ɔɔɓ|ulu|hul|jɔl|hɛn|ə ɓ| nɛ|ahi|ɲah|iɲa|liɲ|ɛna|ɲaa|awo|u l|kɔl|wu |uwu|huw',
    'hni': 'aq |iq |ol |il |eil|ei | e |nei|aol|oq |sol|al |uq | ma|liq|q m|aoq|vq |l l|hha| ss|maq|mei| li| la| me| aq|eiq|q s|l m|sso| hh|yuq|q b|q h|q l| qi|q a|col|lne|l e| co| yo| ne| mi|haq| bi|pyu|q e|oln|iei| ha|lei|yoq|bi | le|qso|aqs| ng|qiq|q y|av |nga|qhh| za|hal|miq|laq|uv |ha |ul |ovq|q q|ivq|oqh|oqj|goq|l n| ao|l h|yul| go| xi|q n|saq|nie|l a| ta|gao|hao|q c|l q|zao|lal|a l|aqn| ya|avq| bo|eiv| al|jal|qja|qni|v l|xil|olp|bo |zaq|l z| mo|duv|lao|ma | da|lpy|so |iqn|ldu|duq| hu|if |zei|ild|v n| ba|ssa|mee|dei|hho|gee|l y|taq|i z|i h|e c|uvq|a b| na| de|q k|yao|eeq|l d| lo|e n|qli|mov|i m|q z|lav|qa |doq| ei|a m|el |zol| zo|ga | py|aln|iv |q d|jol| ka|q x|lme| ce|qiv|aql|faq|l s|q p|i n| qa|huv|i a|kao| si|eq |a g|cei|i l|eel| du|ev |lha|nu |qnu| ze| sa|i y| ni|hyu|o m|alm|l b|hov|zyu|qo | qo|qle| fa|l t|e m|aqh|q t|old| pa|i s|mil|mia|qla|siq|ya | so|o l|gal|soq|jav| ja|q g|vql| jo|olq|l k|ldo| ga|a s|ov | ko|dao|v a|yil|e q|dal| gu|olk|nge|lo |v m|lee|oql|aqy|ilh|qji|iqz|yo |l c|qdu|nee|v d|oqp|lla|bal|oqg| zy| yi|guq|lka|loq|qza|yu |a n|v s|kyu|o q|eev|i g|v q|hav|qha|lma|ilm|hol|l p|olh|e z|i q|q j|l x|aqm|l g|lja| do|a a|e g|nyu|kov|i c|qpy|lif|iql|f h|bao| su|iqh|qei|i p|e s',
    'fry': 'en |an |och| en|ing|cht|de |n e|fan| fa|joc|rjo|ng |yn | rj|it |oar|n f|at | ha| it| be| yn| de| oa|te |in |n s|ht |e f|op | op|t o|fer| fe|wur|elk| el|der| te|lik|nde| ûn|hat|lk |of | of| fo| wu|t r|oan|ar |ke |n o|er |n w|ch | fr|rde|ien|ike|ûnd|n i|ten|e e|urd| sy| st|k h|foa|gen| ge|le |syn|e o|ens|ear|e s|om |tsj|n d| in|jin|n t|rij|fri|ste|e w|e m|il |sil| si|re |n b|min| e |den|ige|dy | dy|id |et |n h|ers|ne |nin|hei| om|mme|t f| me|n g|asj|nst|ins|lin|jen|e b|bes|men| t |sji|ski|mei|hte|ske| al|y t|nne|eid| tr|imm|t i|are|ber|ich|sje|tro|erw|ei |jhe|ijh|n m|is |g e|str|ter| na| ma|âld|ns | mi|lle|all|t h|roc|eri|inn|t e|sti|fol|t d|e n| ta|ker|lea|e r|lde|kip|s e|ard|nsk| da|zen|lli|nge|pen|n n|ein|ere|ona|jon|sjo|nas|ede|hâl|ern|ken|dat|p i| by| gr|anl|r d|nim|dêr| dê| ne|end|n y|arr|e h| we|mie|êze|wêz|ngs| ie|je |nli|tli|esk|ean| ni|soa|rso|eit|ite|ren|ale|f o|lit|as |sûn|rin|erk|ze |st |r i|wwe|aww|haw|ij |rwi|d f|t t|ele|iis|wii|tin|ge |by |wen|tel|g t|erm|eni|wet|raf|tra|tea|ûnt|han|emi|per| pe|g f|est|t s|nal|s f|ik |pli|gin|sts|r s|kle| di|hed|oer| he|urk|ali|n a|rie|beg|dic|gs |epe| ea|aas|e g|e y|p f| ts|rmi|e û|ann|t b|tei|s d|sel| as|êr |bie|ier|dst|al | ek| sû',
    'yua': ' u |al |aʼa|l u|ʼal|áak| tu|il |ak |u k|oʼo|el | ka|máa|an |l m| ye|tel|ete|yet|tiʼ| má|aj |ik |k u|l t| be|láa|ʼob|eʼ |u t|naj| wa| ti|eʼe| ku|u n|wa |kal|kaa| kʼ|aka|n u|ob |tal|ulá|tul|jal|u b| na|ala|iʼ |jeʼ| je|baʼ|ʼ u|aaj|aan| ma| le|maʼ|ajm|jma|maj| si|le | ba|nal|l w|aja|jil|uch|bee|l k|kʼa|tu |tik| dz|u y|ʼan|taʼ|ali|l y|aji|en | ya|jna|ijn|kaʼ|ʼe | ch|ʼ t|sij|aʼ |loʼ|lil| mi|laʼ|ku |uʼu|leʼ|bes|kbe|saʼ|iʼa|tʼa|kux|bey|k y|mix|ʼaa|j t|u c|ʼa |xta|uxt|sik|eet|u d|ant|u m| tʼ|chʼ|bal|alo|ʼaʼ|oʼ | ja|táa| tá|u p|ax |j u|una|iʼi|l b|boʼ|yaj|eya| me|ʼ m|e b|ich|een|mee|ume|tum|chi|mal|ʼab|atm|mat|eti|áan|alm|k k|tma|dzo|k t|mey|hil|u j|nta|áax|a u|lma|x u|nil|ajt|n t|l l|ʼ k|x k|xak|esa| nu| un|ol |yaa|lak|uun|ach|noʼ|ʼat|l j|áat| ju|áaj|aba|k s|okb|zoʼ|akʼ|u l|iku|jta|ʼok|cha|lal|páa| pá|a m| aʼ|ey |xan|kul|et |b t|ʼáa|lti|beʼ|úuc| uc|teʼ|e m|ʼux|tuʼ|ʼol|koʼ|ʼac|e n|ili|naʼ| xa|eyt|ini|kʼá|ʼax|joʼ|yóo| yó|hak|xmá|ixm| ic|a t|tan|kuu|kil|a j| bo|n j|ʼ b| lá|uba|kub|ata|ul |nik|íin|wíi| wí|ʼuk|akp|ajo|kʼi|olt|ix |ʼ y|chk|hʼi|ana|ex |ile|tzi|uku|ani|t u| ke|taj|paj|kpa|éel|ʼée|pʼé|ale|esi|ch |óol|yáa| yá|obo|lta|n k|kʼ |ʼ l|ʼex|y j|ba |abe|jaʼ| no|b y|u s|nuʼ|uns|k w|elo| to|yan',
    'fij': 'na |aka|a n| na|ni | va| me|vak|me | ni|ata| ke| e |a k|a v|a e| ta|ena|ua |i n| en|onu| do| se|nu |don|mat|e v|odo|dod|ka |a m| no|ta |ama|ala| ga|ra |ina|i v|se |ga |u n|ki |la |ei |e d|aki| ca|ai |i t|kei|cak|e m|ale|tak|a s|ce |ece|kec|tam|tik| vu|vei|a d|a t|iko|non|le | ve|ona|i e|i k|dua|a i| ki| ma|anu|i m|ara|a l|a g|kin|tal|tu | du|wa |van|e t|nua|e n|dra|tau|aca| qa| it|e s|awa|ko |nod|au |ita|odr|qai|kat|ani|e g|e k|u m|uta|va |o e|lew| le|nak|kac|itu|ava| ku|i d|kai|uva| ya|ula|kua|law|e e|aut|kav|vin|bul|i s| sa|lal|gal| vi|ito|e c|uku|kad|ma | ti|avi|li |a q|ega|seg| la|oma|vat| ra|e b|tan|avu|a c|vuk|u k|asa|cal|vi |e l|iva|ura|iti|uli|dui|oqo|ewa|era|vul|sau|kam|nit|oti|kot|kas|oka|adu|igi|dig|ait|ke |i c| bu|ya |oya|aga| ka|qo |a o|auv|a y|u e| so|rau|e r|ovo|tov|ken|qom|aqo|taq|u s|utu|ku | oq|o n|aba|ewe|una|val|tav|vo |eiv|mak| ko|u v|vur|cav| lo|eit|o v|i i|uke|ia |o k|ri |uri|gi | di|ti |rar|kar|rav|a r| be|tuk| tu|mer|sa |dok|idi|ola|vuv|mur|i b|aun|gau|i l|ci |oto|kab|koy|e i|lit|oli|otu|lot|yag|iya|uit|idu|uid|yal|ado|sam|ila|ima|ana|ira|mau|isa|we |vu |yav|u o| iv|u q|mar|wai|si |rai|can|aqa|tab|lat|mai|vut|iki|num|nan|e y|ini|lom| er|tor|ade|lav|gid|eni',
    'fur': ' di|di | de| e | in|al | la|rit|eri|ion| a |is |der|la |on |zio|t d| al|ndi|tât|e d|ât | pa|ind|che| ch|it |i i|gni|i a|ni |de |ogn|te |ui |ne |si |ssi| à |ts |à d|ivi| og|idu|div|dui|vid|par| cu| co| li|e p|he |e c|in |âl |azi| un|e s| si|l à|s d| o |i p|e i|un |s e|ess|e l|i d|i c|e a|a l|une|ce | da| so|tri|ar | pr|i s|nt |ent|a s|t a| je|nce|e e|int|itâ|lib| i | sô| no|n c|ns |sô |ste|ri |enc|son|l d| ma|nis|e n|ibe|n d|dis| du|res|ons|ant| pe|s o| st|con|e o|iss|ber|es |ai |jes|ers|per|no |soc|ich|naz|ie |ssu| ni|rtâ|ert|s l|com|ins|i v|il |t c|dal|ate| fa|i g|n p|sun|est|pro|its| na|ris|je |anc|fat|oci| po| vi|s a|sis| il|i l|n e|re | ri|sti|men| an|cj |n o|uzi|n a|nst|ntr|ei |pò | pò|str|rso|e t|ter|o s|nâl| re|hes|s p|âts|tis|ltr|alt|tra|sie|t e|s c|duc|din|uin|ade|ame|s n|n i|e j| se| ta|l p|nte|ond|lit|ist|n s|an |ucj|vôr|a i|e m|ntâ|i f|a d|a c|ont| cj|uni| pu|dai|vit|t o|ari|se |art|ût |ite|i n|i r|onâ|gjo|e r|cen| ce|cla|iet|cul|a a|nit|ign|me |ass|ruz|tru|l e|des| te|ere|fin|ch’|i j|cja| ve|t l|imi|one| ju|l s|nan|cje|iâl|ciâ|l o|tic| le|ôr |gje| gj|ara|lis|e f|ome|i o|cun|e à| me|etâ| ci|i m|r e|pri|l c|i u|nda|oss|cui|tad|rim|eç |ali|man|o p| do|sei|lav|ran|chi|cua',
    'tet': 'tu | ha| ho|ia |ha |iha| ih|a h|nia|ma | ni| di|an |itu|eit|un |ema| em|a d|rei|ire|dir|ida| at|aun|ho |atu| ba|otu|u i|hot| ka|asa|ade|ba |sau|a n|ka |dad|hal|la |de | la|alu|u h|a i| ne| li|lu |a s| mo|os |u a|al | se|da |tan|ir | tu| id|tui|n h|uir| sa|a l|a t|e e|ne | te|u b| ra| ta|a k|e h|e n|ai |ten| no|nal|nas|n i|ki |sia|in |han|mos|a e|n n|ele|bel| na| e |san|u n|u t|be |ebe|le |rai|ak |i h|nki|enk|esa|aso|n t|a r|lib|ens|ane|neb|no | hu|asi|ras| de|rda|erd|ber|ibe|u s|s h|nte| in|o m|hat|a b|abe|ona|sa | ma|n e| si|ori|sos|e a| pr|ter| be|ent|rbi|uk |ara|us |ali|osi|s n| so|lei|u e|ran|a a|s l|usi|hus|a m|sio|luk| re|mor|ama|a p|ari|ate|has|rim|ei | le|a f|at |ser|mak|ik |lab|ata|u k|ion|a o|es |des| es|uni|nsi|nid|nes|is |isu|hah|int|as |sal|te |men|ru |sor|ina|r l|du |erb|i n|u r|n l|n s|lia|su |tus|re |ra |ris|bis|tam| lo|lid| fo|ala|ial|ili|oru| fa|eta| to|imi|o h|ura|ku |iku|si |o l| ko|oin|u m|cas|uca|duc|edu| ed|ese|en |i s|pri|e i|ns |oen|soe|n b|mu |imu|sim|kri|ati|iu | he|elu|har|ira|era| me|ral|ben|man| un|aha|ers|k h|res|ria|ern|ete|tet|ime|e k| tr|nsa|ans|a u|tas|sik|dis|e t|r t|i e|k n|sel|ija|lij|eli|rel|u l|lit|or |e b|hir|e l|lar|are|sie|n k|ano|eri|pre',
    'wln': ' l |ès | dè| qu|t d|ou | d |eût|èt | di| a | po|ût |on |qu |reû| èt|dè |dre| dr|me | to|e d|nt |s d|es | s |di |ns |min| on|tot|er |po |t l| ou| ès|i s| co| i |sse|ins| ch|ot |a l|se |cha|u q|dès|te |çou| ço| mi|s è|s l|l d| pr|int|n a|s p|in |de |lès|u i|ion|un |eun|keu|ske|ask|has|nde| lè|ne |le |èss|nme|inm| si|qui|ont|té |vin| pa|è l|ind|s c|e o|re |ts |e p|l m| so| ma|e s|e è| in|e q|ye |n d| li|cio|ui |out|ome| sè|ut | n | vi|ant|i p|is | no| lî|st |e m|s s|s q|com|ce |i l|t s|s o|li |rin|e l|pay| de|u d|èst|ond| mo| r |i d|s n|yis|ayi|sès|t a|deû| ni|îre|åci|pou|t c|ôte|con| èn|si |e c|d i|vou|bin| bi| ra|fé | fé|e t| ôt|ons|us |u è| vo|é d| ne| av|man|e a|pro|tch|dje|n p|és |ine|n è|div|s m|sin|t p|lu |u l| ri|èye|je |s r|eûr|ûts|ènn|lîb|djî|è p|n l|d è|mèt|dis|nîr|anî|i t| bo|wè |u b|ole|pri|pôr|tes|mon|r l|jî |wèr|n c|s a| mè|î d|è t|bon|nol|l a| tc| pô|leû| fo|nin|ité|o ç|i v|ni | è |r p|sco|n n|s t|t è|l s|ber|and|rt |e r|u o|il | il|r d|t o|l p|d v|rté|t t|ûr |t f| se|t n|n s|i n| le|o l|îbe| om|os |tos|r è|ivi|lî |ète|tin|lwè| lw|ert|n m|olu|ice|l c|nte|ous|tés|ale|seû|t m|nce|son|s i|nn |årt|i r| ci|èdj|ter|ami|è s|t q|ler|d s|k n|avo| tr|a d|n o|o d|nts|e i|ti | pu',
    'eus': 'ko |eta|ta |eko|en | et|ide|a e|o e|bid| es|esk|sku|ubi|kub|an |tze| be|ea |na | ba|era|dea|iza|ber|n e|art| du| ez|ak |zek|tek|ere|ako| er|rri|asu|ald|sun|ntz|tas|ren|ate| da|a b|ik |a i|atu|ez | iz|arr|abe|edo| ed| or|du |ert|tza|nor|n a|k d|a o|k e|oro|te |ra |re |a a|e e|rte|zat|ona|koa| he| pe|ria|do |ask|o d|tso|rts|oa |a d|n b|go |son|per|err|ri |de | as|rok|egi|una|giz|ezk|are|u e|ari| de|zar|o b| ja| gi|ok |zko| au| eg|ngo|lde|za |rik|o a|rra|rre| no| ga| la| in|da |tu |her|bes|ino| al|kat|atz| bi|ek |orr|a h|ita| di|lan|aur|eri|a n|z e|rat|a p|ean| ar|int|uzt|e h|a g|rta| na| ha|est|a l|ezi|n h|dut|ia |ien|kon|rak|bat|gin|rtz|k g|itz|tik|unt|ska|tak|raz|tan| ho|io |har|ute|n d|bai|ite|gab|zan|den|ste|izk|ata|azi|tea|itu|rbe|tat|ker|ena|ahi|nah|i e|zai| za|ter|ika|ago|tzi| gu|nar|be |ara|ket|une|iar|hor|ang|o l|ial|ati|lak|pen|dag|u b|leg| le|nez|ten|eza|e b|un |aio|zti|guz|dez|tua|ing|rka|k b|ait|zin|tar|orb|zio|urr|in |a j|rit|ioa|iko|or |nak|ege|kar|ene|ont|zen|ske|aso|uen|uru|i b|iz |e i|ort|kun|die|adi|i d|ori|nta|ema| em|oki|jas|lia|git|bak|nda|urk|hau|e a|bab|ina|ndu|uta|r e|ana|ala|bur|naz|a z|ain|uko|gat|o g|o i|hiz|ua |zit|lda|zki|z g|ent| ko|ira|e g|ldi|n i|ltz',
    'nbl': ' lo|lo |mun|oku|nye|nge|ye |lel|o l|elo|lok|e l|ung|la |akh| ku|ntu|khe|tu |e u|uny|gel|lun| le|we |ule|nga|omu|he |aba|unt|wa | um| la|ban|a l| ng|ni |uth|yo |elu| ul|umu|ele|le |eni|wen|elw|kum|zwe|uku| uk|a u|pha|kho|ela|ezi|kut|ath|mel|ho |lwa|i l|lom|ume|a k|hi |na | ba|ke |e a|enz|eth|nke|onk|e i|zi |ama|tsh|ba |o e|thi|ala|eng|a n|ana|lul|ulu| om|a a|the|o k|e n| ab|a e|eyo|e k|eli|ndl|het|any|kwa|tha|iph|izw|kub|ukh|a i|hat|ha |lwe|and|kwe|ane|o o|kel|ang|lan| ez|hwe|tho|u u|won|o a|alo| nj|ben| am| yi|liz| kw|be |o u|kul| wo|lob|isa|hul| im|uba| ak|thu|li |lak|hla|thw|i k|len|i u|wan|uhl|ant|ebe|seb|lab|kuh|so |und|ise|i a|kuz|izi|hol|ngo|fun|do |man|cal|e e|ayo|nzi|lem|mth|hlu|ndo|mba|kun|shw|sa |bo |khu|kuk|sek|eke|wak| ya|iso|nza|ase| em|ahl|kus|aku|aka|isi|phi| ka|umb|mbe|lek|o y|yak|i y|abe| ok|e o|nda|hwa|u o|a y|luk|ze |akw|vum|ko | in|hlo| ub|ngi|ots|aph|za |esi|ale|alu|mal|gan|jal|nja|okw| ye|e y|ga |lez|ham|dle|o z| iz|zak|hon|oba|zim|uli|azi|ind|ley|hel|uph|nku|e w|ubu|han|bal|uma|e b|mfu|i o|use| yo|o i|ehl|ntw|zin|bak| en|dla|ica|oni|eze|nje| el|end|uza| li|ili|ali| is|kup|bun|a o|abo|ing|lin|u b|wez|ayi|uke|zif|ziz|men|ani|amu|ney|o w|uzi|lon|nel|fan|kha| wa',
    'pov': ' di|di |ku | ku| ka|du |tu | te|i k| na|u d|itu|ten| si|adu|i d|dir|na |adi|on |rit|iri|son|i p|kad|n d|dad|si |a k|a p|u k| pa|i t|en | i |al |ra | o | pu| pe|nti|ti |ka |da |ent|in |s k|us |a d| pr| ko|ta |eka|pek|u p|pa |a s|i n|u n|is |ida|ur | ta|dur|udu|i s|n k|bi |tud|u t|aso|asi| li| tu|sa |kon| ki|u s|r t|a t|int|ion|i i| un|iku| ri|sin|pro|ki |a n|nin| ni|men| fa|dis|i o|era|ter|nas|pud|ru |ada|ont|un |ber|udi|tru|isi|nal|u o|i r|er |ibi| su|lib|u i|kas| so|ona|kal|n s|utr|tus|u l|l k|ibe|s d|ntu| ut|rda|erd|ia |ne |idu|nta|u j| le|tra|sia|ene|ma |sta|ntr|jin| ji|ndi|ker|lke|alk|ons|tam|ris| st|i l|a u|ame|i f|as |gin|osi|sos|asa|ras|igu| ju|imi|fas|for|sio|ili|su |mbi|amb|gua|i a|mi |tis|aju|eso|lei|ora|i u| se|ns |nsa|uma|ual| ig| ma|ali|nu |el |ote|rot|ind| al|nte| in|a f|tad|a o|l d|s p|dib|nsi|pri| at| de|rim|lid|ati|edu|ura|tes|i b|u a|ei |a i|ial|ini|n o|a r|ing|e t|ens|e d|rti|i e| vo|ju |i m|art| or|kri|sib|orm|mit|a l|n p|dik|ita|sid| e |a e|sum|baj|rba|arb|tar|es |man|u u|o n|nid|uni| el|lda|lik|bli|ubl|pub|ros|uda|min|ant|usa|ngi|s i|kum|ans|ran|vid|tik|iti|opi| op|sie|r s|ri |bri|inu|pus|nfo|unt|ral|rop|ami|i v| me|a m|rsi|kus|l i|ika|s n|atu|n i|au |ers|per',
    'cym': ' i | y |ol |an |yn | ha| ga|dd |ydd|th |gan|awl|haw| a |eu |eth|au |aet| gy| yn|ith|y m| ma|rhy|wl |ddi|l i|mae| un|wb |awb| ba|n b|ae | ne|e g|edd|baw|l a| cy|ddy| rh|ad | eu| dd|eit|yw |iad|’r |neu|n a| gw|hyd|nol|id |nrh|b h|n y|iau|wn |i d|dyl|ac | ac|d y|u h|wyd|hyw|nia| na|lia|n g|unr|ni |ddo|iae|u a|i a|nt | ar| o |eb |yd | ym|od |d a|fyn|tha|dei|l y|ll |ymd| ch|rwy| am|ynn|gyf|u g|idd|r h| ll|a c|add|ir |oed| di|lad|d g| ni|has|mde|ait|’u |i g| sy|dol|wla|yli|ch |l n|ned|d n| he|on | dy|as | ad|edi|cyf|rai|h y|d h|chy|gae|u c|wli|b y|wy |ys |red|el |io |dau|ed |yng|u d|yfr|lid|edl|fyd|ani| a’|ai |ysg|ewn| me|yr | dr|neb|fra|hyn|a’r| i’|mdd|dda|sg |c i| hy| te|awn|a’u|odd|yni|ffy|amd|wei|h g|did|ann| an|’n |efy|ref| da|rei|fre|cym|d c|ryd|all|lla|ill|ail|lai| fe|mew| ge|ian|dys|fod|gyn| yr|gwl|ant| go|d i|rha|dif|g y|y g|h a|al |d d|wch|dio|d r|di |rio|eid|sol|gym| ce|dia|oli|lli|han| wa|yla|dir|s a|dra|gen| de|adw|hau|dig|law|yfa|ddu|ros|hre|wys|d e| er|n e|l c|ael|n d|na’|thr|ion|un | id|iol|ar |h n|ene|cen|far|ig |wah|w w|int|ddf|hol|dwy|n u|gyd| pa|ono|u p|gu |s y|lei|ria|art|lu |nwy| we|ynt|dyn|a r|sed|ose| tr|y’n|sy’|iff|yda|n f| gr|n o|wed| fy|i f|w g|n n|nno|n i|rth',
    'lus': ' a |na |an | ch|ng | th|ang| le|eh |leh|a n| ni| mi|in | tu|ni |te |am |awh|a t|chu|ah |cha|nga| an|hna|a h|han|haw| hi|ih |a c|hua|nvo|anv| ka|wh |n t|h a|h t| in|paw|eih|awn|vo |tur|n a|chh|a l| za|i t|hu |i a|the|hei|a a| da|hi | lo| te| ta|mi | pa|o a|aw |thi|hun| hr|al |uan|ur |hia|dan|ung| di|wng|maw|n h| hm|tha|kan|ei |i m|ga |int| sa| ra|nna|van|nei|ak |n c|ian|ema| em| ne|h c|ram|h l|g t|hhu|n n|ihn|hma|thl|sak|ran|hra|r a|pui|nih|mna|kaw|mah|e h|lan|hin|l t| la| ti|h h|thu|kna|awm|tan|g l|i l| ng|hil| hn|ava|iam| nu|upa|kha|l a|ui |tin|a m| av|dik|tak|daw|awi|a i|lam|uah|k t|mal| kh|lo |hla|un |n m|hri|ikn|zal|a r| na|ata| hu|awl|rem|nte|h m|n l|iti|nun|h d|a p|lên|alê|a k|ana|u a|ima|mim| at|m t|a d|mit|h s|el |il |tla| pu|ing| si| zi|man|tup| ma|h n| re|wm |din|h p|n r| ve|zaw|whi|g a|tih|nan|ual|ka |i r|m c|wk |k a|n d|lov|h k|ngt| he|gah|e c|rin|sia|a s|ha |ia |ek |âng|ntl|zir| va| du|m l|him|awk|tum|nch|i h|n k| tl|ant|duh|ahn|ama|awt|aka| hl|sua|wn |lna|eng|baw| ba|va | aw|ann|uh |rna|gte|ênn|h z|t t|at |una|g z|i z|irn|lh |nat|loh|len|taw|iin|i k|emn|k l| ph| ro|uma|en |ova|la |m a|m h|nam|gin|ngi|vek|tlâ|g h| ha|n e|n s|ma |hle|e p|hre|âwn|zâw|hha|l d|phu|kal|ar ',
    'dag': 'ni | ni|li | ka| di| o |ka | za|ali| so|i k|i n|di |i d| la|din| sh|am |shɛ|i b| n |i s|an |kam|i o|a n|im | ma| be|zal| yi|in | bɛ|gu | ti|uɣu|i y| bi|ɣu |a d|igu|a s|aŋ |oli|zuɣ|ɛli| kp|i z|bɛ |ee | ny|la | da|hi |i t| zu|a k|ya |a b|a z|ŋa |ir |o d|sol|lig|ma |hɛl|aa |lan|ani|gba| su|oka|n n|mal|ili|sok|iri|bee|maa|n b|u n|tiŋ|uni|be |al | sa|ri | yɛ| gb|so |yɛl| tu|iŋg|bu | ba|nyɛ| ta|ɔŋ | ŋa|l s|m n|o y|ini| li|u b|nim|o s|a ŋ|ɛŋa|hɛŋ|ari|tum|ŋ n|a t|n k|i l|ko | wu|bi |uhi| pa|mi |m s|ŋsi|ŋgb|iko|yik|o n|taa|uun|i p| yu|ti |ama|iya| na|m m|aɣi|ŋan|nya|si |o k| ch|i ŋ|wuh|zaa|ŋɔ |suh|aŋs|u l|ia |nir|e n|o t|ban|a o|kpe|zaŋ| ŋɔ|dam|uhu|kpa|i m|n w|yɛ |daa|ɛhi|lim|too| to|kan|rig|mdi|u s|yaa| do|haŋ|ɔ n|aaf|ita|u d|m k| mi|o b|a l|paŋ|uli|ubu|yub|yi |oi |ooi|na |maŋ|iŋ |ba | bɔ|ahi|fi |afi|lit|e l|a y|nzu|inz|o m|ala|sim|aai|baa|aal|n z|r o|ŋ o|bil|cha|n c|aan|m b| pu|e s|i g|m l|ɛm |ima| ku|ŋ z|u m| du|ɣi |e k|igi|n s|m t|n y|chi| ya|lli|n m|puu|bɔŋ|aad|sɔŋ| sɔ|u z|gbɔ|aha|ndi|baŋ|ɛ n|oma|ihi|un |ŋun| ŋu|ins|e o|iin|nka|u t|yu |u k|eni|hig|bɛh|ɛ s|hu | om|kar|ibu|dol|n t|a p|n d|niŋ| ve|pe |n g| wa|rim| pi|uma|aaŋ|sir|m d| ga| bu|ada| kɔ|bia| mu|umd|min|ga |uyu|huy|hir|laɣ|ŋdi',
    'dga': 'ng |aa | a | o | ka| na|ka |ang|eng|a n|a t|ba | ba| ne|a s|a o|ne | ta|nan|zaa|a b| so|ri |taa| be|a k|na | la|la | te|a a|neɛ|nga|e k| po|ga |lɛ |ee | za|ori|ong|oɔ |poɔ|sor|ten| to|bee|g n|o t|e a|o n|men|a l|e o|ɛza|eɛz|ɛlɛ| yɛ| me|yɛ | ky|g b|e n|a y|yɛl| ye|e b|ma |a z|ɛrɛ|yel|a p|ane| bo|rɛ |i k| ny|li |ɛ n|be |ie |ɛɛ |a d|kyɛ|eɛ | no| se|eli|re |i a|iri|ngɛ|o k|g k| an|ɛ l|oma|ɔ a|oba|sen|nyɛ| wa|ɛ b|aal|rɛɛ|a m| ga|nob|ɔ n| ma|ɛ a|eɛr|waa|ɛ k| dɔ|fer| fe|a f|tom|g t|zie|o y|erɛ|g a|ge |nen|e z|i n|ebe| lɛ|rɔ |o p|oɔr|ta |o b| zi|a w|bo | bi| kp|ton|a g| ng|o s|o m|saa|ɔrɔ|ɔ̃ |oɔ̃|ɛ s|ann|nɔ |ron|gɛ |ɔ b|o a|ɔge| sa|nne|kan|ɔɔ | ko|dɔg|boɔ| e |peɛ|g l| de|ɔ k| di|sob|sãã|sɛr| sɛ| zu|bon|ru | da|a e|ala|lan|son|san| sã|kpe|zu |g s|aar|g y|one|ɛ p|ro |uor|puo| pu|alo|gaa|e p|gan| k |obi|e y|o l|nno|yɛr|le |toɔ|ãã |man|ɔgr|uur|o o|da |obo|oob|soo|i m|ben|g o|te |ɛ z|ing|e t|ban|uo |ra |ara|beb| yi| tu|i o|aan|maa|g p|ɔ o|pɔg| pɔ|ine|min|u k| ir|so |g d| yo|ɛ o|i b|bin|g m|iir|de |gro| tɔ|yeb|kye|ana|o z|e l|teɛ|oru|lon|bal|lo |ama|ɛng|aba|aab|gsa|ngs|zan|no |ɛ e|ngn|bii|ibi|bib|i t|nee|ene|onn|ale|di |lɔɔ| lɔ|ɛ d|ire|dir|g w|ɛ t|laa|bie|mo |mmo|nsa|ens| pɛ|kul| ku|eɛl|nnɔ| ve',
    'bre': ' de|en |et |zh | ha|ezh|ar | pe| da| di|où |da |n d|añ | gw| ar|wir| e |ha |gwi| en|an |enn| an|c’h|ir |el |us | ga|eus|den|ep |a g|ez |n e|r d| a |deu|t e|pe |nt |ant|ll |t d|a d|n h|ioù|pep|vez| ma|ur |s g| d’|rez|e v|eze| be|ut |gez|lez| ne|ade| ke|out|r g|dig|nn |ere|ag | vo| c’| re|gan|hag|ell|’he|e a| ve|oll|aou|gao|h e|hel|a v| he| ge|eza|vo |ne |evr|oad|h a|net|are|zañ|ber|er |eve|roa| al|ù h|ni |hin|red|t a|del|p d|re |ele|e d|vro| le|ige|kiz|nki|ank|ran|fra| fr|ini| hi|hol| ho|o d| ev|dio|d’a|uzh|ouz|edi|l a|all|dur|adu|vre|t g|g a|’h |a z|nne|p h|iri| o |eme|iz |l l|bet|h p|l p|h d|r s|eo |rio| pa|ù a|doù|ñ e|obe|al | la|vit|evi|z d|e b| vr| st|t h|mañ| em|zio| ur|l d| eo|r e|ure|nno|war|it |l e|n p|ebe|r m|i e|e e|dez|ege|bou|rel| dr|ado|z a|vel|ñ d|r p|tañ|’ar|t p| eb| se|ven|n a|rc’| zi|skl|ed | zo|l h|h h|our|abo|lab|bez|iñ |aze| ob|iou|hañ|zha|rzh|ent|r f|r v|zen|r a|gev| br|isk|dis| sk|a s|lle|zel|dre| eu| un|ask|ad |zhi|eli|ezi|gwa|ù p|zet|ave|gel|ren|ver|ro | na|bro|izh|oue| ou|a o|ñ h|o a|per|n u|ñ a|d p|kad|mez|esk|at |r b|noù| wa|ma |t n|fe |e k|oar| do|’ho|kla|ñ n|nna|o e|rve|a c|zhe|eiz|rei|a l|êri|lêr|klê|izi|iez|eur|o g|die|des|kev|nad|a m|sev|ime|s a|nta',
    'kek': ' li|li | ch|aq |chi| na|al |il |ru |nam|jun|b a|l l| a |k a| ta|i x|ila|ab |am | ut|naq|ana| ma|nil| te|i p|hij|aru|sa | sa|an |yan|oya|poy|uni|iju| il|ut | po|wi |i t| an|ten|aan|laq|nar|ami|ena|lal|ak |ch |b i| ru|kil|mit| re| aa| k |maa|nki|wan|q r|ala| wi| al|hi |nq |re |cha|eb | wa| ti|it |hir|l c| ju|q c|aak|a a|ank|u t| ra|u l|q t| xt|iru|ik |a l|tix| in| xk|q a| us|xk | ri|i c|mal|xb |a x|ib |l x| xb|i k|m n|q x|aal|a r|anq|xte|lb | aj|jo |l u|u n|in |om | ka|oq | xy|kol| jo|i r|anu|l r|rab|haq|l t|jel|anj|xwa| xw| ko| aq|ink| b |hom|aab|b e|uq |uuq|ruu|nje|ta |te |rib|loq|q e|t t| xj|enq|een|k u|q l|q s|aj |el |k i|ani|n l|jwi|ajw|k c|nk | ar|q w|a u| ee|t l|i l|l a|ni |olb|us |awa|q k|ok |a n|a i|l w|sil|la |taq|h u|xch|b l|waa|och|unk|sik|raj| q |iq |iiq|yaa|kan|i n| ej|i j|usi|e x|leb|xlo|eet|nta|unt|tar| xc|ul |e n|u x|xma| xm|aqa| tz|una|l m|xya|ob |ar |e r|na |l n|n t|uta|h o|xju|h i|i i|tee|a t|e q|k e|taa|z a|tz |i m|o k|s t|u c|ix |paa|xye|nax|e c|n a|tik|n s|i u|b c|b u| le|nak| xl|ara|t s| uu|tul|itu|ixk| i |uho|nuh|n n|hil|n c| ya| e |toj|tak|b m|rix|a c|l k|m m|haa|t n| xn|b n|k r|yo | yo|q n|et |uut|oke|aok|esi|xsi|u r|hic|uch|nun|q u|ol | ro|kab|nka|xko|man',
    'lij': ' a | e |to |çio| de|de | in|on |ion| o |rit| pe|a a| co| se| dr|dri|e a|tæ |açi|in |ent|ito|e e|o d| gh|ti |e d|e p|gh’| di|te |nte|o a|con|rso|ers|per|n d| pr|a s|int|n a|nn |son|le |sci|a d| l’|e i|men|ale|da | da| so|a l|o s|sa |gni| li|iâ | ò |an |se |nsa|e c|eu |i p|o p|ni |ògn|tra|ali|seu|oin|pro|i d|a g| òg|ens|ber|ibe|lib|onn|ioi| qu|’à |h’à|h’a|n e|utt|tut|di |a p|he |e l| tu|seg|e s|do |pe |rtæ|ert|itæ|cia|n c|ter|nto|a e|æ d|à d|n o|i a|che| at|nal|so |’an|i s|iti| ch|ond| d’|isc| ni|ta |tti|ia |a o| pa|içi|naç|i e| i |e n|ame| ri|li |sai|nti|ze |ona| po|ciu|e r| do|o e|o o|â a|a t|un |ndi|soc|e ò|ica|lit|iun|nis|sta|ans|atr|eçi|ego| sa|io |n p|n ò| re|que|i i|n s|ra |e g|o m|tri|ntr|teç|ie | fo|aiâ|ial|a c|est| ’n|a i|o l|ge | na|ggi|co |o g|ese|ori|nta|o c|ont|ezz|ico|o i|ita|art|eri|ern|no |o ò|ca |eli|ist|dis|rav| me|lo |com|ant|uni|avi|vit|taç|i c|par|gge|egg|uæ |quæ|oci|gio|goa| le|sen|dic|ues|e f|æ e|tte|e o| ca|nse| ma|lic|bli|òu |res| es|uçi|gia|l’e|pre|ina|ote|rot|u p| tr|itt| vi|imi|mis|omi|pen|ind|egn|o q|giu| gi| sc|ò d|sso|a n|e q|æ i|a ò|ver|nit|ere|n l|ste|ral|ich|ri | st| mo|i ò|aie|æ a|â e|riâ|por|lê | lê|nda|onp|tto|oal|ava| pu|me |i g|iss|oto|ami|rte',
    'pcd': 'ès | d | l | qu| s |es | a |eût| di| dè|nt |èt |s d| lè|t l|on |t d| èt|lès|e d|er | po|qu |ût |ou |s l|reû| on|int|di | to|min| co| dr|dre|i s| pr|ns |ion|tot|me |s c|le |te | ès| lî|té |sse|cio|ins|e a|ne |ot |s è|ye |se |t a|t p|ts |e s| pa| ch|po |nde|ant| ou| si|ont| so|dès| in|st |s p|dè |cha|lîb|de |t s|s m| li|con|e l| mo|èye|re |i l|èss|si |out|pou|ond|ome|l d|li |in | ma|åci|i d| no| i | al|l m|s q|ut |un |eun|keu|ske|ask|has|leû|èst| de| sè|s s|al |és |n a|deû|ole|ind|s o|t è|e t| se|i p|e o|eûr|a s|e p|qui|r d|e°t|ons|vin| vi|l s| ni|seû|u i| mi|rin|ui |n d|ité| le| dj|be |èl |ter|ni |e q|inm|s n|com|e c|ûre|ûts|îbe|n s|a l|é d|ôte|k n|nme|s r|tés|tes|n p|nte|d v|çou| ço|mon|r l|il | il|t q|bin| bi|one|wèr|mèt|e è| n |ine|pay| ôt|so |yes|sès|dje|u d|u o|rès|ce |n è|eû |î d|nts| st| è |ète|l a|djî|r c|dèl| sa| mè|fé | fé|ass|d a|man|e m| èl|is |ûye|eûy|o l|s a|je |par|pré|s f|e i|u q|ssi|è s| rè| ri|lwè| lw| r | ne|nou|u a|wè |que|dèy|ûr |sin|cla|rté|a t|t o| fe|re°|u è| om|n n|îs |lî |l è|dis|emi|èmi|div|van| av|tch|t n|èri|pro|ami|lit|îdè|d o| ra| as|l p|t c|èrt|°t |fe°|nce|os |tos|c è| c |u l|èté|ièt|ciè|ôci|sôc| nå|vou|ayî|rer|d c|s i|t i|umi|mou| et|nål|î s|le°|ses',
    'roh': ' da|da |iun| in|la |ha | la|a l|as |a p|un |ziu|cha| e |na |per| pe|ret| il| dr|dre|ts |a i|et |ain|il |una|a d|er |l d| cu|in |azi|ing|inc| pr|s e|s d|min| ha| a |ls |ers|nch|ir |sch| mi|za |a s|tà | li|üna|sun| o |a c|mai| ün|t d|nza|las|ter| ch|is |ar |lib|ia | qu|s p|a e|int|rsu|al |pro|ala|ns |s m|ta |n s|e d|ibe| gn|tra|s l| ed|an |a t|ün | sa|ama|ess|gni|ber|man| l |nta|ng |nal|cun|res|ent|ra | re|ant|s i|als|ad |uns|naz| po| se|ert|ed |t a|a h|chi|n c|cum|el |nir|anz|era| co|nte|ats|hi | pa| nu| de|s c|ità| na|uma|uot|czi|ss |a a|nu |nt | d |sta| su|ual| me|a m|ras| ad|ur |gün|ngü| fa|n i|s s| el| di| um|tuo|d a|ote| sc| si|d ü|ica|a r|ist|ets|d e| tu|r l| ma|ari|r a|sia|dal|sa |u p|à d|lit|ran|r i|gua|rs |l e|eis|sei| pu|r s|o g|a v|s a|aja|a g|que|a o|a n|qui|n d| es|ump|r e|ali| tr|tta|s o|ais|a q|cia|ca |n n|a f|r p|han|s n| ac|d i|l i|lla|unt|dis| ar|po |paj|pri|ial|oci|soc| ot|r d|uis|air|a u|ern|con|tat|egu|ati|dar|r ü|ara| st|lic|bli|ria|und|rot|n e|lia|ura|vit|rtà|ita|ami|l s|gna|art|par| te|tsc|giu|e l|ils|ral|es | as|rar|n o|ecz| le|nda|lav|n h|jai|qua|nts|che|tic|n p|zza|rat|enz|e c|let| eg|tis|ssi|ins|nan|nti|ida|gli|igl|l a|uel|uni|das|bel|ada|ubl|pub|edu|men',
    'bfa': ' ko| na|ko |i k|na | ka|et | i | ŋu|ŋut|a k| ti|ti | kö|gwo|en |on |de |yö |are|dyö|si | gw|esi|it |won| to|köd|ode|kod| lo|ödy|o k|t k|e k|utu|tu | ki|n k|ya | ‘b|i t|to |uto|t n|kar|ki | a |lo |any|n ŋ|ren|o t|jur|n n| ju|ele|ta | bu|lö |bul|ulö|iri|ri |kan| sa|yit|nye|sar|ndy|t l|liŋ|nyi|‘ba| ku|ita| ďe|u k|ur |i n|ö t|kit|ďek|dya| le|kon|ret|ö k|i l|o a|eke|ak |ö g|a i|bak|a n|o l|e t|yen|ja |ogw| ga|kin|di |kaď|in |öki|a a|le |gay|ŋit|iŋi|ne |ye |adi|i g|an |se |kes|nag|o ŋ|i b|e ŋ|lel| kw| ad|aďe|iŋ | li|ubu|bub|gi |log|i i|i ŋ|a m|kat| lu|ŋet|aki| an| mo|yet|o s|t i|agw|iki|ŋo |i j|oro| ye|e g|gwe|ŋ k|ruk|ene|ojo|u l|kwe|agi| ag|n t| ďu|nes|ata| ny|a t|o g| te|a ŋ|ine|tor|a ď|tol|toď|we |ony|ni |aka|n l|ili|ien|oli|n a|r k| mi|laŋ| la|a g|yes|ďe |a ‘|o n|kul|den|ase|jo | jo|ön |eja|wej|ond|tet|i p|tod|res|aye|eŋ |ju |aya|wil|gwi|lie|mir|a l|e i|uka|ari|nyu|‘bu|ďir|oďi|o i|joj|din|odi|mor|rön|urö|o j| ke|tök| tö|e l|omo| pi| ri|ron|kas|un |gel|nen| ne|u n|n i|eye|aŋe|i ď|uru| mu|k k|a j|kak| ŋo|nan|ani|rit|ind|i m| tu|gun|ugu|mug|ona|yey|kun|pet|bur|uly|o m|rik|o ‘|i s| yu|a y| me|yem|mom|diŋ| di|ö r| ry|u a|ö n|ji |öji|köj|ute|put| pu|ďuŋ|a r|kik|leŋ|mak|ema|ini|aŋo|kaŋ|let',
    'kri': ' fɔ|fɔ |di |ɛn |in | di| ɛn| we|dɛn| dɛ| in|ɛt |gɛt| gɛ|we | nɔ|ɔdi|bɔd|ray| i |ayt| ra|n d| na|yt |ri | kɔ|an |na |t f|i g|n w|ɛni|i f|nɔ |n f| ɔ |t d|ibɔ|n ɛ|i w|da |ɔ g|n k| de|go | go|tri|ul |de |ɔn | ɛv|n i|ntr|ɔ d|i n|vri|e i|ɔnt|kɔn| se| pa|ɛvr|ɔ f|tin|rib|ay | pi|nt |e d|say|am |ek |wan| am|a d|du | du|t r| pɔ| da|t ɛ| wa| fr|mek| me|ɔda|ɛf | ɔd|sin|man|ɔ m| bi|n n|n g|shɔ|ɔbɔ|a p|at |n y|nɔb|ɔsi|pɔs|ant| ti|wok| wo|l d|se |i p|i k| ma|ɛnt|mɛn|ɔt |ɔ t|t n|t i|hɔn|ni |sɛf|bul|n r|on |yon| yo|ok |it | fi|n s|i s|n b|ap |pan|fri|kin|i d|ɔm | pr|pul|ipu|pip|e f|a i|ɔ s|ɔl | bɔ|n p|esh|t ɔ|ns |rɛs|i l|iŋ |il |fil|n ɔ|is |tap|wet|ebu| eb|i ɛ|ins| tr|kt |ɛkt|tiŋ|ɔ b|dis|em | lɛ|iv |liv|dat|eti|i ɔ| wi|as |yn |e g|if | if|ɔ i|spɛ|s d|en |t p|sem|ili|lɛk| ɔl|s i|ɔ p| gɔ|mar|i m| ka|l i|ti |wit| ko|gen| gr| rɛ| lɔ| sɛ| yu|bɔt|k w| li|bi |kɔm|jɔy|iki|pik|red|e w|m ɛ|ɛp |mɔt|pɛk| so|ba | la| wɔ|i r|rid|p d|l f|ayn|kay|pat|are|yun|ivi| jɔ|kes|ot |m n|o t|so |ɔmɔ|ɔ a|os |rɔm|frɔ|k s|ens|n a|i i|k d|t a|ɛsp| sh|iti|k i|ati|yf |ayf|lay|ɔ e|al | ba|tmɛ|etm|ste| st|m w|ami|ɛk |nta|t w|uke| ɛd|m d| si| ki|amɛ|vam|ɔva|gɔv|f i|up |rup|gru|ɔ r|a ɔ| ch|f d|y ɛ|vin| iv|nsa| ɔf|nsɛ|ik |s ɛ|nib|o ɛ',
    'cnh': 'ak |nak|kha|hna| a |ah |mi | kh|in |ng |an | le| si|le | th| mi|haw|awh|ai | ng|h a|whn| ca|gei|nge|ang| te|ih |ei | hn| ni|hat|thi|i t|a s|at | na|ein|tei|am |k n|si |na |ha |k l| ti|awl|i l| pa| an|mna| in| ah|nga|ung|wl |k a|tua| lo|ram|a h|ong| cu|naw| za|ing|lai|eh |seh|cu |nih| hm|n n|pak|ise|sis|n a| ra|g t|i a|hun|uah|lo |uan|nna|akh|tha|h m| tu| la|hma|te |caa| ch|a c| um| ru|zal|man|h s|i m| ai|lon|alo|k c|n t|rua|eih|a t| di| ka|i k|ial|k h|chu|n k|mah| ma|a n|hmi| da|dan|hil|k t|l a|a k|gah|awn|i c|h k|ian|i r|lte|alt|via|k k|din| i |upa| up| vi|h t|h r|i h|n s|e h|k i| ri|ant|hmu|g a|i n|aah|tik|tla|i v|ria|anh| pe|lei|hia|wh |i z|nh |ann|kna|un |e p|hle|tin|e a| zo| ki|ahn|i d|kan|caw|uh |o t|ntu|umn|hra| hr|iak| bi| nu|phu|ip |kip|awm| he|n m|h u|a u|han|ihm|i p|h p|amn|vo |lti|ilt|e t|di |adi|pad|nin|h l|lna|h c|m k|bia|nvo|muh|n h|duh| du|him|um | ba|k r|ngt|aih|thl|nun|ikh|h n|h z| su|ngk| ph|aln|l k|e n|a z|e z|mhn|ihn|iam|u a|hua|inv| tl|aan|pi |n l|sua|io |cio| ci|hng|h h| zu|m l|iah|h d|eid|zon|ual|pia|zei|oh |a r|m a| hl|ter|u l|wmh|he |aza|k z|a a|chi|awk|bu |nch|kah|har|ngm|ti | ze|rna|aoh|pao|ina|wng|p n|u m|ika|dih| aw|uk | bu|i s|inn|ar |t k|a l|tu |tia',
    'lob': ' a | dɩ| wʋ|wʋ | ha| th|kɛ |nɩ | ti|han|bil|na |aʔ |ibi|tib|dɩ |aa |ana|il | kɛ|nan|ɔɔ |ʋɔ |a n| hʋ| sɩ| na|sɩ |thɩ|a d|yaa|a h| rà|a t|rà |ha | n |hʋɔ|kha|nɛ | ná|ɛ h|anɩ|ɩ d|anɛ|ra |aan| do|ni | ra|ɩ a|l w| ya|ar |oo | ɔɔ|dɩɩ|ná | nà|do |ɩɩ | cʋ|o t|cʋʋ| wo|ɩ t|a w|nà |hɩɛ| tɩ|ɔ k| tɛ|ɛɛn|woo|tɛɛ| pu|ɩ w|ɛn |ɩɛn|ɛna|ʋʋ |ɔ a|ɩn | ɩn|a k|a f|ɛ a|ɛ d|rɩ |ɛʋ |fɛʋ| fɛ|la |ɛ w| kp|r r|ɩ n| gb|tɩb|ɩr | wa|nn |aar|ʋ n|ɛɛ | ʔl| da| le|uur|unu|pun|ɩbɩ|an |ɩ r|ʔ t|ɔ t|mɔ | mɔ|a m|bɩl|ɩɩr|ʋ t|hii|ʋ k|nak|ɩla| fɩ|ɛr | yɛ|fɩr|l h| ʔy|r w|a c|n k|ɔma|hɔm|thɔ| bɔ|n n| ca|ɩ s|oni|ur | jɔ|haa| nɩ|a a|ɔ d| so|n d|ɔr |ɛ t|akɛ|ɩ k|ɛ n|rɛ | bɩ| cɛ|a b|ɩnt| kh|ɛ r|jɔf|par|n t|ɔ n|a ʔ|le |hɩn|ʋaʔ|bɔɔ|aal|ʋ h|uni| wɔ|ʔ d|ɩrɔ| jɩ|nɔ |ma |iin|al |ʋ ʔ|a g|fɩ |a p|wɔr|ʔ y|ɩkh| ɛ | dʋ|a y|pa |i n|nɩr|ɩɛr| pɛ|hʋ |ɔ w|uu |ado|ii |nu |yɛ |ɔfɩ|ɔ s|thɛ| ka|don|da |gbɛ|kpa|ɩ h|caa|à t|a s|wa |ʋnɔ|ɩrɩ|wʋa|i t|ʔya|n a|à n|ʋ d|ɔaʔ|n c|rnɩ|pɩɛ|tɛ |ntɛ|bul|rɔr|duu|waa|ɛ s|r n|ɩnɩ|o d|sʋn| sʋ| to|naa|too|l n|n p|puu|dɩk| kɔ|dʋɔ|ʋnɩ|ɛ k|n g|arɔ|har|ɩ l|nun|ɛ y| ma|er |ʔli|ʋ b|á f|daa|ɩaʔ|á p|bɩɛ|cɛɛ|ɩ c|guu|ɩɛ |aà | aà| nɔ|ʋɔn|rɔ |r a|akh|mak|n ʔ|bɛʋ|r s|nth|iir|inn|a j|li |ʋʋr|i d|ɛl |ɩɛl|ʔyɛ|raa|ʋ w| yɩ|n h|kʋl|à s|ann',
    'arn': 'ñi | ce|ka |pu |ce |el |ew | ñi| ta| ka|me | ki|ael| me|ey |mew|vle|i k| mv| pu| ko|e m|kiñ| ru|añi|tañ| fe|gea|ci |ume|rum| kv|kom|eae|mvl|om |ay |u c|ley|e k|le |gu |am |m p|gvn| pe| zu|en |pi |cem|tvf| tv| wi|elu|e c|em |ugu|vn |zug|y ñ|ele|nie|lu |n k|oki|xok| xo|a k|u k|ñe |iñe|fey|aci|ke |l k|ñma|epi|pep|gka|gel|kim|age|vfa|vme|kvm|oge|mag|igk| we|e r| ci|gen|i n|ntu|lay|ela|iñ |ijk|fij| mo|vza|i p|ta |w k|fem|i z|fac|ñ c| pi|ege|m c|mog|zaw|kvz|l t|aya|apu|map| ma|m k|eay|a m|fel| eg|y k|e e|y c|wig|mue| cu|epu| ep|y t|isu|kis|u m|e p|a w|lea|kvl|a f|lel|tun|a c| fi|w m|nay|eam|ole|i t| ku|eci|ij |u x|jka|cij|nor| no|e f| ni|e t|kon| ge|i m|y r|cum| fv|len|a p|i g|w r|a t|iel|u t|nol| nv|emu|u f|un |e ñ|or |egv| ke|mvn|eke|wen|ayg|n m| in|vne|uec|mge|eju|kej|aw |mel|uae|vfe|eno|ule|yay|i x|iea|m x|yam| ya|uam|zua|afi|mu |uni| gv|u ñ|u p|tua|uñm|ent|ona|tuk| ra|nvw|i w|i f|y m|ygv|ime|la |umu|yci|eyc|ake|u w|way|uku|iri|wir|eza|wez|i r|ine|new| az|xa |vxa|fvx|n n|gko|ogk|log| lo|fie|uji|vla|atu|may|l c|ytu|ayt|vna|su |mek|kam|wel|ney|w f|az |n t|kat|tew|ete|aet|w t| wv|ygu|eye|pa |vpa|kvp| zo|l f|kak|a n|ñke|iñk|vñm|mvñ|amv|u r|ida|int|sug|wkv|vr |xvr| xv|z m|e n|n r|e w|wae',
    'bba': ' ba|ka | ka| sa|u k|ru |bu | n |a k|ia | wi| u |nu | mɔ| tɔ|a m|ba |ari|a t| ko| kp|aa |a s|tɔn| ù |a n|mɔ | bu|ɔnu| te|sar|u s|re |ria|a y|in | sɔ|a b|a w|ere|ra | mɛ|u b|na |un | ku|oo |ii |baa|win|aru|em |u t| ga| yi|koo|n k| wa|ɔɔ |mɛ |n b|ǹ | ǹ| be|aaw|waa|u w|tem| ti|ko |wer|awe|u m|nɛ |wa |ina|i t|kpa|sɔɔ| ma| ya|i k|ɛ b|ɔ b|mi | nɔ| ta|o k|i m|ri |n s| ye|u g|kun| mi|n w|ma |ɔmb|am |wi |si |mbu|i s|e u|u n|ana|era|asi|wee|ro |sɔm|i n|ya |saa| go|aar| bi|n m| tu|n t|goo| di|i b|kpu|be | si| yè|a g|u y|ki |n n|een| we| da|uro| ki|pa |ɔ ù|an |enɛ|sia|o t| wu|en |e k|tii|pur|te |ee |yè |u d| de|wii| se|ua |ɔ k| sw|ni |iru|asa|a d| bw|su |n y|aan|bur|maa|uru|yin|da |ser|sin|m t| ke|a ù|ta |eru|ù w|nɔɔ|e t|ye | su|ibu| mu|o b|ɔ n|de |ɛ u|yer|m g|ora| to| as|nde|e y|ɔsi|o n|i d|̀ g|n d|m k|rɔ |gia|n g|isi|tɔm|eu |keu|gbɛ|igb|yig|aye|gar| nd|ɔ s|anu|i w|ɔ t|ras|tor|e s|i ù|san|e m|di |swa|una|yen|ber|urɔ| du|kpi|e b| gi|ara|ɔm |ɛru|ù g|a u|nun|ɛ s| yɛ|tur|à n|tir|nam|dee| ge|naa|ɔra|ɛ y|ɛ t|bun|nɔ |ɔ̀ |mɔ̀|aka|i y|m m|nan|wun|̀ k|i u|pi |abu|ku | nɛ| do|ugi| gu|du |yii|gam|gaa|ira|e d| na|kua|ese|wes|bwe|sir|aas|iri|awa|n a| so|ù k|ù s|sun|usu|gus|bɛ |bii|sa | wɛ|kas|ɔ u|ura|ama',
    'kea': 'di | di|do |em |to | na|on |o d| e | qu| te|tem| po|na |çon|er |ent| co|i t|udo|tud|êto| tu|m d|qui|rêt|drê| dr|ui |dad| se| ca|i s|el | pa|al |aço|i d|a s|adi|a t| ô |i c| sê| li|ser|i p|o p|men|pod|o e|dê |o n|que|ta |a d|ti | el|i n|nti|pa | ta|ida|odê| si|i e|ra |um |e d| be|sso|co |a p| in|sê |por|con|bem|ion|si |ado|ês |nto|a e|ido|a c| ni|ndi|ame|o t|lib|m p|ça |êm |uêm|guê|n d|nal|sa |ê s| pr|nin| ê | de|s d|a q|oa |soa|éss|io |l d| re|ber|de | ma|m t|pés| pé| es| tr| cu| fa|ca |erd|e e|nac|und|uel|pâ | um|tra|m s| nu|uer|ngu|ing|ôto|rda|ibe| ar|nça|igu| pâ|ia |tâ |ess|i b|nte|lqu|alq|cal|oci|soc| so|ona|dis|ê p|o s|aci|a n|or |raç| sa|i l|i f|pri|e n|a b|com|ont|cas|rab|l p|o q|rio|int|usa|m c|cia|o c|l t| ôt|i q|â d|ter|bê |ual|gua|par|art|lic|ntr| sc|ê t|nu |ura|naç|o ô|l q| st|nta|azê|faz|i ê|cio|omi|sês|ade| ig|man|djo|aba|o m|â n|rte|son| fi|da |ind|stâ|lid|cus|ort|ô d| ho|i r|i ô|ara|r p|rgu|arg|n e|ê d| mu| ês|jo |adj|bad|l e|e p|i m|lei| le|tam|ê c|â s|imi|i a|ssi|ali|nda| fu|zê |ê b|so |ê n| un|ial|n ô|igi|lig|hom| al|sti|câ |o g|gue|o a|nid|no |r e|cie|os |m e|ili| pe|r i| ex|iço|a f| me|ei |s t|fic|ran|taç|l s|end|im |fun|for|ica|n p|dam|sem|li |uen| gu|bri|ied',
    'smo': ' ta|ga |ata| o |aga| fa| ma| le|a t|ma |faa| e |na |le | i |ai |ia | ai|a a|tau|a e|a f|e t|gat|au |a m|i l|ta |a o|tag|se | tu|a i|e a|iga| se|tat|si |a l|e f|ona|o o|o l|uma|i a|o t|oga|aia|asi|ula| um|tas|tul|ua |a s| la|oto|ala|fai|tai|atu|ina|ait|e i|alo| so|a u|aig|i o|toa| on|u o|lag|ana|i s|o s|i t| at|oat|ito|mal|ama| sa|i u|e m|i m|olo|po | po|ea |aat|e l| lo|e s|ava|laf| ia|aal|aua|u i|lo |lot|o a|nuu|i i| ua|uu |tog|no |sao|lea| au|aol|aam|lon|lan|ei |oa |o m|alu|a p|ino|tu |aap| mo|ono|afo|i f|pui|tal|u e|so |ele|fon|unu|uai| to|o i|afa|usa|tus|mai| pu|ega| ga|ain|gai|isi| ag|tin|sa |u m|fua| ao|tun|maf|oli|ale|asa|aas|u p|ali|va |ati|utu|tut|gal|aai|i e|ato|aog|lia|fia|ofi|usi|i p|onu|ton|o f|pea|ape|lue|fea|eag|pul|anu| pe|noa|tot|aa |lei| a |ifu|oif|soi|ipo|mo |lav|o e|ave|la |mau|eai|uga|apu|tap|pe |ese|aut|aus|lel|ueg|sol|uig|man|ni |e o| ni|a n|e p|len|ufa|loa|pot|lau| av|ofo| no|log|aof|uia|ipu|uip|tuu|aun|nog|nei|ene|nu | al|opo|afe|i n|nof|ae |aav|ita|vaa|gav| is|u t|to |ual|sia|poi|oin|tel|sag|ilo|sai|uin|ule| na|uag|pua|itu|uno| va|fo |oai|sig|lol| fe|ili|lig|iag|ail|sal|ola|nis|vae|i g|tam|uti|tia|auf|u a|gi |fil| ae|oip|aip| fi|oi |aim|mol|ute|aaa|iti|te ',
    'koo': 'eri| er|a e|ya | om|a o|mo |ho | ob|obu|ith|omo|e e|olh|e o|o e|wa |we |bya|re |hol|ndu| ne|and|tho|the|ndi| ek|o b|ira|o k|a n|du |iwe|uth|ere|iri|lha|ath| bu|nga|lho|di |ner| ki|han|ind|kan|lhu|uli|but|ban|osi| mu|ang|uts|ra |ugh|li |ulh|ko |aka|si | ku|und|se |eky|ole|he |tse|kut| ey|mun|bul|omu| eb|kya|eki|aba|yo |ire|ebi|ha |ler|ana|ali|ihu|rir|o n|a a|ngi|e k|i e|hok|rib|ery|uho|buh|a i|bwa|nda|rya|ika|yan|wit|i o|no |e n|ene|ki |aby|gho| ka|hug|gha|nge|ne |ing|i n| in|kol|imu|iha|anz|ani|gir|oki|awi|ga |mul| bw| ok|thu|nya|ama| aw|ma |i m|i a|i k|o m|oko|o o|awa|na |rit|kir|rik|ibw| si|alh|wiw|ako|iki|wab|kih|ngo|tha| ba|a k|ilh| ni|iby|a b|ung|i b|hal|ima|iba| ky|bo | ng| no|hun|wos|da |abu|ran|thi|iry|yab|rim|agh|obw|amu|kit|ber|bwi|e b|hwa|bih| na|bi |mbi|iso|yim|eng|hir|umb|its|ril|kyo|nia|e a| ab| by|iyi|nde|tsu|bir|eke|hek|lhw|eyo| wo|kiw|nza|ia | ak|eby|abo|mib|era|ris|za |uyi|mub| ol| en|rih|u w|sib|ibe|amo|o a| at|igh|aha|iko|bwe|riy|nab|yos|yam|isa|kat| ih|kul|eny|ano|nzi|ri |be |wan|lya|sya|emi|eka|kin|go |hab|zir| ha|usi|yow|e s|muk|wam|bal|yak|muy|ka |ryo| am|kwa|lin|u a|hin|ubi|u b|ong|esy|bus|hu | em|aya|wak|hen|o i|bak|ubu|wen|ahi|uba|hub|ham|mab|end|emb|sih',
    'nzi': 'la |lɛ |le |nle| ne|enl|ne | mɔ|ɛ n|kɛ | bɛ| an|nwo| bi| kɛ|ɔɔ |mɔɔ|maa|e a|a b|ala|ial|bia|a n|ye |den| ad|e m|ade| ye|ɛ a|wɔ |e n|a a|wo | ma| la|a ɔ|anz|anl|ɛ m|ɛɛ |nla| nw|nu |ee |zɛɛ|nzɛ|ie |e k|a m|onl|nee|aa |yia|e b|li |aan|son|ɛ b|nyi|nli| so|ɛ ɔ|ia |ɔ m| ɔn| wɔ|a l|yɛ | me|ɔ n| nu| ɔ | gy| ny|ɔ ɔ|ane|alɛ|a s| lɛ|anw|bɛ |men|ɔ k| ɔk|a y|ɔlɛ|ile|ɔwɔ| ɔw|ɛla|gyi|eɛ |e ɔ|ɔ b|yɛl|ɛlɛ|o n|ma |o a|ian|len|na | na|ua |mɔ |nlɛ|e l| aw|ɔnl|bie| ng|e y|e ɛ|ima|yim|a ɛ| a |mɛl| mɛ|ko |wie|awi|i n|ɛ ɛ|wol|o b|ɛ k|e s|olɛ|elɛ|unl|a k|za |di |ɛkɛ| sa|eny| no| ez|i a|ɔ a|saa|ɛle|o ɔ| ba|ɛne|deɛ|nyɛ|ilɛ|ɛ w|oma| ɛn|bɔ | ɔl|zo |ɛ g|lil|tia| ko|bɛk|wom|ɛnl|ulo|oa | yɛ| ɔd| de|o l|gya| ek|u a|eza| di|i m|koa|uko|kul|ɛyɛ|yɛn|any|anu|i ɔ|oko|a e|ti | ti|fa |ɛ s|ra |e d|inl| fa| ɛh|die|nok| kp|ɛ e| bo|ɔ y|ola| ɔf|ɔny|ekɛ|mek|u ɔ|e g|ka |agy| ag|ɛhy|bɔl|wen|dwe|oal|nde| mr| su|bɛb|u m|ɛ l|pɛ | kɔ|bɛn|ɛ y|bɛt|ban|ɔ s|ale|enu| am|hye|oli|ati| at|ɛma|mra|ɔma| ɔm|kɔ |ɔyɛ| ɔy| ɛk| ɔt|to |ɛ d|u n|ebi|deb|ɔɔt| az|nlu| o |ɔ t| ɛl|azo|bel|abe|pun|kpu|ngi|kyi|aky|nga|u l|ngo|ɔti|u b|pal|kpa|zuk| ay|gye|nza|inz|yel|kak|eku|ɔkɛ| ɔb|bo |leɛ|kol|ɔfa|ɔdi|wɛk|dwɛ|edw| ed|e e|tan|ɛta|kye| ɛm| bɔ|ɛnw|nyu|ɔne| ka',
    'maz': 'ra |u̸ | ra|ji | nu| o |yo |a n| u̸|o n|k u| kj|nu | yo| so| k |o o| te|a m|i n|nrr| nr|kja|tex|o r| ma| ng|oo |soo|ja |dya|o k| dy|a j|na |exe|̸ r| b |zo |a k|jo |e̱ |xe |ma |̸ji|u̸j|b e|a r|o s| ne|mi |imi| xi| ez|mu̸|̸ n|e b|ezo|xo |rri|ixo|rix| na|nge|ts |ya |e n| in|a t| mb|ang| pj|ru̸| ts| a |in |ngo|kjo|jan| ja| jñ|a p|su̸|jua|a x|ga | ga|je |osu|ñi |ri |eje|xim|oji| e̱|mbo|ye | ri| jo|ta |̱ e|te̱|go |i y|s a|iñi|ñiñ|jñi| e |sta|est|nes| xo|nee|o t|amu|mam|nte|e y|nu̸|ua |i k|u x|bos|i r|i t|a d| ju|u r| ye|o y| nz| ch| nt|̸ y|pji| mi|ana|ama|uam|̸ k|o d|eji|ee |ngu|i m|pjo|s i|uyo|nuy|a y|rjo|trj|chj| ua|ek |gek|aji|omu|jom|o j|rra|pje|i j|o m|oru|tr |mim|epj|a s| pe|kua|sku|e k|ñej| ñe|u n|e t|o p|isk|xis|a g|anu|gej|a̸ |̸ t|kju|uan|so |n j|e e|o i|nza|iji|chi|i x|eze|gez| an|joj|etr|hi |jos|i i|i s|umu|o g|akj|ze |man|hje|pep|̸ a| i |oñi|xoñ|gum|ba |aba|jab| jy|xor|a c|i p|te |r u|ont|̸ d|e r|ntr|i d|i o|u m|jña|n n| zo|ara|i ñ|xto|ext|to |ra̸|se | pa|jnu|ajn|uaj|ju̸|d a| d |mbe|̸ j|a i|ekj|jek|ya̸|rro| me|pu̸|gon|zak|̸ x|e j|̱ n|esi|zho|a o|a a|u i|io |aja|yaj|jet|xes| xe|pju|n t|e o|ich|hju|tu̸|̸ m|̸ o|anr|jya|e m|roj|udy|nud|its|u j|dyo|si |jim|a b|a z|a e|i a|bar|mba',
    'pis': 'ta | ol|eta|ket|lke|olk| en|em |lo |en | fo|an |fo |im |wan| lo|are| ga| he| sa|gar|rem| ka| wa|eni|o o|blo| bl|hem| ev|ni | ra|mi |ait|rai|vri|evr|emi|ea | we| ma|wea|m o|iwa|m e| no| or|it |ol | ba|or |ing|riw| na|tin|a e|ae |o e|m r|re |bae|no |tre|n o|n f|ntr|i w|ng |man|os |a g|a o| di| me|o g| i |ant|kan|s f| fr|ara|tim|pos|apo|sap|t f|i s| pr|ve |vve|avv|sav|o l| lu|n s| st|a s|n e|ri | pi|luk| gu|rii|fri|a p|sem|oa |a d|a l|n n|aen|iti|wak|uk |a f|kem|ud |gud|kae|n b|i g|ra |nar|a m|dis|a h|m w|a b|aka|e h|o s|a i|ek |is |o h|a n| se|pol|i k|la |ala|o d|ini|ka |as |mas|o k| da|eke|i b|s e|s o|fal|om |m s|i f|ti |o m|sam|ipo|pip| fa|k s|loa|sta|m d|ao |go | go|mti|amt| te|n w|pro|elp|hel|at |m t|mek| ha|on |i l|o b|ts |its|nit|n i|i e|i m|i o|tek|sim|n l| ta|s w|m k|dom|ido|iid| si| la|ati|o t|nao|ed |ase|dat|n g|m n|uim|dui| du|lae| in|a k|m f|am |n h|ren|fre|rit|tti| wi| tr| sk|dim|up |ei |ote|uni|aek|ele|e s|o w|res|kas|lem|pim|niw|lev|t l|ya |a r|o n|n p|son|aso| de|si |nom|itt|a w|s b|ii |ul |kul|sku|iki|sen|nem|ane| so|ion| un|e g|ami|uil|l s|rim|es |m p|lpi|p f|ap |tap|sel|nol|ino|nim|tae|l e|tri|r t|isi|tam|i i|s l|e w|sti|osi|n k|ifr|dif|wit|gti|ngt| ti|l l|n m|m u',
    'ctd': 'ng |na |in | in| th|eh |leh| le|ang| a | hi|ah | ki| ah|hi |ing|h a|ak |hei|the|ei |din| mi|thu|n a|am |hna| kh|a t|eih|nei|te | ta|a l|at | di|h k|ihn|kim|im |ung|i h|awh|ama|a a|gam|an |kha| na|m i|h t|tak|lo | ga| su|sak|i m|ahi|kna|g h| ne|wh |taw|a n| ci|h l|iki|mik|hun|uh |adi|g i| ha|g a|ih | sa| am|han|n k| ak|euh|peu|hih|i a| la|akn|hat|ong| pi| pa|nga|i t|cia|uak|ian|ban|sua|ite| hu|awl|n h|zon|a h|a k|aki|khe|h n|mah|dan|maw|lna|uam| tu|a p| ba| om|hua|inn|un | pe| ma|en |tua|nna|eil|ia |iat|pia| ng|n l|hu |kit|tna|n t|ngt|gah|ai |a m|sun|n m|uah|m t|h s|une|sin|mna|n s| za|g t|a s|k l|pil|awn|ua |pi |nad|e a| up| va|ida| nu|ngi| zo|sep|i i|ate|ilo|tan| si|kua|uan|k i|a g|a b| lo|ina|i k| lu|sia|tee| te|awk|pna|upa|nat|kik|n n|bul|itu|h d|izo|iak|om |el |h i|ek |ma |a i|kil|pan|k t|ila|tun|lam|h p|ile|ihk|m k|g k|gin|lun|kip|akt|ita|ep |paw|awm|i n|t t| se|vai|di |pad|ngk|lsi|h z|iam|oh |dei|g l|kei|hke|i p|g n|i l|a o|hia|khi|hta|au |n i|hen|ipi|kta|gte|i s|kin|kis|ikh|o i|o d|loh|hiz|zia|asa|aht| uh|aih|l t|mpe|emp|hem|ils|ase|nas|ui |tui|khu|h c|ipa|lai|n p|tat|nsa|n z|pih|h m|wln|zah|kiz|aku|h b|m a|eit| da|a d|unt| ph|ann|mi | bi|al |atn|e t|ihs|pha|kib|hin|ihi|mih',
    'cos': ' di|ni |di |tu | à | pa|li | è |par|i p|ti | a | i |oni|rit|i s|ell|itt|i d| ch| si|a s|tà | in|na |si |iri|ali|dir|ion|ttu|à d|i c| u |’el| so|i i|u d| un|la |zio| li|tti|u s|a d|una|nu |azi|i è|so | o | cu| l’|h’e|ch’|gni|a p|a c|u à| pr|ia |ità|lu |ars|ogn|lla|ess|ru |hà | hà|ri | og|i u|sa |in |ghj|i a|u p| ri|du |i m|à a|ona|son|rso|icu|ssa|lib|i l|a a|u o|nal|à u| ni|l’a|à i|a l|hì |chì|ta |gli|ssi|u è|ent|llu|int|da |iss| pu|ari| na|u u|a à|un |cu |i o|naz|za |pru|atu|lit|mod| mo| tu|u l|a h| es|pri| ca|iu | da|aru|odu|tut|hè | hè|à c|nta|u n|u i|tat|i f| ma|qua|a v|i n| sc|è i|utt|ar |con|imu|ind|ili|su |pò | pò| el|inu| de| ci|u c|ùn | ùn|n l|cù | cù|a i|suc| su|iun|sia| d’|rtà|ert|ber|ibe|nza|enz|sci|evi|ci |tri|ett|anu|pà |cum|chi|n c|tar|ial|uci|a o|tic|ini|hju|ara|ich|dic|lli|rà | tr|cia|ca |i t|u t|dev|i h|men|lia|ist|ami|è c|rim|tru| co|i à|sti|mu |sic|è à|u h|ntr|cun|ndi|o i|sta| st|man|ita|ziu|ra |i r| gh|à s|nit|bar|iba|ntu|igl|i v|ii |ici|bli|ust|ris|ont|à l|zzi|min|cur|vit|o p|nti|esi| fa| qu|o d|ric|alt|ica|ssu|unu|hja|u a|è d|ati| sp|ura|uni| s’|oli| vo| fi|lic|ubl|nda|rut|hi |è s|vi |nim| la| vi|va | du|aes|pae|ndu|art|sun|uri|tra|ltr|o a|iti|pin| va|are|raz',
    'ltz': 'en |ech|er |cht|n d|sch| an|n a| de| d |an |ch | re|rec|ht |ng |et |t a|ll |un |all| al|t d| vu|der| ge|che| a | en|ere| op|eng|nge|op |oun| hu|ir |éi |dde|d r|nsc| më|t o|tio|r a|ëns|mën|fir|em |hue| sé| fi|déi| dé|uet|ent|éng|uer|ati|ter|de |in |hte|at |sén|iou|e g|ver| ze|ze |ren|vun|n o| se| fr|l m|ner|lec| ve|e s|räi|frä|ong|e v|h h|odd| od|esc|gem|r d|dee| be|ger|nne| si|n e|r s| ma|men|lle|due| du|ten|eet|den|nat|ges|t f|ier|vu | hi|éie|len|een|téi|t g|hee|gen|n h|nt |h d|e m|ale|ers|p d|it |mat| am|n z| gr|her| as|hen| gi|ele|nen|and|sel|äi |as |ët |le |am |gin| na|rf |ss |int|éin|kee|idd|éit|ënn|tz |u s| ke|erf| da|sse|t s|ité|i d|ich|g v|ken|une|hir|aus| au| st|tle|nal|ona|ion|och|dat|sec|ihe|äih|re |a s|e r|p e|e w|ese|est|cha|s a|t e|sou|nte|he |sin|rt |pro|ee |ree|te |lwe|elw|i a|ell|res|sen|a f|n u|arb| ko|n n|r g|e f|ire|aft|d f|eg |al |eem|ft |ert| pr|ann|géi|oll|nd |wec| wa|mme| fa|ran| e |rch|ou |eso| sc| un|bes|r p|enz| në|per| pe|tt |d g|oss| zo|ego|dës| dë|l d|wer| gé|ane|m g|e k|jid| ji|d e| el|g d|nes|uss|ge |eme|e l|ond| wi|éch|g a|ntl|fen|erc|akt|ffe|ege|etz|um |ede|r f|r e|s d| la| in| oc|lem|gon|rel|aar|kla|ete|het|nn |erl|t v|se |säi|lt |ene|s v|éck|réc',
    'lia': ' ba|ba | ka|iŋ |ka |a k| wɔ| ma| th|a b|yo |o w|ɔ k|ma |a t|o b|o k|ŋ b| iŋ| ki|ɔɔ | ni|ho |nam|a n| wu| yo|wɔɔ|ama|wɔ |niy|aŋ |ɔ y|a w|dɛ |ŋ k|ŋ m|ndɛ| ku|wun|na |und|oho|kiŋ|ko |iya|mal|thi|thɔ| ko|loh|ya |ɛ b|de | na| kɛ|nde|and| hu|a m|alo|ana|ali|mɛn|tha|ɛŋ | wo|iyo| bi|ɛn |a d|kan|ina|e k| mɛ|kɛn|ŋ i|li | wa|a h|wo |i b|mo | e | be|ɛkɛ|kɛk|maŋ|kɔ |ɔkɔ|iyɔ|nɛ |be |wal|nth|ki |ɛnɛ|nka| ɔ |unk|ɔ b| kɔ|a p|amɛ|ta |the|ɔŋ |e w|yɔ |ɛ k|thu|e b|baŋ|he |ɔ w| pa|o m|a y| bɛ|ant|i w|kut|ɛ w|ŋ t|in |ank|yan|imo|him|nku|no |hɔŋ|aa |fɛɛ| si|ŋ w|kam|hu |mas|kiy|biy|ath| ho|bɛŋ|n n|niŋ|han|e t|i k|pam| fɛ|kin|a f| yi|n k|kaŋ|nki|kun|hun|o i|hiy|si |o n|kaa|boh| bo|uta|kul|ɔ m|asi|iki|bɛ |ti |uŋ |lan| yɛ|a s|ɛnk|oo |ɛna| kp|huŋ|to |ŋan|lɔk|uno|hit| de|uth| dɔ|n b|tet|o t|amo|ra |ɛnt| fu|ɛ n|aka|alɔ|eŋ | nk| dɛ|deŋ|ani|nt |ɔmi|kɔm|dɔŋ|bal| sɛ|ban|man| du|ni |ŋin|yɛ |u k|hɔn|siŋ| te|te |ute|e n|ɛra|ɛɛr|min|nan|ɔ i|ind|yik| in|ɛ i|ɛmb|sɛm|kas|uya|kuy|oma|ɛti|mɛt|o d| pu|ŋ h|yoo|i n|ɔ n|e m|ɔma|hii|oŋ |ha |ŋa |po |ŋpo|uŋp|a e|ŋki|kub|ito|ohi|eth|iŋi|kɔs|tho|ɔy |kɔy|iyɛ|oŋk|isi|mɛ |hut|ɔrɔ|ɔn |gbɔ| gb|e e|ku |nkɛ|e i|i m|fak|ulo|u w|n m|bin|mbɛ|oom|foo| fo|so |aso| mu|se |ase|pun|ɔri|bɔr|ubɔ|a i',
    'mlt': 'għa| għ|li | li| je| l |dd | u |ħan|il |and| ta|u l|ħal|al |jon|l j|edd|jed|du | ku| ji|ħad|ll |ndu|kul|d g|add|i j|zjo|ali| mi|zzj| il|ni |et |oni|iet|jie|ew |tà |i t|tal|lħa|ulħ|jew|l l| fi|ħu | ti|tie|azz|l i|a’ |ja |ha |għu|ieg|iji| ko|egħ|a t|l p|ra |u j|all|kun|i l|ta’|oll|min|l g| pr|a l| in|a k|ent|un |agħ|ist|n i|om |hom|kol| jk|la | ma|mil|pro|nal|ber|ddi|ndh|u g|i u| bi|kon|ibe|l k|ma |a j|jis|jn |ert|lib|a m|fil|u f|ezz| ħa| m’|ona|liġ|a g|da | da|in |i g|d l|l ħ|i k|m i|ija|l f| me|jku|ont|men|sta|ta |per|i m|ajj|’għ|m’g|ull|en |ien|ità|el |ejn|nda|d m|rtà|as |ħaj|ieħ|mm | pe|naz| is|iġi|r r|ir |a u|an |ett|t t|u k|nt |ura|ti |jiż|l e|à t|jal|n l|t i|t u|dij|at |nti|int|a b| ir|ħti|u m|xej|lu |em |ers|ġi |inn|w i|dha|iss|oċj|soċ| so|ħra| f’|i s|i f|u u|wie|jit|lha|ntr|tez|ote|rot|ame|tra|s s|tag|xi |ind|ter|ċja| na|oħr|sie|ħaż| im|taj|u t|dho|nij| hu|din|iel|edu|u s|l ġ| fa|n j|ż ż|dan|ieġ|l m|nn |n m| b’|kaz|ill|ngħ|ing|m j|emm|kem| ke|l o|ka |ika|lit|i p|ss |bħa| bħ|a f|u i|bil| ħi|llh|l b|uka|duk| ed|ele|eġ |aż |ri |nta|aqs|qud|sti| ka|tur|t l|jin|gur|ied| xi|lil|ata|tku| tk|kk |ekk|na |una|iż | pa|ern|sir|ssi|a s| iż|età| oħ|eli|ess|żla|ażl|rij|arr|aji|rta|n b|uni',
    'hna': 'mɛ |amɛ|be |wo | am| ɖo|le | le|la | la| be|kpe|ɖo |e a| nɛ| ke|gbe|ekp|nɛ |e l|e n| al| ɖe|ɛ ɖ|o a|ke |ɖe | ny|ɛ a| wo|yi | ye| mɛ|nyi| a |o l|lo |alo|pe | ku|ɖek|a n|ewo| sɔ|o k|na | e |ye | gb|ogb|ku |e j|ɖog|ji |pek| ji|e m|kpɔ|a k|i a| do| wɔ|a ɖ|a l|o n| du|eŋu|b a| o |e d|e k|sɔ |o m|yeb| na| ŋt| kp|e b|e ɖ|ea |a w|nɔ | ag|ɔ a|u ɖ| mu|a a|ŋti|an |e g|e w|kpa|ɛ e|ba |mu |a b|ebe|a d|ti |e s|ɛ l|kew|agb| je|mɛɖ|eye| ey| vo| b |ɛɖe|eɖe|e e|a s|oɖo|ɛa |uwo|n a|do |oe |ŋu |o s| nu|osi|ɛ b|nya|gba| ma|awo|si |vos|wɔ |i b|o ɖ|tɔ |pɔ |ɔ k|o b|ia |e v|i k|ɛn |ɛ n|ma |ɛnɛ|nɛn| nɔ|ɔnɔ|nɔn|mɛa|nu |a y|ɛ k|umɛ|uku| ŋk|e h|omɛ|acɛ|nmɛ|a g|o e|a m| te| dɔ| ha|ɖoɖ|je | ka|e y| ac|a t|u k|ɔkp|e ŋ|du |nɖe|ɔ̀ |ɔ́ |teŋ|i n|ɔna|oa |sew|ɔ n|enu|fyɔ|mɛt|ɔnm|ɖeɖ|wɔn|ɛ̀n|sɛ̀|n b| ak|a e|mɛs|sia|ese|kan|ɔ b|ŋuk|o ŋ|ɔn |gɔn|nsɛ|a ŋ|woe|se |o g| go|sin|ha |rɔn|srɔ|o j|sɛn|e t|ɔ w|yɔ | bl|ɔnɖ|ɛ w|vi |mɛj| ba|cɛ |uɖo|kuɖ|ŋut|ɛ ŋ|u a| so|nú |u s| si|gbɔ|iji|ale| su|ua |jro|akp|n k| hw|jea|ɔ ɖ|dua|kum|iam|ɔ e|ŋkɔ|ɔɛ |ɛsi|sea|in |ɔ o|eka|a z| se|o w|alɔ|o y|ɛha|mɛh|ɛ s|iny|so |tɔ̀| tɔ|woa|ɔ l|use|bus|ta |ɔwo|kul| jr|emɛ| ga|ɛ j|i m|i ɖ|aŋu| es|zɔn| zɔ|pɔk|ɛji|ka |zan|u n|i w|uɖe|ɔtɔ|aɖe|esi|nɛa|nwo|ya | gɔ',
    'zdj': ' ha|wa |na | ya|ya |a h| wa|a u|ki |aki|a n|a m|a y|i y| za|wo |he |hak|dru| na|a w|iya|ru |ina| ye| wo|ha |e h|ahe| ze|ye |har|aha|au |hau|a z|o u| ng|ze |wan|mwa|mdr|ne |zi |o w|si | md|sha|i h|u n|nge|tsi| ne|ana|u y|dji|ain|hah|e z|udj|ena| yi|i n|hai| ma|o m| sh|e n| ud|azi|ndr|mu |za |i z|gen|ni | nd|rum|aru|iwa|i w|yo |ama|and|pva|o n| zi|umw|adj|i m|la |riy|e m| ut|u w|uhu|a s|dju|awa|yah| ms|wah|ats|ari|uwa|end|ayi|amu|dam|shi|u h|asi|aka|nts| mw|ili|ada|wad|u u|li |nad|ho |e y| ka|e w|ka |uba|vat|ren|ali| uh| fa|zah|u z|wak| mu|o h|ndz|hi |dhw|e s| ub|lez|djo|tre|und|no |aan| da|a d|juw|zak|dwa|imu|zo | us|lwa|ung|ifa|a k|a p|ula|ao | pv|ele|a t| dj|ndw|laz|da |mud|dzi|hif|fad|ma |i s|bu |hwi| nt|ini|tso|ezi|jo |ra |itr|rwa|zim|uzi| up|i u|saw|uri|hur|piy|an |fas|e f|o z|msh|adh|aul|dau|ndo|wi |nde|aye|dja|sin|a l|eke|iki|zit|haz|liy|o y| pi|mo |tam|uwo|ind|ngw|gwa| sa|apv| hu|iyo|ayo|de |kay|uts|iba|kel|tek|ia |izo| un|u p|omo|som|mso|nga|maa| no|aho| uk|afa|bal|kap|iha|edj|ngu|wu |guz|ati|eka|nyi|any|hay|naf| hi| uw| ni|ani|yak|hun|hus|ola|its|ji |sa |she|ziw|ish|a f|yil|yiz| ur|usa|muy|e d|tsa|uli|i d|ngo|dro|ika|uka|zid|wam|ibu|hin|ong| ho|dra|yid|liw|yat|dol|mad|do ',
    'guc': ' na|in | sü|ana|a n|a s|üin| wa|a i|na |aa |ua |a a|pül|üla|ain|aka|süp|la |shi|yuu|a w|üpü|ayu|inj|ka |nja|naa|way|üü |tüü| tü|kan|uka|pa |ipa|ma |hi | ip|kua|u u|atü| in|uuk|a e| ka|lu |wan|jat|n n|nai| ak|i s|n s|ata| an|nüi| ee|tüi|aja|jan|nak| su|a t|apü|awa|esh|ees|kat|nap|aku|ia |ane|o u| u |sül|ya |sa |ojo|noj|üna|ülu|ala|asa|üsü|at |n a| mü|ajü|ünü|nno|ira|ne | a |a m|aya|kas| nn|chi|taa|ach| sa|a k|jün|rua|üya|ü n|nay|uma|müs|mma|hua|shu|laj|müi|süy|ü s|sü |sün|naw| sh|uu |ta |n w|a u|tü |hik|wat|uwa|ü a|üsh|nam|lüi|maj|inm|iki|e n|jot| uw|püs|a j|ush|eer| ma|che|lia|una| no|i n| uj|waa|apu|pus|lee|amü|le |nma|atu|jut|iru|ott|eka| ek|suk| mm|yat|tai|t a|sal|u s|aap|ü k|eru| at|aju|sük|jol|tta|e m|no |ki |apa|je |u n|raj|ita|n t|ule|jaa| ac| aa|olü|uli|üle|tum|üku| ot|uje|alu|üma|ash| je|tsü|süs|hia|aak|a o|ee | al|wa |kir|uku|eki|era|ots|jaw| nü|n e|sum|üpu|raa|üsa| un|e w|jun|kaj|jee| um|uja|nat|ama|aji|süm|ü m| ne|u w|n k|ñaj|aña|anü|tka|üch|lo |u a|ula|ale|i a|üul|süu|e s|mai|umm| ut| ko|naj|epi| ep|aas|taw|olo|iir|nül|nac|rai|jüi|ali| er|ai |kai|ü e|wai|e a|hii|uta|ral|ü p|tak|aul|lau|pün|u t| jo|pia|e k|utk|tüs|otü|ika|tch| pü|jir| ta|eme|pan|nee|eek|mak|tir|kot|tün',
    'qwh': 'una|man|an |kun| ka|ana|apa|nma|paq|nun| nu|anm| ma|na |is |pis|aku|aq |nap|nan|ta |kan|qan|anp|npa|ow |qa |n n|how|cho|nin|nqa|yan|nak|mi |am | de|a m|nku|ant|erë|der|a k|chu|ëch|rëc|ata|pa |yon|lla| ni|tsu|now|nam|pan|hun|api|syo|i k| ll| i |mey| ts|ura| ru| na|a n|lap|nch|ey |su |rur|asy| ju| me|key|n k|ach|n m| ke|nas|anq| pi|hqa|shq|aya|nmi|eyn|eyk|tsa|all|yqa|eyq| mu|sey|tse|nts|ash|in |nat| ya|ima|mun|nta|a p| wa| im|kur| al|äna|yno|a r|ats|rni|ran|ni |awa|npi|qpi|aqp|ush|iku|yän|lli|cha|inm|ayi| o |mar|w k|juk|ink|kuy|yku|ley| le|kaw|apt|ark|q i|a j|a a|kay|i m|arn|li |a t|unm|inp|a d|yoq|ama|q n|aqa|uk |a i|ina|ayä|yin|may|wan|kap|rka|oq |anc|iya|s m|ury| ur|q m|ish|wak|war|ur |onk|ita|yac|yta|unk|i n|pip|enq|kin|tsi|wmi|owm|sya|rqa|arq| ja|tin|q l|kiy|yar|s i|owp|nac|u k|uri|ten|pte|pit|a o|ras|i t|inq|ida| pu|ipi|pti|nni|onn|kaq|y n|a w|aki|hak|kar|apä|äya|s d|way|kas|iki|yni|n i|uya|onc|m j|m k|eyt|ari|k n| pa|mat|koq|qmi| wi|kra|pap|shk|q k|n p|un |uts|jut|hpa|shp|w n|i l|nno|ann|u n|tap|pur|llq|ya |naq|uku|a y| us|rya|akr| ak| qe|ka |rwa|kik|yey|yka|pi |rin|n l|m d| qa|nis|rid|ori|tor|wto|awt| aw|isy|sti|ray|u m| qo|y d|s l|s k|ayo|aqm|w m| sh|kus|rik|ych|n u|kam|sik',
    'quc': 'ri | ri| ch|ik | ta| ka|al |b a|ch |aq |aj |ya |a t|ina|che|ach|ech| ku| al|tal|pa | wi| ya| pa|i u| ut|naq|win|ta |hec|ab |jun| ju|a r|el |jel| ma|nik|l c|oje|noj|ono|q a|an |we | we| k | ro| xu| an|ron|k a|xuq|i k|xik|k u|chi|uq |nam|e k|ani|ij |uk | ja|h k|k k|kak|man|l r|taq|l w|cho|uch|mal|cha|are|wac|re | ar|ib |un | at|q y|am |j k|tzi| uc|e r|a j|e u|il |axi| uw|k x|utz|una|zij| q | ru|a k|maj|chk|ke | ke|ak |hi | xa|laj|k r|k o| e |ub |tin|wa |wi |jac|i r|ne |aji|he |uma|l u|q k|i q|it |mit|ami|uwa| ki|hke|ala|e t|tb |q r|taj| o |aki|j r|b e|j c|h r| ne|a n|ob | je|j j|hom|ata|ltz|alt|kab|oma|atb|l t| uk|l k|qe |uqe|raj|i w| na| u |uti|xa |i j|je |e n|kaj|kay|a c| il|kar| wa|b i|ama|k p|na |kat|a m| ni|chw|n c|n k|ax |kub|a w|l p|tz | tz|hak|eta|hik|jaw|aja| ra|ali|lik| aj|uto|n r|hwa|sax|aya|n w|a i|ema|lem|sle|asl| as|ruk|e m|awi|apa|e j|oq |awa|kec|le |j u|i e| re|j t|m r|q j|kac|tzu|wax|nim|ich|uya| ti|n t|tob|eri|jer| ik|q w|ha |kuk|lew|ule|chu|uku|zuk|rum|jas|kic|e a|wok|e p| ol| ul|a u|kuy|uj |ato|kum|to |ara|toj|k w|ixi|e c| b |b r|om | ap|o j|aqa|ima|no |ano|kib|oka| le|aku|kuj|kun| ab| ub|kut|ela|ari|e w|i m|q t|ili|riq|k j|j w|kiw|xaq| a |paw|rec| am|ew |lij|m k',
    'isl': 'um |og | og|ver| að| sk|að |ann|ur |er |ar |étt|rét| ma|til| ti|ða | þe|nn |il |ra |ir | hv| í |ska| ve|ing|hve|eða| eð|ta |r s| ré| vi| er| ei|inn|r m| ha|man| se| me| fr|a s|na |al |enn|em |sem|kal|lag|ið |num|tti|jál|nda|ndi|ein|sin|ga |leg|tt |þjó|a e|i s| á |men|a o|and|jóð|nar|ess|þes|an |a h|þei|ind|ður|éla|fél|n s|di |ags|nnu|eig|nna|eim|tin|ns |han|gum|gi | þj|a a|era| ge|nga|við|ber|m o|gu |ngu|áls|rjá|frj|m s|lu | he|ern| en|ði |aðu|ni |ð e|lan|is |a v|nni|r h|nin|ka |tur| la|ski| má| st|l þ| be|r e|da |kul|sku|l h|i e| al|tak|ss |má |rra|tta|átt|rju|erj|sam| sa|mað|und|s a|rnd|ulu|n m| um|ki |lög|rir| tr| þa|n e|m m|afn|u f|i h|a t| ef|ins| at|i þ|ð l|m e| va|lli|all| lö|i m|s e|a þ|ri |æði|iga|m v|jum|im |r þ| fé|m h|óta|jót|njó|t a|sta| þá|r t|i v|r a|með|vin|gar|a í|a r| ta|st |íki|rík| rí|yri|fyr| fy|ldu|egn| gr|eng|u þ|ru |eru|dum|ndu|jaf| ja|ðfé|óðf|g f|ð þ|óða|ma |li | nj|sky|ttu|m r|hei|var| re|ald|nu |sín| sí|rt |ögu|irr|eir|önn|ðan|tar|rei|gan|i o|n h|rði|rum|s o|rin|g v|eg |egu|g h|g t| af|erk|rið|lát|a f|yld|kyl|lei| le|si |a m| si|ygg|ryg|val| sv|ti | ko|mil|fni|ull|ful| fu|t s|nds|kip|dur|nis|arr|trú|erð|lit|þát|un |ví |því| þv|u o|irð|vir|r b|hag|g a| sé',
    'kqn': 'a k|wa |la |a m| na| ku| mu|na |a b| ba|a n|ji |lo |ne |amb|ila|nse|se |fwa|wai| ye| kw|afw| ka|kal|ang|ika|o k| wa|kya|lwa|kwi|ya |ala|ens|yen|bo |tu |e b|nwa|inw|ain|alo| ya|i n| ne| ky|nan|kwa|ntu|ngw| by|wik|nji|aka|e k|gwa|wak|ha |o b|ako|bya|sha|o n|o y|a l|mbu|ula| pa|iji|yal| lw|ana|o m|ulu|bak|u y| lu| bw|anj|nsa| ns|ilo|abo|i b| ki| bu|hi |aku|bu |sam|abi|ons|chi| mi|bul|muk|uji|mo |bij|waf|ish|ing|yan|ko |izh|mbi| uj|a y|bil| ma|kab|ka |ban|ngi|win| bi|i k|mu |kub|unt|mun|u b|ba |e w| mw|kul|a p|e u|ye |wab|akw|uka|mwa|ngo|kaf|no |usa|ho |u k|e m|luk|zha|bwa|zhi|e n|wan|o l|u m|amo|nde|ong|hil|mba|ma |ata|bwi|uko|gil|mbo| in|ilw|ama|ech|kec| ke|nsh|lum|sa |kam|ail|i w|pam| bo|end|ta |kis|yak|kus|o a|mam|jis|any|ine|imb|vim|eka|pak|shi|kan|kut|eke|lan|a a|ubu|sem|ant|fun|uba|kuk|ela|ufu|wam|le |ale|e y|a u|mi |wil|umu|abu|ulo|biz|esh|aji|sak|bon|ino|sho|gol|kon|ise|uky|lon|asa|miz|uki|kum|nga|lak|uzh|lam|o p|ikw|ume|a w|da |nda|und|zho|gul|ngu|kas|uus|luu|unj|luf| mb|de |kel|kup|emi|yaf| po|ina|mvw|umv|kak|baf|ane|ga |nyi|pil|ipi|lip|jil|avi|wav|aki|kil|tam|u n|mwi|ano|bin|ful|uno|azh|utu|mut| a |me |bun|bas|ule|ute|lu |min|eta|let|vwa|mye|imy|kim|aye|afu|iwa|was|ten|ite',
    'pap': ' di|di | de|ion| y |an |nan|cio|ona|n d|on | na| cu|ere|rec|o d|der|na |cho|ech| pe|ent| e | pa|tur|aci|in |al |per|a t|ho |ad |tin|ur | tu|ers| co|ta | ti|to |son|rso|nte| ta|rib|ba |men|e d|cu |en |iba| ri|un | pr|r p|dad|den|pa |io |cia|a d| li|o r|n p|a c|te |i n| of| in|of |ida|ual|ia |lo |nci|a n|o t|no |a p|sa |pro|tad|con|nal|co |ber|ibe|lib|o p|tra| un| lo|ico|nac|n c| ni|ter|i c|n t|o y| re|n y|o n|enc| su|a s|i e| so|a e|or |ra | ca|cua|i d|ert|rta| me| en|y d|d d| no| po|gun|com|do |a m|ame|ant|su |end|res|o c|o o|ngu|ing|nin|ens|so |nta|i p|ali|a l|rio|nto|l d|er | ma|nde|oci|soc|i s|ito|est| hu|nsa|edi|med|el |cas|ten|e p|ke |lke|alk|dio|sti|ist|n n|n a|n e|cla|ro |n s|nse|aso|gua|igu| ig|l y| ac|o e|u t|r d|cci|nti|lid|da |o l| tr|dic|ici|eli|hon|por|y c| se|ans|e e|a a| pu|ntr|a i|e t|de |hen| he|n h|era|ome|i t|eri|int|ndi|eme|ial|ind|tic|nio|lig|inc|dis|ara|e l|ñan|eña|señ|a y|uni|sta|isa|o m| mo|e a|nna|onn|bli|u e|rim|ont|ecc|ote|rot|ari|pen|lit|n o|ki |aki| ak|tro|otr| ot|man|mpl|eda|y e| fa|iva|sio|bel|esa|ple|des| fu|act|tri|tal|tec|nda|ni |ran|imi|n f|min|i a|ien|is |ais|pai|e c| a |e o|igi|i r|se |ase| si|rac|dna|adn|y l|ste|abo|rab|pre|mat| es|lic|a u| ar',
    'gle': 'ach| ag| ch| a |an | an|ch |ar |ear|agu|us |gus|le |na |ne |ine|e a|chu|art|hun|ile|cht|n c|n a| dh|ta |un |rt |h a|dh | ga|uin| le|cea|ith| ce|e d|is |in |r a|aon|on |a a|tá |aoi| ar|as |ir |a c|uil|nta| bh| na|air|omh| ui|hui|gac|ag |eac|a n|á a|dhu|s a| tá| ná| sa|hai| do|il | ao|go | go|h u|t a|adh|sao|t c|hta|hea|g g|och|the|tha|th | i |a b|isi| in| is|ht |nó | nó|n t|oir|cha|a t|a d|tea|do |n d|idh|ann|ion| co| ai|ní |íoc|amh|ha |dea|s c|mha| ní|siú|irs|cho|nn |oin|n s|far|lac|nái|h n|mh |ean|he | de| dl| gc|s i| th|ná |ain|í d|iún|áis| ph| ma|lea|a s|eid|r d| sh|h d|hao|se | du|nea|éan|e c| d |dlí|s d|tac|inn|lí |nna|h g|hái|s g|n n|l a|ide|rea|rth|hla|i g|áil|e n|rse|h c|únt|iri|áir|eit|ais|sa |í a|int| bi|ana|ant|dui|eam|aid|idi|e t|ona|com|a l|n p|aig|hei|aío|héa|che|irt|a i|r b|coi|h t|dir|eag|s n|eal|hoi|n i|hio| oi|hom|ige| gh|bit|óir|río|ead|ora| fh|eil| ei| at| te|lei| mh| io|rta|d a|nac|ge |oib|hch|ait|onn|ire|eas|ial|h i| ne|bai|ó a| ea|la |r f|s s|pho|gha|agh|gan|h s|n b| fé|d f|ina|ra |aí |ghl| tr|nt |r i|íon|t d|bhe|e g|íte|n l|gco|igh|áth|ogh|lán|mar|ria|bha|ont|oil|o c|nfa|anf|déa| dé| bu| cr|ath|r l|mai|has|seo| se|sí |féi|sia| ré| da|r n|oid|ala|o s|iú |sta',
    'dyo': 'an |ool| an| ka|baj|di | di|ati|ti |en |noo| ku|uwa|aba|aj | ma|ano|san|oos|ak |osa|waa|mi |i k| na|kaa|ay |ole|ŋoo|aay|n a| ba|ana|la |man|aan|ruw|dru|uka|mba|i m|ut | bu|aju|ola|ba | mb|n n|oor| wa| si|bab| mo|aka|len|af |k k|ol |n k|kan|aam|i a|n m|war|awa|umi| dr|eba|wa |poo|aaf|am | eb| mu|as |nab|uba|ar |moo|koo|oo |n u|yoo|y y|j d| ya|kay|i b| fu| ká|i d|ne |nak|buk|uum|m m| nu| yo|a e| fa|kat|jut|aas|ara|i s|waw|um |mof|juu| sa|uŋo|e e|ban|lak|j k|a k|luw| bú|mat|naa|rok|ooy|a m|nen|ene|s s|or |raa|o k|aja| ko|ab |ila|uma|ni |e a| ak|ko |aŋa|je |n b|re |r k|num|aat|muk|iya| le|n l|i e|i f|foo|f f| lu|een|t a|kar|om |uro|kak|ya |iiy|aak|yat|n s|ey |a n|l m|anu|sen|ako|let|o a|ama|suk|o b|to |idr|sid|i w|kur|rom|k b|bur|k a|iil|aŋo|f m|o d|of |kin|e d|uju|era|jaa|fat|ani|n d|laa|ula|eŋo|leŋ|y e| fo|aje|yab| be|ken|e b|eno|amp|aw |ere|kuw|nan|úro|búr|maj|raŋ|caa|yer|aye|aŋ |boo|kaj| ta| sí|rut| ek|a a|kil|aki|ane|oyu|nub|l n|amm|bee|ok |mii|a d|o m|uto|ank|m b|soo|oop|m k|afa|e k|ure|jak|sat|uko|upo|m d|ŋar|ñii|kuñ|abo|amb|uki|omi|umo|tan|oke|wan|kuk| ja|una|one|oon|aañ| el|baa|nuk|etu|a s|nuŋ|mmi|uke|suu|ora|ee |ake|ŋum|maŋ| ne|l a|oy |yii|ŋaa|faŋ|uk |ésu| és|i l|ul |i é| at',
    'hns': 'ke | ke| ha|ai | sa|hai|e k|dja| dj|i k| ka|aur| au|ar |ur |cha|ab | ko|kar|e h| pa|aun|haa|ak |hak|jau|en |an |sab|e s|oi |un |koi| ch|i s|are|hi |i a|e a| aa|we |e d|b k|he | ma|k h|kha|i d| ba|se | se|mê | mê|adj|aah|aan| kh| ra|re |ha |aaw|n k|r d|awe|at |maa|sam|aad|oen|tch|r k|aar|r a|oun|kou|ne |ien|ki |na |ama|bar| na|tie| oh|ati|pan|apa|no |uno| ki|am |n d|dj |ohi|hat|hoe|r s|ès |dès| dè|n s|aai| ok|saa|rat|e b|ttc|ren| bi|n b|jaa|sar|a k|har|al |e m|i h|r b|waa|a s|aat|ahe|hal|ara|go |ego| eg|aam|le |s k|doe| do| bh|pai|cho|jab|n m|paa|e o|e r| ap|aap|e p|m k|kaa|e c|i o|att|ala|j k|n a|o k| de|rak|esa|oes|ge |kan|i m|ch |i e|aka|ikh|ehi| eh|di |par| le|o s|yaa|a p|man|noe|iya|e n|dha| bo|bha|i p|i b|ano|oer|h k|ti | dh|ang|l h|lik| li| so|aba| si|iet|sak|ark|mad|ádi|jád|ann|ri |oe |rka|ake|gar|roe| me|reh| re|ka |aal|ich|a m|hie|r p|djá|ari|ah |naa|oke|tab|ena|san|b l|oka|aha|ahí|i c|bol|khe|bic|kam|n h|ahi| la|r h|aid|b d|ett|biy|nge| ta|r o| be|ewe|s h| ho|a h| ro|ehe|dji|n o|is |ban|bèg| bè|k a|e l|a b|daa|rab|arh|sie|rha|cch|b h|gha|h m|rah|es |ies|ath| oe|kho|a a|ans| pe|e e|i r|ana|èga|o d| go|h s| sò|era|nda| ni|r r|rm |arm|a d|aw |n r|dhi|hna|t s|soe|jat|ddj|èn ',
    'gjn': 'nɛ | nɛ|be | be| ka|e k| ku| ke|so |eŋ |a k|o n| mo| so|ash|a n|shi| ek| e |ɛ e|to |ɛ k|ko |ɔ k|ŋ n| to|aŋ |obe|kas|mob| kɔ|teŋ|ma |ama|nte|hin|int|ga |na | na|kam|ɛ b|mo |a b|eka|kɔ | nk| bu| da|li |kpa|kum| ba| wɔ|a s|e e|aga|dag| a |o e| ma|mu |ful|uŋ |o b|o k|aa |uli|efu| ef|nko|sa |pa |e b|e n|ra |keb|la |baa|a e|she|umu|i k|bu | as|heŋ|ɛ m| n |maŋ| ki|a m| la|nya|hi |ɛ n|a a| ji|shu|ekp|ana|o m| fo|ŋ t|i n|ken|tɔ |e a|u s|e m| ko|kɛ |ikɛ|kik|le |kus|ku |ya |fo |huŋ|ɔtɔ|wɔt|eba|wɔ | sa| mb|asa|ŋ b|i b|naŋ|n n|i s|a w|ŋ m|ush|ŋ d|umo| sh|ŋɛ |a t|ɔ e|a d|ŋ k|esh|o a|ule|wul|bra|ɛ a|aŋɛ| an|mbr|kuŋ|ii |ni |e t|ŋ e|a l|bee|aas| eb|bar|i m| ti|eni|u b|ɛ s|ŋ w|re |anɛ| ny|ili|yil|maa|i a|ŋwu|oŋw|koŋ|ɔ m|ka |kan|nna| nn|yaŋ|ɛ f|ji |kek|ebɔ|eny|kes|ebi|ala|ba |saŋ|kɔn|o t|iga|jig|ge | gb|kak|ar |nkp|o s| fa|eko|u k|bii|bal|awu|i e| es|gbe|eeŋ|naa|ɔ b|awɔ|baw|rɛ |ɔrɛ|bɔr|ere| er|eyi| ey|di |edi|med|ime|dim| di|ɛ d|nan|shɛ|il |kil|yɛl| yɛ|par|rɔ |ɔrɔ|wɔr|nɔ |chɛ| am|esa|e w|lɛ |uso|ɔ n|u j|o d|e s|ech|ri | yi| kp|ta | ta|po |ars|aba|al |yɛ |we |kar|u d| tu|bum|ben|hɛr|ee |ŋ l|ɛla|e f|ɔnɔ|iŋ |tiŋ|u m|o j|e y|oe |fa |ŋ a|oŋ |loŋ|kap|eke|gba|kec|u l|ɛto|piɛ|kpi|key| ab|ena|che| ch|nyi|kur',
    'njo': 'tsü|ng |sü |ung| te|tem|shi|a a|ang|ba | me| ka|ten| ma|en |a m|a t|nun|ete|ma |er | as| aj|ka |a k|met|eme| nu| ta|aja| pe|sun|isu|nis| ni|ate| sh|ak |ali|ei |pei|ema|üng|its|la |ü a|g a|ase| al|ok |ser|tet|jak|üts| ki|ia |iba|ra |sür|nga|ji |ong|sa |i a|i t|zük|em | at|üra|mes|kts|n k|dan|a n|kar|esü|a s|ar |küm|süt| li|okt|asa|lok|kok|ako|zün|g s|lit| kü|dak|hi | an|hia|ama|ala|r t|mak|a p|aka| ak|apa|map|r a|ü m| ag|lem|kti| lo|i l|akt|üka|a l|ü t| ib|üla|sül| nü|kas|ash|ti |pa |uts|ech|g k|ngd| sa|m a|n a| am|lir|ozü|ga |kec| ke|gi |i n|tas|ir |azü|ngt|rte|i m| oz|g m|ing|hin|sen|g t|ai |yim|yak|nya|iny|r n|k k| ti|ele| ya|ent|a i|k t|man|ngb|i s|ite|kda|bon|aji|k a|jan|nem|ens|ren|ngi|ü n|g n|lib|nok|i k|chi|et |gba|ibo|kib|akü|ta | in|gda|sün|ayu|mzü|r k|in |kin|im |nda|k n|bal|ane|agi|ja |agü|ngs|r i|a o|a y|mer|len|lim|mel|ben|tel| se|don|tba|etb|tan|ats|mte| da|r p|üji| it|baj| yi|ija|kij|güt|eno|üba|süb|ima|hit|asü|ere|ümz| ts|m t|tim|ha |cha|end|mal|bur|ets| ba|sat|nüj|gaz|tep|den| ay|uba|kai|nte|okd|gts| je|jun|n m|kba|urt|eta|aia|gai|a d|bok|übo|küb|msü|nsh|yut|k s|ulu|yam|ur |san|ngj|lun|g l|isa|emt|hir|ake|oba|ket| mu|i i|mul| sü|ims|mts|emb|nük|üm |tak|übu|nüb|g p',
    'hus': 'in |al | in| an|l k|ni |n t| ki|tal| ka|kin|ka |n k|ani|an | k |l a|aba| ab|bal|ál | ti| al|áb |láb| to| ts|wa |ts |tom|i k|l i| ja|nál| ju|a a|chi|mná|omn| t |alá|jun|a t| ya| kw| wa|tin|at |t a|l j|ata|k i|íl |idh|nch| ma|yab| ta|pat| pa|n b|a k|ab |i a|i t|tsa|dh |k a|ik |uni|nta|dha|its|ti | ji| i | ax|hik|a i|l t|i j|xi |int| aj|k w|b a|n u|sal| éy| pi|jit|áj |ax |bíl|waj|tam|ij |kwe|chb|uch| uc|am | ex|enc|b i|hbí|kwa|n a|n i|bin| ko|j a|ta |ita|jol| jo|n e|axi|max|n j|iy |a j|aja|jaw|ha |n é|na |k á|il |cha|wen|ala|l p|i i|sin|tsi|yal|éya| na|ej |jay|ap |lap|b j|jíl|pid|xób|exó| oj|aye|y a|awa|a p|t o|lbi|n l|yat|man|ets|pil|ají|éy |alw|uw | ba|óbi|ja |j i|n p| pu|y i|hál|ki | ku|ko |él |xe |ow | ej|tse|lch|y j|lwa|ats|h a|s t| im|b t|ey | oy|o o|chá|y t|e n|le | le|s k|kit|iya|niy| án|hin|dhá| xe| at|s a|xta|bel| be|bat|alk|n y|jlá|ojl|oy |yan|imá| dh| xi|edh|olb|m k|yej|áni|s i|t k|l y|jal| ij|ejt|hal|náj|axt|káw| ká| bi|t i|han|w a|lka|wal|ini|lk | tá|ku |j k|dhé|jch|nél|háj|b k|a y|e t|tow|jto|p a|sej|lat|ilc|unt| uw|s u|hij|xé |on |a w|áki|i p| on|jiy|u t|tám|i e|ajc|b p|w k|ola|hat|jat|tná|atn|yet|t ó|i m|kax|nid|á a|unu|adh|nal|wed|uwe|puw| it| ai|i d|ych|iyc|m a|lé ',
    'xsm': ' o | ba| na|e o|na |ba |ne |aa | se|a n| wo| ma| de|se |ge |a w|ŋa |e b|ɔɔn|o n|ma |no |nɔɔ| nɔ| ye|e n| ko| to|o m| wa|maa|ama|aam| te|a t|ane|o t|ɔno|de |e t|to | ta| ch|a k|o b|ko |e k|a b|ye |oŋa|o d|o w| je|ege|a j|ra |a s|o k|naa| ne|lo |e s|e w|aan|a l|woŋ|jeg|a y|taa|ae |eo | la|o y|e d|a d|i o| ŋw| ke| ka|ri |won|ei |re |wol|wo |em |ni |mo | mo| da|o s|wae|daa|ɔge|a o|tei|a m|i t|iin| pa|aŋa|teo|ora|o o|we |ke |te |li |age|wad|eir|oŋ |toŋ|olo|hwo|chw|dɛ |a c|iri|am |baa| bo| fe|ga |oto|tot|i n|o j|aar| we|ta |im | ti|boŋ|ŋwe| tɔ|onn|are|ina|wor|oli|nab|ee |lag| ni|maŋ|waa| dw|o c|fee|pa |ein| si|wan| ya|i d|bii|abi|e c|log| lo|hɔg|chɔ|dwo|o p|adɛ|baŋ|ŋwa|obo|bob|ini|ia |m n| zo| vo|era|iku|one|a p|o ŋ|wi |dwi|go |ogo|e y|uul|kuu|sik|tɔg|uri|m d| di| ja|elo|ran|yer|o v|m t|ɛ s|che|ea |wea|a ŋ|e m| be| ku|dem|om |o z|ŋe |ka |sei|uli|kur|i s|i w|kei|oor|a z| sa|ete|tet|kol| kw|m w| kɔ|e f|ent|nno|nna|ded|ore|nto|tii|vo |del|aŋ | ze|aŋe|ada|oo |lan|o l|la |sem|igi| wɛ|bia|nte|men|ɔme|gɔm| gɔ|jei|i m|ti |le | dɛ|ura|zur|ezu|yez|i b|pwo|alo|jwo| jw|ene|ŋ d|e l|di |zoo|een|ja |ywo| yw|wom|cho|iga|ŋ o|yaa|ere| ve|e p|kwo|a f|sim|isi|gis|tig|i y|ega|heg|ɔna|uni|tɔn|adw|i k| le|i l',
    'ote': 'da |nu | nu| da|ni |ro | ro|a n|ti |i n|tho|ho | ku|ja |u r|i d|oth| ni|kja| i |i k|a k|cht|o n| kj| go| ka|hti|uch|kuc|got|ka |o k|u k|i g| ra|te |ra |o d| ji|oo |zoo| zo|a z| yu|di |e n|yu |ini|a d|a r|i i| mu| a |tsi|a j|o m|a m| ko|i r|a g| te|pa |ñin| pa|̱i |e d|si |jin|ki | yo|mu̱|u a|i j|i p|yo |fi | jñ|kua|a t|ua |o t| ma|u̱i|u y| fö| xi|jñi|i a|ne |nda|i y|o y|nth| ne|a b|i t|ing|de | ge|kot|a f|a x| xo| o |aa |maa|ödi| bu|u n|gi |o j| mi| de| me| tz|iki|xo |a ñ|u j| bi|o r|i m| ju|ati|ngu|a i|na |a p|o b| nt|xik|ui |bu |mi |ind|ji |a y|̱fi|e̱f|nts|jte|ajt| aj|ko |i x|u i|bi |i b|u t|ent| ñi| nz|hat|tha|o g|ju |gen|pi | nd|ngi|föd|ri | ja| nk| ga| an| na| tu|jti|ujt| uj|o u| be| ri|öts|föt|tzu|e k|ge |ege|geg|o̱i|jo̱|ojo|moj|jmo|gú |ngú|o p|u x|min| ts|nkj|ank|i o|bin|ña |tu |o i|me |ee | bä|be̱|ete|iet|u m|u d|nka|kñi| kñ|e j|ifi|e g|u b| ng| fi| pe|ijm|xij|o a|gu |ya |tee|äts|bät|jie|e p|̱nt|u̱n|fin|u̱ | ño| je|hte|̱ku|u̱k|zu̱|päd| pä|e i|me̱|o f|api|oni|ädi|e f| gi|áki|zák|nzá|uti| to|mui|ina|e r|ga |a o|nzo|e m| ña|ang|tzo|ñit|iti|nfi| nf|ze |e o| ui|dan|ke |jua|ño |je |öch|föc|sif|zo |to | ki|kap|pöd| pö|ku |gan|aki|no | no|i ñ|̱mi|o̱m|do̱| do|a a|ana|nan|oya|zoy|öti',
    'qxn': 'una| ka|an |man|kun|ana| ru|is | ma|pis|run|apa|paq|nma|aku|npa|na |kan|qan|nan|nin|anm|nap|aq |anp|ta |nqa|cha|yan|aw | y |a k|qa | di|nak|n r|yun|haw|mi |pa |api|syu|aya|kay|ich|may|nku|dir|ima|n k|a m|ant|asy|chu|ric|iri|anq| im|tsa|hun|rni|yqa|ayq|in | hu|ata|naw|lla| na| ts|tin|pan|nas|ay |pti|nmi| ni|nch|huk|tsu|say|ura|apt|inq|a r|rur|npi|q y| pa|nta|su |am |lap| ll|pap|unm| wa|nam|inp|a p|i k|un |nts|kap|ita|n m|nat|ach|ayk|arn|pit|unk|inm|kuy|n y|ran| li|uk |a d|w k|a i|s d|a n|ni | mu|u k|irn|qpi|ras|y t|yku| u |ink|uq |iku|aqp|all| ya|uri|kas|sya|liy|i p|yka| ri| pi|ayn|unc|yuq|s i|q r|awp|s m|aru| ar|unp| ku|asa|a a|uya|yna| si|a u|awa|ada|q k|a l|ara|a h| al|kar|hqa|shq|kin|tap|u m|da |s k|iyi|aqa|uku|tan|urn|s y|y r|kla|iki|ida|wan|nni|unn|n a|y m|ma |s u|dik|kur|lli|yta|wpi|a y| is|n i|sak|iyk|m k|iya|yin|siy|ash|rnu|yir|byi|uby|gub| gu|riy|ika| pu|war|kaq|wal|iwa| iw|ish|yap|uni|as |igu|n n|stu|mun|ahi|ats|sti|nna|ann|q m|ank|y i|kri| kr|lig|ili|rmi| ra|qmi|int|yac|ris|pip|ruy|dan|kik|ist|unt|sin|uta|k r|ipi|kaw|kad|arm|aqm| ch|lar|ikl|y d|i r|pay|nac|tud|rak|yud|yay|way|n t| ki|ush|s r|anc|hin|asu|qqa|aqq|w n|a t|isy|ray|ins|n s|adu|inc|gyu|igy|ril| ul|naq|isp|shu',
    'gag': ' he|em |hem|bir| ha|an |erb|ın |akı|hak| ya|lar|ir |in |ar |n h|arı| in| va|san|da |aa |her| ka|nsa|anı|maa|ım |ins|var|nın| ol|na |sın|kı |ası|eri|rın| bi|rbi|lan|kla|un | se|r i|r h|n v|ara|ler|a h| ba|est|bes|rbe|ser|lma|lik|ada|nä |akl|alı|inä|nda|ı h|ını|n b|tli|stl|a b|zım|oru|nma|rin| lä|ä h|al |n k| sa|ına|nan| di|äzı|ääz|lää| on|nna|sin|ama| de| bu| ko|ala|lı |let|yad|lä | ki| ku|nı |ka | ay|m h|ndi|end|çin|içi| iç|sı |mas|esi|ya |n y|baş|ayı|än |m o|ken| ke|kım|kle|olm|kor|ak |evl|ekl|ık |ard|ınd|irt|si |n s|er |irl|k h|ik |mal|ı k|aya|a s|bu |r s|nar|ini|ää |mää|ana|nun|onu| cü| na| yo|li |ona|etl|ili| sı|ı o|a k|yar|a g|vle|ırı|kar|r k|rta|rla|enm|nmä|ä k|rma|m d|aat|baa|äk |mäk|n o|kan|ola|i i|ulu|kab|n e| do|dan|a y|rı |ren|ısı|yır|sun|and|lık| da|a o|tin|eti|di |m k|tak| üü| an|m a|rdı| ge|run|anm|lsı|yap|a d|şka|aşk|är |lär|m s|bil|iya|ıl |iş |ver|ile|dım|üre|üür| gi|rle|a a|lıı|üml|cüm|çık|sıl|nas|ok |yok|mes|rli|unm|ä b|yaş|ıls| so|ikl|dek|lsu|aşl|ril|dä |ndä|ind|m b|nin|mle|şma| ev| iş|n i| aç|n a|ıın|ıla| za|k n|eme|ölä|ı b|non|ano| ta|lun|aal|rıl|len|a e|sey|mse|ims|kim|lii|mak|yan|may|ıı |aşa|dev|dii|uru|din|ı d|ız |sız|ţiy|aţi| uy|ınn|ä d|ri | ve|lış|ial|ni ',
    'shk': ' ki|ki |hø | bë| a |i k|ø k| dh|dha|en |nhø| me|anh|han|ng | ge|i b| mø|ø m|gø |e d| yi| wa|bën|ø b|øg |i g|la |ala|e k|wal|yi | ny|ri |mi |bëë|ne |ëne|me |a d|gen|yër|dyë| dy|i d|ëëd|ödh|i j| yï|da |møg| ke|dhø|pöd| pö|gi |ong|bon| bo| da|ni | ko|rø |dø |ge |a k|ny |i p| dw|ipe|kip|i y| e |e b|g a|dwa| gw|men|pe |ïe |yïe|n a| kö|e y|a n|di |i m|ji |ø d| gï|nyw|i c|kor|gg |ërø| bä|ër | ji| o |a m|hi |bur| bu|nyi|n k|g g|äng| ka| ci|köm|eny|ëdø|i t|ani|g k|ään| kì|dhi|e g|r k| en|i n|cug|ø y|kì |i w| kw|ngi|öög| gö|n d|yij|gwø| cu|ugg|igg|cig|ko |ömi|a g|wøb| ja|y k|kí | kí|g d|mø |wad|øgø|wøg|y a|ka |li |ii |a b|kel|kwø|ø w|add|ïn |gïn|eki|gek|ij |ywø| ba|wat| mi|r m|e w|g m|ken|ggø|e o|ggi|g b|le |ori| gø|elø|uri|ngø|a c|göö|h k|th |ø e|a a|wed|gwe|l k|øøg| kä|bää|ang|yø |e c|i e|egø|ëd | ce|nni| mï|ì k|løg|bi |bbi|øbb|ïb |cïb|ddi|ø g|bän|lø |ed |tee| te|wöm|ywö|d k|ing|i r|eth|cet|inn|kin|ögg|o g|ew | ng|ïdh|bø |i l|jam| á |iri|kir|ënn|ácï| ác|a á|de |kye| ru|yï |e p|dïd| dï|yën|gan|øge|eeg|re |ëy |ïëy|yïë|ëny|ban|g y|n c| kø|meg|än |ócu| óc|øli|bøl| bø|gög|w k|g n|nge|mïd|e m| di| dë|d a|dd |amm|gøl|g e|ïdø|nn |ur |b k|wag|ga | ak|rum|ï g|wøl|ba |dhh|nyø|ëng|tyë| ty|lli|i ø|öge',
    'nba': ' ku|a k|a v| vu|na |wa | na| mu|a m| vw|mu |vwa|u v|nga|ku |la |ya | ka|ga |ka |ndi|a c|kul|di |vul|ang|uli|oxe|e v|o n|xe |o v| li|co | ci| vy|mo | co|emu|kwa|pan|lem|ti |ule| vi|ung|umo|sa |and|i n|i k|a n|ing|e k|end|lin|mbu| va| wa| ca|li |i v|mun|u m| ya|nde| kw|vya|o k|nu |uka|unu|ali|ca |vuk|lo |wox|o c|muk|je |ind|a l|ngi|ika|lik|uti|ko |ula|aka|kum|we |fut|nda|kat|ela|kal|u k| al| wo| in|vun|ngo|esa|u w|kut|uje|de |pwa|ma |apa|ong|zan|umu|nge|man|go |gul|ngu|i c|lif|o w|kus|ala|ane|u c|ipa|so |upw|ifu|u l| ly|e a|ati|amb|wen| mb|nap|isa|bu |iko|ulo|ulu| ma|vo |kup|gi |vip|eso|aku|uku|ayi|vum|e c|lim|o m|ukw|utw|apw|kuv|und|lya|yi |wan|ene|kuk|a y|bun|nen|van|imb|yen|ama|ond|ton|ima|lon|ilo|a w|le |a i|kam|e n| mw| um|una|avo|sem|vak|asi|sim|vwe|uxo|e m|vyo|i i|yox|use|ili|i m|wam|mwa|ne |amo|ana|o l|imo|eka|ike|ges|ale|twa|wis|pwi|oli|mol|pwe|uki|da |nyo|lil|elo|si |vuv|lul|o a|a u|gan|ena|mum|iza|a a|was|uma|vux|mes|ivu|yo |aum|nau|utu|wal|wo |wak|i l|o y|kun| ak|ato|ina|wav|ciz|vox| vo|sin|ipw|ye |yak|uvw|key|eke|nek| ng|upa|yun|uvi|way|i a|ije|ila|kil|uso|i y|kan|ele|dam|any|kay|asa|ame|kwe|eng| si| ik|vup|isi|oko|xok|u n|vut|vuj|nyu|eme|nam|ndu|uta|omb|lye|omp|som|xik',
    'miq': ' ba|ia |ka |a b|ra | ka|aia|kai|a k|ara|ani|la |a a|a s|ni |ba | ai|sa |kan| na|aka| si|in |an |a n|nan| ku|ika| up|upl|pla| la|n k|sin|a u|i b|bri|a l| br|ira|tka| ta|nka|a p| wa|ait|isa| ma|ban|bak|aik|bar| sa|lak|rai|ank|a d|ku |aku|itk|ulk|kul|a w|ris|air|lka| pa|a m|a t|kab|aba|kum|ki |bia|uki|wal| di| ap|na |kar|abi|dia| su|ala|pia|api|sut|i s|ri |uka|asa|ias|ain|duk|mai|bai|tak| pr|rik| ra|i a|ut |ais|ya |as |pri|kia|i k|sip| du|wai|n s|kra| lu| iw| bu|kak|apa|ras|iba|ha |aha|luk|n a|n b|bui|sba|asb|tas|um |ui |wan|ila|aya|lkr|i l|iku|t b|at |ip |ska|u s|aur|bam| ya|ink|awa|kat|u m|sau|mun| mu|a i|i t|i p|atk| ga| an|lik|pan|a r|lar| da|iar|i m|umi|nat|yar|a y|ana|nir|ark|war|alk|sla|asl| as|auk|ai |iwa|ntr|ant|rin| wi|nah| ti|ari|dau|rka|i r|una|ura|i n|n u|ta |pli|nib|kuk|ata|nt |ent|men|ame| py|lah|isi|p k|pai|man|mi |m b| mi|isk|k k|tri|kir|bil| bi|pa |sap|n n|til|gab|pya|yua|pyu|ma |hma|ahm| ri|li |t k|mar|iki|nra|bah| al|iwi|ita| ki|n p|amn|aki|sik| pl|a g|paw|al |yab|nsa|ans|urk|tba|utb|mik|ak |u k|i w|bay|iti|san|pas|tab|u a|ria|rk |lki|aid|upy|kup|rit|ali|pal|ilk|tan|aib|tai|t l|bap|anr|maw|n l|ima|lba|ik |n w|uya|ina|n t|tik|may| ni|mna|kis|mal|sma| sm|iai|is |kni',
    'mam': ' tu|b i|il | ky|n t| n |al | il|l t|u n|tu |aal| b |jaa|tuj|uj | ti|ti |xja| xj|iil|j t| ju| ix|i j| j |an |kya|ix |qii|b a|yaq|een|aqi|un |x t|l k|en | mi|l x|jun|tza| tz|a t|qa |lee|aj |ok |n k|ib | te|nam| to|am |ax |l b|tz |tna|at |tee| qa|a n| an|q i|kle|okl|j k| at|l a|uun| tk| ii|aq |eet|aan|juu| aj| tn| ta| ma|ab |anq|t t|tii| ch|ool|nq | aa|n x|tok|ma |ol |zan|kyo|kyx|yok|x k|chi| ee|et |taa| ya| ib|iti|mit|ana|k t|j j| ja|tb | tb|iin|l j|qe |kye|laa|n b|q t|oq |noq| no| ok|ub |kub|ook| tw|iky|l m|t k|nx |ob |te |q u|twi| ni|kyt|yax|aay|e x|ila|l q|j x| tx|m t|j a|x m|yoo|itz|yee|e t| a |tku|wi | q |iya|i y|ik |k u| ko|naq|nb |ee |xqa|ixq|n j|el |jb | tj|too|mil|m k|tan|ky |nma|anm|tl |ntl|xii| xi|ja |kyj|unx|lqe|ilq| al|o n|a j|n a|y t|naa|una|t x|ay |u m|za |tja| oo|iib|a k|aaw| ka|kyi|txi| ik|unt|l n|lab|k b|i x|xoo|yxo|u j|yja| t |inb|b e|l o|tko|ntz| nt|ex |eex|i t|kol|xi |z o|nan| un|ant|mal|b t|etz|wit|a b| xa|ya |miy|j m|sla|iik| u |yan|ntn|int|nin|n c|xna|x a|e n|imo|him|jak|ka |ama|q a| tt| o |i n| nx|n n|a m| xt|kyu|ala|e k|eel|aaj|wb |awb|kaa|xan|nii|l i|n m|aax|a a|yta|ksl|oks|yb |maa|in |nal|z a|ina| wi|mob| yo| xn|ii |pan|ipa|aka|oje|yii|jay|yu |iip|ajb| k ',
    'tah': 'a a| a | te|te |ra | i |i t|e t|a i|a t|i a|to | e | at|ta |ti | ma| ti|ara|o t|au |a e| ta| fa|fa |ia |na | am|ata|ana|e m|mau|e h|man| o | to|e f|a o|ama| na|a n|o a|re |hia|ira|nar| ar| ra| ai|e i| ha|ore|ha |ato|u t|i i|e a| ro| no|no |atu|a m| or|o n|ai | tu|e r| ē | hō|ō ē|hō |o i|ora|tur| ao| ia|pa |tu |aor|apa|ahi|e p|amā|ura|oto|a r|rot|ma | pa|u i|tei|i r|uru| ap|ua |mā |ohi|ait|aha|par|hi |e o|va |ito|u f| hi|u a| va| it|ipa|hip| oh|rur| av|o o| ir|o e|a f|oa |āra| ei|ro | au|fai| ah|era| fe|ni |ie |eie|tah|ita| ih|ifa|aif|u e|utu|ure|afa|tau|iti|mār|i e|a h|rav|ave|e e| ni|rir|iho|upu| tā|uhi|fau|tir|rar| āt|ā ā| an| pā|ere|ru |pap|ufa|auf|iri|are|u o|e n|i m|api| af|roa|iah|eia|hau|nua|enu|fen|a p|vir|avi|ehi|ā i| mā|ei |u m|pu |āto|pi |aro|e v|reh|tat|tup|tā |a u|ve |rer|ihi|ho |ri |ari|ae |i f|ruh|nah|aut|i o|mai|hin|ava|ipo|aho|ā o|tua| ut|mu |umu|tum|hor|hap|aru|ter|ate|u v|aur|pū |u h|pae|ina|mui|amu|tam|ui |oro|ē h|āru|pār|oti| hu|o r|por|oia| oi|imi| im|far|pe |mua| mu|e u|ā e|tor|ota|po |poi|mat| er|rau|uaf|eti|fet|rā | rā|u r|ino|aot|pat| ho|ē t|tit| po|ē m|ū i|ou |nau|fan| ur|mar|aup|aō | aō|i n|oip|aip|ē a|iar|mir|u p|ati|uir|hui|ite|ape|fif|rah|tap|eta| et',
    'nav': 'doo|íí |ee |bee| be|tʼá|go | tʼ|ʼáá|ígí|gíí| do|óó |dóó| bi|oo |áá |e h| ha|ah |o b| dó| há|í d|haz|á a|dah|í b|łts|níg|ool|tso|į́į|iʼ |éí | éí|hgo| da|oh |da |́į́|soh|aji| na|ood|o d|h d|h b|áád| áá| ah|ádó|hoo|nii| aj|á h|ii |jił| ni|ʼé |iłt|ani|ą́ |ą́ą|ʼą́|azʼ|į́ |há |o t|tʼé|í t|eeł|tʼi|otʼ|yah|o á|ʼ a|ʼiʼ|naa|oot|íní| ho|á á|bin|aʼ |ʼį́|ado|zhd| dí|din|ahj|ahó|iní| ał| áł|ʼ b|éya|kéy|ó n|ʼáa|eeh|jį́|ání|ish|aan|yee| ye|ido|díí|ó b|zʼą|ájí|nah|ʼ d|lį́|nis| hó|ʼah|oda|ʼ á|híg|iné| di|átʼ|ʼíg|é b|ina|kʼe|tah|ole|o h|azą| ad| ké|aa | áj|́ t|́ʼ |hjį|ó h|ʼeh|chʼ|hdo|iin|azh|tʼį|zą́|i b|h n|zin|ooʼ|haa|ʼ h|e a|lee| ba|́go|į́g|ego|izh|ehg|́ą́|łgo|aho|iiʼ|dzi|ní |áad|áha|íʼ |í h|hee|sh | bá|ini|éeg|áán|eł |itʼ|h a|eʼé|ó d|háh|į́ʼ|ees|hak|aah|baa|ahe|łch|níí|ótʼ|ooł|haʼ|odz|ʼaa|hod|ł d|łda|h é|́ d|o a|bił|áan| át|a d|aha|oon|né |iid| hw|kee|e b|ʼii|í é|h t|tʼa|aʼá|í y|ʼée|eha|a t| ła|ó t|iná|á b|łaʼ| az|ada|ʼ t|dai|hin|nih|ikʼ|bik|o n|ił |hwi|aʼa| ji|bá |oʼ |hín|chí|áho| áh|zhn|ahg|h h|ł t|óót|hóó|tʼí|áʼa|zih|odo|ngo|ing|aaʼ|did|naʼ|ída| yá| ii|hó |i d|dii| nd|ind|odl|ʼoo|oln|í a|iji|ítʼ|tsí| ts|įʼ |tʼe|łtʼ|chį| si|hól|tsʼ|gha|áłc|łíg|n d|in |ach|ááł|háʼ|weʼ|hʼį|íłt|jíł|has| at|ida|ałd',
    'ami': ' a | ch|cha|ay |chi|li |ira|aw |i a| ir|ng |a c| sh|aay|nu |a k| nu|kng| ta|ha |ngl|raa|gli|law| tu| kn|mla|aml|tam|an |shi|ing|tu |hi | ma|y t| bi|ong| an|anu|eng|sha|n a|uch|han|hin|a a|chu|she|aka|a s|nuc| pa|u a|g a|u k|y a|ra |gch|ngc|cho|hiy|a p| u |yu |huy|och|kwo|hen|che|i i|a b|woc| kw|ish|ich|iyu|a t|uy | pi|in | ko| ak|hu |ka |ten|yan|ehu|u c|kon|ala|hon|a i|u t| fa|i t|u s|ma |wan|ni |u n|min|eli|heh|en |awa|uni|afa|hay|ang|yaw|ach|nch|uma| ku|mae|ho |u p|ah |apa|ali|lin|ili| ni|w a|wa |shu|emi|aem|a m|u i|n n|hua|w i| ha|a h|a n|a f|map|his|paw|nia|ngs|i n|anc|w c|ate|har| li|hun|pin|u m|na |iah|i k|fan|n i|a w|gsh|ash|ua |rat|ara|nya|ana|o a|pak|kay|fal|aya|iir|bii|ak |uli|u f|kun| ka|a l|kaf|he |i u|pya| we|gte|ngt|aan|maa|yi |e a|ych|rum|haw|ye |g n|w m| ho|osh|n t|ku |tin|bic|un |i p|aru|mak|lal|i s|h a|ayc| ru| aw|u h|ima|hel| wa|ina|lum|u l|nsh|y k|hal|wch|awc|ael|hae|mal|iny|fel|afe|paf|tun|ngw|whu|awh|y i|ngf|mas|ema|lem|ale| la| to|bia| fu|e n|any|a u| ic|pil|u u|ru |y m|pan|ipa|lic|nyi|ifa|ton|am |n b|ama|g t|nul|g c|w k|n c| ti|ush|al |swa| sw|y c|g i|kos|w p|ngh|par| ac|wen|twa|w t|pay|tya| ty|fah|faf|ful|ihu|kil| ki|kan|nga|lak|y s|iay|ngk|w s|wu | yi|h t',
    'lot': 'o a|iko| ik|ng |de |ko |hod|ode| ho|to |i a| to| ob|o e|ri |ang|ti |nyi|e h|i i|i o|o i|e i|re | ah|ni | on|bo |won|ati|aat|aho|any|ani|man|yo |owo| ow|ere|ya |n o|ana|wo |yi |yya|ier|eng|ben|obe| ab|oni|jyo|hun| hu| el|ngi|dan| da| aa|obo|ari| jy| bw|o o|ve |bwo| ve|i d|na |lo |nya|un | ne|o n|o v|han|on | an|ita| ih|ulu|iji|tul|ony|ama|mij|g o| am|awa|a o|si |an | it|hon|ung|lun|lul|ji |a a|abo|a i|ong|ulo|nie|emi|g a|i h|iti| or|isi|aba|io |osi|e a|a b|iyy|no |ik |i t| ad|ara|hos| aw| ar|iny|atu|kuy| ku| at|ori|bab| in|e o|uyy|elu|yit|ta |elo|rri|e e|ono|ma |gan|i e|ami| em|wan| et|gi |g i|iam| wa|nga|au |adi|yyi|waa|ngo|o t|aha|gia|oi |rem|di |a e|ra |a t|ian| is|k i|eyy| mi|ore|yan|it |fau|iri|ema|a h|ihi|ak |ida|igi|iha|uma|ing|hi | im|egi|rre|uni| ir|mik|i j|abi|koi| ma|iho|wah| eg|mir|i b|eti|uk |ek |gid|orr|o h|rum|n a|umi|bis|n i|aga|bia|tan|sih|k a|imi|nit|wa | ek| om|ihw|k h|ie |da |otu|rij|err|yiy|jin|oti|k t|uba|ner|uri| iy|uno| ey|a j| ok|jan|ija|gem|kum|mis| fa| eh|um |oji| al|bwa|o j| lo|i l|tek|ata| ha|g m|n h|irr|ria|ilo|ia |dur|yau|obi|ai |tik|kik|oki|sie|i f|eko|eha|moj|i k|rwo|ubw|bub|muk|omu|k o|hwo|wat|lot|g t| er|nan| ig|iru|g w| lu|tar|uho|nar|yim|adu|mio',
    'cak': ' ri|ri | ch| ru| ju|jun|a r| wi|chi|an |un |i r| ta|chu|ch |el |win|n r|qa |huq| ni|l r|b a|hi |uqa|ik |äq |näq| ki|ruw|inä|b ä|k a| k |n j|i k|en |ta |tzi|q a|ij | pa|j r|noj| ma|in | al|pa |jel|taq|ach| xa|oje|i n|aq | re| xt|len|ono|man|äl |xa |n w|aj |ïk |ib | nu|uk |wi |a c|al | äl| at| ul|uch|ina|ule| oj|aqi|i w|re | ro| a |naq|h u|a x|n c| an|tz |k o|q r|wac|iki|uwa|ruk| ti|ew |lew|i t|l c|aji|ich| ko|ama|xti|a k|n k|qi |äch|uq |il |nik|ub |ab |äj |wäc|zij| tz|ron|k r|sam|l t|l w|oji|ala|maj|j c| q |i c|tik| as|än |ütz| üt|ob |utz|a t|sle|asl| aj|i x|ruc|kon|k i|h r|n t|iq |e r| o |k u|rut|una|rik|nel| än|j t|uwä|l n|itz|hin|laj|h o| in| sa|i m|nïk|j k|kik|ya |ke |ima|l k| b |l j|isa|nim|jin|q i|nir|raj|ira| ra|pan|ajo|läj|cha|nan| ka|zil| ut|o c|kit|ijo|uwi|hïk|chï|uj |ric|ine|ïl |kir|ruq|a j|ike|hik|iri|k c|n x| ij|b e|onï|to |z n|nib|xtu|tb |atb|ma |i a|h a|haj|ale|qal|jqa|ejq|kan|ja |zin|atz|ilä|q k|k n|rej|j p|q c|aqa| na|k w|xik| wu|ris|upa|hup|n p|j j|rij|n n|ak |q t|nub|i q|tij|oj |na |äx |tiq|w r|wuj|jo |jib|kic|i j|jon|tzo|ire| ja|uto|lan|ito|iya|n m|on |cho|jij|ani|rub|oma| et| ey|a b|mab|jir|jle| ac|ikï|rel|zob|q n| wa|mak|kïl|a o|q w|a m|q x| x |u x| u |e j| am',
    'tzh': 'ik |tik| ya| te|te |ya |ta |k t| ta|a s|ike|l t|eti|me |ch´|ich|il |el |nik|a j|uk | ma| ay|al | me|k y|cho|e s|a y|ay |e y|ini|´un|e b|luk| sp| ja|ech|rec|ere|ke |u´u|rer|win| wi| sk| be|k s|k´a|a x|an |sil|e m|´an|elu|isi|pis|bel| so|oti|un |ok |sok|ket|sk´|k a|nti|ant|lum| yu|spi|e a|ho |yu´| o |ja´|a´ | ji|l w| yi|e t|ak´|ch |jic|k j| st|a m|n t|l y|mal|k´o|y s|e j|ali|o y|yic|sre| sr| k´|lti|t´e|a t| jk|´el|at´|cha|ma |lil|nal|uma|ul | ni|nta|n y|pas|sta| re|jun|l s|ach| sl|´op| tu|´in|lik|ile| le| x |h´ |yan|n j| ba|k o| ju|k´i|jk´|ix |xch|let|xu´| xu| lu|lal| pa|hap|jch|o t|tul| ch|a k|le |yal|wal|jwa|ajw| xc|kux|alt|nop|nix| aj|lel|ent|wen|ale|jal| mu| bi| yo|une|tak| jp|h´a|k m|slu|ala|swe| sw|lan|ani|aja|paj|muk|ame|bil|k´u|ati|´a |ina|tay|a b|bot|´ y| at| su|spa|u´ |oik|uk´| xk|´il|sti|h y|lek|yik|ika|ax |jel|ot´| ko|hoi|ume|k l|ban|h´u| jc|yot|k x|l j| sn|chu|mac|yuk|ayu|l a|y r|yak|´ n|e x|la |aye|´ul|e l|ot |x a| sm|nax|una|n s|t´a|yel|xku|met| to|t´i|it´|bit|ti |o m|eme|tem|op |h´i| ts|ne |ast|x y|´ m|eli|aik|y m|x j|yat|l l| ku|mul|nel|sun|ula|ele| xa|int| jt|unt|l k|tsa| al|k k|sno|ka |huk|may|e r|tes|bai|in |ja |ek |a n|aa | la|lta|kol|to | in|mam|eye|nte|´ s|xin',
    'tzo': 'ta | ta|el |ik | sk| i | st|a s|tik|e s| oy|ech|un |ol |k’u|l t| k’|uk |u’u| mu|sta|al |te |’un|ent|oy | sp|cho|rec|ere|der|sk’|yu’| yu| o |sko|ane|il |spa|ke | ya|l s|eti|tol|oto|kot|pas| ju|i s|k’a|nel|as |’ch|ho |k s|jel|o s|e o|le |’an|mu’|l i|n s|jun| le|’ux|’k’|sde|ch |nte| ke| sd| de|ele| va|’u |nik|a’k| te|k t|gen| ge|a j|ch’|yan|l y| xa| ch| si|an |e m|l g| je|l k|k o|lel|’el|ale|i’c|a k|in |nta|h’u| ja|u s|a y|s s|y s| vi|k’e|k m|cha|xa |l o|ven|a t| bu|lek|k y|ela|sch|vin| s | sc| ko|ne |jec|va |n k|i t|bil| sv| sl|lum|tae|me |chu|muk|a o|chi|sve|k i|bal|ini|l v|oje| se|tel|mte|amt| me|’uk|une|tal|aje|net|s o|k’o|si’| sm|sba|a m|aci|y y|uxi|ike|lal| sn|ael|aik| ts| sb|y t|yuk|o k|k’i|lta|kol|l l|o t|lik|lan| el|u’c|e i|ij |tsa|ja’|toj|sto|mal|stu|’in|uni|ion|kux|i k|ant|e l|eel|bee|jol|ojo|bu |tun|tak|hi |xch|ak’|one|cio| li|s t|a v|noj|ano|xa’|tso|ine|a b|u’k|oj |o y|e t|es | na|ju |ux |mil| a’|han|a’b|j i|olt|tai|n t|l n|k k|uxc|lti|ail|sin| al|tad|lib|kil|umi|alu|uma|bai|l j|ek |va’|a l| no|seg|j s| lu|nal|hu’|aj |baj|l m|oyu|s a|a p|alt|oó |noó|ibe|n j|ila|eki|x e|hoe|’ol|kta|iel|mul|ej |ban|i j|ar | pa|e j|nxa|anx| yi|euk|jeu|maj|a c|kxa|ikx|iti|t’u|rta|ert|ber|u v',
    'lns': 'dzə| dz| ki| a | wù|zə̀| fó| vi| e | gh|̀m |ìr |ə̀m| ké|ùn |wùn|ay |gha|wìr|ér |kér| wì| à |n à|fó |hay|r d| ke|wun| fo|fo |e k|ìn |o w|m k|r g|réŋ| á |un | wu| ye| ns|ə̀ |óo | kì|n w| sh|fóo|ví |ó a| ve|kin|e w|ə́ |y f|a d|ə̀n|a k|n k|kìn|wù |òŋ |kfə| wo| kf| rə| mo|vit|iny|̀n |zə |zəə|í v|ír |wír| wí|éŋ |ŋ w|ke |ve |wòŋ| wò| é |ee |in |mo |er |n s|í w|r f|tì |ji | ji|ər |sər|nsə|n f|ita|m w| ré|ker|o k|r w|ín |yò’| yò|se | se|kit|a’ | là|ne |áví|aáv|taá| yi|ŋré|éŋr| wi|tat|nsa| li|n a|’ k| ny|là |tí |yo |nyo|an |r k|i w|áa |wáa| wá| ví|à v|y w|r v|ò’ |itu|əə̀|é w|á w|sí |sa’|və́|vin|ye |eé |ì k|r y|nta| sí|èn | və|iì |atì|int|e v|sho|tu |à k|n e|éy |han|rə́|im | lì| ta|á’ |o s|a y|ù k|oo |o’ |wo |èr | bó| ko|n é|e n|əə |lim|lìm|’ a|e d|yee|mé | kù|e s| sá|fə́|yiì|i k| sé|y a| fè|é k|en |o d|u k|bó |e y|e g|a s| kí|e l|m y|m v|ìm |fə̀|o y|ŋ k|m s|’ə̀|ə̀’|mó’| sa|y k|íy |sá’|à f|m r|’éy|iy |vij| wà|say|e á|á k|e m|n v|’ y|n á| yì|e f|uŋ |n n|à’ |o n|n d|a l|ə e|í f|ó w|si | si|itú|́ə |ə́ə| bi|ùm |nya|à n|yin|rə̀|’ w|r m|ŋ f|ir | yé|yí |wiy|sé | tá|ií |y e|o v|’ f|ŋ m|kil|y r|woŋ|juŋ| tà|ki |kiŋ|əə́|úm |túm|í k|ə s|kùm| kw|wir|́ w|y s|áŋ |átí|tát| ku|vee|ŋ v|àa |wàa|koŋ|oŋ |mvə| mv',
    'ton': 'nga| e | fa|aka| ‘a|fak| ‘o|ha |‘a | pe|i ‘|a ‘|e t| to|i h|oto|a e| ‘i|ai |e n| ke| ta|ga |u ‘|ke | ng|ata|a k|ku |‘ok|pe |oku| ko|onu|kot|e k|e f| mo| ha|‘i |o e|e ‘|aha|ang|ki |ton|a p|hi |ne |mo |tot|nu |he |ahi|au |gaa|a f| ‘e|tah| ma|’i |tau| ai| he|aah|ko |oko|i k|‘o |oa |a m|ung|i f|o ‘|tok|i a|ua |ea |mal|u k|toa| fo| ki|a t|o f|e m|no | ne|i p|pea|a n|ota|u’a|kai| ho|i t|e’a| ka|kal|ia |na |u t|i m|au’|kau|ama|aki|ika|ina|tai|ono|’an|ain|’at|hon|‘e |a’a|pul|e p|e l|aue|gau|a’e|o h|ili| tu|ala|‘en|ule|‘ik|ni |u m|u f|ei |a’u|fon|ta’|ene|tu’|gat|ue |le’|nua| la| pu|kat| fe|a’i| me|u’u|li |ali|’u |ao |ui |ehe|alu|atu|ing|kam|’un|o t|kaf|u’i|tan|ong|ako|fil|e h|ngo|o k|tui|tat|ana|’a |ma’|lao|le |kak|fai| ni|nau|fou|u p|fua| ia|ale|ka’|kah| ku| na|ofu|oun|uhi| fi|tu |mei|efi|a h|keh|fa’|hin|na’|ta | ak|e a|ele|lot|alo|lu’|gof|o m|sia|otu|ie |ulu|itu|o’i|i’i|’ak|mo’|u a|vah|sos|tak|kuo|lie|lau|oni|aut|lel| ‘u|lo | te|man|olo|kas|afa|la |aum|ohi|tam|kan|u n|mai|aan|lun|‘ul|aau|ngi|han|o’u|ava|mak|ka |afo| le|e’i| hi|uo |si |kon|’e |fan|ha’|lei|ti |to |a a|’uh|e’u|’ef|lak|o n|ino|mi |’ui|’ap|o p|’ah|ofo|uma|nis|‘ak| lo|hok|aho|vei|o’o|kae|hia|ilo|to’|ito|efa|u h|ahe| va|ial|osi',
    'tbz': 'kɛ | kɛ|ti |aa | a |ɛ ɖ|o n|nkɛ|mɛ |ɛ k| ɖi| nk|ɛ n|ɖo | ɖo|yi |i ɖ|iti|tɛ |nɛ | yi|ɛ b| ba|i k| mɛ| ti|a k| bo|mu |ba |nit|bo |bɛ |i b|ri |oni|ɛ m|u k| bɛ|ɛ t| we| on|ku |a ɖ| na| nɖ|yɛɛ|i m| ɖɛ|ɛɛ |a b|a w|ɛ y|ɛ a|a n|we | ka|o k|ɔu | ku| ɖa|nnɛ|ɛ o|i t|oo |kaa| o |ɔũ |mɔũ|omɔ|u o| ɖɔ|ni |nni|mmɛ|ii |i o| om| mu| ny|nti|mmu|na |oti|kó |a y|nku| nɛ|ɔkɛ| yɛ|i n|ɖaa|ɖɛ |ɛi | ŋa|i y|o ɖ|tin| kp| yo|naa|ɖi |rɛ |u n|i a|ɔbɛ|tɔu|ɛɛ̃| kó|e a| kɔ| ko|ɛ̃ |yɛ̃|otɔ|a m|ntɛ|u y|yoo|kɔɔ|bot| mb|ari| ot| ma|ɖɔ |kɛy|kɛn|ɔ̃m|nyi|hɛi|ɛ̃n|ee | tú|tɔ̃|amu|maa|myɛ|ɔ̃ |e k| nt|ent|ati|ɛkɛ|ɛ ŋ|ɖa | tɛ|ɔ k|tú |u m| nn|ũ y|enk|ɔri|ŋa |baa|ɖii|imɔ|̃mm|wɛ̃|nɖa| cɛ|ɛmm|ɛyɛ| mɔ|utɔ|ɖak|mut|ɔɔr|nɖɔ| my| ya|mɔu|kɛp|tib|ɖik|eti|enn|ten|ɛ̃t|kpɛ|itɛ| ŋo|a t|wee|a a|a o| sɔ|o o|yɛm|tri|bɛɛ|̃tɛ|e n|kɛk|̃kɛ|ɛ̃k|pat|ihɛ|nyɛ|ɛɛk|ɛ c|kpe|̃nt|ɔ̃n|koo|rim|cyɛ|o b|ant|ɔnn|omm|cɛ̃|ɖit|kot|ko |mbɛ|tɔb|o m|ɛ f|aat|kpa|ɛ i|ute|kut|a ŋ|bɔk|kɛt|ou |ɖɛɛ|̃nk|ann| ni|byɛ| ŋm| nf|i c|tik|aku| mm|a c|oku|u ɖ|yie| tɔ|kɛm|mɔk|o y|akɔ|nɖo|pɛt|kɛb|bi |ɛtɛ|two|nte|ɖɔu|o a|ɔ m|ipa|ɖip|ó ɖ|inn| ns|aar|kɔb|pĩ |aan|o t|ɛbi|tim|uu |iko|ɛpa|ɖɔɔ|kɛɖ|fɔ̃| by|ikɛ|ɛ w|ĩnk|yĩn|iit|uku|nfɛ|u b|u t|pok|ua |i s|uɔ |wuɔ|kwu|atr|pɛi|mɛs|ɛtɔ|kɛw|ibi|ye ',
    'lad': ' de|de |os |ion|sio| la|on | i |el |asi|la |ere|o d|ien|ent|es |en |ra |der| el|ech| a |cho|rec|as | ko|a l| ka|a p|ene|ona| en|na |ho |al |da |e d|tie| su|nte| ti|ers|per| pe|ad |do | se|ada|o a|to |kon|rso|son|s d| es|e l|e e|e s| un|est|ida|s i| pa| pr|ne |a t|kad|te | o |dad|n d|a s|par|no | po| li|ar | re|a d|n e|men|tad|ado|era|ara|s k|sta| di|nas| lo|er |ser|su |a e|a k|sia|o e|los| in|nto| so|n k| to|nal|pro|les|ual|lib|ke |res|a a| ke|l d|s p|dos|nes|o i|mie|gun|por|nsi|ens|s e|las|ami|ter|tra|imi|ika|or |rta|kom|ale| na|l k|isi|sos|una|ras|din|e k|o p|ali|un |a u|e a|o k|osi|ngu|ing|ert|uno|tod|kas|ido|del| ku|o s|n p|ber|ibe|ia |igu|n l| ak|one|d d|i l|s o|n i|i d| dj|dra|ame|ksi| le|art|io | no|hos|gua|s n|man|s l|uni|e p|dju|a i|ten|lid|ura|das|i a|eks|ta |kla|des|e r| ig|sen| ma| me|nta|kav|ote|rot|avo|l e|ran|ome|end|se |dis|ndi|kua|ial|n o| si|ade| ot|tar|an |odo|vor| fa|zar| mo|akt|ste|iko| as|l i|ria|r a|odr|pod|avz|ntr|ont|s t|tos|us |sus|s s|lav|u p|int|ond|a o|ka |o l|otr|bre|ora|kto|tis|nid|r l|zo |eme|tek|ey |ley|ant|s f|i e|e i| ni|vid|tid|min|n t| al|o t|aza|nde|o o|r s|n s|tro|rse|ars|nos|duk|dez|r e|ral| ed|lo |ro |r p|pri|oza|ias|vle|r d|pre|ari|rar| ar',
    'mto': ' ja|ats|e’e|jat|ts |’e |üt |yak| ya| ts|jay|at |pën|di | di|ayu|ün | jä|ve’| ve| pë|yu |a’a|jä |t j|vin| vi|ën |tsy|se’|tse|e j| jy|tuk| ka|a j|n j|ida| ty|nts|ëjk| tu|kid|uki|tso|nüt|uk |akj| ky|önü|int|va’|ava| jö|ka’| uk|s j|a t|t p|n v|aak|n t| ny|’a |kin|akt|jöm|inm|ma |t v|jya| pa|ööj|yöö|daa|u’ |uu’|juu| ju| tö|öma|utö|t t|jüt|jty|öjt| pu|k p|yaa|oy |tyk|in |’em|jü |nya|’oy|o’o|u j|nma|ë’ë| ti|yuk|tyu|p t|tön|kat|e t|so |nün|’nü|pav| na|ëët| oy|y j| më|kjü|ax | ax|i v|pün|s y|yo’|üp |jyö|ö’n|x j|a v|yjü|syj|s d|’ak|k j|kut|vii|kün|ëna|a’n|t n|ët |ip |jts|u d|yat| ni|yka|pu |yë |’n |jup| ku|mat|s k|utë|töö|any| py|t k|tö’|kya|pe’|öjk| y’|aky|i t|na |’an| yë|jüp|mëë|työ|i y|jö’|dë | dë|up |ü j|it |’ix|e y|p j|ö’k|ji |nü |töj|yin|vyi| vy|tëj|em |dü | dü|dat|yëë|ktu|ja |akp|ajp|ä p|jki|da’|yay|u y|y t|kku|nk |ii |tii|n p|küt| ix|nax|n d|va |kju|ixp|ä’ä|tsj|n y|n k|ayo|xüt|jpü|put|’yi|tsë|nyi|akv|kää|akä|kja|jkü|akk|ijn|iij|ä v|aan|jk | my|ä j|aty|xa |önk|öön|’ä |’ t|xpë|yip|kmu|kaj|s p|yüt|o’y|oki|ä t|akm|ëka|tëk|mp |tsü|i a|i j|yji|ëyj|’ëy|kë’|kyu|ak’|tsö|p p|ü v|y’i|o j|yëj| të|i p|m a|um |vä’| vä|yav|yam|ëjx|këj|pëj|da | o’|ü k|ajt|mut|u n|maj|yoo|e d|kpa|pay|tok|ink|m t|ap ',
    'ast': 'es | de|os | y |de |la | a | la|ien|en |rec|ent|ech|a l|na | so|dre| dr| pe|a p|e l|n d|ón |ona|hu |chu| to|per|les|u a|al |ión|aci|tie| es|que|nte| co| qu|a d| ll| ti|ció|ers| d |son|rso|se | se|ue |u d| na|a s|los|a t|el |s d| en| pr|ion| o |oa |toa| lo|ar |er |res|cio|men|cia|con|tu |te |nes|so |dá |ale|s y|lli|e y| in|un |ici|tra| re|est|ia |lib|s n| un|nci|nac|pro|y a|a a|ra | ne|e s|ual|one|nal| po|a e|iu |del|rá |mie|una|end| pa|nun| nu|s a|s t|ase|s p|esc|á d|e n|e c|ber|enc|idá| le|ntr| el|da |ter|ica|ami|ert| di|ere|ame|ese|dic|ndi| cu|ibe|col|a c|s e|des| ca| ma|ali|ene|u y|a n| al|nde|a u|a q| xu| fa|n s|e p|l d|oci|soc|ier|qui|ntu|n e|aes|s o|cie|r d|a m|y p|man|s s|nta| ac|sco|n t|y e|tá |ome|tiv|ial| me|u n|com|n c|l y|esp|ies|d a|ten|ont|a y|sos|ide|vid|era|ond|squ|esq|n p|in |eme|hos|cho|bre|ser|tar| as|pre|re |s q|imi|s l| l |u t|lle|n a|e d|drá|eli|nen|rem|ens|cla|sta|e t|s c|y l|y d|gua|n l|cas|sen|bli|ari|tri|su |dis|lid|ada|tos|l e|aid|nai|egu| vi|die|ind|mes|nda|pen|tor|uie|cua|ca |rac|ta |otr| ot|igu| ig|ibr|olo|tol|edá|isf|ru |o r|l s|nel|l t|r a|rar| fu|efe|rim|ote|rot|u e|ant|ele| tr|o p|rtá|a v|r l|met|u o|áu |cu |ori|o d|tic|str|sin|za |or |ola|ral|u l',
    'tsz': 'kua|ni |ka |ua |arh| ja|rhi|a j|eku|uar|ani| ka|aku|aka| ju|a i|a k|cha|i j|mbe|urh|imb|jur|iku|ti |ech|ats| k |iam|tsi| ui|k u| ia|him| ma|ri |sï |iri|jat|era|eri|u j|i k|rip|uir|rhe|i i|sti|i e|ngu|ipu|u k|bek|eng|nga| am| ji|men|rhu|amb|end| ua| en|ini|ma | ku|ang| im|aak|ndu|ame|amu| es|ist|uec|du | ir|uak|ga |ata|esk|kue|ati|rak|and|sis|hu |ire| no| o |ki |ku |gua|mbo|a e|pu |no |i n|che|a u|a n|uan|per|ksï|aŋa|ha |i m|ajp|be |han|jpe|sku|hek|kun| an|jku|jim|nch|eni|i u|jan| is|i a|ajk|a m|uku| na|nda|pue|u i|sik|man|hik|ime|ŋan|a t|ski|aua|uni|jas| ue|uaj|ura|ima|her|esi|ses| se|tak|a a|ta |nts|ŋaa|tu |i o|ndi|uat|mer| ni|hak|o i|o n| ts|uer|par|aec|mu |eka|eta|bo |ant|ter|isï|iks|uae|ret|a s|tsk|iŋa|nta|kat|ana|ama|tan|asï|si |ing| in|anc|eŋa|u a|muk|ram|kur|na |rat| er|so |jin|maj|ari|nia|pek|hit|hin|apu|ru |ate|ran|ska|tik|mbi|rin|est|mar| te|u e|int|iat|ast|jtu|tsï| ne|jau|tin|ung|nap|eru|bik|tse|iti|ŋas|rha|ngi|apa|emb|uek|oŋa|tar| i |upi|jup|o a|a o|i t|ara|oni|gon|ngo|hes|oka|uch|taa|ema|nem|i p|ï j|aat| pa| ch|dan|u u| ar|aks|sta|ete| ta|ijk|nde|rek| mi|ets|uta|jaŋ|meŋ|pen|e j|eua|ind|o j|uen|reŋ|uej|sek|ï a|sïn|raa|boŋ|taj|gi |eia|ita|hen|ask|mbu|tem|uŋa|kuk|api|sïj',
    'swb': 'na | ya| ha|wa |a m|ya | na|a u| wa| mu|a h|ana|i y|shi|la |hak|ha |ki |a y|si |aki|a n|a z| zi|tru|utr|a s|i m|mut|ula|u a|a w| ma| sh|ru |har|mwa|hi | mw| za|ao |a i|ri |au |tso|a k|ari|he | ku|wan|ahe|ama| au|kul|ndr|tsi|i n|io |ma |afa|za |asi|awa|azi|ili|ni |its|mu |i z| an|ish| ka| un|ika|ka |kao|nu |iha|e n|o w|aka|i w|zi |i u|yah| it|naf|ats|end|ngi|a t|fas|ra |li | uk|i a|o y|a a| ud|sha| ut|aha|ada|usi|u h|o a|mus|ia | ul|ali|udj|i i| at|imu|ila| ts|ren|kin|uka| am|dja|hus|ots|ina|una|ara|iwa|ala|eng|vhu|ɓil|eo |ele|zin|we |dre|lio|jam|usu| ɓi|re |o h|u w|amu|e u|e h|ba |mba|u i|oka|sok|ing|dzi|zim|e m|wah|amb|wi |u u|i h|o u|adh|iki|sa |wo |saw|dam|o n|ahi| uv|tre|o k|ifa|o m|kan|me | in|dhw|upa|uts|avh|ini|a d|ang|ani|yot| yo|par|any|uru|dza|nad|omo|som|tsa|ɗe |ata|ung|yo | ki|muh|ume|e a|inu|law|ngu|e w|fan|kav|i k|aru|u y|rum|zih|laz|lwa|mo |hik|way|nga|u n|yum|nyu|iny| mb|itr|zit|o z| vh|hwi|and|eli|ahu|u m|uɓa|eke|uku|apa|nya|awo| sa|tse|haz|no |ye | ɗe| tr|uli|ja | uɓ| us|bel|mbe|ndz|muk|leo|ɓal| ur|ola|ind|ita|han|vha|mah|hih|udi|iri|dji|swa|da |are| uf|sen|iya| pi|aã |uvh| mi|sah|ush|him|hwa|aye|umu|ong|iwe|uzi|fad|uha|ria| is|rel|mae|a ɓ|u k|ke | ik| up|ash|di ',
    'cab': 'un | lu|i l|n l| la|an |ti | ha|ai |igi|ia |lun|gia|a l| li|dan|uti|ni |üri|rig|gür| yu| gü|bai| le|aun|gua|yut| ka|u l|agu|ri |ida|le | fu|hau|lan|ien|uru|n a|e l|uba|ara|n g|n h|aba|ügü|run|han|a g|i h|fur| su|i g|ra |sun|in |en |ari|ani|n s| lú|lua|gu |ira|air|uri|gun|gie| me|ei |iña| gi|lid|ban|rüg|uni|lig|ka |egu|ada|iñe| da|n f|arü|a y|aga|lag|du |ati|igu|siñ|aha|uma|ñe | ga|uar|hab| ab|udu|úru| an|hin|ua |awa|gü |mie|umi|rum|me |i a|rud| ti|gai| si|kai|au |lub|a m|las|n k|amu|uai|iru|lúr|ñei|tu |adá|ieg| tu|rag|iha|aü | ñe|ún |i s|giñ|gar|lib|i y|ihi|tid|nig|bu |n m|u t|uag|ága|bih|ibi|abu|ma |ain| ub|agü|a t| lí|lab|dun|ham|ña |bau|u u|n t|nha| lá| ta|lau|lum|mur|di |ha |rún|da |atu|sie|e a|ima|gim|a h| ma|anh|dei|i t|ugi|ubá|nda|adü| ad|mu | am| ba|adi|nba|ini|u h|ngu|bág|nde|wad|man|u i|war|gaw|i d|lar|su |a a|dau|n u|lad|agi|irú|üni|güd|asu|u s|mut|i f|ámu|dám|a k|ugu|düg|rid|i b|wai|uwa|ü l|n d|eri|gum| gu|ina|cha|e t|had| bu|ung|u g|abú| au|ní |and|wan|ran| úa|end|has|dag|gün|ama|san|iba|gir|hag|hai|ful|hig|chi|ích|u y|u a|nu |anu|ün | id| ua|und|i m|riñ| ar|mai|yer|úye|lúy|min|to | to|rad|ára| gá|idu|nra|úsi|i k|ibá|úar|n ú|ren|ure|ide| wa|na |si |isi|ais|aña|eru|ser',
    'krl': 'en |ize|da | da|evu|oig|gev|ige| oi|on |kan|ist|anz|sti|gah|ien|eh |el | ku|us | ri|n o|lli|liz|al |vus|nza|zal| jo|an |ris| on|zel|hiz|ahi| ka|l o|ika|tik|oga|ua |ttu|jog|uks| ol|itt|väl| vä|l r|all| li|lla|kse|ah |n p|tsi|es |miz|zen|oll| va| pe|per|loi|sie|zeh|izi|stu|bo |ibo|lib|ksi|in |ii |a k|n d| hä|val|oin| ta|äne| su|n v|vuk|äll|uad|n k| to|oli|h k|yht| yh|zie|hän| mu|oi |idä| pi| mi| om|rua|ami|nen|kud| ni|uol|tu |n t|ine|oiz|kon| tä|s o|a o|ai |ih |a v|sua|h d|aht|ei | ei| si|toi|lly|et |i s|is |tta|as |hte|kun|dua|teh|ust|ehe|voi|ne |pid|und|tun|iel|tah|ti |nda| ki|tua|olo|ell|la |il |mat|zes|ald|i k|ytt|se |udu|n m|eru|ats|vel|äy |oma|arv|unn|est|ast|iä |hto|rus|n s|puo|däy|ett|le |s j|a a| ra| ru| tu|nan|h o|lis|aze| pu|to |n l|sen| se|uo |i o|dä | pa|aha|tti|kai|utt|ott|tet|tam|sta|a p|end|s s|ual| so|ta |i t|äh |mie|s d|ulo|pas|opa|nna|tul|joi| lu|avo|uga|mug|s t|irj|kir|n e|sii|s k|äyt|aik|ty |tty|nik|ivo|ole|uma| al|mua| vo|ali|o t|zet|du |i v|y o|a h|aza|a t|oih|ehi|htu| op|tur| mo|i m|täv|pah|a r|isk|ako|izu|man|ike|att| ko|ala|nzu|hel|ste|ots|sot|moi|lii|usk| us|ata| ju|ttä|do |i d|ele|os |rvo| ar|taz|lin|sku|yzi|urv|die|uon|ado|han|daz|ill|ieh|edu|zak| za|lal',
    'zam': 'uan|kua| ku|an |n n|en |xa | xa| nd| na|ti | ye|ob |ndo|ak |dob| ch|a n|las|as |men|ho |cho| me| di| mb| pa|ar |nla|par| nl|iti|dit|ts |i m|gak| gu|na |es | nt| ga|b k|lu |n g|yet|ien|o k|ets|nak|mie|n k| o |kie| mi|ie |o c|mbe|s x|dib|iet|rie| ri| lu|bes|n l|gui| ti|ta |a m|ab |ba | nk|nta|et |s n|nki|yen|ol |idi|b y|a k|n m|ent|ib |tid|t m|i n|s p|r n|ui | ng|xga| xg|k k| ki|xen|bxe| bx| ka| ta|in |rti|ort| or|a g|gab|n x| la|yes|che|s y|a d|a y|u n|ap |kap|i k|s o|bol|mbo|s c|its| yu| li|nti| ba|iba|ndi|kin|s k|e k|k x|k p|is |nar|n y|b x|nto|jui| ju|o m|o n|i c|i x|e x|nt |ed |enl|hen|b m|uit|a o|a b|r k|u x|no |ino|a l|l k|s r|s t|n b|mbi|lis|a p|uin|k d|tsi|la | ro|a x|eti|t k|n t|tim|u g|ted|nlu|ue |rue|r d|ró |aró|gua|b t|nga|s d|uʼ |i t|ad |n d|iki|bik|ana|nda|k n|a j|n o|b n|i y|xi |ixi|dix|b c| nx|taʼ|sin| ts|s l|yuʼ|nte|y c|uy |yuy|ngo|i r|cru| cr|aʼ |s m|cua| cu|gol|e n|ual|l x|ux |gux|ey |lad|e m|b p|k m|s b|k c|ngu|he |tl |utl|xut| xu|ʼ t|iit|ula|mi |imi|e t|mí |o r|ó k|u r|i b|b g|lin|k y|s g|b o|nag|x k|i o|bki|mbk|r g|od |b l|ai |r m|pa |p k|d n|ala|ou |tou| ñu|e y|o y|l y|o g|us |gus|a r|k r|d x|ied|die|a t|n c|ix |bix| bi|guu|yii|ayi|nay|oul|xou|nxo|t x|tob|o o',
    'top': 'an |akg|lak|ata|aka|ama|ala| na| ka| ix|ni |kan|ini| la|a t| ta|mak|la |n n|tla|chu|in |ch |tam|kat|kga| ni|ta | ch| ak|lan|h i|lat|kam| tl|ixk|awa|wak|nin|tal| wa|a n|ka |xku|uwi|kg |xla|alh|kuw|min|win|hu |ach|kch|akc| xl|ak |wan|n t|tu |ma |nak|n k|pal|ani|ami|nit|ika| tu|na |ali| pa|nac|i k|ask| ma|pul|tum|it | li|nka|kak|n l|nat|una|man|k i|hun|ti |ank|n c|ula|i n|kgs|a l|akx|kal|g l|p a|ap |i t|ila|nan|tak|sin| ti|gsi|tat|nil|um |lh |ilh|u n| pu|tun|a a|a k|u t|xta|apa|i l|nik|map|ima|atu|nal|n w|ema|nem| ne|a w|h a|gal|ina|tap|aya| at|u k|ixt|atl|wa |law|lim|a m|hka|lhk| xa|k a|uwa| al|at |kgt| in|ana|a x|lht|nu |okg|mat|n x|utu|lhi| am|u l|ku |apu|a p|xtu| an|gta|kas|wal|xni|tay|sk |a c|t a|taw|lit|kxn|ixl|ats|hi |hta|kuj|sku|unu|mal|n i|p u|i i|tsi|axt|lik|ixp|akn|sta|puw|un | ut|gch|kgc|glh|kgl|tas|i a|xpu|n p|aks|kgo|n a|kxt|i p|g a|t n|lip|kla|akl|mas|kil|u p|itu|u x|ast|kap|t t|i x|kgk|paw|tan|aku|uka|a i|si |i c|liw|iti|ga |yaw|gax|gan|k p|n m|kni|pas|umi|cha|iwa|uni| un|lha|gam|yak|tik|tac|iku|chi|i m|xli|uju|nam| mi|t w|put|xal|lam|lal| e |e e|je | je|tka|max|lin|t x|wit|tok|ati|ipa|ekg|ita|gka|gat|hin|gap|e t| ki|li |m n|m k|ya |atk|xan|axa| ap|xto|wek|u a|huw|lhu',
    'cha': 'na |an | i | na| ma| pa| de| ya|yan|ion|on | si|sio|man|ra |ha |cho|ho |par|ina|ara| gi|ere|iha|o n|der|ech|rec|n i|ai |i d|do |asi|gi |sih|a i|o p|a u|ent|n g|gai|al | ni| to|odo|tod|ad |o m| in|ona|a n| ga|men| li|ao |i p|at |pat|a m|a t|a y|a s|ni |dad|a p|nal|nas| gu|i m|a g|ida|ibe|ana| ta|nte|o s|sin| nu|o y|rta|ert|ber|lib| ka|ui |tad| co|o g|n p| un|ine|ame|n n|te | es|uma| pr|est|cia|o t|nen|i t|l n|n s|a d|be |n m|nta|i l|nui|en |i i|ya |to | re|mas|ebe|deb|ia |tao|ot | um| so| po|sa |as |so |a a|et | ti|gui|tan|pro|lo | fa|i k|res|ksi|per|oci|soc|gin|ase| ha|o i|un |tra|are|i s| pe|ano|i f|sta|asa|e n|i u|no |con|go |afa|pot|ang|a e|ter|nto|com|i c|sti|ro |ntr|e u|de |e d|n d| di|co |ari|i e|uet| la|isa|min|i a|io |rio|tay| se| as|nih|ala|tin| uf|nsi|a h|fan|usa|ico|ale|n y|kue|tku|uat|tek|lai|kas|e g|a l|ti |ers|i g|aya|ade|ini|gua|a k|ali|n e|tro|ont|ufa|duc|emp|ma |bli|aba|tal|atk|kua|n k|eks|ote|rot|ado|ant|gur|nam|t p|int|nda|s n|ial| ku|nga|fa |haf|ras|n l|otr| ot|ati|nci|nid|eho|reh|cas|uca|edu| ed|dna|adn|ral|fam|agu|sao|po |e y|d n|es |bal|kab|nan|des|ome|ten|nna|ena|ens|son|rso|t i|mo |eha|seh|in |ste|alo| ch|n c|era| us|n a|i n|ura|da |aha|ora|n f|lid|les|ta ',
    'crs': 'an |ann|on |ou |en |yon|syo|n d|te | an|n l|nn |wa | la|son|gan| ga| so|nny|rwa|n p|ny | di|drw| dr| en| ko| po|nna|asy|tou| to|n s| le|yen| de|pou|nan|n a|un |oun|mou|imo|dim|er |kon| sa| ba| ki|dan|bye|ban|et |n k| ek| ob| e | da|man| pe|oby|ek |n e|al |ki | li|ite| pa|ot |u d|dev| lo| pr|n o|onn|pa |ans|i p| re|ali|per|si |ret|enn|zot|lib|e d|n g|lit|nas|a d| no|e s| i |e l|ik |sa |e k|ter|nou| ma| zo|osi| os|vre|ns | na|anm|fan|ant|nte|evr|ler|san|pro|a e|ken|rte|lal|i a|az |ksy|oke| ok|e p| ka|ert|n b|ote|tra|nal|n t|re |k l|e e|ber|ibe|n n|rav|e o|kas| fa| tr|ers|osy|sos|ni |el |edi|ika|n z|y a| me|met|ava|rso| se|ont|ran|dik|fer|ona|ras|ave|ir | ne|ese|ab |e a|nm |lwa|i k|onm|rit|ei |pei|t g|sya|lar|r l|ezo|men|led|se |li |par|alw|a s|n f|i g|nma|lav|t l|ar |a p|ent|i e|ete|ver|u b|ay |vay|mar|a g|ser|i l|nt |eks|ak |res|l e|nda|kot|i s|ti |in |rel|are|l k|ara|y p|apa|zan|ib |n m|ary|pre|y e| in|r e|lik|i t|ini|ond|rot|imi|van|kri|i d|avi|a k|ort|n i|a t| fe|is |yal| ni|kla|sak|ern| av|azi| fo|nne|n r|s e|y s|ere|i n|k p|bli|ons|tis|tan|a a|tek|wen| be|min|rim|aso|for|t d|rme|erm|e t|y t|a l|k d|eta|let|r i| si|ati|lop|zyo|izy|dis|ín |iín|de |pri|lez|zir|nen|zon|rez|asi|a n',
    'ddn': 'na |ma | a |nna|a n| ka|ka | ba|a a|a b| n | ma| nn|ama|om |yom|ni | bɔ|a k| da|i k| go|daa|a d| ku|aam|gon|a m|i n|nɛ |a s| hi|ɛi |iya|rɔ |ɔrɔ|mɛi|ara| sa|bɔr|a g|aa |a h| ga|inɛ| za|fɔ |ayo|onn|ya |ra | bi|ani|iyo|ɔŋɔ|bɔŋ|bam|kul| fɔ|nɔ |yo |amɛ| di|ri |ini|ei | nɔ|a t|lu |ulu|waa| kw|ii | si|ari|una|ŋɔ |hin|bin| na|si |sɛ |a c|riy|ɔ n|kun|ba | sɛ|wei|aar|i b|i g|ga |ɛ a| ta|kwa|ɛ b|i s|a f| ci|ɔ b|n m|tɛ |ɔu | ya| du|sar|u b|m d|u g|ɔ k|sii|iri|u n|ɛrɛ|i d|gwe|a z|u k| su|ŋa | tɛ|m n|bu | de|niy| gw|bar|asi|taa|di |ono|su |ɔ s| mɛ| cɛ|rɛ |ali|no |n s|ɔ f|uyo|ɛ n|ima|i h|baa|abu|hɛi| hɛ|o z|zam| ŋw| ti|i t|aab|ko |li |aal|man|ɔ g|ɛiy|las|n b|oo |nni|ila|til| ɔu| ko|a y|o d|o b|ɛ g|gan|ci |sɔu|isɔ|fis| fi| be|aŋa|ɔ m|him|yan|cɛr| mɔ|cou| co|eri|eer|maa|o k|saa| ji| se|ɛ d|i m|u a|ee |dee|wɔ | wɔ|mi |imi|zaŋ|am |asa| la|ɔ d|a w|uur|zaa|yaa|ana|u s|nan|ŋu |ann|ɛtɛ|e b|m b|dim|ɛɛ |eiy|bei|aka|n g|ɛnɛ|ŋwɛ|oyo|o g|uri|duu|u h|a ŋ| al|enn|sen|ɛ h|a j|du |i c|kaa|uma|rum|ɛru|ala|yay| bɛ|ɔɔr|nay|dii| ha|i a|i f|ɔɔ |ɛ k|i y|laa|ɛ f|tɛr|cin|dam|gu | ad|la |ouy|ɛ m|aas|wɛn|inn|ada| ni|aay|loo| lo|ant|ina| fe|ti |aat|je |ije|iij|hii|ta |ŋwa|o n|n k| nu|i z|m k|isi|jis|wɛ |i ɔ|osi|oos|goo|u c',
    'loz': 'a k| ku|na |ku |wa | ka|a m|a n|ni | ba|ya | mu| ya| ni|lo |la |swa|ba |o y| na|wan|i k|elo|a b| ha|u k|ane|tu | sw|nel|li |ka |i s|ona|ela| li|a l|utu|u n|mut| si|a y|ha |a s| ko|za |ng | i |ana|mwa| mw| u |i m|a h|aha|pa | ye|apa|kap|kon|sa | ma| tu|a u| mi|nah|fel|ufe|auf|kau|ta |ula|a t|ang|u b|man|ele|ye |pil|mul|kwa|lel|mi |a z|o k|i b|ae |hae| kw|mel|ili| za|kul|g i|u s|e k|isw| a | sa|ina| bu| wa|eza|lat|to |u f|ala|wi |zo | ze|o z|ata|e m|a f|ila|i n|sin|ume|o m|ban|iwa|nya|una|kun|uli| yo|ze |ile|a p|atu| la|lwa| fa|ebe|uta| pi|a i|lez|ali|i y|lik|aba|i i|fa |ao |lao| fi|seb|sil|ket|eng|bal|mus|ki | wi|i l|bez|u i| zw|tum|g w|u y|u m|ezo|lis|le |zi |si |i h|i u| ke|alo|fum|o n| ta|wal| lu|ezi|uto|tut|lin| it|kut| wo|o w|o b|iba|isa| ki|no | il|ike|e s|e i|bat| bo|yal|yon|uma|ika|u z|aza| ny|ani|u l|u p|ale|zwa|han|ulu|uku|ise| pa|bon|ate| fu|a a|osi|e h|wo | ez|fiw|yan|iny|hai|eli|but|o h|cwa| cw|i t|usa|bo |tal|ano|mun|e n|e b|itu|elw|ena|bas|ngo|ten|lib|kat|zwe|ape|ko |u w|e l|u e|and|nga|ga |ken|sal|u t|lan|zwi| ng|yo |sik|ham|use|ati|go |wel|muh|u a|a w|nda|ako|nak|amu|asa|ita|usi|tus|api|oto|kot|bel| se|yen|bak|ulo|tul|umu|lit|uba|g o|o i|ho |ing| in|mis|kol|iko|pum',
    'mri': 'nga| te|ga |te |i t| i |na | wh|ia |a k| ki|ang|hi |wha|ki |ahi|a t|ana|tan| ta|e t| e |a i|ata|a a|ei | ng|a m|aka|hak| me| ma|o t|a w|e w|a e|tah| ti|nei|ai | ka| o |eta| an|i n|i a|ta |gat|ran|i i|ika|tik|e m| ra|me | ia|ua |ka |kia|i k| ko|o i|tet|a r| a |ko |e a|a h|i r|re |e k|ona| tu|whi|a o|ane|tu |atu| at| mo| wa|ara|i m|e n|ea |oa |kau| ho|rit|ra |oki|ite|i w|kat| ro|aro|hok|tia|no |hai|i e|u k|a n|i o|o n| to| he|tur|ke | no|wi |iwi| iw|e i|ung|kah| ah|hua|mah|e h|ro |ato|ing|mo |man|ora|i h|aha|aua|ten|tau|toa| ha|ina| ai| ri|to |oto|han|utu|ton|hei|ake|aki|kap| ne|rot|he |uru|ru |e r|run| ru|whe|ene|ati|o k|ere|e o| on|apa| hu|ein|au |u a|wa | ak|mei|eng|iwh|hiw| na|pu | ke|a p|tea|tut|ure|ako|uri|aur| or|ore|nua|enu|hen|o r|ahu|oho|o a|hin|wat|kar|har|e p|aer|hae|pa |ono|mea|iti|ui |ho |o m|kaa|kaw|ate|kor|oti|awa|pon|wah|apu|ira|kan|noh|mai|mat|rar|opu|ri |pap|upa|aup|ao | ao|nui|uar|ine|aar| et|u m| pa|ari|e e|mar| pu| ar|rah|rat|hia|ne |ahe|kin|noa| po|aho|tak|kei|rop|uat|ita|kit|u i|awh|ter|mon|tin|o o|tuk|mau|nat|ti |ong|upu|kua| pe|tir|u t|u o|pai|are|ino|ama|iak|apo| ku| en|anu|ano|ma |gar| hi|u w|nau| in|ura| ut|e u|nan|uta|ngo|ae |aru|hor|u r|koa|pua|uak|o h',
    'hsb': 'nje|je | a |pra| sw|raw| pr|wo |swo| na| wo| pł|jen|a s| za|a p|na |awo| ma| je|wob| po|ja |o n|anj|ne |óžd|kóž| kó| so|dy | nj|e p|abo| wu|owa|enj|ždy|a w|ma |płi|bo | ab|ju |sta|y m|woj|so |obo|nja| w |bod|płe|wje|e w|osć|ow |ić |e a|ch |o s|dźě|e s|ym |dźe|stw|o w| st|eho|ć k|ho | dź|ich|nym|ać |nos|jes|jez|odn|ej |mi |wan|nju|ny |jed|eje|a z|o z|ost|u w|će |o p|e z|e d|ist|oje| ko|zak|smě|ć a|wać|a a|aja|za |a d|jeh|am |edn|o j|u a|a n|otr|kot|raj|awn|mje| do|dow| zj|ež |nyc|a j|two|łis|esm|isk|a k|žiw|u p|jew|awa|aro|wot|źěł|man|ě s|mě |u s|ske| dr|ez |zje|wa |m a|ena| wš|měr|sće|taj| šk|ki |ako|wól|du |mu |kow|wos|tre|kra|dne|tat|dru| to|iwa| tu|eny|rje|m w|i s|o d|rod|nar|łow|i w|and|dno|pow|adn|atn| by|łeć|kit|nic| ni|odu|wój|swó|emu|im |ski|bje|a t|tut|adź|a m|wěd|u z|ći |sći|y p|i z|ćen| mě|jem|rež|nan|nu |n j|łez|ški|nak|imi|run|łos|hło| ch|jej|ke |els|pod|dźi|słu|o t| kr|nej|źe |dny|m p|maj|om | z |po |su | su|jo |ojo|owj|čło|źel|ndź|stu|tar|měn|odo|cn |dnj|e m|jaw|zja|dna|ych|la | ta|ran|ce |ćiw|eći|it |e j|chł|yć |óln|ó n|tó |htó|cht|tu |tej|łuš|isł|oso| te|ije|o m|nis|kej|źěl|aln|ial|cia|oci|soc|ruh|kim|i p|eli| re|uži|wnj|wop|eć |twa| mj|sto|i a| čł|cy |šit|wši|bi ',
    'cri': ' di|di | cu|du |uê |tud| tu|udu|ngu| ng|guê|cu |ón |tu | ca|ê t|u n|tê |êtu|u d| tê|rêt|irê|dir|ni | ni|ê d|çón|ca | e | na|a n|a c|la |a d|na |de |dê |i t|u c| fa|sá | dê|ade| ê |a p|dad| sá|sé | sé|ê c|a t|fa |pô | pô|lá |açó| ua|e d|ua |i d| co|ué |ent|i p| pl| li|xi |do | ô |sê |ê f|al | ma| pa|á n|ual|á c|a s|con|to | de| fé| se|ê s|tla|ê m|qué| té|i s|i l|sti|u s|lib|ida|ado| a | qu|éla|tél|fé |ont|á d| xi|lqu|alq|qua|men|o d|i c| sê|plo|rda|erd|ber|ibe|uá |cuá|elá|ê p|ê n|é c|lig|ça |n d|ia |pa |i ê| mê| es|o s|oci|soc|i n|é t|da |cia|nal|u m|ali|cá |ntl| le|á p|est|é n|co |ico|nto| re|sel|i e|ión|aci| mo|é d|tad| tl|o n|ê u| so|lo |ist| pe|n c|li |a m|mé |ona|ion|ter|cas|nte|bli|o t|dá |ote|lot|tá | ju|sta| ba|nê | nê|ôtl| ôt|é s|n s|cla|e c|ens| mi|ina|á f|ssê|êss|mês|a ê|ji |lia|cio|nac|cuê|i f|é m|ti |á t|é p|ei |lei|pli|pê | pê|ura| vi|zá |á s|itu|axi|tlo|igi|adu|u l|á e|pen| ne|u p|e e|min| gl|ial| vo| go|ê e|n ô|u e|gió|obl| ob|teç|mil|ami| in|gá |o c|ili|dé |txi| to|and|man|e a|viç|lê |gué|a e|ime|cie|ame|eli|rel|ô d|raç| sa|u t|n t|en |nen| mu|no |des|pu |lup|glu|i g|o e|ass|ómé|hóm| hó|naç|eçó|e ê|fam|int|ô n|lid| dé|u a| an|sad|u f|n e|içó|çu |içu|mal|ocá|cum|ust',
    'pbb': 'a k|pa |we | na|sa |na | hi|n i| i |a n| s |te |i p| a |hi |a h| we|asa|yuu|nas| ma|c a| yu|a m|a w|wa |ma |ya | ki|e s| pa| k |a s|apa|a e|aa |maa| wa| ha|uu | ya|ec |kwe| ka|ala|wal|kyu| te|k a| ky|a y| sa|ena|a p| hu|la | c | ne|u h|f i|c h|sap|a t|e w|iwe|kiw|me |e h|una|ewe|ete|yuh| it|en | f | ew| pt| u |ha |e n|hu | üs|yu |wen| pe|hab|ewu|s y|wet|uwe|a ü|b w|ab |t h| ze|i z|a d| ku|u k| ee|u n|üus| üu|i s|uun| n |hpa| ip|ime|e p|ite|een| t | hw|isa| pu|akh|k t|uwa|v i|e k|iya|uhp|kim|ka |pee|khe|uc | v |a i|wes|ama|nwe|e y|yuw|a c|men| im| th|d i|ta |e u| wë|ewa|hak|nap|kah| kw|new|hwe| ec|un |ume|epa|myu|imy|tew| pi|u p|sam| ik|pta|mhi| mh|piy|kha|tey| is|s k|t i|hsa| h | d | pk|pkh|wun|ek |i n| p |ac |ekw| iy|wey|s p|tep|u y|esa|huw| nw|it |eek|eec|tee|wec|hn |ika|uuc|akw|huu|s a|ayu|weh|e f|uka| uk|naa|s h|a f|ki |su |thë|eya|ahn|ehu|i k| me|s t|wek|iyu|c n|uya|uuw|e i|h u| da|e m|wew|hit|ëc |wëc|i y|ana|cte|u s|wum|uuy|s m|kuh|e ü|ate|the|ees|nee|ey |ipa|awe|ic |ema|swa|eyu|an |uk |hme|eh | ay|yc |at |ne |ase| äh|yte|uht| kh|luu| lu|his|wep|ste|üst| aw|ahi|hë |yat|a v|hew|kac|ew |se |met|sn | ah|e e|hwa|a a|pte|san|ihy|kih|hte|khi|ipe|ze |kay|he |wët|i w|esn|i h|t n|aba',
    'qva': 'man|una| ka|ana| ma|an | ru|ta |nan|nqa|na |aq |ach|ch |anp|kun|kan|cha|qa |npa|run|qan|paq|anq| ch|is |pis|apa|a k|ima|am |hay|ita|ura|si |a m|aku| im|h u|rur|a r|pan|lap| la|in |chu|pit|nch| u |nam| ya|uy |n r|sha|nuy| ju|hu |kay|nma|nta|npi|ash|ayn| pi| ni|a j| wa|tin|ay |ama|asi|ant|anm|nas| na|nin|chi|anc|ayk|ata| mu|yun|syu|asy| al| ja|ha |i k|kin|pti|juk|a a|ali|aru|n m|rak|mi |onq|ur |yta|mun|nap|kur|nak|ipi|res|iku|uk |ynu|pip|h a|pet|spe|esp| re|wan|hik|apä|kuy|u k|api|may|q k|ni |apt|yku| ar|y m|un |yar|i m|awa|li |i r| ki| y |enq|ych|n k|arp|rup|a p|kon|ran|kar|inp|yan|jar|tas|eta|kaq|aqa|a c|aki|m p|ina|n y| ri|mas|äna|rqa| o |nat|a y|nku|wak|ayc|kas|yac|ako|ayt|pas|a l|s a|pa |a i|ank|kik|yni|q r|päk|y r| ak|arq|ika|aka|q m|iki|anu|i i|a n|n c|kap|wal|rik|h ü|tac|kac|yka|i y|ma |upä|akä|ayp| ay|mac|tuk|äch|hka|and|inc|ark|raq|uch|pän|kaw|n l|ka |mar|mat|han|tap| am| qo|naq|u c|aro|a w|n n|upt|hun|äku|ar |ras|ten|uka|otu|qot|kär|nni|unn|nir|nsi|n j|al |iwa|q a|rka|n a|y k|pte|rap|a q|unp| ac|aqp|m k|uku|ndu|äri|u m|u n|rpi|ish|s n| iw| li|rin|ara|ypa|unm|koq|int|a o|chk|äqa|maq|üsi| üs|y l|nmi|n i|qac|oq |y n|s m|ira|tan|rpa| pa| is|ans|äko|i n|q i|asa|ämi|shu|du |taq',
    'mxv': ' ku|a a| ña| i | a |ka |a k|ja |yi |ayi|ñay|nu | ja|u k|ku |i i|a ñ|ñu | tn|ma |ni |tu | ma|a t|na | ka|chi|a i|aka|u u| ta| nu|i k|tak|te |i ñ|va |sa | u |yo |iyo| te|tna|nde| iy| ñu|i t|hi | su|u i|i n| ch| sa| nd| í |u n|ín | ií|a n| na|iín|kui|iñu|uni|i s|o j| tu|niñ|ini|í t|tni|i j|sun|u j|u t| ji|ña |ind|u m| in|kuk|a m|e s|tnu|ñat|atu|e k| an|u ñ|kue|u s|ech|i m|hin|utu|a s| va|e e|uin|ve | ve|uec|n ñ|a í|a c|atn|kua|a v|nda|kun|eva|dev|a j|u í|und|xi |í n| xi|ji |aí |sik| si|i í| e |o t|uku| ni|ya |ú k|aku|kak|uka|kaj|ua |iku|ko |ava|ú t|n t|o i|kan|anu|tut| ya|e t| o |jin|aji|kus|e ñ|̱ k|kaa|ndu|u c|in |ani| ñá|o v|vi | aí|í ñ| ko| ín| at|u̱ | ki|kut|nú |i c|ñú | ñú|de |det|ínu|uch|e i|si |ndi|and|té | té|tú |uko|usa|tat|í j|n i|dut|nu̱| kú|nav|a̱ |aa̱|o o|a x| nú|í i|n k|uí |eña|deñ|da |i x|ika|ga |nga|e n|atú|nun|inu|oto|kot|to |eí | un|n n|kuc|iya|ama|o n|an |kú |̱ n|do |ndo|nka|aa |i v|átu|ñát|jik|mi |ai |u y|aja|nin|yu |kas|a o|i y|su |ivi|ata|deí| vi|eta|jiy|riñ|tri| tr|ké | ké| ì |u ì|kat|̱ t|axi|nax|ní |uiy|o̱ |ate|sam|isa|xis|ñi |iñi| ke|áji|u v|ki |ink|ú i|iko|ú n| jí|umi|sum|nuk|ija|nij|nuí|uxi|uat|iaj|dia|ang|nan|unu|ui |ue |o ñ|o k| yu|aña|uva| uv|yiv| ng|ta ',
    'gla': 'ach| a |an |ch |h a| ai|ir |air|dh |eac| an|tha| th|n a|r a|ha |a c| ch| ne|adh|ith|hea| bh|ean| ag|cha|idh|th |us |gus|agu|òir|nea|a b|a a|hai| dh|ann| ga|aig| cò|s a|nn | sa|chd|h n|bhi|gac|a t| na|eo |còi|am |sea|il |hit|aid|had|na |on | bi|in |ig |agh|ail|hd |ead|gha| fh|neo|ta |ar |nta|bit|a d|n c|aor|h s|ise|rsa|h c|m b|le |hao|han|ich|sao|is | co|hla|as |n d| ri|lea|bha|ant|a s|e a|ile|h t| se|nan| gu|inn|n s|iri|rea|g g| fo|eil|eas| le|n t|che|a g|dhe|ors|d a|nna|h g|tea|dar|n n|eal|hòi|ghl|ain|h f|ire|dha|e c| tr|ear|ùth|ana|lta|sa | e |igh|rac|cho|ri |r n|aod|fha|n f|alt|o a|te |s s|hei|chò| am|onn|ion|uil|l a|sai|son|rso|irs| dì|gu |irt|chu| de|mh |sam|nns|h b|ad |rra|ogh|lac|nac|dìo|rt |mai|ill| nà|aic| ma|co |eag|oda|gh | ao|ìon|n l|hid| ea|nai| ph| ei|hac|àis|nài|dea|rai|h d|r d|sin| si|r s|ric|arr|s n|ho |aon|lai|mha|thi| do|hda| gh|fhe|nam|san|s c|ne | ui| ob| st|the|tac|ona|omh| la|oir|hal|ll |hch|thc|dùt| dù|hoi|h e|bhe|amh|r t|seo|ns |rid|ein|bh | is| io|eth|hui|h u|oba| sh| cu|asa|ghe|h r|ur |tro|ìom|bho| h |a h|lag|mhe|t a| mh| te|s t|aca|dhi|o d|ada|ara|èan|r b|sac|cea|oil|n g|oin|obh| bu|n b|mar|gai|m s|ine|uin|lam|fog|do |abh|s e|ro |ars|a f|a r|a m|g a|o c',
    'qvm': 'una|nts|tsi|kun| ka|ant|pis|is |paq|man|apa|aq |an |kan|ana|nap|nan|iku| ma|sik|a k|na |shq|hqa|qa |mi |ash|sip| de|ta |ipa|si |tsa|chu|api|noq|lap|der|hun|ëch|rëc|erë|i k|int|say|ami|pan| ts|unt| la|ima|aku|anp|pa | ru|nma|ita|wan|qpi|anm|nas|nin|ayn| ju|npa|pit| na|nku| im|a m|qan|ata|yun|oq |kas|asy|yno|run| y |pam|tin|pti|apt|a r| ya|oqp|i d|syu|q k|tsu|ipi|n k|nam|ala|ach|juk|awa|kay|su |nak|ayk|npi|ho |cho|aqp|may|ish|s m| wa|nat|tap| pi| mu|kap|ay |ura| al|a a|qku|kin|in |kaq|hwa|shw|ali|mun|ama|q y|yan|a y|rur|kik|unk| ku|naw|s k| ni|iki|cha|aqa|q m|pip| ki|a n|a p| re|n i|ush|kuy|q t|a d|aka|i p|ma |q l|nmi|ras|yku|li |ats|unn|ark|mar|lla|a i|n j|yni|aqk|ink|uri|n a|s l|a l|nni|chö|asa|mal| ar|ran|äna|rka|n n|la |wal|iwa| iw|ank|uk |i r|un |ten|pap|nta|mas|a j| aw|q i|s t|all|kaw|yin|ayi|ano|san|nqa|ara|lay|esp|res|yla|s a|aru|ypa|n m|s d|qpa|apä|yac|sar|shi|a t|inm|nac|y k|öpi|höp| pa|unm|idä|rid|tur|wtu|awt|n l|s r|ika|kri|kus|yka|päs|rak|ina|ayl|sya|ych|q a|inp| o |y t|n r|esk| es|nch|äku|i y|äsh|shp|n y|y n| sh| qa|u k| lu|spi|lat|ayp|kar|ast|uts|o k|nno|jyu|ijy|lij|eli|rel|s y|kur|arp|yar|aki|wak|hak|ruy|pli|mpl|ump|kum|hpa|tak|lan|yta|sin|rte|ert|per| pe|das|ukl|n t',
    'fao': 'um | og|og |ætt|ræt|til| ti| ræ|ur |ver|il |tt | at| ha|at | ve|ing| sk| í |ri | fr| ei|erð|ska|t t|ll |øll|ein|lig|va |ndi| vi| øl|lla|sam|ava|hav| sa|la |l h|in |ell| el|an |and|a s|ann|fyr|a r|ið |yri|ða |lag|sum| fy|ng |ra |nna|ar |rða|di | av|al | he| su|iga| er|kal|við|av |num|i s|si |a f|ind|ræl|men|m s|sin|ga |m o|g a| tr|g h|r s|ir |na |ela|fel|tan| al|gin|tta| um|vør|hvø|enn|t v| va|lan|ngi|m e| hv| te|tti|nar|l v|æls|fræ|ru |nn |t a|r f|a t|und| la| mi| st|rli|ag |g f|eru|tjæ|ja |i a|var|dur|l a|er |lum|era|arl|tar|i o|að |g s|ski|tin|igu|vís|gum|i h|nd |ndu|l s|i e|ari|eið|a a|ðin|bei|jæð|m v|ger|lme|alm|ins|t s|a v|kan|n s|n o|t e|a o|g t|lsi|ður|nað|i t|ki |frí|ram|fra| ið|i v|rð |ni |læg|han|ald|r t|ti |mfe|amf| tj|mun|nda|rt |a h|ara|r o|gar|rði|n t| me|nnu| sí|g v| se|ns |rum|m h|r e|ryg|try|r r|vur|evu|hev|ð e|ama|r h|iði|stø|kap|ka |n m|utt| ut|í h|eig|sku|vir|arb| ar|sta|ði |t í|vin|ta |sín|ast|rít|l f| ta|a l|inn| fe|st |ldu| út|r í|vil|u t|dum|tur|rnd|ern|i ø|rev| re|d e|gd |n h|dir| ho|ers|per| pe| hj|llu|aka|mis| so|øðu|ift|arv|ags|a e|úna|trú|mál|esi|hes| an|m a|ørt|t f|g e|man|nni|ina|rbe|í f|gnu|úgv|ðan|iðs|ítt|ð t|md |n v| ge|nin|ong|g o|hon|tei| on|ggj',
    'kal': 'ut |inn|ssa|naa|it |unn|iss|eqa|taa|qar|nni|ati|alu|iit|ik |nna|sin| pi|aat|nng|neq|uun|aan|arn|nii|ner|luu|igi|llu|tit|ass| na|ann|ita|lu |tig|ill|rsi|t a|nis|mik|umi|isi|t p|ani|t i| ki|pis|aas|ers|amm| in|sam|ngi|rni|art|sum|saa|ine|ni | aa|nal|ssu|mut|rne|sut|its|git|ffi|aqa|gii|nut|nik|ars|mal|rtu| il|mma|ina|inu|amu|aam|ima|aal|isa|tsi|mmi|ler|uti|mi |asu|t n| ta|all|qat|aff|gaa|aaf|t t|uss|kku| at|tun|tut|ssi|oq |kin|erm|t k|ikk|atu|tsu|ala|min|rmi|sim|ini|nne|iin|ull|ama|igu| su|ili|rsu|nga|uni|gin|sis|isu|mas|aar|aav|ile|sus| tu|at |t s|lli|ane|tam|aq |gut|orn|san|ami|lla|kut|sit|voq|avo|u i|ila|uus|i a| im|uga|ata|k a|sar|uma|iaq|nnu|aap|rti|tum|lug|eq |sor|kil|app|gis|lun|imm|iar|mat|saq|eri|una|uar|ior|mil|nia|eqq|qan|man|lil|k i|suu|akk|ris|ern|k p|seq|nam|liu|aga|i i|per|q a|ari|laq|rlu|use|nui|uli|sun|ort|qqa|iff|ugi|ats|ert|ors|sug|qas|u a|sul|iis|nar|q i| al|asi|ttu|tta|nun|fii|lag|utt|uts|uia|rta| pe|u n|aqq|sig|qut|erl|gal|aaq|ang|i t|aru|k n|u p|put| ak|teq|laa|rso|gil|qaa|oqa|peq|lua|fig|sia|nil|k t|qqi|ppa|sat|gas|avi|q k|ilu|uut|une| is|ker|ali|i k|rsa|tar|tor|tin|nat|tuu| eq| nu|iga|uta| an|itt|ppu|pil|anu|gav|iuu|usu|pin|lan|ger|nge|q p|ppe|upp| up|ria|taq',
    'cni': 'tsa|ri |sat|eet|ame|nca|cam|mee|ets|i i|i a|ati|ite|eit|ari|ti |ant|jei|eri|ee |te |que|iri| te|tsi|ca |shi|ate|e o|onc|inc| on|oca|aje| ir|ro |ter|tee| oc|a a|ats|ita|ica|pee|ash| in|isa|tej|i o|nta|e a|ric|aro| an|aqu| ai|i t|ji |nte|eji|aca|ais|iro|ori|tea|san|int|ero|aar|can|ape|its|tir|qui|ata|nti|tac| ca|hin|ipa|nqu|ete|pin| av|aye|rio|aco|si |eer|tim|avi|o a|nts|caa|ava|ni |cat|ear|e i|ron|uer|coa|ira|ani|e t| ma|anc| as| it|oni|maa| ar|ior| pi|taq|ane|tar|vin|ine|imp| am| at|eta|a i| ei|car|pap|sip|aaj|hit| im|sar|ime| pa|ama|ina|rit|i c|e p|mpi|eir|mpa|yet|nea|a o|eje|nco|ra |ini|nin|han|sha|ish|ej |asa|oaj|tan|ta |emp| yo| i |j i| qu|ui |iqu|ror|anq|tat|ue | ac|ea |ima|inq|a t|oje|ipe|uea|yee|pat|ara|roa|i p|uem|ora|yor|ent|ote|ena|ana|ran|tav|man|oaq|tas|i y|me | co|cap|osh|nat|api|taj|ait|pai|uen|vac|i e|ris|sir|era|i m|mpe|par|coj|amp|o c|sam|uee|i q|a p|eti|net|ota|a c|ino|mej|mat|equ|ano|uis|e c|saa|cav|rir|tay|pas|ne |sin| ts|pit|iti|hir| ti|sa | os|ont|epe|tap|o t|eac|maj|aac|roi|non|o i|esh|imo|eim|coi|ato|vam|mip|omi|tom|ye |i s|jat|aja|teq|sit|o p| ja|raa|ner|tep|nej|var|ven|nay|oye|o o|mis|emi|ean|nan|aji|nas|a e|cot|naj|ire| aq|tei|oit|coy|ram|ras|not|cha|tai',
    'chk': 'an | an|on |n a|we |n e| me|pwe|un |mon|epw|en |emo| em| ep|in |n m| ar| wo|eni|or |ni |wor|me |nge| no|non|gen|ei |kun|e e|it |mei| ra|ini|ait| fo|sin| pu|rai|ch |ang|pun|ama|r a|och| re| es|n r| pw|n n|are| fa|e p|re |n f|ap |i w|uku|nam|t a|as |ara|n t|e f|mas|ram| ch| to|wan|fan|nis| mi|kku|e a|e n| tu|ng |isi|pwa|ren|i a|esa|cho|unu|sen|ung|mi |kin|sap|n p| ng|nap|ana| na|onu|fon|ese| ne|i p|i e|oun|for|nga|ong|nu |ein|fin| po|ich|e w|is |nin|ri |n s| o | fi|gan|pus|i m|r e|ar |okk|usi|ton|nen|ten|n i|sou|nso|ans|sok| so|i n|ori| su|ewe|man|umu|ina|n c|n k|che| ek|fic|ufi|tuf| se|e s|ata|s m|eu |mun|e t|hok| ka|fen|n o|eki| oc|p w| a |ngu| eu|ta |se | ew| mu|ok | ni|efi|n u|rep|akk|suk|n w|tum|pis|tip|ifi|er |mwe|amw|o e|e m| ti|nuk|gun|a e|u m|ine|apa|nif|hch|chc| ma| ki|r r|u n|iti|chi|ffo|ka |ika| ik|e u|r m|ite| un|mu |s e|ora|ani|ann|ir |hen|u f|won|no |nnu|pen|amo|win|hon|men|kuk|ien| ei|eng| sa|i f|ufe|min| mo|fis|wen|e c|opu|pop|uk |h n|off|fof|iwi|e k|ape|u a|tor|kap| mw|k n|t m|i r|ekk|nno|onn|r t|ti |inn|a m|nat|uan|nua|wes|utt|a f|ipi|s n|koc| at|i t|aw |eme|s p|pan| pi|o m|mef|am |mwa|ak |nom|sak|h s|ett| in|i s| we|s a|eno|nun|sun|niw| am|uni|naw|u e| ut|tte| au',
    'mah': 'en |on |an |in | im|n k| ko| an|im |ok | eo|o a|n i|n e| je|ko | ka|eo |lok| ma|ij |aro| ej| in|ilo| il|ej | en|lo |n m|ron|mij|non|n a|n j|rmi|arm| ar|mar|ak |e e|or | no|k i| ki|ot |o e|kaj|n b| ak|j e|ien|eor|jo |bwe|m b|elo|r a|jel|r i| lo|k k|mon|o j|we | bw|ke |ar |jen|o i| be|ojo|joj|wot|ir |ajo| ju| re|ol |eje|lol|jer|bar|e i|n l|bal|kin|ake| na|ane|ber| wa|j k|erb|er |juk|win|nan| ke|mak| wo| ai|e k|k j|al |rba|men|ele|ne | bo|air|kwo|r e|awi|waw|m e|o r| ba| mo| e |kie| me| le| em|uon| jo|j i|nem|ro |l k|l e|bok| ek|ona|k e|kar|kom|jab| dr|juo|emk|rok|n w|ur |our|mou|et |nok| ja|jok|e j|oj |woj|mkw| ro| ie|lem|alo|ein|kot|o k|le |n n|omo|jet|kij| ji|rej|k a|uk |ewo|abr|ijo|mwi|ela|j b|mno|emn|man|rew|bre| kw| bu|wij|r k|m k|l i|bel|kok|n d|jej|t i|kka|ekk|kej|e m|kju|ukj|kab|iki|dro|uko|buk|emw|ibe| ib|na |ae |r n|jba|ejb|wor|r j|j j|k n|oki|n r|ben|won|a i|aje|j a|kak|ri |lal|j m|oko|oma| to| ir|lel|mje|ote|ije|emo|re | ij|jeb|un |m a|ki |aki|okl|nwo|inw|t j|jon|m j|emj|tem| ot|ul |oba|k m|kel|tok|one|t e|r b|iji| ik|t w|klo|wal|kwa|aj |naj|t k|rei|are|ono| un|rol| li| ra|nae|o l|eka|lan| el|ima|oke|ta |o w|k b|o m|e n|k l|jin|lij|ali|kal|o n|ena|ren|i i|t b|r m|j l|r w',
    'rar': ' te|nga|ang|ga |te |a t|i t|ia |e t| ta| i |aka| ki| e |ai |tai|a a| ak|a k|ata|aan|eta|tet|re |o t|e a|ta |au |tu |a i| an|e k| ia|ki |atu| tu|a e|tan|u t|kor|kia|gat| ra| au| ko|ore|kaa|ana|na | to|e i| ua|to |tei|uat|i a|ika| ti|ama|tik|man|i u| me|a m|ato|kat|u a|no | no|aki|i r|ite|ra |ei | ma|a n|toa|tau|ian|eia|o i| ka|e r|ona|oto|rot| ro|ua |ka |me |ora|ton|tur|rav|a r| pa|i i| o | or|ura|eit|tua|a o|u i|tam|kak|a p|ako|lei|ile|sil|asi|bas| ba|tak|ava|e m|o a|apa|raa|oa |pu |e e|gaa|api|nat|e o|kit|u k|ma |ure|aru|ti |nam|ke |oat|uru|par|iri|iki|ano|ita|ri |u e|i e|rur|aur|nak|e p|i k|ake|ave|aia|e n|rak|pap|oan| ai|ati|mei| ap|kam|ait|ira|ran| na|ing|aat|ko |iti|va |ou | pu|ipo|upu|tup|ari|utu|ru |kot|i m|uan|ere|noa|ean|noo|pir| pi|ro | ng|auk|aro|ve |oko|u b| a |u m|oo |rua|rat|ate|pii|tao|oro| aa|i p|ino|kin|ara|u o|u p| re| it|pak|kan| va|kav| ik|mar|iia|ota|kap|kai|rik|rai|aor|eir|rei| at|pin|ria|amo|imi|kim|tou|u n|mat|aok|kar|e u|i o| mu| ar|a u|tat|aer|eng|po |oip|poi|aip|una|apu|roa|aap|pa |uko|uao|a b|o r| pe|aua|e b|ori|mor|ne |i n|tea|kau|mi |tir|u r|nau|tut|uap|pua|uta|uka|rau| ‘a|ina|rin| ir|o e|paa|umu|mua|taa|tin|oti|rar|tia|iai|o m|ao |opu|eu |peu| ke|rea',
    'qvn': 'man|una|an |kun|aku|si | ka| ma|apa|nma|ana|ta | ru|ata|ach|as |na |anm|am |ima|chr|nan|sha| na|aak|run|tan|paa|nas|cha| pi|may|tas|unm|chu| im|qa |mi |ant|nch| ch|ama|a k|paq|ash|ay |i m|nsi|nta| wa|ita|hru|nqa| ju|pan|aq |anp|kan|pit|a r|yun|kap|nam| ya|ipa|wan| ri|npa|hu |nak| u |pa | al|hay|n m|ali|syu|asy|chi|nat|a m|nuy|nin|ans|awa|ura|naa|juk|nmi|anc| mu|qan|i k|mun|ru |n r|lap| la|rur|aat|ha |hra|tin|nap|isk|kur|pti|i u|qsi|ina|anq|kas|nku|n a|rka|ski| is|rbi|irb|a p|ish|pi |pis|a j|a a|a i|asi|yac|in |a n|aqs|yan|kay| ni|yaq|rqa|uch|qku|urk|ayq|rim|aya|kir|ika|un |yta|qta|a w|aqk|npi|daq|ayn|rik|uy |anu|ran|n n|inm| am|nda|and|yqa|u m|iya| ta|i a|tam|hak|isi|y r|kin|n c|jin| ji|i r|kar|rak|i i|uk |ruu|ara|ayp|m p|kaq| ay|naq|mam|u i|iku|u k|ray|yla|lip|n j| ur|li |uku|tuk|arq|kuy|inq|ari|ayt|apt|ypa|a q|ins|qni|n i|uyl|kaw|rsi|was|s k|a y|ink|aqt|ham|hin|q n|aqa|kaa|ysi|ala|kac|rap|uta|a l|aka|pac|rya|ury|pas|asa|uka|usi|uus|unc|s m|map|ank|a c|aa |ays|ush|y k|kuq|upa|maq| qu|hun|i y|aqn|lut| lu|qmi|u n|utu|qut|mas|bis|way|s a|aki|wak|m k|ych|hik|raq|naw|n l|n y|nti| pa|i j| ja|rac|upt|nni|unn|han|aan|laa|kla|ukl|ynu|api|n w|i c|nir|lam|i n|has|aqm|k r|wam|adu|mat|yap|ayi',
    'wwa': ' o | da| yi|da |ma |a o|iri|yir|ri |ba |na |a y|i d| ba| ta| ǹ|o n|i y|ro |ki |ǹ |i o|a d|a s|di | i |sar|ris|bà | bà|o t|aro|isa|a m|a t| di| ma|ta | na|a n| ka| sa| bo|an |o b|ka | ya|a b|ook| nɛ| ti|sa |a i|i t|oki|wan| wa| tɔ|i b|a k|soo| so|aa |o w|ii |de |ti |ori|maa|nɛk|mii|ima| to|ari|ɛki| mi|re | de| ye|o y|̀ y|i s| yo| fɔ|o d|tor|ku |mma|tin|si |i m|i n|rim|ya |i k|nde|paa|yon|tɔɔ|imm|e d|kpa|n o|o k|ama|aam|yaa|oti|tir|yi |iro|aar|daa|ɔba|ɔɔb|den|n d|aan|nkp|ink|yer|ɛɛn|isi|a p|oma|fɔɔ|bo | mɛ|uri|ɔɔr| nɔ|su |rik|on |yee|ire| te|eri|u y|sim|oot|boo|aba|aŋi|o o|ɔku|ɔɔk|o i|ɛ o|à t|mɛɛ|ɔri|n t|nɔɔ|en |onn|tan|eet|e n| ku|e m|pɛɛ| pɛ|o p|n b|ɛnd|̀ b|asi|ŋis|yaŋ|u d|tu |ra |nda|sir| co|ina|fɔ |yin|ɛɛ |n n|kɔɔ| kɔ| sɔ|sab| su|bar|eti|à d|and|wo | wo|yoŋ|tɔ |ŋa |e y|ɔɔt|ɛ b|u t|a w|ɛ y|ara|ɛ̃ɛ|wɛ̃| wɛ|e s|bot|bom|ond|nsi|u n|o f|ɔ d|are| si|iba|rib|iya|riy|dur|ãdu| ãd|too|kpɛ|o s|ɔya|i c|tim|ɔti|sɔɔ|ika|tak|u s|kir|uki|puk| pu|oon|coo|ato|aat|kaa|ɔɔs|yì | yì|n y|tet|à y| pe| do|ne |nne|̀ t|e t|ŋo |oŋo|dɛɛ|te |ete|uti|kut| kp| mu|ɛmb|ɛɛm|yɛɛ| yɛ|tee|à k|kar|ni |nni|à o|nna|ann|dan| pa|a c|ɛ d|a f|nɛ |i f|nri|inr|ena|een| se|à m|ɔɔ |okp|sɛs|a ã|ɔ f|ɛti|in |emm|dem| tu|ɛ n|sɛ ',
    'buc': 'aŋa|ŋa | ni|ni |si |a n|ka |nin|i n|i a| an|in | ha| mi|an |ŋu |uŋu| fi|isi|ndr|eka|ki |dre|rek| nd|a a|la | hu|luŋ|ulu|hul|i h|iku|u m|ula| ma|a m|aha|zi | ku|a h| na|hak|n f|aki|n’n| am|kul|’ni|i m|in’|ani|ana|u n|ami|mis|min| fa|u a|sha|a k|tsi|azi|ala|ha | ts|fik|asi|aka|afa|ama|a t|ira|a i|iaŋ|uru|eu | ta|dja|izi|a f| au|au | mu| sh|tan|naz|i f|raŋ| iz|i k|n h|naŋ|li |ŋan|mu |u h| ra|nik|naf|nyi| dj|i i|ti |a r|i r|fas|rah|n t|mbu| ki|ia |u k|fih| re|and|bu | mb|ali|fid|har|kur|i t|yi |uaŋ|ihi|ata| at|aru| ka|ru | it|laŋ|vaŋ|ara|reu|iny|aza|faŋ|wi |ifa|ngu|mah|ra |sis|tì |itì|imu|ma |ri |his|i s|ang|na |ian|bi |ada|hwi|iɓa|ou |sa |ria|mia|iki|abi|jab|a u|usu|dhw|shi|aɓu|ɓaɓ|siɓ|sia| si|ano|fan|ifi|tu | hi|i u|u d|ahu|ish|ova|nov|mus|maã|adh|ro |itr|m m|n s|haŋ|fa | la|ari|mik|rak|u t|n n|n k|tra|idi|u i|iri|fad|a s|kut|u f|asa|ini|lal|eti|era| ɓi|idz|aã |adi|hua|zah|faz|n d|da |gu |n u|ika|kus|han|hus|uhu|i d|tas|ato|bar|aba|kab| da|umi|rum|ava|zim|laz|ina|nga|jam|rua| va|za |eng|swa|sir|tsa|tri|usi|hif|hat|tou|uhi|haf|kir| di| ne|ɓil|tru|utr|fif|ivu|iha|amu|has|zur|dzu|dza|azu|haz|ais|mai|a ɓ|ati| ro|uɓa|u r|rik|ruh|kal|vu |sin|hal|nek|bwa|din|a d|i l|ila|oka|dan|ida|etu|ret',
    'qvh': 'una|kun|nan|pis|is |an | ka|ana|aku|aq | ru| ma|man|na |anp|mi |äna|shq|ash|ta |api|hqa|apa|paq|qa |npa|cha|run|yän|nak|qan|kuy|ima|ita|lap|pan|naw| la| im| y |ata|ami|pit|nap|aw |kaq|kan|ali| al|a k|n r|nku| ya|kas|haw|npi|kay|a m| sa|tap|say|ach|ura|nat|ayn|nin|uyä|rur|may|q k|nam| ju|pa |nta|i k|ayk|nqa|a r| sh|qku|shu|a y| ri|yna|ayä| wa|aqk|ink|kin|awp|nas|yni|su |ans|juk|li |aru|ris|a i|ank| na|s m|yan|a l|ant| pi|anq| o |nsu|a a|tas|s y|ray|inp|yas|s r|a j|spi|isp|qpi|syu|asy|tin|uku|aqp|yun|pti|wan|aqa|i m|a s|sh |ish|awa|uma|aki|wak|ipi| ch| ni|ush|yac|s s|ypa|pip|anm|ark|asi|yku|ayp|s k|maq|hum|n k|s a|n y|yka| ja|uya|ina|apt|in |ni | ar|uyn|ran|wpa|rka|mar| wi|äku|kur|nch|arp|nka|nmi| mu|has|aya|h k|ila|yar|kus|hak|i i|pak|n m|kak| pa|ay |i y|pän|ur |mat|ask|n a|a w|uk |lak|apä|q a|iku|ruy|ara|q r|wpi|ika|yqa|ayq|a p|iki|ar |pay|n s|ruk|rak|ma |nac|y r|i p| aw|kik|kap| as|q y|i r|jar|rim|bri|ibr|taq|pam|sar|sin|san| mi| ki|par|wil|wmi|awm|lib| li|n l|i a|way|ala|s i|a n|tuk| tu|ich|w k|aka|nda|and|ras|a o|y a|n j|kaw|yap|äya|n i|nni| qe|usa|n w|wal|iwa| iw|mun|rpi|asu|yta|nna|ann|s l| ku|iya|naq|w r|imi|rik|arq| tä|huy|jus|yay|unp| ra|y l|ych|u l|ipa|rdä|urd|tur|wtu|awt',
    'toj': ' ja|ja |ni |b’a| b’| oj|a j|oj |’a |l j|a s|uk |b’ | ch|i j|li |nal| ma|al |k j|kil|b’o|ob’|’ob|il |i o|jas|a l|ma | wa|i s| sk| ju|a o| ya| k’|ja’|an |ax |u’u|ana|a m|wax|sk’|cha| mi|ok |sok|ali|a t|as | so|ha |a b|jni|ani|i m|cho|i b|tik| le|win| sw|tsa|k’u|’um|sb’|lan|’ s|’in|k’i|um | lu|nki|ink|swi|ojn|lu’| sp|tuk| i |m k|’ch|’an|ina|spe|a’c|un |ila| ni|i c|jel|j b|ab’|lek|k’a|ta |jun|san| ta|uki|j j| a |ini|a y|hon|ets|pet|yal|sta|’b’|ki |ula|nab|ona|iwa|niw|hni|chn|a a|a’ |’aj| ay|yuj|ik | st| a’|min|’il|luk| yu|e j|yi |xuk|juk| yi|el |a k| tu|x s|s w|i y|kol|tal|aje|ay |anu| ko|lta|ma’|’un|ala|j y| t’|lal|uj |e i|olt| ts|’ni|k s|b’i|j s| sl| ku|a n|a’n|ukt|ju’|ek |yuk|jyu|ajy| aj|eli|wan|k c|ktu|ti |la |mas|t’i|k a|sch| sc|xta|le |sle|nuk|j a|ch |k y|lti|ke |kul| sb|ji |a’t|iki|k’e|som|tso|n c|’ma|a’m|x y|ast|uma|i t|eki|a i|pan|ane|aj |tel|wak|tan|n s|i a|’ b|sa |je |’al|ub’|ya’|e’b|ne’|asb|ley|ol |mi |j k|ak |k m|iti|’ul|na | sn|uke|hol|aji|’ y|l o|’i |i i|och|i’b|yi’| ti|’el|ka |n j|man|k o| it|n i|nsa|ens|pen|y s|j o|nub|jpa|ijp|sij| si|mon|omo|kom|mje|omj|uan|’ua|k b| e |sts|i w|’te|mul|taj|eyi|yoj| yo| oc|naj|aju|xa |l b|a c|a’y| ix|l w|asa|jum| sm|sar|’u’|l s|a w|axu',
    'lue': 'a k|chi| ku| mu|na | na|aku| ch|la |sa |ana|a n|a m| ka|nga|utu|tu |esa|mut|wa |a c|a l|lwa| lw|wak|ga |ka |uli|pwa|lus|alu|cha|nyi|we |hi |ila|ang|ses|uch|kul|use|ose|ena|sen|nal|kan|uka|kup|lo |muk| va|nak|pwe|a a|ach|kwe|ipw|i k|ing| an|hip|shi|e m|upw|e k|ma |kut|a v|amu|yi |eny| kw|aha|imb|ava|wos| wo|u w|eka|kum|ko |aka|mul|umu|a w|lim|kuh|o k|any|ze | ja|o c|akw|fuc|ala|hak|aji|sek|a j|van|kuk| ha|ama|yoy|ese|eke|isa|mo |lif|and|o m|hiy|uta|nav|mwa|ha |ifu|ali|kal|wan|han|wam|ham|kes| wu|kah|ela|uma|him| wa|ech|nam|avi|uku|wes|asa|mba|ili|ngo|yel|oye|apw| ya|vat| vy|ung|che|ina|uze|mbi|ish|jis|utw|elo|iyo|nac|vo |tan|ulu|u k|vak|hin|has| ji|bi | mw|wec|kak|kuz|twa|avo|uha|jil|ta |ata|ula|ulo|iha|muc|zan|uza|olo|e n|amw|ise|kun|uki|hen|yin|yak|i l|ona|hon|hav|mwe|a h|a y|yen|uwa|kuv|iji|kwa|awu|naw|imo|kin|ne | ly|una|uho|gol|jin|sem| ma|gan|u a|wuz|ngi|mbu|tel|ako|ush|mil|lil|man| li|i n|kus|ita|atu|his|vis|tam|kuw|naj|kwi|ong|lon|hil|hik|wav|amb|wah|ola|ate|awa|nda| mi|ge |nge|ndu|jak|tav|hal|kuy|u v| lu|wal|kav|i c|nde|ika|lik|vya|gul|ngu|umb|jij|u n|nji|o y|ene|i m|afu|i j|iko|dun|kay|i v|o j|o v|amo|o n|yum|vyu|wol|lwo|alw|e c|de |kuc|tuk|ba |wuk|wun|kap|da |fwe|uji|ye ',
    'qvc': 'una|ta |kun|ana|mba| ka|na |ay |chu| ma|nam|man|lla| ru|apa|aq |pa |amb|ash|a m|ach| yu|qa |umb|uq |a a|cha|yum|nda|baq| ch|bay|ata|yuq|run|pis|is |ich|an |chi|nqa|hay|yta|a y|aku|tin|hu |and|a k|all|ina| di|nap|hpa|shp|am |nch|aqa|lap|ama|dir|nas|paq| su|da |ric|iri|suq|nan|nat|uyu|qta|ima|in |ayt|ati| at|kan|api|ch |anq|gun|aqt|kas| ya|huy|mi |hiq|ngu|y r| wa|h a|nak|a s|qku|iku|hqa|shq|q k| mu| pa| ni|qan|syu|asy|a r|hin|nin|shu|a p| ak|ura| am|yun|uqk|ma |lli| al|anc|yan|sin|mas|ran|mun| im|a i|rur|a d| na|laq|uku|pti|shi|a c|wan|yac|yku|may|iq |q r|ing| ll|asi|mbi|naq|a n|kay|u k|rmi|a w|ita|ayu|ush|maq|apt|kap| pi|inc|arm|war|ayk|qpi|hum|kam|q c|ayp|ray|pi |i k|nll|yas|a t|uma| sh|q a|qll|la |kin|nma|tra|lit|ind|qac|i y|pay|ila|q y|qam|ysh|ays|adu|pip|n m|awa| pu|tan| as|nni|unn|a u|kra|akr|q m|qal|hik|ara|ipi|aql|ism|inl|qmi|rin|aqp|y n| ay|m a|iya|naw|mik| tr|aka|unq|isk|pan|mac|tap|y l|ras|m p| an|smi|uqm|ung|a l|q i|yll|ayl|n s|ish|uya|q s|baj|aba|rab| ta|ask|bis|imb|ika|s a|ypa|n a|mat|tim|ndi| qe|iyt|pac|s y|lut|aya|ast|kuy|nis|yay|yuy|ni |ley| le|n l| is|ski|asa|kus|y t|y m|taq|inm|daq|uch|n c|yis| ju|dar|ida|kuq|i m|m d|sti|q l|du |bi |n k|wsa|aws|kaw|s d|nim|apu|tri',
    'jiv': 'nia|ini|ent| ae|nts|aen|tin| tu|a a|iti|ar |ait|i a|ai |iai|ts |ti |chi|ia |in |kia| nu|tur|sar| ni|ich|sh |am |wai|awa| ch|ura|ra |i t|n a|ain| pu|nka|puj|cha|iki|ish|tsu| wa|tai|ink|ma |ha |nki| ta|ara|iaw|ni |sha|ash|mas|nun|ach|aku|ker|unk|tak|nke|amu|h a|ch |asa|an |iar|usa|aín| aí|a n|íni|ana|kui|kic| pa|uju|unt|ati|rin|tsa|suk|ntr|uat|kam|jus|kan|uk |hik|ank|er | ma|rti| an| ai| ya| ek|ram|art|i n|ka |nam| un|a u|min|énk|nai|s n|kák|at |kar|kma|a t| as|u a|una|pén| pé|ham| ak|nui|r a|r p|hic|kua|uit|ama|aka|jai|ri |ke |uma|ak |atu|eku|aja|m p|tus| at| en|nta|imi|mia| na|uin|man|rma|tuk|amt|rar|atn|its|tri|rat|war|sam| aj| ay|r n|s a|a p| ju|ush|áka|uke|mta|ajá|iru| ir|mu |mak|aya| aá|arm|pac|n n|aik|umi|t a|yam|tki|hit|iat|aki| ká|pap|ats|k a|wak|run|amr|hat|uja| su|aká| um|tia|kak|api|nua|k n|h n|kti|mik|i c|yaj|nan| we|uis|aim|tra|tnu|ari|k p|san|na |n t|i k|mat|nma|tek|nen|ene| ar|ake|ata|as |yai|a w| ts|i w| ka|n p|i u| au|kus|t t|itk|íki|hík|chí|tka|atk|eka|uri|tum|ji |m a|uim|unu|uch|kis|iam|nt |uun| uu|i e|hti|sht|s t|ust|a e|aár|msa|ani|iak| am|ais| uc|sa |ki |i j|ant|mru|un |ik |hmi|chm|mar|sti|án |n u|tji|itj|a c|h t|i p|jú | jú| aú|i m| sh|s m|i i|enk|rak|j t|n e',
    'lld': ' de| po|es |da | y |na | le| da|por|iun|a d|la |un |ona|ziu|de |son|rso|dër| dë|ors|e d|t d|rt | ch|le |ign|azi|gni|a p| vi|ërt| dl|ra | à |ni |vig|a c|té |che|i p|a s|à l|he |ala| sü| so|nì |gnì|ter|a à| gn|za | cu| o | la|les| re|ia |res| na| in|ns |e s|ënt| al|a n|cun|y d|ité|üa |süa|a a|n d|nza|sci|ëgn|mën|nte|ne |a t|tra| co|a m|a l|ara| pr| a |uns|des|s l|amë|ta |te | te| i |er |ada|al |e p| ne|ert| li|ënz|sc |gn |nt | sc|con|zia|chë|s p|e l|s c|nal|naz| pe|pro|s y|ita|or |s d|dla|e c|öna|unt| me|nes|ina|a g|esc|e v|per| ma|ozi|soz| n’|a o|n p| se|gön|egö|deg|sta| ti|a v|e n|atr|a y|rć |ërć|i d|dem|ede|one|tes|anz|nta|ent|ai |izi|ica|hës|ber| më|med|ora|uzi|iam| mo|ali|for| fo|é d|int|at |ca |ibe|lib| n |’at| tl|tad|dal|ers|po | va|ist| pa|ond|üda|dl |raz| ar| di|ma |n l|s n|ant|ëi |dle|e m|se |zit|cia| es|i c|tri|ntr|s v|lia| tr| st|o g|taz|str|min|t a|a f|a i|lit|tla|ti |n s|ss |ëss|mës|nit|döt|ver|fè |afè|iaf| ci|hir|chi|tl |vëi|nüd|vëg| vë|e a|uni| pu|ili|vit|nia| ni|s a| d’|ich|ion|n’a|pol|ëst|ês |tês|ć y|tè |s s|a r|é y|ruz|tru|’is|eté|ste|y s|pri|din| or|deb|sü |lic|bli| av|ria|nda|e r|enü|fen|def|ì d|ch |o p|di |s t|y l|mit|imi|val|ami| é | fa|man|ial|zio|o d|lig|nzi',
    'hlt': 'ng |na |ah | th|ang|ai | na| kh|ham|tha| la|la | ha|eh | ah|i a| ma|hai|lan|hla|eng|thl|om |oei| a | ka|ih |am | ne|a t| pa|boe|kha|el |mai|a h|ing|neh|oel|i n| bo|moe|kah|h t|a n|ngt| ca|te |eih| te|hmo|amh|a k|loe|mhm|h k| ra|g t|oe |en |a a|ong|awn|ung|mah|ek |h a| om| ti|uen|h l|ain| at|h n|m b|hui|ram|nga|g k|ina| lo|h p|khu|at |h m|kho| sa|haw|h h|tom|i t|ui |aw |oen|m t|g a|a l| ni|paw|aih|ak |wn |taw| va|k t|h b|gai| tu|hat|ka |gto|h r|g n|amt|tun|oh | ng|aen|l a|e a| bi|m m|mue|sak|loh| ta|g m|ueh|aek|pae|a c|ei |mtu|tlo|oek|n t| ba|ata|kna|a o|hno|hlo|e t| bu|bi |vae|can|ban|thu|k n|a r| hn|don| do|hin|a b|tue|tho|a s|olh|tih|wh |awh|ihl|lam| da|adi|a d|m k|awt|ith|osa|g h| u |g l|n m|dan| mu|i h| ro|ni |di |pad|upa| up|ala|cal|ca |coe|hoe|m o|ngh|he | he|hol| co| me|lai|no |ama| am|hos|ngp|e k|ghi| ya|nen|pin|i l|lh |nin|l t|a p|gna|ngn|i k|nda| po|l n|pa |phu|ait|a m|h y|ae |bue|o n|tan|roe|dah|wnd|daw| hm|o a|aeh|e n|ben| be|hue|poe|t n|un |baw|m n|i p| im|uek|wt |gta|eba|g p|ngl|h s|a u|ngk|sae|sai|van|hum| ph|um | ku|ibi|bib|e l|e b|ael| so|tae|g c|sue|ada| ad|pt |tpt| tp|t k|gkh| tl|ekn|apa|g b|e h| cu|lpo|alp|yal|ut |awk|ep |aca|h c|lon|w t|pui|so |meb|gla| hi|t t',
    'que': 'una|cun|na |nga|lla| ca|cha|acu|ta |a c|man|ga |qui|ac | ch| ma|ucu|chu|pi |pac|ana|mi |cuy|a m|nac|ari|tuc|ach|ata| qu|all|ang|um | ru| tu|tac|cta|ami|ing|nam|uy | ll|a p| sh| pa|hum|run|i c|shu|shp|ish|hay|lac| cu|api|pay|y r|pa |ash|ich|hua|act|ca |ama|c c|nap|a s| hu|hca|shc|a t|ayc|huc|án | al|ric|apa|es |pes|icu|ahu|uán|huá|hpa|ayp|har|ycu|can|yta|cay|cac|ay |an |ayt|hin| ta| pi|nat|rin|uin|chi|ita|shi|mas|a a|aca| ya| mi| ni|la |ina|a q|a h|ung|nal|ima| ri|usa|aus|cau|in |ypa|lli|llu|a r|yac|uya|ape|iqu|uiq|i t|li |nis|nta|n c|ura|tan|ayl|and|ipa|cpi|lat|uct|ant|nda|may|uis|a l|yll|n t|m t|uc |uic|hu |sna|asn|aya|hpi|dar|hat| ha|atu|c q|tap|i h|cam|ill|yan|a u|nah|yuy| yu|yay|i a|tum|i p|say|i m|acp|c m|has|mac|a n|i s| ay|uma| pu|ysh|ays|ran|ush|n l|gap|rip|tar|ipe| ti|c a|ypi|m c|rim|gac| ja|rur|ngu|luc|pin|i y|mil|lam|pip|aqu|hac|pit|cll|n a|pur|n p|jap|ull|ma |rmi|arm|uar|gal|uip|hic|hur|nch|a y|ayu|uas|lay|lpa|llp|i l|ala|iña|u c|hui|hus|uah|a j|lan|acl|yla|c y|tin|tic|n r|ri | im|a i|ris| su| ap|asi|ipi|s m|y l|uri|yuc|mit|n m|pic|cuc|c l|cat|i n|n q|ín |san|tam|yma|aym|uiñ|uac|guy|lqu|llq|cul|sum|hit|m y|s c|lap|sha|car|hun|tat|y c|s a|uit|ica|pan| am|ell|uel|que|pap',
    'pon': 'en | ka|an |ahn|hn | de|de |ki | pa| me|ama| oh|oh |ng |ara|iki|n e|il | en|me | pw|e p| ar|man|kan|son| sa|pah|n k|as | so|n p|n a|ros| ah|pil|aro|os |kar|ang|mas|ram| ko|da |rai| pi| ma|nik| we|n d|pwu|hni| eh|nam|pwe|i d|hu |e k|weh|n w|ana|i m|ail|ale|ede|n s|n m|pai|s a|h p|s k|ong|sal|aik|men|in |ek |doa| mw|oso|nge|ada|eme|e m| pe|soh|kos|ehu|ahk|gen|aka|san|i p|sou|e s|on |asa|was|ohn| wi| li|hda|te |hte|pwi|ian|kak|e d| se| ni|ung|wun|led| ia|oht| em|we |et |wet| na|wei|hk |oah|mwe|pen|dek|wah|dah| uh|epw|eh |l k|n o|ene|ei |ein|e e|ira| ir|la |wia|l s|ou | di|e a|mwo|ak | po|lip|hng|ehn|ie |l p| wa|nan|h m|mwa|ans|wuk|pwa|h k|aso| to|ahu|ed |a m|n i|ni |u m|apw| ke|a d|poa|ipi|i k|l m|nei|i a|k k| da|e i| ak|el |wel|hla|di |g p|oad| do|l a|wih|ehi|oas|ehd|toh|pwo|hki| re| an|uka|ine|hi | ki|ahr|ipw|ele|nso|g k|kat|ehk|re | ep|ned|nne|onn|ehl| mi|ado|iso|dip| la|hl |h s|awa|hre|ih |sa |a k|at |pw |eki|k p| in|al |wal|ihn|med|ala|ida|ili|g o|neh| du|i n|le |ud |uhd|ahp|hr |id |i e|air|oan|soa|n u|ur | te|hpw|kad|omw|wom|k e|ndi|ond|seu|i s|saw|pa |uku|suk| su|eng|meh|sen|nse|a s|pid|mie|lel|e r|kei|leh|s m|a a|kas|e u|rek|ir |due|hon|uho|n l|ia |our|mou| mo|ewe|aia|kai|lok',
    'agr': 'ain|mai|ai |ina|sh |ash|ent|i a|ich| nu|nts| ae|aen| ai|ama|nai|au |aka|wai|tsu| ta|tik| as|tak|ait| wa|chi|dau|ida|n a|gka|ts |in |uja|shi|u a|aid|cha|am |amu|a a|kam| pu|kic| tu|puj|i t|nun|kan|ak | ti|sa |k a|h a|hi |aja|iki|an |num|ima|unu|ch |ush|nma|agk| ni|m a| an|ui |uma|uju|ham|tai|its|uk |ag |aku| ag|ish|ata|asa|s a|sui| ch|nii|hic|kas| aj|ja |aya|as |um |kat|i n|usa|tus|a n|ane|mak|nak|ugk|nug|shk| ya|uni|mun|aki|ka |ii |jam|mas|nen| ap|awa|jai|ita|h n|kus|un |tuj| at| ju|na |nia|h t| pa|jum|tin|tka|ake|bau|anm|tsa|umi| um|ats|ig |uti|yam|nja|apu|sag| am|wak|ek |jas|kes|itk|mta|esh|ik |una|hka|ta |ika|ete|suk|nka| ma|k t|uwa|amt|ji |ach|mam| du| di|aun|a t|jin|ink|enj|jut|aju|jun| sh|ais|auj|dut|tan| ak|gke|sam|g a|pu |apa|tas|tek| au|nuw|a p|uwe|eka|amj|nu |tam|ya |aim|jui|n t|chu|bet| be|ntu|kui|u n|gta|i u|a j|uim|tnu|atn|nag|ku |iig|hii|i w|a d|nui|dit|g t|dek| de|aji|kag|gba| ay|ant|n p|may|s p|kma|mu |a w|nta| em|kin|nam|egk|unm|mik|gma|s n|tna| na|hik|uch|paj|ma |h w|jaw|ti |eja|u d|hu |kej| ku|aik|hku| ji|kti|ikt| in|aig|ega|mka|u t| im|ets| et|ikm|kak| yu|iya|inu| un|mat|api|pap|jus|i y|us |emt|iin|wa |agb|iwa| iw|aga|ema|i p|k w|s t|agt|i d|n n|man|mag|m p|i b',
    'quh': 'lla|aj | ka|ta |man|una|sqa|nta|cha|pis|na |an |is | ma|ant|ana|ach|nan|paj|qa |asq|api|anp|qan|ank| ch|kun|a m|ata| ll|chu|nku|ati|kuy|nin|yni|yoj|taj|hay| at|npa|a k|ina|ama|ay |jta|in |ima| ru|lap|wan|iyo|ajt|chi|a p|awa|tiy|j k|spa|ill|laj|yta|aku|niy|uku| pi| wa|ari| tu|tuk|jin| ji|oj |kan|iyn|all|uy |lan|hus|run|iku| im|nma|ayk|pi |isq|a a|mas|ku |a r| uj|yku|sni|kay|asp|tap|tia| ti|jll|pa |may|ipi|mun|nqa| qh|n k| mu|asi|a l|a c| ya|apa|hu |ma |pip|ayq|s a|anm|apu|pil|us |k a|ian|a j|uch|nch| ri|npi|a u|ray|kas| pa|upa|j l|ri |kac|s k|j m|tan|anq|kup|n t|a t|ion|pun|khu|qha|wsa|aws|kaw|j j|pay| as|uma|hik|int| ni|ayn|par|pat|uni|a q| ki|aqa|tin|ayr|kus|iki|kik|rim|was|rua|ris|uri|nra|ayt|qen|yqe|j p|yri|n y|ara|i k|j c|kam|nas|nap|yac|nk |hak|n j|a w|tat|anr|n m| de|aci|ita|taw| sa| ju|sta|ni | su|y r|j r|en | pu| yu|rik|yll|uj |pur|kin|jku|sis|uyt|j t| ja|anc|qac|has|aya|s m|yan|kaj|nwa|cio|u t|nay|ich|mac|asn|jch| qo|uya|a y| re|un |hun|u k|cia|han| un|yqa|ska|usk| kh| le|n l|isp|iyt|tac|nam|upi|yka|waj|n r|war|ayo|ka |sak|one|lig|pac|y k|isn|y a| ta|rin|his|n a|s c|hij| aj|ayl|lam|yma| ay|a s|n c|j q|ojp|lat|nes|nit|n p|pal|uas|juc|ley|s l|kuc|say|las|ijl|mar|har|kap|jpi',
    'tca': ' na|xü̃|rü | rü|ü̃ |ü n| i |na |a n|ma | ng|ngẽ|ü̃x| ta| ĩ |̃ r|̃xü|nam|gu |nax|uü̃|acü| du|duü|a t|üxi|wüx|xgu|üxü|ĩ n| wü|i n|ame|̃ ĩ| nü|me |cü |e n|ẽma|gẽm|gü |wa |chi|nüx|ü̃g|ü t|axü|uxü|a̱x|ixĩ|gẽx|xi |tax|i d|u i|axu|uma|i i|xna|gum|̱xg|ana|exü| ni|ü r|ẽxg|nan|ürü|nix|e̱x|̃ n|nac|xĩ |̃gü|a r|ama|gac|xga|ẽ̱x|ãẽ̱| ãẽ|̱x |u r|ach|üwa|cür|ucü|xuc| ya|tan|rüw|ca̱|gux|ü i|̱xn| e̱|ü e|max|aã |üma| gu| no|u n| me|ã n|a w|orü|nor|̃ma|ü̃c|ü̃ã|ãxü|i w|maã|arü|tex|ü̃m|ẽxü|̃ca|nap| ch|tam|axã| to|xé |exé| te|ata|ang|a ã|nat|rac|ura|pur|yax|xu |mar|meã|cha|̱xe|xex|hix|ãne|chu|eã |ü m| ma|nag|ga |̱ac|ṯa| ṯ|ta |̱xu|u̱x|hu̱|hig|a ĩ|güx|aü̃|haü|a m|̃gu|xẽẽ|üxn|̃́ |ü̃́|ãcü|nge|x r|gü̃|agu|iü̃|hiü|ĩnü|xĩn|igü|ich|xic|a y|x i|axĩ|anü|ĩ d| pu|xma|ixe|̃ãn|atü|xĩx| yi|xwa|to |ẽẽx|xch|ewa|yix|̃ y|i t|xux|cüm|ügü|a i|ü g|o i|ngü|ngu|́ n|ü ĩ|ega| eg|a e|nüẽ|é t| po|ĩ g|wa̱| bu|ẽxm|axc|̃xẽ|a c|nay|apu|pox|apo|mex|ĩxg|gex|ra |era|bux|axw|xũx|axũ|new|a d|ü w|nü |aya|xcu|oxc|i ã|ü c|ĩ ñ|x n|pan|upa|per|ope|pop|ñaã| ña|̃ i|rüü|igu|xig|naw|uxg|ü p|e r|egu|cu |üng|rün|ĩ w|xca|cüx|aux|erü| er|ügu|axõ|xãc|ü d|́ta|ẽ́t|üẽ́|ixu|üü̃|ogü|tog|i p|une|é n|ãgu|nüm|ãma|ne |xüx|ri |xri|xãx|ü̱x|xü̱|̃ e|̃͟ã|ü̃͟|ãrü|amu',
    'chj': ' ds|sa |dsa|a j| e | ju|ía |a e|a d|la | la|u d| jm|ua | sí|a s|a l|i d|e j|uu |li |jua| li| na|ma |a t| a | ki|mo |ki |sía|jmo|jä |ju | jä|na |a n|o d|a k| i | o |i j|ä d|nía| de| gu|rec|e l| ma|ere|der| jn| ní| ñi|ho |cho|ech|ia |ñi |o e|jï | jï|tu | tu|e s|íä |o k| su|a a|e d|i t|jma|a o|i l|ï d| sa|su |nia|kö | kö|a m|ja |a i|síä|tá | fu| ni| ja| ru|sá | tä| tá|suu| lu|fuu|dso|ka | ka|tä |ta | ï |ne | ta|ä e|i k|dsá|dsu|u n|o j| h |a h|iä |lu | ku|nac|jne|i e|a ñ|u j|ï j|tï | tï| si|ue | ji|o m|u l|u t|e a| ti|á e|gua|ru |u s|ací|e t|i n|á d|ä k|a g|ti |ä j|a r|ba | ba|kuu|ä n|e n|iö |tö |u g|dsi|eé |kä | kä|á l|u a| sï|ä a|uú |h i|jni|ö ñ|siä|juu|íá |ö s|aci| tö|ji |o g|si |ä l|así| as|no |o s|i g| vo|oó |a ï|juú|ie |jní|á j| é |ni |mi |íö |eli|síá| ej|ciö|uí |guí|i m|oo | un| uu|kï | kï|á k|so |e i|i s|o t|ï t|ï e| tí| ie|uá | le|u e|ö l|ö n|uï |guï|ï k|cío|cíö|o n|a f|ö k|uo |e k|ui |gui| mo| lí|rue|sia|soó|a u|o l| re|u ñ| jí|o i|vo |co |i o|juá|rac|ara|lar|cla|ecl|dec|ï l| mi|hi |jue|tíä|ö e|lig|rel|u k|é f| go|ö j|e m|á n|a v|í l| kí|u m|ó d| ó |a ó| í | no|u o|soo|i ñ|o ñ|un |h u|á o|leé|ú d| jú| u |u u|mu |í j|jí |ï g|ï a| jo| je|ïá |sïá|ïa |lá | lá|i b| – |geé| ge|chi',
    'kwi': 'az | wa|kaz| ka|an | m |pa |tpa|ai |nit| ni|wan|awa|kas|ne |nka|m j| ma|aka|it |ama|na |chi|aru|as |mak| su|ant|asa|ara|cha| an|tus|a w| pa|n k|in |rus|atp|paz| ku|ntu|a a|nta|a k|mai| ch|ura| ja|a m|sa |kit|pai|wat|itp|maz|ain|kpa|akp|kal|war|sun|z k|t t|wai|kar| aw|t n|a p| p |aza|t m|us |n p|pam|m n|za |n m|spa|usp|ran|ion| pu|z p| nk|at |n n|z w|taw|alk|ach|ra |pur|int|ash| sa|cio|ska|a s|ane|a n| t |tak|z m|aki|min|hiw|iwa|ana|jat|ruz|tar|usk|z a|jma| jm| au|kai|lka|mam|hi |uz |ish|n a| n |unk|i a| pi|aci|alt|jan|al | tp| na|ltu|kua|hat|kam|un |zna|s w|i w|uka|ta |rak|tuz|miz|i k|tm |atm|ent|nte|sha|z s|ika|onk|wua|izn|nma|anm|usa|s k|p n|ais|nti|unt|i m|z n|au |mas|m l|pak|kui| nt|uru|e m|ici| in|ual|s m|tch|wa |han|hin|tpu|sai|kan|n s|uin|ar | ki|par|a t|ait|nna|kaw|p p|zpa|uzp| tu|ita|ha |sar|i n|s a| mi|t p|lki|was|lta|e s|pas|akt|ann|rai|aiz|n w|zka|t k|npa|ina|r t|ian|ram|ami|amm|itm|z i|apt|e a|i p|itu|ter|a i|raw|kun|kta|hik|pia|ial|cia|nal|nac| up|z u|pit|uan| h |k h|nk |hna|s n|mtu|shi|lne|aln|h k|a c|ciu|san|sht|ank|uma|tur|i s|tip|tra|tmi|ten|ist|uch| wu|puz|lmi|ira|e w|shn|amt|kin|ink|tne|sur|wac|kul|a u|ail|sam|iun|pta|nak|p r| is|men|una| pr|nam| us|tua|ien|uai',
    'rgn': 'la |oun| la| e |un | di|iou|na |una|a l|da |zio| pr|a p| da|ét |rét|dir|iré|a s|per| pe| ad|à d| à |ad |sa |a d|ers| in|ta |ni |tà |rso|sou|i p|azi|gni|nt | su|a à| cu| m | un|ènt|ogn| og| dl|a c|èsa| ma|ia | i |a a|za |mèn| o |pro|su |t d|li |a e| ès|t m| st|ma |a u| co| li|nza|i d|in |dla|di |e m|stè|t e|int|ità|ii | ri| al|cun|e d|i s|m l| l |i e|amè|a i|n c|a t| qu| pu|n s|ich|ra |rop|ter| ni|sia|ita|ber|ibe|lib|a o|umè| el|a n|a m| si| u |el |sun|si | re|our|n a|unt| to|ché|l i|e l| de|u s|qua|naz|n p|ist|rtà|ert|ent| ch|ti |cum| d |a è|i o|e p|l d|èl |nte|isu|nis|rì |nta|pre| tl|al |e a|à e|tot|èda|èla|opi|tra| pa|sta|rà |ndi|ual|ali|prì|t i|sci|n e|n d|ri |ot |uzi| c |ois|tèd|gio|dis|raz|i a|ch |t a|e i|d c|èri|i l|pri|tri|a f|rim|uni|ost| sc|put|nd |izi|ara|sèn|ènz| se| at|d r|nit|dli|zi |op | ar|n o|nda|és |ntr|m u|à è|trà|utr|vit|str|eri| te|is |nèl| gi|und|ric|chi|cié|imi|i c|i à| du|soc| ci|bli| po|a g|esi|men|hés|uèl|ina|i i| so|ind|art|i m|unè|èd |cou|n l|cit|iél|lit| na|ca |ica|tic|lig|eli|d l|ur |sti|dic|res|tla|min| sa|id | è |i n| j |ruz|tru| is|avo|mat|età|pii|d o|tè |a r|p d|ris|tès| pè|ezi|enz|con|u r|and|tur| fo|idi|ran|taz|c l|t o|par|l a|rii|de |iun|asi|ias',
    'oki': ' ko| ag| ch|ey |ogo|gol|tog|et |age|ol |chi|get|eto|man| ne|ima| im|oti|tin|to |ito|iny|ik |hit|po |nye|o a| ng|nda|en |y i|yey|and|l k|kot|che|da |uti|got|ngo|ap | en|epo|kom|it |tik|in |tut|otu|t n|tap|eta| go|ono| em|oma| to|k c|ag |nep|eme|mag|t a|yin|nyi|t k|a k| ke|isi|eny|opo|p k| on| ga|gop|no |agi|gal|ich|t c|nyo|ote|och|iik|rip|neg|ipe| is|iso|ip |gis|nge|tet|yet|osi| pi|a n|net|ago|y k|pet|met|o n|chu|eng|yol|n i|ret|ogi|koy|ei |asi|gas|sit| so|sip|omo|tie|kop| ka|pii|y a|erg|gey|ani|ege|ge |n e|l c|cho|on |hi |ak | ak|i k|ete|ig |ut |opu|p n|mog|ali| ri|men|egi| ti|ale|op |hig|ony| iy|k k|n k|kos|ine|set|key|ane|y g|som|y n|hep|ji |o g|oto|emo|ore|o k|o e|ch |top| ot|kon|an |ati|g k|ser| se|hey|l g|ay |l n|ger|ita|nit|ech|ini| ki|n a|n c|t o|ere|iye|k a| te|i t|nga| ta|hon|gei|t e|gig|sin|iag|tia|k t|log| lo|tic|gog|omu|rga|hut|nik|o c|put| ma|pun|gin|p s|t i|gip|iet|n o|kch|non|ok |oso|sye|isy|t t|ept|tep|oyo|iyo|not|gom|n t|kat|oy |esi|tor|ek |ese|lit|ra |ewe|ipa|n n|yay|uch|sos|o s|lji|olj|y e|oya|at |ois|k o|ong|ait|ama|e t| or|kap|epi|taa|sic|omi|p t|pto|u k|olu|yon|igi|igo|i r|goy|ing|nes|tes|ego|o r|hu |wen|lew|koc| sa|y c| in|n g|y s|mut|tey|ney|pan|ora|pey|g g',
    'tob': 'da | da|axa| qa|ata| na| ca|taq|ca |aq |ac | hu|shi|o o|a a|na |a l|uo |huo| ot|a q|aua|chi|ayi|a n|ta |tax|t d|pi |xac| en|yi |gue|ec |may|ota| ma|qat|ena|qai|c n|it |hit|ish|a h| la|a i|aỹa| a |igu|cam|am |nau| ỹa| is|q d|gui|ama|hig|ana|ỹax|at |a ỹ|uac|nat|a s|i o|iỹa| o | sa|i q|hiỹ|a d|ala|lat|aqt|a c|o c|i n|xau| sh|lec|i i|c c|aic|qta|hua| al|ach|hi |c d|agu|en |xan|qan|eta|a m| i |ua |e e|egu|ot |uen|eet|i d|qaỹ|xat|ai | ch|ui |api|ue |t c|nax|sat|hue|uap|uet|lhu|a e|c q| t |ape|tac|nac| ll|ane|ale|ỹa |ỹat|i c|t n|i m|n d| l |a t|i e|c h|ica|ii |tta|lli|lla|asa| ee|uii|oỹi|qoỹ| ne|cha|ipi|cpi|iue|lỹa|ic |q e|ues|i h| on|sa |alh| iu|lal|peg|max|i s|ash|nam| lỹ|och|ona|laq|m l|ỹin|t q|ich|ais|acp|uax|ỹam|uec|qal|lic|ita|ỹaỹ|sai|et |lap| nt|ott|in |nqo|anq|ne |qch|pax|nta|q c|aqa|alo|uas|esa|u a| ỹo|q n| am| de|to |ilo|lax|tag|ga |q q|tec|ete|l a|i l|c m|em |ail|eda|m d|n a|ỹot|o n|yip|mai|nqa|que|de | ya|eu | nq|oua|sou|apa|xa |nap|laỹ|l o|xag|oxo|ole|ate|nec|aqc|nan|q i|qto|yaq|a y|tap|uem|ill|c e|iit|hii| ed| ay|lot| il|nal|aan|lo |ỹal|tau| no|co |q ỹ|ivi| iv|m n|ỹau|ha |qpi|aqp|lam|oqt|igo|ỹaa| aq| ai|cho|n n| n |maq|ite|m h|teg|tee|neg|ỹip|ote|e c|lpi|t i|aca|tai|q s|saq',
    'guu': ' th|thë|hë |ë p| pë|pë |i t|wë |ë t|ham|mi |oti|a t|ma |amo| rë|hit|ë k|awë|ihi|tha| ha|ou |rë | ku|ima|ai | to|iti|tim|ami|pra|ë r|mot|ë h|hi |i h| no|ni |kãi| kã|tot|ãi |tih|ama|taw| hi|ita| ri|iã |riã| ã | wã| sh|ha |he |i r|i k|omi|mai|ei |ë ã|tit|ã r|raw|ë n|mou|iwë|tiw|iha|i p|no |ohi|o t| ta|u t|ëni| ih| ma|ehe|ëri|upr|kup|ë i| ai| pa|ë w| ka|noh|rih|tao|ë s|kam|pi |hã | he|aom|peh|i a|për|ã t|ui |kui| pe|uri|ãhã|opë|ao |uhi|puh| pu|hap|wei|apo|pën| ur|ã h| hu|pou|hip|wãh|aih|opr|ayo|ë m|oho|hir|ëhë|e t|ata|ĩhĩ|top|sho|wãr| të|pat| ya|rio|ri |eri| ĩh|you|tëh|ari|a p| ko|ipi| wa|hën|hei|par|ã n|ëam|yëk|iyë|piy| pi|ipr|ĩ t|u p|tam|hot|rao|ho |ono|ã k|shi|iwe|ira|kuo|ram|i y|uwe|rai|ota| oh|eti|het|io |her|ith|mop|o k|aiw|rẽ | rẽ|rëa|rou|uwë|rip|sha|hĩ |ii | ay|u h|kom|ẽĩ |ouw|hai|aro| kõ|u k|aya|e k|e h|ëko|ãrĩ|i w|ë a|ë u|a k|the|o w|a h|ewë|ihã|pro|ope|pop|ëma|kua|ãno|ihe|ëyë|oni| mi| a |a a|kou|opo|i m|ti |i n|imo|him|i s|weh|uku|yai|ë o| e |pon|mih|apr|hãn|wëy| wë|har|aha|a u|ta |uo |nos|mam|owẽ|now|rew|o m|ano|owë|suk|usu|rii|o r|toa|ipo|i ĩ|ahe|aia|a r|yao|nah|hër|uam|hat|e p|opi|u w|ore|ã p|ato|mat|wẽĩ|rea|suw| su|way|han|wã |o p|ro |hĩr|kat|ẽ t| us|ëi |õmi|kõm|i e|ëki',
    'qxu': 'nch|chi|his| ka|anc|pas|as |aq |spa|ana|apa|man|paq|una|lla|nan|is |isp|kan| ma|an |ta | ll|a k|cha|na |ech| de|kun|cho|rec|ere|der|ina|nap|wan|pa |hon|onc|mi |taq|aqt|ipa|hin|asp|chu|inc| hi|qa |aku|ach|tin|sqa|i d|qta|pip|awa|hu |asq|kaq|q k|s k| ya|ay | ru|ima|s m|nta|anm|was|npa|pan| pi|ama|yta|anp|hay|ant| ch|tap|nas|k a|lan|nmi|ata|may|a m|in |aqm|qan|lap|ayt|sta|qti|yan|a a|yoq|sma|ism|pi |laq| hu|a r|qmi| ni|ank|q m|uwa|n h| im| wa|all|n k|swa|kus|ari|q h|s l|a l| es|ruw|ati| qa|ma |kas|nin|est|nk |asw|ara| sa|s a|s h|oq |run|ita| at|ist| ay|s y|sku|isk|ion|a p|api|nit|i k|a y| pa| ha|nak|uya|y l|lli|ayn|kay|nat|cio|aci|ypi|has|sar|ayp|s q|mun|qpa|lin| al|huk|a h|q a|n p|nma|a s| ta|ayk|s w|iku| mu|un |yac|aqa|a c|iwa|u n| am|ayo|s i|pak|q p|kam|asi|n l|sun|say|yni|ien|ado|dio|asa|per| qe|uch|a q| as|tan|nku| ju|yku| ca|la |s p|kuy|mac|han|aqp|nac|udi|tud|stu|s e|kll|mar|qni|tad|ios|waw|iyo|niy| ku|unc|ota|par|mpa|amp|usp|a d|qen|yqe|ayq|uez|jue|nqa|ich|a i|rim| ri|pun|ley| le|n m|sin|yay| yu|tiy|kaw|qll|naq|nay| na|a n|usu|dia|akl| ak|sam|n d|nsa|ens|pie|aqn|a e| di|tay| pe|hiw|q w| tu|u c|haw|s o|yma|npi|u l|ni |anq|s s|cia|aya|oqt|hap|yna|huy|pac|s c|s r|rmi|arm|war|sti',
    'pau': ' a |el | ra|ra | ng| ch| el|ngi|l m| ma|cha|ech|ad |had| l | me|l a|ii |gii|ir |ma |i a|lem|eng|mel|nga|che| be|lle|kl | ll|ar |a l|tir|eme|mo |gar|a n|l e|rng|a b| di|a c|l r|arn|elt|a u|hel|a k|ul | mo|l c|d a|okl|ng |lti| ar| kl|l l|ek |il |mal| er|er |ak |mok|eke|lec|k l|bel|elu|ele|ch |k a|bek|mek|lel|men|chu|nge|kle|iak|dia|r b|al |bec|ome|o m|r r| ti|rre|d e|uul|r e|r n| om|lt |edm|ebe|l n|i m|ai |ema|b e|ker|l d|mer|r a|dmo| se| en|ub |cho| te|ung|hub|ale|rek|uch| lo|lmo|a i|l t|tel|a o|k e|ruu|eru|a d|a s|ang| e |a m|isi|ilm| il|a t|r m| ul|alt|kel|aik|del|r t|ll |a r|seb|ekl|ked|it |lse|l k| am|h r|len| bu|irr| uc|dec|l o| un|u a|uld|sis|osi|t e|luu|ach|dir| bl|r l|gil|i e|r c|rir|sel|iil|chi|amo|ngm|d l|uu |era|uai|lek| ro|tia|dil| ur|gmo|gdi|ngd|lac|bua|hul| le|rel|eli|d m|iu |ged| de|gal|reo|git|lte|ike|or |hos|mor|eri|muk|ull|l b|dim|e d|u m|i r|l u|ode|edu|kla|siu|eor|els|lk |alk|t r|akl| ke|ed |ube|kli|d r|kir|als| al|oi |bai|ika|rar|u e|i l|ui |gui|ogu|rog| re|ukl|sec|olt|g m|err|all|bed|l s|ial|lir|o c|urr|o s|ude|h e|ble|id |lou|lal|e m|lde|ios|dio|ell|t m| sk|gul|ngu|eld|hed| ou|imu|ldi| lu|lun|g a|kng|su |lda|t a|um |me |idi|lla|dal|ire|o o|eku| si|di |lul|rii',
    'shp': ' ja|qui|i j|hue|ui |on |iqu|ahu| iq|que|jah|bi |a j|ra |i i|ti |ash|n j|ues|ain| hu|sho|sca|ama|hon|ati|jat|esc|uet| jo|oni|an |ato|nbi|ino|jon|aqu|bo |jai|in |a i|sh |uin|tsa|ets|bir|ira|abi|nan|ma | qu|equ|ueq|ima|ian|mab|tia|ja |ora|onb|noa|con|ana|to |res|a a|oas| yo|cam|ibi|est|iti|shi|non|tim|ai |nti| ic|uen|sti|can|aca| ac|n a|nsh|ibo|équ|hué|en |uéq| ma|abo|n i|rib|i h|h j|aco|ton| be|ina|eti|sa | sh|asc|jac|ant|jas|mai|ish|i a| es|caa|o j| co|ni |hin|mat| in|nma|yoi|apo|sab| at|aon|ins|na |bao|nin|atí|osh| ap|es |ene|o a|a h|pon| te|cá |ire|tio|ara| aq|iri| is|ona|ior|nib|cat|i q|onm|tir|i c|rab|oia|nra|s h|o i|iai|n y|mas| on|ena|icá| it|n s|are|car|yam|een|era|tíb|tí |esé|nco|ran|i s|bor|ica| ts|uee|nen|sen| se| ca|ari|n b|iba|íbi|ich|ata|h h|maa|ben|ait|n h|nha|anr|tso|n q|tee|tan|eta|í j|o b|jan|aba|aas|enb|cas|cos|n m|a m|anb|acá|ca |cop|ico|inc| ra|aat| bi|i y| me|cai|bia|sha| ba|a b|n e|nqu|sé |anc|man|onr|inb|aya|i t|bet|ebo|oa |n c|int| as|mea|hib|nai|scá|a q|iam|i n|as |ano|tas|í i|baq|ema|nbo| na| no| ia|nca|opí|oma|hui|son|she|bí |bic| h |a t|rat| ar|maq|uer| im|n r|n p|i m|nos|n t|a e|inm|joi|uir|mer|aaq|a c|ue | pi| am|uib|obo|apa|cho|o y|j a| j |anq|nme|oca',
    'gug': ' ha|ha |ere|a o|pe |vo |ich|rek|ra |ko |cha|rã |aʼe|va |ech| de|eko|cho|der|ogu|gua|ho |rec| og|gue| ma|uer|e h|agu|a h|may|e o|o d|ete|aym| he| pe| te| oi|o h|te |o o|yma| oj| oñ|hag|uér|ma |erã|e m|éra|oje|ua |mba| re|oñe|ve |i o|etã|kué|upe|ʼer|vaʼ| av|a i| va|baʼ| ku|por|oik|óra| yv|pet|gui|a t|re |a y|nte|ave|ión|pór| nd|a m|ypó|yvy| om|ñem|iko|kat|vyp|hup|emb|vei|e i| je|ad |a r|ava|jep|ekó|apo|ui |óvo| ic|mbi| mb|a a|upi|ika|kóv|chu|end|épe|o p| té|haʼ|ehe|omb|áic|nda|o i|tet|érã|tér|ñan|ei |a k|ipo| ko|ta |are|e p|ávo|ón |ter|ció|aci| op|mbo|ã o|het|ive|rup|egu| up|hes|gar|vav|áva|ora|a j|pa |dad|po |bia|emo|se |ese|nde|api|jeh|ang|amb|tã |ʼe |ara|a l|teĩ|yre|tel|hái|iap|e a|nga|and|ite|atú|aik|e n|pic|pyr|e t|ngu|kua|apy|de | ñe| ta|opy|ndo|avo|rav|cie|oci|soc|ã h|orã|atu|ʼyr|apó|epe| oh|éi |i h|ait|i t|tem|avé|tap|o a|epo|eve| so|ert|ndi|ond|pi | ru| ik|e v| há|o v| ja|o k|mi |umi| um|ape|óva|léi| lé|a p|dai|guá|o t|ue |men|epy|eda|ied|a n|eic|tad|rta|ber|ibe|lib| li|div|gué| ip|uaa|ida|pyt| iñ| im|u h|koʼ|e k|py |ime|e j|úi |túi|ide| id|oʼã|al |eña|ñeñ|ant|opa|vai|o m|ã t|ers|kov|évo|ʼev| na|aʼé|lig|eli|eʼẽ|imb| oĩ|cla|éva|tu |nid|ĩch|ʼap|aʼa|póv|ápe|da |el |ndu|uni|rõ ',
    'mzi': ' ng|nga|a n|jin|tse|ga | ts|a k|ngo|se |in | ko|n n|xi |kui| ku|en | xi| xu| ta|ndi|jua|a t|kju|tji|uta|xut|jo | kj|e n|i n|ta |ojo| tj|i k|e k|i t|n k|o n|n t|nda|’a |a x|e x| nd|ama|goj|ind|o t|ie |ko |je |yij|ma |ots|sie|ni |kji| ka|chj|on |ua |jen|e t|ije|ya |ee |een| na|i x|sen|ats|tsi|xki|n x|ngi|ui |iya|ini|go |a s|kot|ang| xk|nkj|die|gay|see|axk| ma|aji|kam|ink|kiy|iee| ch|ani|ixi|ayi|tsa|jot|o x|ian|and|din| se|da |y’a|eng|t’a|gat|uin|ia |na |jmi|nix|gan|tax|nan|min|ay’|o k|an |eje|nia|xko|koj|ien| ni|kon|ii |hje| ki| jm|tan|sia|kue| sk|atj|ach| yi|iko|tay|dse|nax|a c|a m|kja|jii|xti| mi|gi |maj|ti |aa | ba|aki|nds|gon|itj|jni|osi|kos|ndo|ikj|i m|áa |kat| si|nt’| nt|axi|iti|akj|ijo|a j| ti|ima|ich|enx|xin|sko|mat|kit|uak|do |o j|nri|sob|e s|iji|hji|jon|taj|ki |bat|un |jit|daj|end| en|kie|kok|cha|ond|tja|nxi|son|chi|ona|i s|ri |inr|jee|mac|sik|jia|eji|be |its|jun|uju|xuj|okj|xch| xt|gin|mej| je|tin|uee|i b|tik|ton|int|xim|eni|isi|ajo|n s|sej|jaa|e m|íi |tje|abe|ón |ánd|uit|inx|ina|nch|a’a|a b|aya|jam|ijn|tjo|enj|dik|oni|njo|tas|cho|oji|a y| so|óo |n y|báa|obá|nji|anj|oti|ena|ajm|it’|sku|oko|tok|ata|max|año|xáa|n m|jón|tit|axc|hjí|inc|nán|iná|tjó| me|kix|tso|ask|tim|iin|oba',
    'mic': 'ta’| we| ta|a’n| ki|kis|’n | te|it |n t|tel|aqa|aqq|en |qq | aq|wen|’ta|qan|taq|sit|koq|ik |o’t|na | ko|sna|isn|n w|asi|msi|mit|t w|waj|oqw|sik|qwa|isi|n k|eli|jo’|ajo| ms|in |an | ma|wej|ij |k k|jku|ejk|si |eke|li |te’|a’t|t k|’aq|sin|q t|tek|ksi|sut|tas|luk|e’w|qmi|aqm|lsu|tij|n m|jit|n a|k m|i a|uks|k t|nik|ika|ey |oqo|la’| ke| al|wji| wj|uk |new| ne|k a|ew |q w|ite|ukw|t t| tl|kul|als|iji|’te|na’|ele| el| wi|wla|nn |ita|wa’|’wa|j k|tuk|e’t|ult|k w|maw|lam|j t|inu|’ti|uta|ke’|sij|muk|kwe|ann|l’a|ul’|tmu|maj| mi|a’s|asu|a k|j a|n p|ami|ewt|lti|kin|tew|kwa|uti|ank|lek|ela|wik|tet|min|aq |qoe|ek |a’k|i k|tla|’l |’k | ap|a m|’ki|ma’|tli|a t|’si|pas| pa|ikt| wl|kl |ku’|q k|ett|wte|ima|ala| na|i t|utm|q m| ik|n n|ewe|qam|oey|uj |e’k|ej |ktu|ikn|la |kas|u’a|tl |sum|wij|wes|aju|mim|o’m|ina|’tu|mu | mu|j w|j m|pla|mk |nuk|’mi|a’m|ama|e’l|a’ |kej|uku|ket|a w|l w|tt |jik|aj |mal|i’t|ki’|kit|w t|ate|kun|kat|lit|iw |jiw|a’l| kw|ani|kew|muj| et|t e|amu|usu|mut|’tm|esk|l a|u k|tma|las|tmi|uaq|awi|ti’|ams|ui’|i’l|nut|nmu|man|mi |lo’|mas|imk|el |tik| sa|lta|a n|a a|kui|i i|etl|i w|puk|tu’|etu|’ka|i’k|ewi|q a|l m|sul|t m|ti |wek|wat|kut|i’a|itk|wmi| wm|i m|maq|tal|nki|apa|et |n e|ken|ati|l t| nu',
    'haw': 'ka | ka|na | i |ana|e k|a i|ke |a m|i k|a h|a a|nā | ke| nā| ‘a| a | ho|o k|ho’| ma|ia |a n|le |a k|a ‘| no| ‘i|aka| me| o |o’o|nak| kā|au |ua |‘ia|‘an| e |me |no |kān|i n|ole|e ‘|oa |ā k|āna| ‘o|apa|ma | ua|pau|ai |a o| ap|ona|noa|ono|i ‘| ko|ale|a p|pon|u k|aup|’i |o ‘| po|‘ol|han|e n|ni |uni|a l| kū|pun|upu| au|kan|’ok| ha|oho| pa|e a|’a |a u|a’a|i h|noh|a e|ike|ho |o’i|wai|la |o a|a’o|kon|e h|a w|kau|i m|i a| he|ahi|pal|’ol| wa|lu |kah| lo|mal|a’e|e m| ku|hi |‘a’| ai|na’|man|u ‘|oko|pa’|u a|aha|ina|ui |ila| kī|ā p|oha|e e|’e |i i|eka|ha |vil|īvi|kīv|lik|ehu|leh|o n|i e|ule|e i|oka|’o |ano|ulu|umu|ea |āwa|nāw|ānā|he |i o|e p|i u| lu|loa|ku |ā a| mā|mea|a’i|’op|kūl|ā m|’om|hui|hō’| hō| kē|’on|una|u l|ko’|kū’|kai|law|mak|ele|aku| wā|ao |kum|i p|lek|āin| a’|oma|ae |ō’i| la|o’a|awe|āul|iāu|aiā| hu|’au|wā | le|mu |wal|wa |kua|ena|ē a|‘ē | ‘ē|lo |li |ili| lā|’ik|ēia|kēi|mai|lun| li|ū’o|uao|aua|ela|ka’|hon|iki|ama|ala|ewa|e u|opa|ino|uhi|alu|ola|hu |kul|lan|ne |o m|la’|ā l|ha’|o o|‘oh| ak|lam|āla|māl|u i|hul|mua|olo|ā h|opo| an|len|o i|ko | mu|ūla|pah|pil| ‘ā|ika|u o|kae|o l|no’|u m|e l|mau|mo |omo|kom|koh|ki |ū ‘|lā |e’a|hew|i’i|u e|oin|oku|ā ‘|hia|luh|hal|e o|‘o |lok|iwa|aiw| pi|oli',
    'yap': ' ng| ma| ni|ni |nge|en |n n|ge | e | ko|ko |ne |ay | fa|bin|nga|ii | ba|in |mat|e g| ro|att| gi|ttʼ|idi|tʼa|dii|gid|och|ʼaw|e m|wen|awe|ara|gub|ubi|y m|i m|ine| gu|kʼ |ra |aa | na|el |am |bay|an |okʼ|rok|i n|aba|mab|cha|n e|g n| ta| ar|ngi|boc|ng | mo|e n|chi|on | u |eg |e t|nam|ang|i b|ane|y n| ga| ya|n k|iy | da|ogo|gin|iye|l n|n b|i g|w n|oto|mot| be|l k|rog|aw |uw |e k| bi|toc|e b|bee|a n|re |gon|uf |fan|ach|ch |ee | ch|lan|apa|mar|hiy|baa|che|ag |puf|nib|wel|obo|lob|rwe|arw|o n|reb|are|ʼ n|e a|il |ab |ban|haa|olo| ol| i |yel|gak|o f|dab|riy|yal| ka| re| ti|tin|m n|tay|iti| mi|ey |ayu| pu| la|len|han| bo| pi|ma |yuw| ay|owa|e p|akʼ|a b|far|fac|aku|mak| ku|ali|ga |un |m r|ina|a i|ing|i k|kan|ir |ig |a m|age|b n|ita|n m| zi| ne|ba |yan|e r|ow |abi|tir|lʼ |paa|ʼ g|i y|ung|now| ri|kub|fa |d n|gar|lun|liy|naw| yo|i o| ke|e y|l m|ano|gaa|zil|i d|kʼe|tal|aen|ama| ra|ada|ney|n g|u l|a p|r n|a f|w m|y e|ar |taf|ulu|g k|aar| ge|wae|ʼe |bo |ebo|gan|a e|nʼe|anʼ| yu|mit|mad|bap|ani|ale|kul|oro|ul |f r|gey|gen|nag|ite|nin|w k|g g|e l|o g|iro|g f|hig|nit|rba| pa|uer|kue|ʼen|al | am|n f|ram|a r|gi |e c|ed | er|iya|iba|man|fel|sku|r r|w r|row|ol |ffe|aff| un|gay|awa|uba|he |g a|fap|ʼ u|tab|i t',
    'cbt': 'huë|ya |hua| hu|a n| ya|a h|ina|so |na |uër|chi| ni|hin| no| co|uë |rin|aso|aca|quë|ëri| na|ach|in |cas|o y|api|a i| in|pi |co |poa|ohu|ua |npo|ahu|a c|opi|oya|noy|inp|a a| pa|an |nan|ta |sha|ëhu|nap|nhu| ma| sa|inh|no |ana| pi|uac|ha | a |a p|ipi|o n|a y|oa | an|ë n|n n|pin|ita|arë|uën| qu|tër|toh|cat|mar|nin|nto|ata|ëra| ip|pit|pir|nis|ant|tac|ë c|n a|nta|ish|yap|iya|o m|o t| të|ma |ërë|piy|ran|i p|iso|o s|a s|aqu|atë|rë |nën|ën |ais|sac|uan|nac|i n|rno|irn|cop|tëh|yon|sa |ë a|cai|top|ton|rëh|oro| ca|pah|ani|int|pac|hui|ins|n q|on |nit|ëqu|n c| to| sh|iri|ato|apo|ito|nqu|ont|oas|i c|noh|nip|ënt|ihu|n i|tah|ona|coi|tëq|ro |o p|ë p|n p|anë|ënp|ica|ino|ni |oin|a m|qui|ëca|ain|nat|par|nso|nch|a t|naq|ian|pia|oso|ini|uat|itë|o i|npa|cha|ri |ama|ë y|ntë|a q|cac|onq|oca|npi|o c|hi |hac|o a|i s|tin|ari|ënë| ch|soh| am| pë|san|ima|uir| yo|n y|sor|nos|iyo|niy|rëc| ac|i y|son|pat|n h|inc|ra |i i|pa |shi| ta|map| po|uëc|pën|ori|nti|onp|pih|nor|apa|i t|ëma|uëm|uar|pop|och|anp|roc|ayo|uay|i h|uai|o h|aro|i a|ti |rti|art|asa|ash|uëa|ëtë|uët|ano| im|ara|poc|a e|ela|uel|cue|scu|esc| es|aco|rët|ëch|ion|hit|ota|uic|ira|isë|ois|tar|n s| as|ipa|iqu|ëa |uah|non|tot|can|oi |ëta|mac| so|i m|con|ë i|uas',
    'ame': ' ñe|et |ene|a a|ñeñ|eñt|net|ch | am|ech|t ̃| po|ama|en |a t|che| at|all|err|uen|ma |pa | ña| ye|̃a |hue|ha |ñt |am̃| al|ach|rra|yen|e ñ|ohu|ra | ch| ̃ |ñam|m̃a|po |ena|a e|t ñ|a ñ| pa|ere|esh|heñ| e |ret|t a|eñe|rec| de|ñe | t |a y| co|cho|llo| ac|der|tt̃|att| o |na |tet|sha|cha|ñer|are|t̃e|n a|et̃|ñt̃|tse|o c|t e|̃ a|a m|ate|c̈h|loh|arr| ec|nes|o ñ|tar|ets|a p|o p|hen| ts|och| m |ho |t p| er|mue|t̃o|ñet| añ|oct|coh| es|o a|ten| ta|poc|ats|h a|ane|añ |t̃ |a c|sen|ñen|e a|ota|ese|pue|ent|epa|ata|o o|eñ |e p|h e|s a|tye|rro|mac|te |cte|t̃a|̃oc|sa |er |os |ro |s ñ|rr |nen|to |e c|cma|pat|̃pa|apa|̃ch|ot̃|hos|hye|chy|r p|t d|tat|h c|par| mu|e t|t̃t| eñ|eto| yo|set|t̃p|t̃c|tan|cop|o t|yec|she|yes|lle|uas|rua|aru|ña |op |mpo| ar|ahu|̃te|es |tsa|ye |nan|ñ ñ|eña|ana|uel|̈ha| en|ñec|ey |ame|m e|uet| pu|a n| an|ts |ete|hua|ell|o m| na|no |pon|lpo|llp|̃ec|sro|tsr|e o|̃ p|pen| pe|eño|h y|n ñ|nta|asa|rre|tañ|teñ|ecm|ant|pot|an |emp|r e|cot|que|ec̈|añe|nte|̃e |as |ses|ser|n p|n e|̃ c|ñ d|ora|oc̈|on |amo| sh|eco|nar|uer|uep|orr|ñ p|ñot|eno|n d|n y|ñal|o y| ma|̃ e|tep|het|ñoc|aye|p ñ|amu|̃ey|oya|̃ar|rot|tso|mo |ñ a|eye|yor|mar|tã|ta | ya|hat|o d|tam|r ñ|llc|enp| te|map|ll |nac|ar | t̃| or|ann| ̃a',
    'gyr': 'ra |atu| av|kat|ko |eko|rek|tu |kwa|ava|ae |mbo|ei |se |va |a o| oi| va|ave| mb|e o| op|ar |aka| nd|opa|vei|pak|ira| ya|oik| gw|pe |u a|a a|amb|iya|vae|ekw|ua |chi| re|wa |gwa|bua| am|bae|mba|emb|a p|vir| vi|mbu|i o|ika| te| ko|ire|ese| pi|e a|yai| se|sa |ri |nga|e i|e y|ve |a v|i a|ta |nda|gar|ure|yur| yu|a i|pri| oy|ung|nun|tek|ëi |aër|vaë|nde|ai |ndi|boe|ëra|i v|a y|and|bor|ora|ete|oya|o o|ere|ota|a m|a t|koi|ipe|yan|te |inu| in|pip|e m|e r|o y|yem| ye|imb|oro| ch|era| ru|res|diy|mbi|a n|end|a g|rer|gwe|e n|yav| iy| ñe|ara|wai|epi|pi |oi | o |e v|i i|ipo|i n|tei|ite|o v|upi|e s|i k|upe|pot|de |okw|asu|was|hir|ich|oye|avi|o i| po|ndo|ase|rup|apo|aik|ke |hia|ach|ikw|a r|i y|oñe|isa|oet| im|sek|i s|upr|tup|eir| ei|po |chu|oim|tëi| su|a s|o a|ise|pia|ia | ip|hup|aer|e k| om|ime|su |tas|sui|war| ik|ñep|eta|emo|eis|por|u v|ore|o m|u o|asa| ae|e t|iko|ita|ait|rok|ose| os|r a|a k|er |rai|kor|i t|yap|par|ui |pis|a ñ|mo | ke|iro|wac|pëi|kua|moñ|ipi|no |bim| ño|iap|ño |r r| të|omb| ve|aei|rav|o k|pit|oip|ndu|mon|tui| ra|o r|isi|apr|u p|pir|ya |aya|dae|i p|epë|ñet|sar|igw|iki|vik|esa|opi|rop|ike|tar|bot|ipa|iet|oit|omo|sep|ako| ak|sir|r o|i r|uve|rep|are|umo|rum|roy|osa| oñ|epe|yep| ai|eku',
    'vep': 'en |iže| i |el |ehe|ikt| va|oik|ktu| oi| om|an |den|nda|da | me|tuz|om |ide|he |z’ |uz’|l o|hiž| ka|use| jo|meh|aha|žel|end|val|ele|m o|le |ahi|gah| te|oga|jog| ü|ha |dan|id |ali|hel|ude|vai| ra|ald|l m|ai |tus|̈ht|üh|iži| mu|kai|ta | ku|und|ed |kon| ta| ko|uda|n k|äne|e m|lda|liž| ol|toi|tud|iš |es |ndu|hän| hä|as |kun|iče|oid|a m|ahv|tad|ud |dus|ada|nen| sa|ei | ei|i s|oma|n t|mug|hva|rah| ni|d i|voi|a i|ita| mi|oiž|aik|sel|sta|n p| ma|n v|ija|i v|e k|e t|rad|žid|il |n a|žeh|čen|al |išt|vah|d o| to|tar|nd |e o|n i|itu|dam|teg|pid|i t|mat|a k|oli|ze |hte|i k|len|oit| el|n m| si|čče|ad | ič|ičč|e i|hth|old|uga|ona|dah|päi|žen|a t|mel|d m|pen|ope|thi|žo |ažo|gaž|uzi|amb|kud|ego|nik| pi|äi |esk|kes|n o|eht|sa |idä|d k| ke|jan| ne|iž |sen|usi|eze|in |arb|ado|miž|and|ust|tom|i p|teh|elo|lit| us| po|nec|ma |miš|i o|rvo|arv|čez| vo| tä|zid|ami|tam|kan|a u|ugo|zoi|i m|iki|a e|eda|ike|ho |oho|sid|aič|n s|on | so|ond|sko|itt|ihe|jas|dud|iše|i h|des|ahu|jou| su|biž|rbi|seh|dku|ldk|d j|ole|gen|aja|a v|nz |spä|aht|nan|ast|e h|n j|hol| ho|jal|man| pa|što|ial|usk|n r|cij|adu|še |ne |oin|el’|hud|eji|tej|n u|hta|daj|oud| op|i u|doi|s t|täu|s v| ez|dal|tah|roi|n e|ako|zak| za|goi|änd| pe| vä|nai',
    'cpu': 'ri |tzi|ant|iri|ari|tsi|ica|aye|nta| ir|i i|atz|ca |tya|zir|yet|i o|aar|i a|a i|yaa|ro |iro|shi|ni |ita|can|ait|eri|aca|ric|ter|yee|car|tha|ero|aro|ash|eta|zi |ats|te |oca|i t|que|ine| at|e i| te| oc|nca|pit| in|qui|een|ya |mpi|eni|si | ee|aan|pay|ira|cov| on|eet|tai|tac|a o|amp|caa|apa|inc|ñaa|zim|ara|ima|ipa| ca|aqu|sic|tar|ava|ova| ts|hin|ite|ntz|tay|i j|rir|a a|ne |aty| ar|ota|nty|ity|tat|o i|nam|ori|etz|ame|ror|ta |vai|ron|nqu|ata|eer|cam|onc|eva|i c| pa| ap|ina|o o|oni|jev| o |hat|ete| ic|cat|eth|mee|e o|taq|tan|rat|a t| im| na|i e|ran|par|e a|aac|pai|its|iya|mat| ja|i n|i p|int|nco|ove|ent|pas|air|eej|rip|nts|nte|tav|jat|api|ue |ont|per|ety|oña|san|anq|aco|sir|eja| iñ| je|tye|aap|omp|iña|uer|aay|ith| os|rin|ma |ana| om|eca|tec|ui |uem|ema|o t| an|hit|iyo|raa|ra |vat|aiy|ye |vac|net|ate|hir|imo|riy|yot|tem|pin|imp|itz|har|iqu|opa|inq|var|mpa|emi|ath|a j|uin|aat|taa|mit|ven|jan|uit|osa| is|maa|vas|sin|cha| tz| ip|oye|roo|cai|ape|roc|ire|pat|rov|equ|a p|poñ|rot|o a|nat|aav|e e| ma|ner|ai |osh|imi|tas|mpe|aas|era|e t|sip|ha |ije| op|vay|a e|otz|ico|ve |iry|aña|ane|ish|ote|ani|man|oqu|rom|gai|aga|o j|a c|iye|ach|ren|mi | pi|hañ|iva|sit| ij|mon|cot|roñ|vet|ave|o c|nin|oco| ot|rii',
    'acu': 'ain| ai|ai | tu|tai|ina|nui|ita|uit| nu|ha |ash|i t|int|tur|ngk|inu|chi|tin|ura|nau|sha|a n|sar|nts|art| ni|iki|rti|rin|i a|ar |cha|ka |ich|tsu|gka|ts |usa|u a|ras|a a|ang|kia| ch|in |au |nun|ker| wa| ma|ni | pa|sh |suk|kic|ach|puj| pu|mas|uk |tus|awa|ra |tnu|atn|hik|nu |aka|uju|ch |a t|nin|ia |aya|asa|amt|gke|eng|aun|kar|u n|un |iar|nch|kan|ari|pac| na|uri|h n|ish|i n|n p|ung|h a|mta|ri |uka|jus|kat| ta|kam|a p|pen| pe|war|wak|ern|its|r n|er |uwa|ake| as|nak|aki|nuw|ti |tak|una|ata|an | ak|s a|rno|ier|bie|obi|gob| go|rar|ara|nan|n a|a m|r p|nam|ram|hit|a c| ap|ing|ng |nti| an|no |k a|apu|tan|sri|eka|wai|nma|anm|ana|aik|inc|hat|tra| aw|ami|hti|sht|uch| yu|u t|uni|ush|jai|ya |k p|ama|mia|s m|aar|iis| in|uja| aa|tim|may|tek|ete|met| me|run|rka|uin|wat|nia| uc|umi| um|pu |isa| ne|iin|r t|am |iru|ak |sun| ya|aja| su|ink|s w|hic|a s|aus|wa |ais|tun|iri|nek|k n|kka|akk|eri|uma|tka|unt| ir|ini|nka|as |ati|imi|unc|i y|yat|nay|gki|a j|n n|r a|auk|i w|jui|atk|sa |mat|nuk|his|yai|ntr|tas|atr|mau|mir|ust| ji|ait|naw|ek | ts|nur|i j|tsa|ats|waj|arm|i u|nii|kis|e a|ase|pas|mi |rta|aru|u w|i c|jii| ti|har|kas|a w|era|sta| en| ka| ki|mik|rma| ju|r m|ham|k t|maa|a k|kch|usr|yus|is |a i|na |hir|se ',
    'not': 'que|ra | ca|ati|gue|ti |a i| ir|ani|nga|isa|sat|ue |ina|nin|ais|igu|can|uen|ro |nta|ing|te |nat| pi|ira|ca |tsi|i i|ant|iro|ara|iri| in| ai|eng|ata|car|ora|aca|a p|aqu|int|ats| or|uer|aro|e c|ri |sig|asi|ga |mat|i o|gan|ta |ite|taq|aga|tag|mi |gom|ngu| ma|ngo|aig|i c|gui|i p|e o| te|ong|gai|a o| on|e a|ita| pa|ero|ini|i a|tim|a c|nqu| qu|oma|e i|iqu|guë|agu|ni |anq|oca|sit|emi| an|iti|san|nti|sin|ome|uë |ima|imi|pin|mit|rir|ari|qui|rac|pai|ui |omi|bir|tai|ica|air|i m|obi|nia|nar|ten|a t|oba|uem|eit|mei|ang|oti|tin|iat|o a|tir|ota| ar|quë|nts|rin|ito|a a|bas| ba|eri|ate|isi|pij| it|o i|tar|ena|man|e p| po|ma |gar|equ|egu|i t|roc|si |oco|ran| om|o o|eni|cot|toc|tis|pit|iba| ob| oc|mag|rob|rot|ntë| sa|gas|caa|bac|águ|o p|anë|rog|roo|pic|bin|ipa|iji|uit|jem| je|a q|a b|uir| ig|rom|tan|nas|ëma|rai|oot|got|asa|ain|pag|re |ori|ane|i j|tac|a s|iac|iga|mis|bai|në |ogo|e q|ëgo|tëg| co|uëm|ëri|ábi|ria|mar| ic|ino|gob|jan|ë c|ija|ë a|bat|oqu|ë i|gáb|ngá|a j|ont|cat| im|uim|ai |are|nib|ne |com|gac|aat|agá|na |jin|pág| pá|oto|uib|tas|ote|ico|igo|ëmi|uër|a m|o m|o c|oro|ror|era|ibo|bor|ton|jeg|not|rag|niq|ogó|ëro|pob|pas|ë p| as|maq|ëqu|uëq|eta|uet|teq|cas|irá|coq|tiq|sai|tsa|es | jo|mip|i q|i b',
    'sme': 'vuo|uoh| vu|ja | da|aš |at | ja| le|laš|lea|hta|a v|ta |id |uoi|as |ii |uođ|iga|oig|oht|tvu|ala|gat|atv| ju|dah|vvo|uvv|ohk|ea |ođa| dá|juo|a d|in |a o|je |aid|hje|ahj|hke|ga |dja|ddj|usa|idd|ot | ma|čča|ačč|sa |s l| oa|ear|t d| ga|rid|it |a s| ov|alg|gal|lmm|okt|i d|iid|ge |fri|eat|te |hus| ol|ola|a j|nna|vnn|eha|keh| fr|čas|a b| su| al|aga|sii|an |áht|vot|eal|ovd|us |vtt|hač|juv|oju|mii|all|t v|ahu| bu|dag| ea|on |lgg|t j|arr| se|htt|aht|đa |ála|de |gga|buo|stá|is |svu|i j|s j| vá| ii|lág|e g| mi|avu|von| si| ri|tta|ahk| bo|ažž|dda|hte|e d|vál|š d|bea| ve|štu|đai|mmo|n j| be|et |ost|saš|t s|ut |gá |lgá| ná|alm|arg|ovt|a m|rii| du|tá |žžu|ása|ssá|ái |n d| gu|i o|nal|uvn|lla|hka|tus|jav|go |lbm|t o|d j|kká|kte|š v|žut|oaž|ass|vdd| rá| go|tag|kta|e o|rra|ága| di|oda|osi|šuv|mmá|mat|ain|oah|tas|tto|t m|a g|ođđ|hkk|uos|sea|das|mea|stu|ast|alu| do|age|tii|uol|dat|lli| lá|eam|vea| na|ide|n l|švu|olm|t l|bar|iin| ba|lač|i b|ssi|uid|bok|odj|uod|gas|kko|lus| ok|uht|eah| ie|ikk|mi |š s|ššu|ttu| so|á m|má |án |a f|iel|t g|š o|dan|d b|dit|nái|ahp|doa|rvo|sis| má|dáh|su |s g|kár|akk|duo|jal|suo|n v|áss|dás|a a|oll|hti| st|lde|a l|mai|áld|ašv|ami|dea|naš|agu|mie|skk|i i|huv|ama|gea|moš|bmo|olb',
    'yad': 'rva|tya|iy |arv|irv|ada| ra|ra | ri|vay|ay |cha| sa|a j|rvi|ara|da |ich|y r|rir| da|yan|vat|a r|va | va|amu|ijy|rar| ti|ya |ati| ji|ari|nij| ni|a n|ata|u n|yad|var|sar|uty|aty|ye |y j|dar|dye|aju|nva|anv|ity|vic| ja|idy|tit|ju |jya|a t|asa|ava|ta |yu |tiy|ant|tid|ary|ami| ne|a s|rya|ach|nty|taj|anu|ita| ta|imy|chi|ne |iva|vij|usi|mus| vi|a m|van|siy|yat|sam|adi| mu|mir|mu |nu |riy|ani|dat|iry|a v|uy |mut|myu|y v|u v|muy|y d|y s|jar|tar|yar| nu|had|cad|uca|a d|viv|y n|nut|i r|jmu|u r|y t|ryi|aya|uch|ivy|jaa|ech|rve|ma |uma|ti |e j|e t|dam|chu|era|miy|hip|e v|e r| j |vad|has|ram|piy|ipi|yam|daj|imu|u t|yi |ha |ñum|au |u d|tye|oda|tav|i t|jyu|nti| ju|iqu|tyu|ivi|u j|yas|mur|jir|ric|yuc|u s|sat| ca|j i|que|jau|jva|ijm| yi|rat|i j|tyi|muc|yiv|niq|nrv| nr|umi|mya|rim|dañ|e s|ija|eta|uri|ate|ura|hir|aad|yja| jn|adu|asi|añu|riv|vam| jv|dod|int|eva|cho|isi|tim|omu|ran|tad|yic|niy|che|sav|dim|vja|enu|unu|iya|umu|jnu|iyj|a y|di |sac|jam|ni |aja|ter|vyi|uba|jub|uya|yij|i n| jm|rvj|amy|vec|tja|jit|har|jac|jav|upa|der|ado|ije|rye|yum|yev|uti|iju|jiv|div| vu|jas|yom|muj|tan|mit|nad|nna|ann|can|num|uva|han| mi|ude|rup|vya|yet|uni|jec|sir|ana|qui|urv|cat|ja |sja|jan|jim|nuv|iti|uta|hut|ñi |eda|ade',
    'ura': 'in |ha |cha|ne | ne|uru|ain| ca| ra|a c| co|a n|iha|ru |aur|ach|n n| ni|ana| ch|aai|cac|aau|ai |aca|n c|uhi|nih|e c|ein|ina|na |naa|coa|ruh|haa| na|eei|ane|rai|ich|uha|auh|rau|ojo|iji|caa|chu|joa|nac|aa |hi |ine|a r|aen|e n|oai|i n|i c|nee|u r|ere|i r|aoj|han|oco|iin|u n|coc|u c|hin|hae|oha|eeu|cai|en |eur|hu |nan| ac|a j|ata|coi| qu|e a|hur|aih|cur|oin| je|uri| it|nii| cu|te |ita|ree|raa|ihu|ue | ic|cuh|ela|a a|oaa|e r|que|jia|jer|ati|ena| ja|nai|e j|tii| ai|ta |aan|ara|cor|ii |rij|aao|eca|n i|tan|ucu| le| te|toh|ei | sa|rih|era|ero|ato|eje|eri|nao|jan|hac|jie|aoh|lan|joe|hat|nej|sat|nen|aun| ri|ra |ecu|ri |cao| at|aon|rer|oar|u a|re |oec|ner|taa|oat|oro|iei|n r|ona| jo| ba| ji|hei|ihe|jel|i i|ric| am|ene|can|ami|ini|a t|aja|nre|enr|oae|tee|jij| er|a s|qui|hau|a i|nu |an |jaa|ca | en|nat|lee|acu| nu|ren|hao|la |toj|oto|e s|i a|n j|jee|lau| be|ito|iic|mih|ier|ore| es|oau|ruc| ru|ton|taj|roa|hun|ate|nri|e t|aal| re|oee|aot|rao|iri|i b|n a|ait| la|e i|no |roe|n e|ban|i q|n l|eni|mii|i e| in|n q|rin|nei|e e|onr|iao|nij| to|ala|jau|jii|rno|ern|bie|obi|gob| go| ta|iaa|nec|uhe|o n|oac|au |aba|nab|unr|och|eoc|eeo| si|aje|a e|i t|ete|u j|uju|n t|una|une|a q|aer|cau|i j|e l|laa|ler|ole|tol',
    'cbu': 'pa |ari|chi|ots|a t|pot|tpo| tp| va|ach|ina|tar|ats| ta|ri |van|spa|iya|tsi|ts |ama|tsp|ia |nts|int|sta| at|ani|ya |a a|am |tam|apa|nar|tsa|ich|ash|ara|ha |ro |ana|tin|ta |shi|a v|ni |tst|sia|rin|ati| ma|hpa|ita|aro|chp| go|i t| ka|a k|i a|a m|asi|mam|a i|gob|ko |ch | ki|ini|hiy|tac| ya|sa |ota|bie|obi|on |aya| na|tap|hin| is|ier|sha|ano|gts|agt|ata|ron| an|sh | to|nas|oro| pa|pi |ria|iri| as|ago|sir| ch| za|rit|ish|pch|noa|nat|lli|ero|cha|och|niy|ova|vat|sin|hid|oa |mag| it|tak|o v|a g|ist|sar|ato| yo|hia|o a|o t|iat|hir|hig|ava|ayo|pay|kiy|npa|kin| ko|a y| pc|sht|a p|ako|osh|may|igo| ic|asa|a n|pat|gor|mac|din|idi|iar| sh|kor|adk|zad|i k|sho|i p|yot|got| ts|tat|zta|azt|api|ros|s t|dko|vaz|rav|inp|hil|pan|rak|yam| ap|yog|xar|to |ir |nag|hto|psh|ona|nia|vap|a s|in | vi| mi|yac|og |iyo|s v|m z|opi|ad |ima| tá|tpa|ap |ora|aki|¿ta| ¿t|o i|pag|kas|yat|siy|na |r t|a c|i v|kam|rag|yas|nap|go |amo|tov|cho|hta|yá |iyá|ill|s i| ar|aha|rar|oxa|tox|os |kan|agi|is |i i|vas|m p|hic|yar|ias|si |lin|osi|rap|mon|h t|all|nak|tay| ll|nad|hon|yop| ps|yri|ayr|ipa|az |azi|s k|nta|h a|tss|sam|kch|iam|tag|á k|mas|g y|iro|m t|vip|lit|i y|kar|tot|ito|paz|ách|tác|cht|man|oma|atp|rno|ern|pac|kuk| ku|a ¿|n t',
    'huu': 'na |ena| na| ra|a n|mɨe| bu|nai|ñen|ill|a i|com|ɨe | ie|a b|iñe|ia |ie |mo |aim|rai|lla|a r|imɨ|ɨnɨ|mɨn|omɨ|uiñ|ana| co|rui|aca|e i|air|iru|a j| il|nɨ |nia|ga |a c|e r|can| ja|no |ona|fue|una|bun|lle|bu |e n|afu|raf|ɨen|jɨa|ɨna| is|bie|aɨ |len|soi|iso|ɨno|ani|ua |aɨc|o n|aga|nag| du|ue |e c|ɨaɨ|ɨco|laɨ|emo|naɨ| ca|de |ien| ji|ɨ n|o i|nan|a f|ail|acɨ|se |aɨr|ide| jɨ|amo|iac| ll| ma|ita|raɨ|ɨra|llo|lan|ier| dɨ|cai|aɨm|a d|aia|jai|a u| fe|rno|ern|obi|gob| go| nɨ|oid|e f|ɨmɨ|mon|caɨ|re |ɨjɨ|aɨj|maɨ|nɨe| se|ɨmo|ama| ur|cɨn|oia|e j|dɨ |tai|mac|aɨe|o j|ima|ano|i i|edɨ|nua|eiñ|fɨn| fɨ|ome|nɨn|ain|ai |omo|la |fac| fa| da|fei|uen|e s|aiñ|jit|cɨ |ere|añe|dɨm|ina|e d| bi|o b|ɨ c|oll|iad|log|fui|ɨ j| ua|uer|due|dui|nam|oñe|ise|ais|oga|amɨ|gam|a g|tañ| ia|ɨem|daj| it|uil|iño|ri |ino|aie|aɨn|oi |eni|jac|ese|o d|mai| ju|ñua|iñu|ñed|ecɨ|anu|a m|ata|uri|ado|sia| si|o l|ɨ r|efu|sef|ca |u j|nom|uai|bue|jam|a ɨ| rɨ|non|aje|ɨca|itɨ|mui|ɨba| ɨb|mec|aac|aja|e ɨ|a o| jo|ega|ra |rue|ɨma|e u|a s|ɨño|nɨr|nin|idɨ|uid|e a|lam|cue|ban|uru|umo|bum|ne |ɨne|dɨn|uia|e b|ira|jir|uem|ɨru|ɨ i|e g|ɨes|dɨe|eda|sed|rɨñ|oni|je |dɨc| an|do |ɨnu|taa|mat|ño |ɨni| ol|u m|ɨa |are|u n|ɨga|dɨg|ofo|jof|noñ|ben|dol|i d|iaɨ|ɨdɨ|ebe',
    'cof': 'sa |i t|a t|man|hi |chi|ant| ma| to|nan|an |ti |no |ka |nta|la | ch|oe | i |shi|tsa| ts| pa|to |ta |a c| ju|jun| ti|nsh|ala|ano|e t| jo|ila|joe|nka| sa| ya| in|a m| se| ta|hil|e i|a i|e j|a k|a j|ino| ke|nun| ki|ira|ena|ri |ra |era|a s|i j|le |ke |pan|i p|uns|ae |ya |unk|o p|o m|in |i m|yan|ana|ken|jer| je|n j|i s|kir| mi|min|ari|iya|aka| mo|ara|ank|se |ona|ral|san|ans|n m|jon|iti|un |o s|ran|de |i n| ka|ola|chu| na|toe|n t|e p|i k|e k|ojo|noj|ode|pod| po|tan|o k|e m|tar|hun|ile|ten|ajo|laj|bi |n p|e s|a p|nke|nti| te| pi|o t|lae|ina|kan| la|nol|on | tu|e y|onu| ne|tit|nla|lon|i y|lar|rat|o j|ach|n s|ayi|pay|na |anl|olo|bol| bo|be |ela|i i|mi |kar|nal|pe |are|ele|sel|lak|ton|pa | so|lab|n k|niy| ni|anu|eti|til|ono|n i|nle|piy|mir|ibi|mo |son|ent|ati|abe|ake|yak|jo | ku|o n|ika|ech|nch|nen| ja|ato|a y| pe|n n|unt|nec|o i|nbi|una|wen|lac|tae|oka|mok|i e| we|nte|a n|re |ere|sen|enk|inl|ami|obi|eno|o w|uni|nar|tin| do|yal|nto|bin|hik| sh|umi|let|iri|en |tob|pil|e a|ama| am|mun|i b|aya|e l|i c|ash|jan|ine|yib|lo | e |yar|ura|kuw| er|i l|n y|atu|esa| a |mon|eya| o | nu|abi|a a|uto|tut|ape|yap|unb| mu|enc|o y|a l|nin|yil|bit| ji| lo| ko| pu|sal|iyo|hiy|kur|uwe|lat|res|o e|mer| me|tam|e n',
    'boa': ' ts| me|ne |e m| mé|jcy|e t|tsá|íjc|é m|né |cyá|meí|ke |re |tsa| mú|íty|eke|á m|sá |óne|mek| pá|jts|vyé|tsí|yur|tyu|áme|é t|rón|uró|hdu| mu|iyá|ré |mee|yét|té |yón|iyó|ivy|pii|éhd|ááb|eíj|iiv|llé|aat|mép|hdú|cya|été|mún|a m|ere|eer|jɨ́|pám|yá |ity|saa|á t|é i|e p|épi| té| íj| pa|újɨ|e i|áné|́ɨ́|ɨ́ɨ|ñúj|iñú|u m|ane|óné|dur| im|úha|téh| te|ɨ́ |múh|ímí|één|tsó|yé |ma |dú | ɨ́| aa|wáá|méé|hjɨ|rá |urá|ene|me |e í|ki |i t| á |í m|imí|ú m| né|muu|náa|iiñ|éjt| tú|mem|até|wák|myé|énú|ye |ure|a t|uhd|muh|ñe |mí |ri |ha |véj|evé|túk|áiy|ú t|ats|ñé |i m|jch|jɨ |ɨ́j|tyú|te |úna|á p|mé |íñe|jca|imy|uur|méi| ím| di|vú |íñé|úne|aa |naa|éké|ábó|cat|ame|éév|mep|éme|tye|úná|kev|yái|mɨ́|aam|ahd|kim|áki|yéi|éiy|vu |tu |u t|ijc|vye|een|óít|tyé|é p|évé|tsɨ|yu |úiy|óme|pɨ́|úré|pañ|sɨ́|áne|e á|néh|yáh| ii|́jt|úke|tsú|du |aan|yán|ájc| wá|éne|óiy|ca |ɨ́n|hi |úhb|tso|píí|ké |́áá|ɨ́á|síñ|emé|meú|úné|ává|áts|soj|áré|é w|éré|meɨ|róm|amé|ten|étú|áll|ááv|aki|yak|ajc|jác|etu|a i|úvú|chí|éhj|ju |ími|e a|ávy|áhi|á i|úún|jyu|tú |ték|ewá|mew|dúr|sah|é ɨ|híí|haj|ná |áa |vén|jty|íll|míl|váj|á á|éít|baj|hba|aúh|dit|tsi|ate|ívy|all| wa|ɨjt|a í|íiy|eri| ií|eté| ij|i p|taú| ta|méw|eɨ́|yet|sóí|júú|ɨ́m|úme|síí|íív| pí|ú p|néé',
    'cbs': ' ja|en |n j|ven|bun|ki |anu|un |nun|au | da|nve|unv|cha|jau|bu |abu| va| be|uki|nbu|idu|tid|in |kin|i j|nan|aka|ibu|unb|ubu|n i|ama| ju|a j|i i|aya|jav|aki|ets|ibi|an |tsa|bet|hak|jun| yu| ib|nen|ane|xan| xa|ich|uni|ave|buk|ina|bi |sib|asi|das|mak|ni |i b|yam| ik|ati|dub| ic|da |ken|a v|ada|man|n x|dab|kat|abe|van|ka |kab|uma|sa |iki|duk| pe| ch|ma |n d|tsi|ats|nki|be |ake|bub|ika| me|si |xun|n y|dan|u j|xin| xi|ska|i d|nu |e v|u m|day|u n| ji|u b|u i|a b|n a|a d|una|di |ask|bia|uda|yud|iti|n p|ank|eda|med|chi|vak|ava|ema|nem| ne| ma| un|ive|jiv|jan| na|n n|adi|ias|abi|jab|inu|ae |mae|ya |ima| in|ana|ain|ha |kad|u d|vad| an|e j|vat|yui|n m| bi|n c|a i|ida|ene|na | ak|ela|uel|cue|scu|esc| es|axu| pa|jay|a a|i e|ink|nin|i c|ja | ni|eva|vay|nma|pa |epa|pep|tim|mad|num| ba|apa|sap|pab|nch|anc|aib| ta|nti|lan|tib| ke|yus|kam|nab| ev| ai|i x| it|uin|a x| ka|u k|atu|ixu|anm|a p|sti|bes|no |rno|ern|ier|bie|obi|gob| go|n g|ani| du|vea|e b|bai|ia |usi|u y|enu|nam|jai|n t|i a|bik| ti|sin|pak|ai |bum|a u|mat|ben|inb|eki| ui|u u|unu|tu |nka|a n|n k|san|u x|u v|dau|u p|a y|tun|est|ua |o x|va |may|i u|aid|dua|eab|ne |yab|n b|ipa|a t|a m|men|ame|ea |ant|kax|kik|n e|a e| bu|bak|kai|yak|jas|pad|uya',
    'ztu': 'ny |a a| a |u u| un|nny|bu | bu|unn|ra | ra|ih |e e|a p| ch| e | pa|hr |ahr|pah|y r|e c| de| na|y n|ee | i |a b|e i|te | te|na |ta | ni|a t| p | ga|ere|ch |ree|der| ta|i i|r g|ga |h r|nn |chi| gu| x |rih| ih|ty |y b|nih|ni | ty|i t|que|a c|p d|by |ei | ny| qu|h p|uei|h c|h n| c |uny|aa |ony|oon|yoo|x t|hby|ihb| o |cy | cy|i c|ihz|e r| la|uun|guu|hnn|ye |i n|syo|ëhn|cëh| cë|hih|y c|a r|zy |zh |xi | xi|hzy|hzh| re|asy|y l|zi |y q|nye|lah| pr|i d|a s|ru | ri| zi|y z|y x|le |y t|n n|ar |aar|a l|e n|taa|ann|loh|e b|y g|h b|ah |r y|ahz|eh | ca|a n|re | n |a x|h g| li| rn|ca |iru|hir|hu |rnn|rta|za |ida|oh |ze | ze| ll|chu|aht| co|nni|hah|n r| u |la |cla| lo|daa| di| bl|r c|nah|y p| eh|iny|ii | in|o c|y o|yih| gy|er |c t|yee|bye|wby| wb|pro|nna| s |u r|di |ert|ber|ibe|lib| sa|lle|i l|hii|h t|y d|eer|jee|iga|cas| st|o o|aha|h q| ru|pri|i r|h x|ras|ara|lar|ecl|dec|sa |gah|dig|blo|ly |wee|el |h y|a z|r l| nn|co |p b|cwe|uh |can|eje|tej|ote|rot|be |gaa| sc|aan|tih| mn| an|n s|ll |aly| aa|eel|scw|hi |gue|u x|ona|yon| sy|ica|rca| rc|z b|yu |a i|x g|se | jw|ng |ëng|hti|dy | dy|ohi|r r| le|maa|ast|y s| yb|deh|i x|hny|eli|rel|i u|gui|i g|a d| al|n d|h d|u g|paa|uee|naa| yc|lid|ali|nal| yn| yd|hty',
    'piu': 'ku |tja|ngk|tju|aku| tj|ang|jak| ng|gku|a n|ytj|any|a t|nan|nga|pa |arr| ku|ana|ya |ngu|nyt|ra | wa|gka|urr| pa|uta|nyi|ka |kul|u k|wan|utj|u n|rra|jut|kut|ing|yan|ntj|a w|ara| ya|ant|aly|rri|a p|u t| ny|upa|ran|u w|pal|gar|yi | ma|uny|a k|gur|jup|nya|yin|ung|u y|iya|a y|tji|ta |int|rin|kun|wiy|ina|yun|ula|u p|unt|jun| wi|la |ru |a m|lya|nta|aru|kar|tan|man| ka|apa|rrk|uwa| yu|jan|na |nyu|npa|juk|u m|pan|lyt|gan|ntu|ayi|uru|aan|mar|wal|tu | pu|gaa|waa|iny|ult|uli|ura|rka|ltj|rur|lku|irr|anp|guw|ja |rru|uka| ra|tin|gu |pay|kur|aar|nku|alu|ira|kan|jin|una|uku|ama|rap|tak|itj|yal|i r| mi|i t|mpa|atj|alk|nti|ala|rrp|tar|i p|pun|nin|rpa|jar|jur|ju |rar|yar|kap|ank|ri |iku|api| pi|lin|run|amp|pam| ni|i n|kit|jap|utu| yi|aya|ani|tup|ata|lir|rtj|rrt|tir| ti|kuu|pur|tay|i w|pir|pak|i y|ni |iit|rku|lun|ji |lat|min|par|ulk|jul|aal|pin|lki|luw| lu|yut|atu|awa|uya|kuy|yur|kin|uut|ayu|may|ink|lpa|lam|mii|gal|uwu|awi|ipa|tur|kam|ila|unk|ruk|inp|jaw|iin|i k|ipi|kat|rak|ali|i m|nak|lur|ita|put|upu|lan|u l|iti|yir|pip|rik|ati|ini|yat|tal|yaa|taw|kal|uly|kuk|ilk|tun|ump|kaa|wu |nam|pi |alp|jii|nyp|nki|win|wat|kak|pii|uwi|iip|ari|uul|aki|jil|mat|lum|jik|lpi|yil|kik|ulp|nka|a l|unu|nar|ma |wa |raw|pik',
    'cbr': ' ca|icë|in | ic| un|ën |uni|qui|ca |cën|a a|ma |uin|cë |n a|ain| ai|ti |i i|n c|n u|bi |un |nan|ama|ni |tsi|a i|cam|sa |i c|a u|i u|ima|nu |ñu |sin|iti| bë|bët|tim| ñu| it|a c|tan|an |ana|anu|ëts|nun| cu|u i|inu|isa|si |oqu|nti|ina|ra | si|abi|í i|xun|car| an|ara|ati|tí | ui|i a|n b|ë u| at|nin| qu|a t| ta|ant| oq|ban|ncë| a |acë| ba|rib|ia | us|a b|ica|ibi| ra|usa| më|ani|n s|nën|ësa|cës|ais|iri|u c|u a|ixu|rno|ern|ier|bie|obi|gob| go|i b|aqu|mai|ocë|nic|nqu|cuë|n ñ| ac|anc|ëma|anq|uix| im|i o|mab|i r|nia|man|ë i| up|ití|ins|ëtë|nët| në|non|ë a|u m|cua| aq|apu| ap|ari|onë|ëni|mën|ëën|uëë|na |pí |upí|cëm|uis|int|bë |a o|air|ai |ce |rab|x c|bit|una|ënë|tën|anm|its| is|n i|ibë|ënu|rai| me|nmi|n m|ish|sai|xan| xa|ax |cëx| ax| bi|uan|sab|nio|ë c|ami| am|mi |pun|nix|imo|a ñ|ë b|i n|n x|nbi|a q| pa| ti|mëë|hi |shi|i m| in|ënc|n n|i ñ|sar|ë q|nma|n p|pit|ëta|ix |ric|uir|í o|n g|a m|upi|mit|ice|uia|a g|ëx |nib|ui |a e| bu| ub|tis|rin|sh |i s|në |ian|ucë|sam|a s|mic|can|nsh|n q|cac|aca| en|ntí|ë t| ma|oi |chi|cup|ios|dio| di| nu| as|añu|n t|ëët|cue| es|buc|tuá| tu|n r|nux|nsa|ats|ëti|inë|ioc|n ë|otí|ëxu|nac|n e|iqu|u ñ| añ|inm|xa | ia|ta |tit|sën| së|xbi|ela|uel|scu|esc|nëo|uën| oi|cun|ucu',
    'mcf': 'qui| ch| ic|id |tsi|uid|mbo|sh |amb|ash|bo |o i|que|aid|ëda|ac |ict|bëd|ias|sia| ca|cts|bi | bë|dam|on |in |n c|ho | qu|uin| ni|c b|ida|hui|chu|cac|sho|cho|uts|iqu| ut|esh|cqu|chi|ec |ido| da|o c|i c|nid|ën |ics|nqu|dai|csa|ues| ma|mbi| ta|abi|ats|equ|tse|n n|n m|dën|sam|ses|mat|idë|c i|ton|en | ab| na|h c|boe|ted|di |edi| cu|a c|dnu|ueq| ad|bit| ai|uiq|ada|iac|dqu|shu|ite| pa|d d|o a|d a|es |tia|h n|das| at|nu |apa|un |bad|sin|uen|pad|pan|ibi|ato|d n|sib|aba|tab|ta |uio|don| mi|n a|emb|da |oqu|h q| is|ono|i n|adq|nëd|anë|imb|dap|tan|idi| ua|ai |u q| iq| në|hoq|ësh|oës|noë|ino|ipa|do |hia|ibo|dad|din|uip|n t|n p|nue|abo|nec|cai|adn|hun|i a|bon|nia|iai|bid|nac|no | be|cue|ant|enq|a u|ado|con| co|oec|d u|cui|men|na |nen|ade|c c|c a|tsë| sh|h a|una|anu|nti|ëid|nëi|pab|shë|n i|io |uec|d i|i m|ebi|i b|dac| pi|iuc|h p|aqu|sun|ic | ne|d c|c t|ucq|ito|hit|mib|nun|sëc|piu|n u|inq| am|ocq|oen|ëqu|hie|o b|i q|n b|ies|h u|bed|te |hën|pim|api|iap|iec|uai|ish|hon|cuë|acn|d m|nai|csh| me|cbi|ëcq|noa|adt|o n|uia|n d|uie|ene|acb|dot|ueb| em|c m|hid|iad|ota|pi |ecq|ets|uet|d b|osh| më|icq|enu|dan|dob|ioc|s u|idt|esu|ubu|hub|nan|o y|ued|edn|obë|an |pen|ane|anq|i t|nc |inc|ëpi|hëp|o s|can|nda|den| ba',
    'bis': 'ng |ong|lon|an |em |blo| bl| i |man|mo | mo| ol|wan| he| lo|hem|ol | we|n i| ma|et |en |at |aet|rae| wo| o |we | ga|gat| ra|i g|oma|o w|n o|wom| wa| ka|sem|vri|evr| ev|t r|t b|emi|m o|g h|sen| no|mi |n m|n b|e i|ri |g s|m w|ing|ae | sa|iwa|i m|kem|eke|mba|i n|la |ala|riw|li | fr| fa|amb| ba|fal|tin|oli|i b| me| se|bae|bam| na|in |eis| st|ise|tem|lem|g w|ia |mek|ti |g m|asi|fas|m s|e h|ave|no | pr|om |m m|sin|ve |sav|m e|i s|a m|fri|m b|g k|ap |t l|sta|o b|afa| ia|o f|o s|iti|ole| fo|n w| in| ta|raf|ara|nar|g o|n l|im |e m|aem|pro|ens|m h|fol|tek|nte|tae| so|ed |sae|ni |dom|ido|rid|ta | ti|i w|um |g t|a b|i k|eni|sos|ili| en|tap|t m|eta|tri| tr|usu|ase|kas|se | pa|g f|ok |wok|lse|ols|gti|ngt| pi|sum|ini|e o|ret|ote|a l|ntr|aon|son|aso| di|ot |l b|l r|ipo|l m|t w|m f|oa |nse|gen|age| ag|ont|kao|nas|g l|pol|n p|is |a w|o t|res| tu|m t|m p|ete|i p|o m|loa|lae|men|are|aed|ama| la|aen|aot|ere| de|get| ri| re|it |ea |g b| ko|rot|a i|gud|m r|es |m n|ef |aef|int|ema|ik |eve|sol|g n|lit|jen|m l|kae|wet|g d|spe|mar|rom|nal|go | go|kte|ekt|nis|nom| te|m i|eri|lev|oso|nei|ren|rei|rit|o o|n f|kei|uke|duk|edu| ed|o r|os |sip| gu|ona|kse|fro|n g|fea|g g|o l|tre|i f|min|dis|ak | lu|i l|sme|o p|i o',
    'orh': ' bi| ch|shi|in |en | sh|uan| zh|hin|i b|hi |nek|bin|hua|ken|eke|ine|ish|chu|ye |n b|ng |li |zhi| du|ing|anl|bis|nli| ba|eye|bey| be|an |cha| n |chi|han| re|du |yi |i y|eng|ong| yi|she| e |yu |gi |ngi| ti| ng|n c|re |hen|tin| gu|hiy| ye|a c|ang|i n|ra | ra|a r|i c|ka |aka|bak|i t|n n|u b|yo |e b|iyu|e c|hu |n z|un |zhu|i z| yo|n s|e n|u y|n e|i r|shu|i s|sha|uk |duk|uru|ui |he |gur|run|gzh|ngz|i d|ur |bur|zha|ren|hui|bi |eri| er|n d|mbu|amb|bam| a | fa|e g|zhe|a b|o b|ehu|che|e s|ri |g b|heh|hon|n g|ngd|pin|his|i e|hao|gsh|ngs|ian|el |e r| we|n a|wei|e z| li|hun|l b|aa |gon|och|zho|den|gde| pi|yel|o c| ro| go|wi | wi|n f|g d|nzh| in|haa|cho|uli|lin|guo|sho|ai | nu|yan|nya| ge|aoy|n m|ro |e w|e y| da|o y|oo | oo|n r|ei |nch|gch|ngc|u s|oyu| bo| mi|n y|nyi|e e| ni|nhe|n w|ngk|anz|u d|ich|hai|ush|uoc|anc|o z|any|nsh|esh|uzh|g a|ho |e t|mi |i g| ga|uu |bia|ali| o |gan|u g|o s|lü |enh|izh|fen|hit|u c|lia|n l|erb|ger|huz|iao|ha | hu|ii |ihu|huu|huo|n i|o r|uo | he|a d|ibe|ngw|nin|o n|ohu|k b|alü|fal|a y|a w|ngf|uch|u n|a s|ao | fu|ans|uny|hal|be |rbe|ozh|di |a n|n h|ni |yua|i w| to|n t|ghu|ngh|k g|hee| ko|g n|din| w |u o|hib|u e|gwe|na | na|ü d|fan|fa |u w|g e|kua|gku|ol |hol|uga|nug|r p',
    'ese': 'jja|jji|qui|ajj|ojj|ji |ya | es|ja |uia|a a|cua|ana|ese|jje|je |ejj|jo | jj|ahu|a e|uan| qu|a c|na |i e|ijj|ani| a |hue|jay|a j|aya| oj|aja|ama|cue|ue |hua|ni |maj|aqu|e e|ia |sej|acu| cu|oya|caj|cha|eya|a o|o e|aje|aña|a p|esh|eja|sha|a s| mi|ecu|yaj| ca|aba|iya|ña |jañ|poa|hui|ijo|pia|uij|ian|ajo|aca|poj|iaj|ohu|e j|a q|me |yoj|aco|jia|epo|eba|se |ca | po|bae|i o|ayo|apo|i j|hac|uic|uab| oy| ch|shi|o a| pi|icu|equ| ja|jas|sey|ase|ehu| ya|eca|io |naj|e c|ash|e o|ame|uej| aj| ac| jo|ona|nah|jaj|ica| sh|bac| hu|jam|ma |miy|mes|baq|hah| ec|iqu|iam|ipo|oma|jij|joy|mim|hij|cui| ep|uni|a h|ion|e m|teh| na|e s|a n|a m| ba|i a|ach|eme| eb|jaa|e q|i q| et|oan|tii|jah|ima|yac|hio|abe| so|huo|ai |apa|uay|nij|oja|ha | ej| si|e p|oqu|i c|chi| se|ime|imi| o |i p|que|jem|aej|o j|och|coc|oaj|jab|jac| ji|she|poq|aji|a b|uis|iac|yio|sec|uih| sa|eej|e a|ba |o o|pon|iap|sho|pom|yas|ua |sij|ui |com|ham| oh|jes|uoh|ihu|o s|o m|uem|mi |api|pam|a y|sab|nio|eun|reu| re|eti|map|ano| hi|hoi|jiq|ete|i m| de|uec|jey|o c|ich|jim| te|oba|jjo|soh| e |i s|so |ina| ey| ai|nac|ose|oi |co |njo|onj|iip|he | aq|e y|hia|ad |dad|ida|nid|mun|omu| ma|coj|aa |ahi|oa |iim|i y|sap|uio|pio| eq|can|aec|miq|ade|dej|yay|ojo|mij',
    'cic': 'at | ka|ann|nna|ya |kan|kma|chi| na|aka|ish| is|kat|o̱ | ch|t i|att|tta|a n|nan|ani|mat|i k|ha |hat| ha|tak|akm| ni|aho|a̱ |nak|hi |a k|ook|ka |ban|nah|a c|a a|hoo|̱ i|ni |a i|mak|ana|alh|iba|haa|ho̱|sa |na |i b|cha| yo|okm|a o|itt|niy|ki |iya|i y|tok|sha|t n|yi |yyi|íyy|bíy| bí| it|ika|t a|yya|oot|a h| ki|hib|aat|kya|isa|̱ma|ta |api|naa|shi| ik|oky|ach|ó̱m|mó̱| mó|ano|ima|ka̱|yok|ak |oka| ay| ba|ot |ma̱|hpi|lhp| im| o̱|lla|yo |aal|hmi|̱ k|t h|iho|̱ a|tti|li |aya|la |nih|hok| aa|pis|baa|i n|hto|cho|iha| al|aap|ihm|ala| at|oli|mal|kha|okh|nik|sht|koo| hi|oko|hol| sh|a s| ya|tih|ali|aaf|sso|i c|ill|áyy|nok|lli|nta|ánt|iyy| an|i i|aha|ila|ahm|oho|moh|mi |a b|pa | ho| sa|i s|pi |t k|ako|iss|lis|all|tto|ato|hiy|omp|nom|och|pil|̱ n|kch|ikc|̱ h|i h|ksh|yah|a m|law|sal|ksa|oks|fok|afo|lik|so |fil|kfi|okf|hak|ikb|lal|t á|too|ppa|aa | oo|ko̱|hma|ma |mpa|oba|hik|mik| i̱|hih|iis|pii|lak|sho|iks|aak|yyo|ayy|wwi|aww|íll|tíl|ttí|k m|ich|o h|hip|ota|lht| ib|man| áy|pac|ayo|hán|nch|o k| ap|ikm|kmo|lhi|o n|mmi|amm|hch|tim|ffa|aff|k y|him|yac|pot|ipo|kbi|oss| os| ta|i t|tob|shh|han|o i|aai|opp|yop|tat|shá| án|i̱h|ni̱|hka|shk|oto|mah|mmo|̱na|i̱n|̱ c|̱ y|ohm|hmo|lam|it |ba |t y|nti|int|min|ami|aam|i̱l',
    'csa': ' ts| le|†̎ |ia |os |lej|ou |tso|sou| li|oo |sia|ej†|jmo| ne|ne |j†̎| ta|tsa| ki|̎ t|t†̎|a l|kio| t†|le |ii |kö | kö| jm| ju|uu |e k| ni|mos|sa |u t|joo|ojo|moj| mo|asi| ku|tas|ios|a t|ni |s t|o t|io |e t|†̍ |ijm|i j| si|u l| mu|xii|aka| ma|o l|i k|o n|lij|juu|a n|mak|a m|s l|kal|mo | e |ta |ixi| mi| ti|e l|e j|muk|mix|s n|alo|kuu|uku| ka|u k|s k|na |ö m|chi|sam|i l|a k| ch|i m|ua |o j|loo|a j|a s| s |̎ l|li |s m|äs |ö n|a̱ |̎ j|e m|lii| í |ito|hit|i t| re|o̱ |ama| na| la|nio|too|re | so|o s|gï |aa |ní |jmä|nia|̎ k|̱ t|ti |ö j|soo|kua|au | rü|̍ t|so̱|u n|ija|isi|lis|ï k|mä |í t| jn| gï| ji|u e|o k| ja| in|a r|̎ n| xi|nü | nü|s í|u m|la†|jij|s i|u†̍|gu†|̎ i|s j|̱ l|e i|jua|u s|j†̍| sa| s†| ij|upi|jup|kuo| is|jna|kur|a†̍|jaa|ugu|mug|aäs|iní|ini| i |u i|jï |i s|ií |pií|ös |ma |kia|nei|s e|tin|it†|lit|̍ l|kue|í l|í n|kaj|jau|ï j|m†̎|e s| jï|a i|as |̍s |†̍s|e e|o e|i g|üs |s r|iso| ñi|o m|uré|ü l|aa̱|ajm|es |i n|rü |la | il|̱o |o̱o|s†̍|̱ n| ik|mäs|amä|mam|s†̎|ejm| ej|oös|í m|í k|uo | el|rüs|ima|ka |ue |̍ s|̱ k|e n|̎ e|jo | jo|ei |ee | es|ée |rée|ï t|kï |oo̱|aj†|laj|ta̱|u j|ekö|lek|o í|ika|lig|kau|ä̱ |meï|am†|jni|ila|ala|o r|ja̱|s x|t†̍|uas|kat| ek|ä l|a c|oü |ku |eli|ä e| o |ü s|uos|iä ',
    'mcd': 'in |an |fin|tir|iro|qui|n n|nan|uin| yo|n a| na|hua|ahu| fu|ofo|on |fo |ara|ati|oqu|ain|cai|ifi|fut|tsa|n y|huu|ifo|ant|ai |sha|nti|har|ran| sh|uts|aif|inf|rof|n c| ah|ato|shu|ash|nfi| ra|n i|sca|sho| cu|oma|oan|ono|ora| no|hon|aca|oin| ca|yon|non|ma |foq| hu|mai|un |yor| ni|ra |can|tif|pai| ic|ica| ts|iai|roq|n f| at|rom|n m|ton|fai|ush|iti|rat|afi|ama|uun|cus|uat|to | ma|san|ari|fof|rif|cas| is|nia|a f|unu|n s|coi|tso|n t|iqu|nca|tan|ish|foa|o a|afo|hu |nfo|soa|no |o f|ri |ana|oti|ian| as|yoi|aqu|n r|asc|cat|cah| fi|ito|ano|nhu|anh|apa|o y|noc|raf|i y|cha|ina|a n|uua|ait|ori|n h|anc|afa|nra|inr|ico|uar|maf|fia|i i|nri|anr|usc|o i|ro |ima| oi|o c|nfa|sa |cun|oco|i n| ta|iya|hin|onf|ino|anf|a c|isi|uu | mi|i f|si |i a|uta|ofu|a i|shi|ata|mat|o r|i c| an|i t| ar|u a|hum|raq|uaf|fun|ui |yam| ch|nqu|ras|iri|for|api|tap|sma|aiy|n o|rac|umu|nus|anu|yaf|cof|ti |fot|hac|rin|o n|a s|ua |inq|man|nif|not|uap|npa|noa|ofi|u f|a h|min|asm| iq|acu|aic|ipa|u s|ami|chi|ans|ich| ai| ya|ani|nta|ca |ura|a r|asi|pim|aiq|afu| ip|o m|uca|uas|i h|oit| it|inc|nu |uma|pat|uai|a y|oia|mua| pa| in| mu|ufo|uan|mur|o s|a t|aco|nna|uhu|sis|ann|i s|ont|o t|han|aia|anp|oa |uti|fit| fa|nsh|mac|oca|tas|o p|nic|tor',
    'amc': ' ja|qui|n j|mun|jat|in |ato|hqu|uin|tim|imu|ui |unh|nan|on |can|to |ati|un |aha|ama|o j|i j|an | cu|jau|nhq| yo|hin|a j|aqu|vo |yam|au |nqu|anq| qu|cuz|ina|ova| sh|uza|hnu|uih|ton|hca| hi| jo|uca|xon|anp|jah|tza|pu |u c|npu|nuc| ha|oni|anh|mah|n n|utu|n h|ohi|cun|yoh|ja |nhc|aya|hai|hax| vu|amu|shi|jon|nut| na|ovi|ihq|non|ano|n c| nu|utz|ica|ara|vin| tz|vi |ahi|xan|mat|ax |har|nhn|iyo|tzo|iri|uiy|ono|ivo|yoo|u j|n v|zov|n y|acu|ovo|ona|hon| ho|hir|nov|jam|cat|unu|uir|hi |iqu|ivi|riv|noo|sha| co|o c|zan|raa|ha |i n|niv|o h|han|tun| ra|vut|uni|yon|ann|yov|haq|uun|ric|n q|i v|nti| va|i y|n t|iha|zi |ni |nuu|azi|raz|axo|chi|aun|nya| vi|tzi|a h|va |oma|nin|i q|vac|nxo|oha|oxa| ca|nha|ti |iro|n s|aay|ani|vau|oon|inh|oo |ana|ihn|ito|ait|ima|tut|nah|mam|hap| ch|rom| no|hit|nna|vaa|i h|tan|za |apo|i c|van|ya | ni|apa|cov|ira|atz|oya|maq|oov|avi|man|naa|vih|onv|u h|aat|jaq|iti|coo|ant|ini|nvo|nic|ino|caa|a n|ra |hox|pan|zat|zah|oca|izt|oco|iya|ca |ham|o y|o v|uma| ju|a c|sht|ish| mu|aah|o s|onh|aho|i t|rah|ora|hav|viz|cav|n d|zin|uno|x n|una|vun|anx|nma|ich|nno|hih|n m|zqu|a v|uya|ava|nih|zti|axa|ari|iiq|pai|iva|zax|hiq|ain|itu| j |ixo|ran|nri|aco|aaq|hiz|noh|o n|dio|ori|i s|ahq|hoc|ocu|noc',
    'amr': 'hua|dik|ik |o̱ | o̱| hu| di| ne|k o|̱ n|da |ne | ke| no|ka |e̱ |a d|ken| ka|nog| da| e̱|hue|po |a t|̱ e| ti|oe̱|ti |ue |pa |pi |e d|yo |npa|enp|e k|taj| on|aj |ere|dak|ya |ayo|pak|ahu|a k|o̱n|iri|air|uai|o k|o h|a n|a h| po| ay|i k|poe|aya|̱ d|nig|a o|ak |ada|on |rno|ern|ier|bie|obi|gob| go| o |opo|nop|e n| pa| ek|ate|e a|no |kat| i̱| ko|uad|toe|nay|kdi| e |ri |̱ni|ko̱|epi| i |o n|khu| ta|eka|tep|but|tbu|atb|rat|ara| ar|i p|i̱ |gda|ogd| ba| to| ja|end|k i| ma|re |i o|nda|o o|ker|akh|e e|nen|uab|a e|o e|i e| ku| na|̱ k|bay|mad|a p|̱ne|e̱p|k k|apo|uap|ee̱|e o|en |abo|k e|og |a a|nma|si |a i|okd|te | be|e p|rek|bok|e h|i n|ig |ea |mey|ta |ut |anm|man|uas|nta|ont|kno|oke|pok|ihu|tih|gti|adi|asi|nok|na |api|ogo|ika| mo|g a|akp|kud|pee|a̱ |baa|e̱n| ap|to̱|i h|̱po|o t|a b|uea|k m|kpo|gba|ogb|jah|e̱y|kah|ba |ke |igt|ati|uat|ok |uak|aa |ana|ent|ua |̱me|akn|akd|n k|oka|uah|i t|̱y | pe|̱ o|̱ h|e b|oya|doy|ado|jak|okn| ok|mo |o̱m|epo|eno|kna|pop|ato| ea|ota|kup|aba|me |a m|be |go̱|ey |nep|ro |̱pa|kan| ed|nhu|onh|aka|uda|ia |ria|j k|ehu|ber|o m|n t|i g|tto|ett| et|ek |j t|n p|ivo|tiv|cat|uca|duc|edu|tro|ntr|cen| ce|o a|ike|opa|upo|k h|da̱|j p| er|eta|ret|e g|o d|uan| ya|nba|y k|ke̱|n b| in|apa',
    'cot': 'que|aqu|tsa|aca|ca |aji|tsi|nca|oca| ir|cam|ame|ets|eet|mee|i i|nta|ue |gue|sat|uet|iro|i a|mpa|a a|nqu|ji |ant|ari|taq|int|ica| in|j i| an|onc|caj|ata|ri |e a|ti |e o|ats|jia|qui|emp|uer|uem| oc|iaq|eti|ate| on| te|shi|tee|pae|aj |its|ro |a i|ae | ca|ita|ee |e i|eji|tac|sa |isa|nts|tej|anq|iri|cat| aa|can|agu|ati|eta|pa | ai|ani|ero|te |caa|maj|iqu|sip|taj|apa|ais|san|eri|inc|anc|o a|ira|ipa|aat|aco|ama| it| ma|eca|ash|iac|par|aja|a o|nte|tan|i o|ooc|hoo|cho| ia|ato|igu|aas|si |caq|jir|nin| ar|ogu|a c|sic|i t|a t| am|no |gui|uej|inq|epa| qu|ron|tat|pap|tim|ota|cac|ano|asa|maa|ava|ite|uec| ag|ui |ont|avi|ent|aro|uit|to |opa|uin|nch|ima|equ|imp|jit|e t|eje|iji|egu|uea|iat|rog|e c|i c|ric|ara|gar|ine|nti|vac|ija|rig|roc| i |tas|ane|cot|tic|jaj|hin|paj|saj|jan|o c|api|hit|tar|ej |uen|a m|jet|ram| co|ish| ac|aac|eja|aaj|siq|o i|cag|aav|ana|tap|tep|coj|vin|cav|ove|man|oro|ion|tio|j a|iga|oqu|amp|ini|o o|pat|nor|ono|gon| pi| ta| ch|rot|jaq|tag|nea|ran|taa|niq|rop|ago|nij|ave|coa|i m|rov|oji|jai|ueg|i q|pit|nej|men| at|jig|nit|ote|oni| ya|nco|ra |saq|oj |aar|ega|veg|eat|uep|ots| ot| sh|pan|mat|rir|ami|iti|hij|rim|ea |are|tem|uis|ime|enq|rij|cor|uij|oac|sim|ria|o t|ena|ten|ta |ven|ete|a q',
    'ajg': 'wo | a |yi |o a|mɛ | ɖo|gbe|ɖo |amɛ|le | wo| le| yi|o e| nɔ|nɔ |ɖe | ɖe|be | ci| am|e e|ɔ e| gb| ko|wi |okp|ɖek|ɔ a|e a|kpo| sɔ| en|ɛ a|eyi|a n|i a|pwi|kpw| ey| ej| al|e ɖ|pok|o ɖ|eju|a s|tɔ |enu|ɔ w| ny|do | eg|sɔ | ɔ | kp|lo |egb|nu |cɛ |nyi|kpɔ|i ɖ|ɔwo|alo|ekp|acɛ| ac|ci |i y|u a|nyɔ|ɛɖe| es|agb|i e|mɛɖ|o n|etɔ|i w|ɔ n|ese|to | vo|ko |bet| wa|ju |se |an | mɛ|iwo| ag|sɛn|e n|i n|yɔ |i l|ɔn |nya|wa |ji |ciw|e k|umɛ|kod| e |lɔ |na |ŋu |odo|pɔ |a g|n a| ŋu|de | de| lɔ|a k|ɛ n|tɔw|edɔ| ed|ɔ ɖ| do| nɛ|ɛ e|o y| ji|ɛ k|ɛn |ɔ c|uwo|o k|u l|a ɖ|ɛnɛ|nɛn| sɛ|vo |eka|ɔwa|o l|awa|n e| nu|shi| na|kpa|e s|ɛ l|gbɔ|i k|wɛ |ovo|vov|ɔ g| to|hwe| hw|ni | ni|wan|ɛ y|ukɔ|ya |ɔ k| je|a y| ka|eny|gba|nɔn| su|ɔnɔ|omɛ|o g|o v|eŋu|dɔn|ɔmɛ|gan|a e|o w| dr|e l|uɖe|nsɛ|eɖe|e w|waw|i d|i j|e h|jum|u ɖ|e g|a d|i c|ɔɖe|o s|hi |o d|ɔkp|alɔ|ɔ d|a l|vi |a w|i s|o j|in | go|swɛ|ka |ple|dɔw|ŋuk|a v| be|atɔ|wen|o ɔ|iyi|je |ana|lan| xo|vok|ɔ l|ɛ c|u c|akp| ak|e d|e c|ɖeɖ|we |xwe|ɛwo|esw|bes|o p|any|kpl|uku|nwo|bu |ke |awo| et|byɔ| by|ɛbu|mɛb|i t|gam|ɛns|xu |oɖo|ega|nuw|a x|ann|a a|pɔk|ɔnd|eto|n n|e y|kan|ɔnu|mɔ |o c|yɔn|bɔ | ɖa|so | xɔ|gom|iny|gbɛ|leŋ| pl|wat|lɔn|yiy|u g|ɔnw| ju|ɛke|nɛk|ɔ t|a h|a t|n c|kɔn|ɛ ɔ|aŋu|i g',
    'arl': ' na|a n|iya|ani|na |aja|a p|ini|ra |ia |ya |a m| ma|pue|naa|qui|ish|ara| pu|cua|aar|aa |nu | pa|uey|a c|eya|shi| ta|ari|a s|ano|a t|ja |no |a j| ji|sha|nia|aca| qu|yan|ria| ca|jiy|ana|niu|ta |ata|maj|hiy| cu|aaj|aji|onu| ni|a q|jaa| se|iti|nii|iis|iji|tam|uaa|nin|mii| mi|u p|pan|hua|car|jan|ri |san|aat|niy|uet|uaj|ni |man|unu|pa |ua |iri|uhu|can|yaj|que|tia|ocu| sa|nis|mon|amo|saa|jin|han|tun|etu|esa|o n|uin|mar|hac|ojo|iqu|juh|te |i n| ja|aqu|tio|iur|asa|uri|uan|jio|u n|ura| po|osa|ian|a r|equ|yat|i p|ios|jua|anu|ioj|oon|ant|jia| so|nte|ama|seq|io |iu |taa|nio|ses|oju|iij|iit|nur|sa |uia|ji |i m|riy|soc|iir|u j|poo|ca |i c|niq|o m|iar|enu|iaa|aju|ucu|u t|osh|o p|uiy|tas|nti|uis|o j|ati|acu|iaj|uir|naj|tij| ju|ash|cam|nij|ami| to|jii|oni|maa|jiu|jon|noj|jos|tes|art|ont|apu|oor|tar|yac|uit|yar|mas|ora|tan|iin|rin|aan|sac|ota|oji| ru|yoc|ate|rac|hit|ase| no|ues|rio|cun|era|iuj|are|toj|i s|uac|eyo|tap|ori|e s|uju|cas|e t|aso|yas|e n|ree|uer|uji|ion|his|riq|aj |joo| ti|ohu|esh|ejo|yaq|coj| sh|u m|sen|tis|hin|saq|uas| co|nuj|rta|nar|u c|uii|aru|ias|o q|asu|mue|ere|ras|uqu|ete|uta|j i|uar|haa|uno|uuc|uen|ser|i t|too|eto|ruc|ee |i j|sam|o s|rup|oj |soj|oot|aje|raj|upu| mu|nit|jet|roo| ro',
    'ppl': 'an | te| ta|al | ti|pal| gi|at |chi|t t| mu|it |eli|wel|tay| ne|ay | ga| pa|i t|wan| wa|ga | we|ne |et |uch|muc|li |a t|su |hi |met|hiw|e t|a g|tiw|lit|tik|eme|hem|ehe|teh|gan|iat|n t| ya|iwa|git|t g|egi|esu|tia|tes|ia |ina|ech|ha |i g|a m|ipa|yah|tec|aha| in|ich|gic|uk |a w|wat|neg| ma| ip|l t|u t|ati|t w|pia| se| u |n g|gen|t m|aga|ti | ye|l n|iwe|ine| ge|wa |te |cha|wit|k t|ek |yek|y t|emi|nem|tuk|a i|n w|gi |gip|na |l m|a n|aht|han|mat|se |hti|y y|ya |ma |xti|en |tah|ipi|n m|nat|mun|iwi| tu|y g|n p|imu|tim|ita|mi |gin| su|cht|i m|k s|e g|a p|ixt|ta |awi|wia|uma|t n|upa|u g|une|i n|mum| ag|i i|t p|ni |i w|ik |ama|ka |teg|l g| uk|ima|gim|t u|iwt|l w|agi|mag|tam|ikn|ach|kch|ikc|y i|i p|ak | qa|htu|tka|atk|uli|kne|gix|lwi|ilw|qak|hta|tig|u y|dat| da|kti|tup|tal|tan|eza|nga|eng|mac|i y|aya|tat|ikp|pat|a y|wtu|gez|age|tag|tin|t i|n i|u w|may|awa|ami|tit|tul|iti|mit|za |n n|iga|uzu|puz|mup|wi |igi|kpi|u a|ite|uwa| ix| nu|ini|uat|zua|ikt|taw|mui|net|e a|k g|ani|ewi|k m|una| na|ukt|l i|gal| ch|y m|n y|a u|wag|a s|axt|iaw|yaw|pa |l y|l p|k n|iw |lew|ale|nan|mut|n s|muw|k u|e n|u p|e p|lia|yuk|eyu|sey|uta|nam|mpa|san|usa|nus|gil|t s|atu|ixp|iya|gah|u m|l u|epa|k p|nwa|anw|mu |til|nex|e s',
    'aar': 'ih | ga|ay | ka| ma|ah | ta|gar|le | fa| le|num| ke|ee |kee| nu|aam|at | ba|um |h g|ar | ya|r l|nna|lli|ta |li | ku|fax|inn|mih|iin|add|ull| ge|itt|ami|kul|al |taa|a k|akk|kaa|yaa|dda|i n| wa|ma |kay| ca|gey|h a|e k|baa|nay|hin| hi|an |tak|am |y k|oh |axx|ik |urr|ama|ala| di|aa |ari|eya|aad|ayy| he| du|h t| is|to |ak | si|a d|tan| ad|mta|imt|xxi|rri| cu|rit|du |adu|isi|lle|aax|yan|axe| ay|aan|eh |ita|si |uk |kku| in|ada|ina|xe |yyu|a m|tô |bel|xim|h k|cur|da |tta|ayt|nam|aah|a g| ra|axo|aal|unt|yun| sa|ltô|elt|ebe|heb|iya|sit|ni |de |ink|eeh|rwa|arw|ara|ku |e t| ab|kke|gal|doo|h m|sin|o k|ell|all| da|h f|tii|ani|mad|sa |yat|mar|uh |e a|nki|tto|bar|i g|m i| xa|sih| gu|ol |k y|m k|a h|nti|aga|bax|ke |kih|e g| el|maa|lee|udd| um| qa|na |e h|nu |ddo|lat|ino|a b|dde|edd| ed|uud|riy|waa|dal|m f|nni|mal|t k|emi|eem|ana|h c| do|e d|a x|saa| xi|e w|qa |toh|la |cad|i b| ag|ki |y a|ale|duu|te |l t|een|e c|ot |t a|dat|rih|ti |ima|day|att|aaq|abb|u i|axa|dig|ô n|aca|way|ola|ata|gat|naa|i a|dii|uda|t g|i k|eni|e u|abu| gi|raa|a f|ysi|aba|waq| an| it|nah|em |ane|aqa| ha|h i|mik|dud|ams|gam|nim|iim|it |uma|e f| te|oy |m m|a t|anu|ool|adq|aki|mma|umm|axs|ô b|h h|dah|tte| to|aab|had|eha|see| se|mat',
    'bax': 'é |e n| ng|te | yi|ne |shi|ét| ke| ns|yi | te|úe|ngu| pu|́t |i n| mb|a n| sh|nsh|e y|ié| mf|e m|ké| nt|́é|ée| gh|hé|nga|ghe|́ k| mu|́n |mú|́ m|mfe|ún|fé|e p|me |kê| yu|̂t | na|êt| ne| pe| nd|hie|t m|́e |o’ |ua |pua|a’ |re |she| ku|be |mbe|ú |na |t n|ntu|n n|’ n|he | me| nj|pe |i m|kú|hi |tú|gu |’i |ga |úm|tu |gú|shu|e s|̂ n|́m |u n|èn|sa’| a |a m| ny|â |yú| pa|a p|am |ùe|û | wu|e k| lo|́ n|ap |̀n |lo’|m n|pa |ér|i y| nk| tu|tne|́tn|i’ | fa|e t|gam|̂ne|t p|t y|’sh| ma| la|e l|nyi|a s|́en| po|nje|e a|mo’|nsa|gû|yü| gu|́ú|úu|i p|èt|nda|nte|t k|̈tu|üt|nyu|́ g|́re| fu|yu |n m|u g|e f|’ t| mo|wet|nta|em |ô |en |it |mbi|a y| sa|kè|a k|ete|n k|mgb|i t|r’i|e g|m t|puo|î |uo |i k|́ y|’ y|kwe|́ t|mi | mi|u m|bè| mg|da |m m|ire|̂ p| ṅ|gé|nge|̂me|m p|pô|jé|’ s|ú’|n g|fa’|wum|’ m|pú|́ s|t t|p n|lé| le|esh|ndi|’ne|té| kw|ume|̀te|gbe|nke|yir|yé|ân|nji|eng|ene|vé|nâ|̀t |u l|a’n|bô|i l|fú|a t|yù|fa |ôn|nku|ndu|ka |n p|’ p|ndo|msh|nju| ye|nen|tke|lú|mbo| i |e r|̂ y| li|’ k|la’|iny|yin|et |pme|upm|wup|sha|hî|̀e’|’ng|dem| lu|̂re|mbu|sho|én|’ f|psh|i s|̀e |̀en|hi’|e’s|mes| ka|èr|tè| su|hâ|́ke|ék|nse|e w|̂ t|jit|a l|âm|́tk|ot |uot|ùt|bit|t g|u’i',
    'nku': 'ʋn | lɛ|lɛ | bɔ|bɔ |ʋʋn|ɛɛ |ɛ h| hʋ|an |hʋn| yʋ| ma| ya|yʋʋ|aa | pɛ|aan|pɛɛ|rɛ | hɛ|ɔ y|ɩn |maa|ya |hɔ | hɔ|a b|n l|ɛ b|n y|ɛ y| sa|wɛɛ|ɛ l|n m|n b| wɛ|n w|a y|ɛrɛ|n h|n p|ara|ra |mar|kɔ |ɩɩn|gɔ |’n | ha|ri |ɔ b|a h|haa|nɩn|hɛ | ko|nnɩ|ɔ h|ŋɔ |ɛ m|rɩ |saa|ori|ɩnn|a m|aak|ɔ s| ba|kor|n k| gb|ɔ g| yɩ|ɔ l| mʋ|n d|nan| rɛ|i h|yɩn|a l|mʋn|nm |ʋnm| da|nŋɔ|akɔ|yaa|ɩ h|sa |bɔɔ|ɛ s|ɔ r|ɔ n|ʋnŋ| rɩ|hɛr|nɩɩ|n s|ɛgɛ| bɛ|ʋnn|ka | nɩ|ɔgɔ|hɛɛ|wɩn| wɩ|gʋʋ| gʋ|aba| bɩ|bɛr|i b|ɩ b|nkɔ|yʋg|ɛ d| ti|a t|ba |bɛɛ|gbɛ| tɔ|ɔ m|laa|yan|ɔ d|n g|ɛ p|n’n|ʋn’|n t|tɩɩ| tɩ|m h|ɛ t| a |aɩ | dɩ| ji|a r|dɩ |ɩ y|ɛʋn| la|i l|nʋn|dʋ | dʋ|a w| gu|ɩla|bɩl|daa|go | mɩ|gɛ |gu |nnʋ|ɔ k|ɛ k|ank|n j| ab|ɔ z|nʋʋ| nʋ|ɛɛʋ|ogo|ɔ t|bii|a s|ɔɔ |nka|ɩnk|in |iin| bi|ugo|bug| bu|si | si|ʋgɔ|zʋn| zʋ| ka| le|ɔŋɔ|ɔɔŋ|hʋʋ| na|ɩ l|tɛg|ɛtɛ|tɛt| tɛ|gbe|ɩnŋ|ina|jin|dɛ | dɛ|ɛ n|o b|ɩɩ |sɔg|mɔ |ii |sɛg|ɛ g|a g|ɛ j|taa| ta|oo |lag|cɛr| cɛ|a’n|ba’|yo |yog| yo|a a|mɩɩ|i y|’rɛ|ak’|ei |oi |ʋ l|ika|zik| zi| su|nrɩ|ʋnr|ɔɩ |ɔ a| kp|ege|beg|gʋ |ʋgʋ|gaɩ|ɩga|jɩg| jɩ|ti |ɩ t|ɛɩn|ɛɛɩ|dan|baa|ɔ j|ŋmɔ|nŋm|ɛ r|ɩgɔ|tii| go|n n|o l|a n|ʋ m|ɛ’n|gɛ’|gus|ga |jab| ja|ɔ p|yoo|oyo|ooy|goo|ugu|dug| du|agɔ|ji |ɛ w|o h|hɩn| hɩ|ɛsɛ|rɛs|ɔm |lɔm|ni |o r|mɩn|u b|iyo|miy|omi',
    'cbi': 'tsa| ba| ju|in | de|ain| ts|nu |bai|aa |naa| na| ti|u d|ve |a t|ya |chi| ne|la |ne |chu|u t| ch|u j|hu |a b|e t|u b|ba |dee|nts|san|hi |jun|a n| ke| mu|n t|a k|tyu|sa |uu |unt|ang|ech|enu|anu|ach|eec|nge|ti | ya|cha|hac|e n|ave|ala|eta|a m|yu |uty|uba|lla|ju |inu|ñu |a j|jut|n n|saa|tu |nuu|det|tya|uve|en |ill|a d| mi|ken|tav| ma|juu| ta|aju|unu|u k|gen|tal|i m|aat|hil|sha|ren| ka| pa|tin|aaj| ty|ush| ki|u n|ha |a c|ke |are|u c| tu|mu |shu| ve|ra |eju|ash|ata|i k|uñu|muj|i t|min|aan|i n|tse|dej|mub|sen|di |u p|ika|kee|enm| bu|n m|e m|ity|ude|n j|ee | ku|and|i b|nmi|taa|aak|kut|i j|vee|ura|aya|aka|paa|ehi|añu|u m|e y|was|a p|ale| i |awa|ndy|ake|bul|mij|bal|hun|a i|ike| ur|ija|ka |nde|lu |ela| nu|ngi|tad|shi|juv|juñ| la|kaa|n y|jtu|uud|itu|e k|era|ind|nch|ara|e j|umu|kar|een| su|adi|eet|esh|ge |ai |kik|i d| pu|dya|lan|a y|tus|ate|n k|tit|a v|de |sar|end|man|yuv|uti|den|ma |ñub|eng|e v|kui|aaw|e d|iba|iñu|udi|iik|yee|tye|le |kay|buu|uku|u s|yan|sai|iku| lu|jeh|uje|jch|ujc|uin|yai|mit| uu|i c|ety|a a|uus|emu|iya|uta|e c|ent| en|i p|n d|ure|dek|nut|nda|eñu|ndi|sat|a u|ull|anc|din|kii| aa|uwa| ik|aal|maa| wa|eel|aeh|laa|pud|amu|ish|ru |ula|ait|und|utu|ulu|ama|ati|ire|e l|ana|ees|eve|ats',
    'crh': ' ve|ve | aq|er |iy |lik|lar| ma|mal|ir |na |ına| ke|a m|da | er|aq |an |tir|aqq|ali|r k|qqı|maq| ya|en |ler|qın| ol|ikt|kes|es |kti|ini|r e|ala|lma|nda| ta| qa|ek |de | bi| se|lan|mek| et|ser|ğan|eti| de|eri|est|bes|rbe|erb|ar |arı|q a| da|alı|bir| me|gen|a d|ni |ası|yet| iç|dan|ara|ıñ |nıñ|rin|tli| ba|ne | öz|a b|ınd|ya | sa| qo|et |iñ |niñ| te|sın|ine|e b|qla|ilm| be| al|nma| mu|stl|ün |e s|e e|ır |olm|dır|tas|öz |let|anm|etl|iye|emi|nı |qor| es|ıq |lme|ket|asi|siy| bu|ile|mus|ik |miy|aat|e a| iş|çal|tle|e q| ki|lıq|tme|etm|rı |aql|il |e d|til|r v|irl|r a|ız |esa|are|sta|eke|lğa|e m|lge|n e|mez|qat|nde|igi|lig|ill|ıdı|qar|n q|rle|ola|ağa|st |rın|esi| va|atl|ı v|sas|le |lav|rça|orç| ce|a o|kim| şa|bu |kle|ikl|gi |den|y v|li |lıd|nen|ğa |viy|arn|evl|ast|sil|tke|tla|ez |k a|t v| on|tin|sız|eme|anğ|e y|ege|taq|mle|ilg|r b|mil| di|ril|avi|sav|usa|k v|cem|ı i|ını|baş|and|z m|vle|dev|e k|etk|y t|çün|içü|i t|k e|len|tar|anu|qan|sin|e o|ılm|onı|ut |hut|ahu|yah|ken| qu|se |mse|ims|şah|q s|ter| ha|mem|e i|ede|r t|aiy|liy|lli| mi|aqı|ard| in|n i|şqa|rme|mes|ber|say|rek| ar|dal|t e|ina|em | em|tem|a q|ı q|aye|atı|oğr|mla|aqs|rli|q v|ahs| fa|r i|ama|nğa|ıñı|eki|n v|re |i i|n m|rge| il|zar|i a',
    'duu': 'ngx|ix |ing|gx |ax |ang| av|ngf|nin| ni|gf |x n|anv|lix|ev |yv |x a|uan|lf |alf|vli|zan|anx| al|lev| le|x s|nx |x j|jua| ju|ong|nvl|vza|avz|f a|x z|ngv|x l|ux |v a|f j| ma|sax| sa|x m|x g|uiv|xin| to|gui| gu| ji|yan|zyx| zy|ef |x t|f s|iv |if |f m|px |opx|top|vji|ivj| xi|ov | se|uix|x c| ef|yyv|xyy|yxy|eng|ox |syv| sy|nf |f g|yox|sex|aix|max| go|v z|v g|v t|nyv| ny|man|myv| my|v l|gon|hui|xhu|v n|jia|x b|vna|yvn|iax| fa|jyo|yx |nv |cax|hov|x e|six|yix|f n|v m|enx|jiv|zon| zo|nxy|x x| cc| mi| zu|v c|ren|exh|jix|cca|mix|inx|nax|f c|jin|gxz| bo|dov|env|sen|ian|xxi|f l|v j|lan|eiv|xia|bof|faf|xyu|xyi|zix|x d| ca| jy|unx|avl|wei|bix| bi|v b|x f|gv |oxy|vsi|zux|xji|ex |xya|av |v s|x h|xzi|vla| si|af |yux|enf|zzu|anf|can| ga| ta|uf |x p| ho| we| cy|zen|hux|pin|ixy| da|f x| zz| re|jie|xjy|gxj| an|vxi|xzo|gyx| gy|ymf|cym| yi|x y|v x|inf|f f| ce|uxz|fli|afl|uvl|f p|nxj|avn|tai| do|nxz|aif|yf |dyf|avd|ofz|bya|zui|xka|xdi|ixb|cen|gvs|den|xse| fu|v f|f t|xxu|fuv|zun|sal|vsa|avs|vhu|oxx|xza|jya| ty|iex|hun| hu|fby|sux|v w|yua|nvh|vdy|ton|fdo|mfd| la|fza|siv| ze|ixx| ko|din|wux|lx |vwe|gvw|fhu|ofh|vde|gvd| pi|x w|vre|x r|v k| cu|ivt|uv |fzu|f z|rif|bri| br|nyx|vny|xra|lya| ly|lif|v e|f b|cuf|pyv',
    'cfm': 'ak |nak| na|ah | th|an |ng | si|ei |in | in| mi| ah|eh |seh|the|h s| pa|hei|ise|si |sis|i n|ang|n n| le|kha|le |k a|ih | a |am |h m| as|i t|ram|um |awl| ma|nei|asi| ka|n t| ne|paw|h t|ii | kh|thu|at |en | ii|ing|wl |i a|kan|mi |g a|din|ai |ung|i m| um|al | cu| hl|mai| ra|hu | da|uah|n s|n a| di|m n|un |h h|hat| hr|h n| za|p i|lo |t i|lun|nga| ih|k n|nun|tha| lo|gah|a s|et |uan|ip |kip| tu|n z|k i|k l|iki|mik|h a|n m|dan|len|aan|tua|zet|i h| an|k t|zal| ze|hra|hla| hm|pak| tl|m h| hn|phu|i c| co|awn|haw|ale|k k| te| aw|vo | su|min|l a| nu|ovo|cov|cu |akh|rua| ru|im |tlu|inu|awk| ba|daa|l k| ti|n k|n l|hmu|ar |g p|wk |h d|uh |i i|ban|l t|hal|m t| la|maw|i p|eih|n h|wn |l n|i s| ng| sa|hua|k c|ui | ph|mip|u a|lei|sua|ual|g t|h z|k d|h c|om |n p|k p|il |h p| ca| zi|sin|o k|ek |kom|cui| se|lah|hun|hle|zir|h u|m l|inn|i l|k u|n d|h r|mua|law|rep|thi|a t|hna|rh |hi | hi|a h| ki|o i|par|m p|aw |ha |h k| ci|ida|i z|ep |gre|ngr|ir |e m| ha|u r|ipa|ian|wh |awh|g i|h l| hu|i r|hri| bi|h b|n i|o t|t n|duh| du| fi|h i|awi|sun|n b|a k|san|tik|l i|thl|man|hlu|e a|i f|sim|g d|pa |ran|han|i d|e z|a u|u h|ik |nn |lh | ko|l h|m i|vek|hum|wi |m a|iak|bia|m m|u t|k r|fim|i k|k m|n c|ril|e i|el |pi | ta',
    'fat': 'a n| wɔ| no|no |dɛ | dɛ|ra | a |mu |dzi|na |a ɔ|nyi|wɔ |ara|yɛ | mu|iar|bia|a a| ny|a w|an | bi| na|ma |ho |ndz| ho| ob|obi|e n|yi |dze|oa | nd| ne|noa|ne |ino|zin|a d|man|tse|ana|zi |a m|u n| an|ɔ n|o n| ɔy|ɛ ɔ| mb|ɔyɛ|ɔma|ɛ o|ze |naa| n |bi |nya|n a|aa |yim|ɛ n|a o| as|n n|yin|ɛ w| on|ɔn |ama| hɔ|o a| am|ye | ɔm|nny|o m| ma|e a|i n|hɔn|ɔ d|i m|ina|mpa| ba|kwa|i d|uma|ɛm |ua |do |o b|wan|ɔwɔ|ase|o h|bɔ |i a|mba|ya |ɛ a|nye|ɔdz|imp| do| wo|ets|se |mbr| kw| ɔw|wum|dwu|a b|ɛ m|n e|pa |o d|sen|u a|o k|edz| ed|aho|onn|tsi|m n|eny|a h|uw |kuw|ba |amb|hyɛ| dz|adz|w a|ena|ɔts| ad|sua|bra| so|fo |som| yi|wɔm|odz|ɔ a|i h|er |abɔ|o w|ayɛ| bɔ|nko|so |set|ban|o o|fa |om |o e|ɛ d| nk| ts| en| fa|ow |ber|ony|m a| ab|sɛm|kor| nh|fi |ɛ b|ɛɛ |oma|wom|nwo| nw|nhy|r n|mam|w n| ns| be|a e|a k|n b|n d| gy|ia |any|e m|ee |gye| nn| da|yam|hod|n m|dɛm| ɔn|u o|e b|ea |adɛ|aad|or |gyi|nam| aw|ɔfa|u b|iyi|yɛɛ|en |am |fah|asa|asu|mas|edw| ak|ar |pɛ |ehy|yeh|hye| ɔd|mbo|i b|asɛ| nt|ata|bu |aso| fi|ɔ h|sia|e d| ɔt|rɛ |i w| yɛ|a y|um |tum|war| ku| ɔb|hwe| mp|sea| ɔs|hwɛ|ew |abe|kã | ɔf|wɔa|a f|da |ɛ h|dwe| pɛ|sa |wɔw|oro| ah|ɔbɛ|r a|yɛf|eyi|otu|nsa|row|i ɔ| ky|nts|wɛ |yer| ar|ta |ɔ b|aka|gua|o t|e f|eso|in |ame',
    'ido': 'la | la|ta | yu|ar |so |ro |yur|o e| e | di|eso|al |a y|o o| es|as |uro| om| pr|o d|omn|di |a p|a l| ko| li| o | re|s l| pe|nu |mnu|per|ava|ua |to |vas|res|ion|i e|hav| ha| su|o p|ita|ri |ez | ed|ber|ibe|lib| in| po| se|cio|a e|ant|nte|a s|ere|er |u h|ata|pro|r l|ese|e p|e l|uri|ter|sez|a d| de|nta|en |ed | ne|do |io |rga|pri| da|ekt|lu |irg| ir|o i|go | en|kon|aci|ra | lu|a k|ga |kom|nal|ika|r e|a n|int|ial| so|nac|o k| na|ece|esa| nu|oci|soc|ona|ala|dar|re |kto|a a|sta|ni |ent|u e|es |i l| ma|sua|l e|or |r s|uni|i s|ne | a |sti|i p|gal|ega| eg|i o|ale|var|da |tat|e s|and| fa|nul|o n|oni|o a|o r|o s|esi| al|ers|nci|no |nes|e d|te |i d|r p|por|lua|e e|ria|d a|cev|rec|tre|ont|tek| pu| qu|eri|a f|a o|lig| ex|ing|ca |ltr|alt|l a|eva|co |i n|na |pos| ad|ote|rot|sar|ulu| vi|nda|ena|art|ndo|aca|igi|o l|le |sen|nti|zit|izi|riz|era|pre|ado|un | ku|oza|lik|ti |ntr|ten|ern|nio|l o|dis|kla|si |s y|tra| un|ono|rel|a r|duk| pa|nar|tar|e f|mar|r a|r i|ili|ces|il |sa |bli|fas|rfa|arf|lo |est|tri| ar|iva|tal|ami|eku|vo |zo |imi|mis|par|son|rso|qua|lan|rna| pl|cia|kal|tik|iti|eli|mpl|ngo|tin|ist|ver| ag|tit|d e| ho|mna|uka|edu| ju|o j|po |ral|e m|dil|pi |kti|i r|ica|eda|sed|ose|e r|uza|eve|de |bla',
    'ina': ' de|te |le | le|de |e d|ion|al |tio|on |ere|ate| e |to |ect| in|tat|ent|e p|cto|rec|ote|der| al|per|e e| pe|e a|es |ati|e l|ita|ess|ona|o d|nte|er | to| su|del| pr| ha|in | es|tot|el | co|e i|a l|ha |os |e s|ers|men|o a|rso|sse|su |son|n d| a |pro|ser| qu|cti| un|na |un |ter|e c| li|s e|qua| re|ite|nti|ber| o |ia |a h|con|ual|res|ali|tia|ant|era|nat|ibe|lib|ar |ra |ic |n l|tra|ue |cun|e t|tos|nto|que|nes|ari|ecu|l p|nal| di|e o|o e|lit|rit|n e| na|ame|a s| so| po|lic|ist|tes|ert|a e|e r|one|io |l d|soc|e n|dis|ste|r l| il|nit|ssi|ro |com| pa|n p| se|a d|n a|rta|o l|rat|equ| eq|re | ma|e m|l e| ac|l l|oci|o s|lig|cia|e f|s d| as|bli|e h|ge |nec| ne|n t|act|l s|sta|eli|so |l i| ca|as |mit| tr|se |o p|e q|cla|n s|lte|alt|ill|lo |ass|est|nta|sec|nde|fun| fu|pos|ial|iti|igi|lle|s i|man| me|eta|uni|r s|eme|pri|ri |l m|pre|bil|r a|pot|e v|a u|cat|min|rim|ont|n c|tec|l r|ura|vit|imi|ta |rti|tor|int|o i|und| fa|tic|s p|cie|val|edi|ios|ene|ici|a c|ili|sat|ica|ile|abi| ex|rar|ten|ntr|rot|no |uno|u p|cur|a a| vi|ndi|dic|sit|ine|ori|inc| is|e u|ebe|deb|isa|med|ral|mar|r i|ato| el|lia|sso|acc|art|par|ime| ar|inf|o t|for|ict|fic| sc|tit|itt|pen|ind|a p|rio|l t|ais|pai|nda|cit|non| no| pl|nqu|unq',
    'ktu': ' ya|na |ya |a k| na|a y|a m| ku|a n|u y|and|a b| mu|wan| ba| lu|yin|tu |yan|ve | ki|ka | yi|nda|a l| mp|la |di |ndi|ana|ntu|si |so |da |ons|e n|mpe|aka|nso| ke|pe |mun|lu |unt|i y|alu|o m|sal| ma|luv|ta |ina|e y|ke |u m|uve|nza|ndu|u n|ban|ala|i m|za |amb|fwa|u k|to |isa| ko|kon|ayi|o y|ma |du |kim|ulu|kan| me|ang|usa|kus|ama| to|wa |end|anz| ve|a v|ins|yon|nyo| ny|nsi|i k|a d|i n|sa |mos| mo|mbu|und| bi|osi|uti| fw|ika|e k|kuz|len|imp|mab| le|ind|vwa|uka|ata|tin|pwa|mpw|kuk|ba |uta| at|adi|mba|mut|olo|sik|ngu|bu | di|kis|ila|lo |sam| sa|isi|e m|usu|su |ngi|ula|mu |abu|nga| nz|lus|yi |yay|but|o n|e l|ni | nt| ka|dya|kak|dil|wu |awu|esa|amu|ti |imv|o k| bu|bal|e b|kul|ant|gu |ngo|inz|bun|a t|mpa|utu|kin|iku|dis| dy|nka|ank|mvu|u f|ong|uzi|zwa|i l|bim|sad| mb|vuk|dik|uzw|lam|tan|mef|idi|usi|mus|lwa|fun|kuv|ga |ken|bak|ing|luz|ela|baw|bis|yal|uya|luy|bay|nsa|mak|kut|ku |nta|ibu|kub|a a|atu|kat|ufu|uvw|i t|i a|ani|swa|uza| ni|uku|tuk|kol|lak|uso|ola| ns|twa|uko|pam|efw|bam|i s|eng|umb|don|ndo|yak|u t|iti|mbi|eta| nk|iki|gi |a s|luk|sol|nzo|te |nak|oko|mam|tal|pes|dib|u b|ati|gid|uke|nu | nd|umu| vw|ilw|dus|luf|zo |mvw|met|bum| ng|sul|ima|wel|kwe|ukw|zol|yam|ota|kot|lan|zit|i b|i v|kun',
    'fkv': 'en |on |ja | ja|oon|in | oo|an |ikk|la |ise|kke|n o|oik|n t|keu|n j|a o| oi|ais|aan|haa|us | va|ta |n k| jo|lla| ka|eus|itt|sta|n e|än |ist|nen|iin|n s|et |jok|tä |lis|sen|a j|sa |tte|ett|ään|kai|kha| ta|ell|sel|aat|ali|le |hee|hai|aik|okh| hä|eli| ko| sa|hää|tta| ei|hän|ssa|ksi|een|ko |ä o|a t|uks|at |pha|aph|vap|a k|n m|hii|mis|äne|taa|ei |tah|ans|ine|iss|ast| ol|tha|aal| mi| el|sii|i j| si| tä|kan|li | ma|oli|lai| tu|iki|a h|ttä|per| pe|a p|ti |ten|a v|eth| pi|kil|sti|ii |hi |ahi|ois|a s|sam|thä|te |tää|ish|i o| se| te|isu|tti|sil| om|ila|ä j| la| et|sä |oll|suu|sju|asj|ole| ra|man| ke|oma|nin| ty|stä|työ|lin|ala|ä t|i p|the|lii|oit|hau|ämä|mat|ama|lä |sis|a m|ssä|val|min|uun|iit| he| ih|ää | yh|kä |sth|att|she|s s|maa|naa|hen|pit|n p|kon|usk| su|aas|ust|ill|nii|oin| to| jä|t o|ain|n v|hmi|ihm|yöt|sty|n r|vas|suo| lu|i k| ku|nas| na|sko|tus|täm|net|ile| ni|ä k|hei|pet|ope|aa |nni|nsa|est|uoj|it |a a| pa|pa |e l|joi|omi|iaa|i m| us|ink|lma|ilm| il|shi|jul| ju|isi|t k|saa|het|uet|eue|t s|set|etu|ötä|aha|ulk|rus|eru|ess| hy|ket|tet|ava|ä v|ter|n h|i e|n l|uen| so|una|jun|n n| mu|euk|tuk|n a|ns |ät |äät|t j|eet|a i|ki | op|utt|ä s|han|t m|lki|ses|yst|eel|kkä|mik| ky|imi|uom|tuo|tii',
    'lat': 'is |et |us |ae |tat|um | et|que|ati|ue | qu|est| su| co|ion| po|em |oni|qui|ius|tes| in| iu|ate|e i|ent|ote|pot|tis| ha|abe|eri|ita|bet|bus|s e|hab|uis|s p|uae|ibu|tem|sua|sta|squ|isq|end|tio|per|m h|con|nis|nti|es |ndi| de| pr|ium|ici|ter|e q|s a| re|ips| ip|am |dis|s i| di|e c|ibe|lib| ho|i p|rum| ad|nte|rat|ri | li|psi|di |m e|rit|ili|e s|tur|iur|omn| om|mo |siu| ve|t s|vit| si| nu|one|ert|a e|ra |st |ber|ine|it |ari|ut |gen|t a|t p|hom|and| ex|tri|nda| pe| cu|atu|rim|s c| op|ne |qua|int| pa|min|nib| pu|ta |nem|i i| ge|in |nt |s s|cie|t c|ur |e e|ad | ne|ivi|s v|ia |m p|mni|e p|iae|re |nes| ut|leg|ali|lic| vi|el |vel| at|ris|rta|ura|a s| es|tia|par|t i|s d|s h| so|ina| fa|quo| mo|rae|iis|sin|tqu|atq|e a|isc|ull|civ| ci| se|cip|ien|s n|te |era|eta| do|bli|ubl|pub|t e|fic|ni |equ|ua |i s|t d|com|m c|t h|ui |tiu|men|nul|ini|s l|ria|pro|io |ons|unt|dem|da |a c| ca|a d|a p|ffi| le|oci|erc|ten|tut|omo|mod|dic|sui|ii | au|ere|pra|cri|gio|tus|lar|er |t q|omi|iet|soc| al|ssi|rce|usa|sti|ica|ei |lia| ae|nae|ers|omm| ma|e o|ute|itu|o i|emo|o n|m s|i c|ori| te|egi|ea |imi|s o|rel|ant|niu|rti|sci|ntu|i e|ope|rin|t o|mun|sit|pos|aru|as |m a|iqu|tel| mu|fam|ex |ces|sa |aus|cau|ela|a i|de |lla',
    'glv': 'ey |agh| ch|ys |yn | as|y c|dy | dy|as |gh |ooi|ley| ny|ee |hoo| er|lle|ill|oil| ta|ta |ny |bee|ne |rys|cho|air| ca|s e|ane|hey|iry|cai| ec|er |nna| un|it |nan|unn| sh|a c| gy|ght|ish|ec | co| y |oon|sh |ht |ghe|eh |sho|rbe|erb|y u|yr |c d|e e| be|che| ay|gys|yns|y a|s c| ve|nag|cha| yn|ayn|sey|yss|e g| da|esh| se|s s|syn|she|ash|il |ail|ris|eyr|y v|hag|e a| je|y s|rag| lh|n a|ns |ssy|h a|y e|ney|s d| fo|nys| st|hee|e t|h e| le|oo |ell|ie |jeh|hie|h s|hes|e d|y d| fe|da | re|y g|sha|y h|ve |r n|ha |n c|coo| el|rry|obb|ech|rit|iag|shi|h c|ll |nyn|id |n o| so|y l|h y|e s|on |soo|orr|hyn|l s|t d| e |lei|a b|lit|rri|l a| ma|s n|h t|sag|lhi|rym| gh|e y| tr| cu|e c|urr|s y| he|y n|r e|’n |ona|hoi|sta|eih|lyn|oai|h n|oh |hoh|n t|sny|rsn|yrs|ad |ym |y t|nsa|oi |cur|t e|t a|dey|ddy|tey|r c|n e| go|ett|mag|a s|al |shl|cor|r a|oin| ob|t t| li|s f|rra|n l|chu|oad| eh|rso|ers|eer|gyn|iet|n d| oc|se |s a|gho|hoa| vo|tra|osh|iar|ori|ior|lio|ih | sl| ke|ene|hen|igh|eig|ann|red| lo| t’|an |e l|mys|h b|raa|eil| de|s l|s t| oo| ri|nne|ony| ph|ghy|a v|ees|moo|byr| ho|y j|rei|ade|h v| th|edd|noo|nno|n s|oid|s b|ick|ue |ayr|n n|lhe|rim|tri|h l|yd |h d|bby|kia| ki|thi| na|dei|a’n|es |vee|eu | cl|te |ogh',
    'mfq': ' g |an | u | ni| ku|en |yen| ye|ul | bu|ua | n |kul| yi|iko|yik| mɔ| l |ɔg | k |ba |al |l k|il |nŋ | ya|n n|nn |aa | ma| ti|mɔg|g y|l n|nin|n g|ug | ka|inŋ| i | wa|a k| su|aan| ba| bi|maa| po|wan|nil|oug|g n|po |n u|nba|ko |l g|g b|n b|o y|tie| nb|sua|od | b |l b| do|kod|dou|ann|l m|ie |a b|u b|aal| tu| gi| la|bu |n y|ii |yal|ban| da|gii| be|a n|bua|u n|n t|n w|iɛl|uol|lan|kua|a g|n l|nd |i k|a y|ɛl |n k|be |d n|and| si| lu|l y|ad |m n|kan|siɛ|taa|am |uon|ol |n s|n i|u y|g m|tuo|aad|u m| bo|paa|nm | ji|anm|yaa|gd |uan| kp|a t|k u|bii|buo| ny|i s| ja|iɛ |k b|b k|b b|d g|’o | ta|gn |g k|g l|ne | ne|l u| na|biɛ|d y|onn|nu |mɔn|ab |na |g s|ugn| ca|n m|ala|iil|ag | gu|u t|ien|n d|l t|i b|a d|u p| pu|nya|lie| li|o n|dan|agd|id |o k|ud |uud| sa|ni |bon|saa|ual| ci| yo|l p|you|u d|g d|kaa|g t|e y|l l|daa|yan|naa|eb |ieb| ga|ɔn |laa|o g|aam|g g|ŋ y|l s|b g|lua|u l| pa|iin|a p|k l|a m|lu |a l|ugd|lug|aɔg| ŋa| fi|i g|a u|o b| di|buu|ɔni|cab|dug|d k|n p|e b|e k|o l|nan|u k|tin|i m|kpi|kpa|nta|d l|n j|k w|d c|d u|ŋ b|guu|ŋ l| du|iɛn|jaa|u j|d s|di |e n|aat|m g|du |atu|kal|ana|gaa|n ŋ|int|ŋɔn| ŋɔ|da |dag|und|te |e g|ŋ g|aag|ŋaa|in |l i|la |a s|u g|l d|d d|nii|ɔnu|sɔn| sɔ|cɔl| cɔ|n c|jii|fuo|anf',
    'mxi': ' de|ne |e d| la|ion|e l|es |to |de |la |ent|one|tio|te | pe|os |per| in|tat| a |a p|le |a l|as |o a|ret|eto|ale|dre| dr|ate|ati|ta |na |ona|re |e a|les|nti| co|ene| to| e |e e|nte|men|tot|a s|ien|in |ia |el |tia|tie| ti|ers|a t|rso|tos|son|ota|ita| le|que| pr|e p|ant| au|con| li|e s|s d|et | et|res| el| qu|ame|cti|ber|ess|er | su| re|se |s e|o d|tra| se|s a|sse|sua|e t|nat|s s|nen|rà |nal|a c|e c|ual|ere| l’|ua |e i|lib|ue |ter|a a|ica|pro|a d|sta|bbe|nes|ect|t a| ad| al|ser| si|ato|nt |are|nta|o e|ele|erà|las| ne|nto|del| d’|omm|a e|io |iss| pa| so|ra |au |una|s p| un|ibb|ote|ssa|ond|est|tes|s t|rta|com| na|ias|ad |era|so |aut|cun|ert|s i|ten|ali|no |lit|s n|ont|vit|sso|ass| ci|ndi|ssi|cia|oci|soc|oll|e q|iti|aqu| aq|o s|gua|cas| ma|pre|o i|ria|den| fo|ial|lle| po|mat| st| di|s l|o p|ieu|sie|tiv|par|o t| tr|a n|ind|int|uno|mo |egu|oto| mo|act| ac|tal|ntr|tas|sec|ari|nde|tor|t i|dic|ata|fon|e n|a i|qua|ca |nio|ist|rat|alt|on |e r|t d| es|eta|lo | ca|l s|iva|n e|bli|n c|r l|cto|tri|rim|rot|ena|ura|ncu|enc|a v| as|pen|ut |ciu|nda|ori|uol|vuo|evu|sev|lse|als|lig|a r|sti|ine|cla|ltr|n l|rse|tan| eg|man|val|unt|ire|sat|lic|ste|rar|pot|d u|tec|rec|art|s f|ico|ecu|mmi| cu|a f| fa|e f|pos',
    'pcm': ' de| we|di | di|or |dem|ay |em | sa| e |ke |say|ey | go| an| to|e d|im |to |wey| ma|for| pe| fo|nd |go |on |ake| be|t t|get|et |y d| ge| no| na| or|de |ght|igh|rig| ri| im|ll |mak|e s|ri |e w|ht | do|ers| li|tin|and|eve|y e|son|rso|per| ev|am | am|be |e f|eri|do |ntr|ont|no |r d|ng |ver|tri|kon| ko|ing|o d|ne |one| ta|t r|m g| ti|ion|le |e n|e g|odi|bod| wa|aim|nai|i w|st |ome|an | so|i k|e e|o g|any|e l|all|ike|lik|m d|in | wo|it |i p|n d|o a|wan|fit| fi|o m|da |at |ell|t a|we |wor|m w|e t|e a|na | of|ust|mus| mu|me | co|if | if|ple|opl|eop|peo|f d|of |kin|e b|her|o t|is |dis|wel|o s|e o|lk |alk|tal|the|ind|y w|nt |so |t s|re |ent| on|y n| ki| al|er |ve |rio|men|m n|i o|m b|n g|y m|t d|k a| re|ta |ork|n e|ce |m t|n w|e c|oda| se|ive|ee |rk |ny |gom| ba|r i|m s|en |nod|ano|o b|d t|dey|l w|y a| fr|o f|r a|wn |own|eti|nob|oth|e m|com|ad |bad| fa| ow|ibo|obo|r w|y o|ree|r s|m o|m a| ot|se |as | as|arr|m m|i g|m k|k s| wh|y i|liv|a p|dat| da| ag|ow |g w|l d| o |o w|ry |m f|ut |wet|n a|sel|o l|t o|n o|ge |ok |ook|eac|rea|l a|od |d d|n b|d m|d e|i a|e i|out|rib|e p|ld |i m|i s| lo|ain|gai|aga|d p|a d|ata|ch |rn | bo|t g|mar|use|ly |ime|tim|ar |i f|s d|t w|y g|ood|bou|abo| ab|tay|m l|lf ',
    'niu': ' ta|aga| e |e t|aka|ke | fa|au |ata| ke|he |tau| he|ai |fak|a k| mo|ua |ga |o e|e h|i k|ta |a m| ha|mo |ia | to| ku|ha |e f|kua| ma|a h|u t|a t|gat|tag|e m| la| ai|onu|ton|ki |hia|a f|kat|ti |tu |uhi|e k|nuh|aha|na |ko |iag|atu|oti| ot| ka|ana| ko|a o|i e|mou|a n|u m|kau|aut|a e| na|a l|aki|i h|a a|i m|i a|kai|mat|lat|nak|oua|gah|u k|oke|pok| po|utu|i f|ala|u f|tak|tok|oa |pui|uag|aag| ki|ni |kak| tu|han|ama|e l|ui |la | pu|tai|oka|a i|ne |ano|afi|kia|kaf|uia|ili| ni|no |noa|kan|u a|hal|mai|a p|e p|kam|tah|ato|hua|ahu|i t|o k| ia|ena|men| me| ga|u p|ono|fai|e n|e a|lau| ne| ag|lag|afa|ehe|tua|tat|fia|mau|ipu|uip|vek|eve|fon|ufo|tuf|eke|i l|ka |oaa|oui|kaa|fil|lia|kah|oko|eki|lev| le|u l| at|tup|i n|aan|eag|lu |oki|ma | i |u h|loa|uta|nu |fo |aua|ake|ave|fet|afe|man|o m|ako|aak|aho|mag|to |ho |e e|i p|te |alo|tut|ale|pal|hag|oag|kal|toa| a |oto|ago|nai| ho|kit|iki|o f|o h|gi |lal|fi |laf|hi |tap| fi|li |keh|uto|fok| fo|koa|ofi|aof|tao|aek|ita|mit| mi|ute|o n|haa| fe|lea|ele|kae|eka|kot| no|agi|ola|iti|uak|pua|ifi|fif|tui|nat|u e|fan|ulo|olo|uma|tal|gaa|tot|oma|gom|oho|hol| mu|kel|mah|aui|upa|lo |le |ota|ofo|nof|lol|upu|oli|kap|apu|hau|etu| ti|olu|tol|nau| pa|aul| vi|alu|fal|ifu|lif',
    'kqs': 'le | le| o | wa|aa |do |an |o l|on | ni|wan|ni | ci| ma|lan| nd|na |a m| pe| do|ana|ngd|ndo| te|ing|yo |a l|ele| be|ma |ala| ko|lin| mo|a w| a | to|oo |ara|mo |a n|n n|o k| no|en | ba|cio|te |a d|tu |iyo|pe |o c|o w|e o|a k| we| ha|wel| li|ng |yi |non|o t|o n|nda|i m|a b|la |eyi|gdo|io |ra |baa|aki|hak| ka|e w|aar|laa|ola|o s|e k|e t| du|iya| la|wa |dua|u n|ton| ke|len|ndu|cie|ua |naa|i n|etu|bet|ong|da |and|kiy|a p|e n| so|e m|n t| ku|a o| me|a t|oi |doi|e b|e l|ceu|o b|n h|du |n d|ang|sol| su|ba | ce|kon|o o|daa|eng|yan|o m|den|mal|n w| na| ho|ina|un |ke |u l|gu |eu | yi| wo|e p|osa|tos|n l|ngi|end|o y|a c|e a| di|e s|u w| mi|yiy|i o|nan|i l|pil| tu|uey|i k|ann|i t|o h|a s|ole|ben|o a|doo|me | th|gde|kun| si|ool|o d|sa |nna| bi|ee |n k|waa| pi| yo|und| ve|lel|mi |uwe|gi |sin| sa|n b|ell|e d|mee|ngu|euc|u d|lo |ena|loo|ran|ko |vel|eli|n c|ya |n p|iin|koo|dii|wey|ow |ei | lo|i s|o p|yoo|woo|e y|a a|ula|a y|num| nu|ie |aci|uce|kal|aan|nta|ant|kar|pen|gda|sar|hoo| ye|thy|now|dan| ti| de|don|be |sue|i p|ene|e h|gba|n m|nga|kan|u o|yei|ngo| ta|ila|i c|ten| ki|diy|wo |i w|aal|kul|i b|ilo|u c|taa|saa|i a|ne |omu|oli|lle|hyo|nay| he|u p|ond| mu|li | fa|e f|yen|sun|ye |pla| pl|pee|g p|nun',
    'sey': ' pa|ye |e p|a i| ku|pai|pa |e k| ye|kua|iye| ka| ne|je |ji |ai | si|i k|aye|a y|i n|i p|re |i a|a p| iy|pay|si | ja|ua |yë |iji|kui|ui |se |ne |jë | ma|ayë|e s|ñe |pi |oye|ja |aiy|uas|ë k| ña| ij|mai|to |e i| a |peo|ia |aij| i | pe|e o|wa |kat|a k|e e|ajë|ña |e j|e ñ|sia|epa|ato| e |e y|utu|tut| tu|kë |eje|aje|e t|i t| de|asa|de |rep| it|we |iwa|oji|eoj|na |tu | ts|ë p|ni |a ñ| ñe|jaj| ko| oy|i s|kay| ë |ire|a a|ti |iti|ije|yep|i i|añe|ë t|yek|epi| iw|ani|ere|kaj|a ë|are|asi|ina|e n|a m|eja| we|yej|i y| kë| ai|akë| sa|e m|ise|i d|eñe|neñ|a w|ija|oka|kok|yer|kai|ka |i m| to|ase|i j|apë|oya|toy|uañ| re| te|ipë|o i|aka|mak|eoy| o |a s|pëa|aja| ay|pan|say|owa|ai̱|air|ekë|ese|o p|e d|a j| ak| yë|ë s|u p|nej|te |ñej|nij|rip|ari|dar|jai|i̱ | in|ë y|a o|yaj| me|a t|pë |iwe|oja|ain|ë d|e r|saj|aip|ea |o y|ë m| ju|tsi|eye|waj|aiw|aña|ned|ose|o s|ta |ë j| ti|jar| is|ais|ipi|ëa |ë i|do |wes|awe|e a|ore|iko|u k|oni|apa| ap|siw|ito|ëre|ëka|tsë| do|jay|sik|sa |sao|ama|kas| ro|ë r|këp|tse|añu|o o| ow| da|ida|aku|eke| ir|eso|kaw| ik|sai|u i|kon|aid|yey|o k|me |api|kër|kap|ë ë|iku|ñeñ|aoy|oe |soe|tso|o j|ëpa|sea|yo | yo| wa|iñe|deo|sos|kor|ide|ëye|yëy|o m|ëos|o n|par|doj|edo|wej|mëo|sëk|ëje|ini|ikë',
    'gsw': 'er |sch|ùn |der| ùn|cht|ch |ach|ich|rac|che|ze | de|ht |re | si| d’| ze|e s| e | ra|de |nsc|t s|n d|te |e ù|he | ge|ens| me| s | je|ver|jed|ere|e g|men|s r|ie |et |dde|ùng|ede|sin| he| vù|e j|het|r m|e w|ng |odd| od| ve| ìn|e e|eit|n s|nn |lic|e v|e d|wie|ànd|le |vùn|nde|t ù|ion|ter| àl|h h| wi| àn|me |li |àti|ein|ne |àll| sì|réi|fré|e à|hàn| hà|hte|ni | wa|tio|rùn|ìn |lle|e h|e m|ini|eme|r d| gs|hei|àn |e z|ìnn|ine|erf|nàt|nte|ell|ùff|ìt |mme|ent|sìn|ìch|n e|r s| st|e ì| fr|it | ùf|mìt|e f|hàf|nìe| be|t w|mr | mr| so|ss |fer| fe|ff | mì| wà|t à|àft|ner|ìsc|tli|rf |je |làn| er|n à|t z|chà| nì|t e| dì|sse| wì|lli|ìer| vo|we | àr|e o|nd |ùnd|äu |nàl|onà|och|àss|ers|àng|sic|ànn|ft |e l|in |h d|e n|es |and| ìs|ùm |stà| gr| äu|t v| nà|her|nge|ite|se |t d|ùmm|àli| no|e b|di |t g|n o|em |war|ndi| wo| là|vùm|àch|mei|àl |isc|lit|on | re|ùnt|ohn|ihe|éih|e r|ntl|n v|rìc|ìtz| sc|tz |etz|gse|are|éi |r ì|tt |grù|üss|rt |àle|gsc|ge |hn |kei|erl|n r|i m|wei|rwe|àrw|ìnd|wàs|ke |gen|ert|fen|ffe| fà| às|n m|ric|so |erù|vor|r g|àlt|awe|law|sal|e p|m g|ls |àls| üs|l w|gàl|lig|rel|chì|r ù|ìs |dìs|n f|jje|ejj|gej|gew|nùn|kùm|ess|lls|itt|s d|ße |ìeß|n z|gt |r w| ìm|gel|gem|ooc|noo|éff|era|s s|sùn|ùri|dùr',
    'kdh': 'ɛ́ɛ|́ɛ | bɩ|dɛ́| we|na |yáá|áá | yá|ɛ́ |áa | na|́ b| nɛ|nɛ́| tɩ|ná | ɩr| dɛ|ɩdɛ| ɩd|a w|ʊ́ |aá |daá|ɩ́ |á b|wen| bá| da|á y| ba|dɩ |lá |báa|wee|íko|yík| yí|een|sɩ |á ɩ|zɩ́|ɔ́ɔ|ní |ení|rʊ́|ɩ b|bɩd|ɩrʊ|enb|tɛ́|a b| wɛ|́ɛ́|a t|á n|wɛn|ɩ n| tɛ|ɔwʊ|a ɩ|nbí|ko |́dɩ|ɛ́d|́ y|ɛná|́ n|í w|rɛ |zɩ |yí |éyí|ɖéy| ɖé|tɩ |ɛ b|ɩlá|á t|ɩ d|ɩ ɩ|ɩda| bɔ|́ ɩ|ɩ́ɩ|́ɔ |í b|amá|bí | sɩ|wá |á w|ɛ t|ɩlɩ|ɩsɩ|lɩ́|ɔzɩ|ɔɔz| ɩl|ɛ y|́zɩ|bɩɩ|yɩ |ya |ɩ w|aal|á k| kɩ|́ɩ |bɩ́| yɩ|alá|kɛ́|ɩná|a k|ɛ n|waa|́m |wʊ́|́ɔ́|bɔw|a y|́tɩ|mɔ́|ɩ́l| za|rɩ́|amɔ| be|tɩ́|yuú| wa|baa|áán|dam|rɩ |laa|í ɖ|kow|ka |bɩk|ʊ́ʊ|́rɛ|ɛ́r|tɩm|mɛ́|zam|ɩzɩ| iy|asɩ|tɩl|rʊ |ɩ y|uú |sɩs|ɩ́n|á d|ɩ t|ɔ́z|owá|ɩka|di |ɖɛ |ɛ k|lɛ́|ŋa |ráa| tɔ| ma|aaz|wɛ |re |má | ɖa|ɛ ɖ|ɩmɛ|ɩdɔ|las|ɛ ɩ|a d|árʊ|iyu|tɔ́|rá |ará|mar|ɛ a|ɛ l|ɔ́m|ána|máá| ta|cɔw| cɔ|bɔ́| la|ídi|ííd|bíí| ke|ɩrɩ|́la|nɩ́|ɩrá|le |ré |́nb|ɩɩl|a ɖ|í d|kí |lʊ́|azɩ|ɛna|ʊrɛ|wʊr|á ɖ| bɛ|́ʊ |o ɩ|ɔɔl|ɩrɔ|náa|ɩ c|bɩl|ádɩ|áád| bo|́ŋa|ɩ́ŋ|ala|fér|úúl|o i|rɔɔ|a n|ɔ b|́ d|í ɩ|ɖam|gɛ́|ɩ́t|ezé|kez|ɛ w|átɩ|cɩr|ɔbɔ|dɔb|ɛ s|ɩgɛ|bɔɔ|nbɔ|mɔɔ|ám |aár|naá|ɩdɩ|́na|́ w|ɛ c| ɩc|enk|ɔ́ |ni |íni|alʊ| al|á a|́ɛn|ɩwɛ|ɩɩz| wá|ʊ́t|énb| ɩb|ana|́ɖɛ|ʊ́ɖ|bir| ɩs|ɩ ɖ|ɩlɛ|ɔ d|lɩz|bɩg|e b|bal|máa|lám|nya|ɔrɔ|́ t|tɩd|tí |á s|ɖɔ |ʊɖɔ|ɖʊɖ',
    'tdt': 'an | ha|ma |ia |nia| ni|ema| em|tu | se| be| ho|ha |iha| ih|ida| id|ak |da |ara| la|un |a h|a i| tu|bel|le |ele|in |tan| mo|la | na|a n|ran|uk |a s|’e |e’e|ne’| ne| di|atu|a b|n e| he| at|eta|het| ra|n n|ei |sei|u h|ori|ir |uir|tui|elu|sel|hal|e b| ta|a d|is |luk|a l|i h|e h|k h|ris|mor|n s|n t|rai|n i|alo|rei|asa|be |aun|itu|eit|ire|dir|a t|lar| e |han|sau| ba|ira|k n|ai |hak|nar|ba |a r|n h| to|ain| ka|esa|mak|nas|ra |di |odi|hod|n l| ma|a m|otu|hot|san|ane|oma|tom|e n|lo |lun|ulu|tul| li|ho |k i|nes|kar|rak|ar |uai|a u|os |s h|aka|r n| fo|hir| ua| da|ik |k e|uma|u b|ate|a e|su |isu|bis|rbi|erb|ser|a k|e m|u a|i n|uku| uk|en |ihi|aih|ten| si|u e|a f|ala|ras|mos|lib|kun|e t|’ak|i’a|di’|ek |ene|tin| lo|lok|hah|si |osi|hos| bu|k b|mat| um|fo |ur |u t|u i|k s| fa|ok |aha|kol|i l|i s|usa| su|e k|u n|n a|n b|dad|n u|oin|n m|ka |ola|nek| es|has|lan| sa|sar|sus|ati|fat|n d|at |kla|erd|u m|u s|sko|esk|bur|lu |tuk|utu|mut|amu|ham| fi|r i|e f|dal|sti|kai|hat| de|sik|s t|de |ade|rda|ber|ibe|dak|án |e s|n r|a o|ama|n k|iar|fia| hi| kl|k a|ru |oru|sor|aso| ru|sir|r t|i t|s e|e l|lak|o l|i i|uka|tak|s d|tam|ibu|ada|o t|k f|ua |alu|abe|as |ura|iu |liu|uat|bua|lia|r h|sai|r l|k l|e e|r d|r e|nu ',
    'twi': 'sɛ |a a| sɛ|ra |ne |a n|ara| a |eɛ | bi|an | wɔ|iar|bia| ne| as|no | no|ɛ s|yɛ |aa |deɛ|bi |mu | ho|obi| ob| an|ho |a ɛ|a b|ma | mu|na |ɛ a|e n|n a|man|ɛ o|so |e a|ɛ ɔ|asɛ|o n|naa|ɛde|ana|kwa|o a|pa | so|ipa|nip|sɛd| na| on|wan|a ɔ|ɛ n|oni|ɛyɛ| mm|a w| n | ɛy| ny| nn| kw| ad|mma|wɔ |oɔ |ama|a m|iri|i m|ɔ n|nni| ba|ɛ w|i a|ɔma|o b|de |wɔn|tum|o s| ɛn| ɔm|a o|i n|nyi|mi |umi|o k| ma|ni |di |nya|e m|ase| de| am|ie |adw|ɔn | ah|ɛ ɛ|ɔ a|uo |u n| ab| yɛ|n n|a s|mar|ua | bɔ|a h|ɛm |pɛ |yin|ya |n s| kɔ|e h|bɔ |uma|wum|rɛ | ɔd|aso|ɔ b|e s| sa|re |a k|sɛm| yi|ɔde|dwu|nam|i s|aho|n b|saa| ns|o d|ina|ba |erɛ|ban|e b|ade|fa |ɔ h|yi |ɛsɛ| ɛs|ɛ b|ɔtu|ani| nk| ɔt|nsɛ|ɛns|m n|om | fi|ka |i k|m a|u a|die|am |foɔ|bir|gye|kor|ena|ten|rɔ |orɔ|ri |hyɛ| ko|kuo|kɔ | di|a d|ene|sua|ɛ m| at|nka|fir| bɛ|nso| ku|ete| mf| be|nii|ibi|rib|kye|ye |i b|o ɛ|ɔne|adi|se |ofo|fof|i h|ɛɛ |yɛɛ| aw| tu|u ɛ|ko |ans| pɛ| ɔn|soɔ|bom|abo| ɛb| ak|ber|wɛ |hwɛ| da|for|n f|mfa|u b|ɔ m|hɔ | hɔ|m m|i y|i ɛ|sa |dwe|a y|ɔyɛ|ɔ w|o w|are|m k|twe|n m|oa | gy|ii |o m|im |o t|ora|seɛ|wɔt| dw|bɔn|e o| fo|to |ɔ s|nsi| ɛk|i f|ɔre| ka|nko|e y| nt|nsa|wen|fra|ɔfr|set|aba| ɔy| bo|war|awa|kab|i t|ɛbɛ| af|da |we |ee |ɛnn|nu |yer|ia | ti|tir|o h',
    'auc': ' ke|mo |ani|pa | to|tom|ay |mpa|te |nan|ni | wa|oma| an|e a|ye |may|imp| in|ome|nte|e k|emo|kew|omo|ewe|nke|a t|ama|ked|eye|bey|eda|o w|ink|dan|bay|ano|e w|mam|ke |mon|y i|me |imo| be|amo|ado| im|eng|ngi|wen|a a|no |ana|oba| na|o a|ete|mom|o k| ad|ket|ena|wao|gim|ono|e t|aom|man|omp|ant| mo|nam|mem|ina|i k|a k|aye| ay|ape|kek|egi|pon|dob|o i|pe |tap|ata|wat| ma| po|i b|wak|ame|e p|nim|ake| ne|gi |weg|i t|men|e i|nom|eki|eka|e b|y k|i w|one|ent|ki |i i|e n|e m|nen|ka |omi|nga|eem|ing| wi|ñen|yom| we|ge |kee|kim|dam|gan|kam|nge|wa |ipa|ank|o t|eke|a w|e e|y w|ede| om|aa | ba|i a|god|a m|a n| ek|ont| eñ|nka|iwa|wiw|nip|eñe|odo|y t|gin|o m|ñom|ate|eyo| go|nob|o n|i n|mim|iga| am|eme|maa|aki|key|min|dom|o b|amp|ga |imi|a e|i m| at| ge|nem|gam|ada|wad|aka|de |nki|onk|oni|nee| on|eño|mi |i e|keb|dok| ye|enk|e g|kem|y a|do |y n| ko|ang|a i|o e|ong|we |ene|e o| ki|i g|yek|bak|ee |ebe|ne |o o|weñ|oke|wab|int| te|aak|waa|owe|kow|ya |y g| pi|di |eña|ike|wo |kig|a o|awe|eya|gey|y m|nit|ema|opo|po |ibe| ñe|iyo| iy|ten|gon|abo|kab|i p|dem|bek|abe|wem|ona|ebi| ga|ton|nig|non|mke|omk| aw|a g|ite|oyn|wee|e y|wiñ|bad|a b|neg|nop|tok|o g|kib|nik|kin|ii | ak|y p|eet|bee| pa|ego|oda|bod|yen|iye| en|mpo',
    'gaz': 'aa |uu |an |ni | ka|nam|aan|saa|maa| na|ii |mma|umm|tti|i k| qa| fi|rga|ti |iyy| mi|a n|in |qab|ta |fi |raa|irg|mir|isa|ami|kam| wa| is|mni|amn|dha|yuu|yyu|a i|miy|chu|aba|amu|huu|ach| ni|a k|a a|a f|ba |aat|yaa|ee |ga |kan| ta| bi|att|i q|oot|tii|akk|oo | hi|ata|kka|u n|waa| dh|yoo|aas|a e|kaa|a b|arg| ar| ke| yo| ee| ga|ees|ama|a h|a m|i i|uf |uuf|haa|i a|hin|ota| ha|iin|moo|a u|da |daa|man|ess|wal| ho| ma|bu | ba| ad|u a|sum|abu|ada|is | ak|ook|eeg|gac|mu |kee|taa| uu| sa|i m|ani|hoj|i f|sa |n h|nya|a q|ira| ya|i d|i h|f m|u h|ums|ka |rra|irr|n i|ssa|na |muu| hu|a t|u y| da|add|bar|a d|ana|i b|aad|itt|hun|as |udh| ir|isu|a w|een| qo|a s|ara|gar|sat|goo|ati|nna|und|nda|yya|biy|awa|haw|mum|rum| la|rgo|i w|nis|bir|jii|ya |aaf|n m|msa|gum|kko| to|ila| fu|eer|gam|lee|eny|asu|u m|ra |n k|amm|ala|al |oji|kun| ku|a g|n d|tee|mat|roo|ero|yer| ye|okk|tok|era|see|baa|dda|ant|aal|faa|aru|sii|mee|ame|uma|nii|u b| aa|kii|oki|i y|suu| mo|egu|rka|ale|n n|n b|lam|asa| am|tum|laa|u q|ura|enn|ken|u f|gaa| e |ffa|tam| se| u |n a|han|oka|ega| bu|dar|kar|mal|bee|qoo|hii|n g|jir| ji|fuu|uum|dan|n y|u t|abb|bba|lis|ili|bil| a |edh|fud|otu|inn|and|ma |yak|o y|af |ood|n q|ko |nni|i s|su |a y|u d|arb|ham',
    'zro': 'cha|ka |ich|ha |a k|uka|nu |a n|anu|nuk| ka| nu|a i|iki| ta| ik|nia|kic|a t|ta |kua| ku|aja|na |ja |iku|ini|ia |iri|aka|ani| ch|ana|han|awi| ni|uan|a a|ria|a c|pan|kin|ima|ata| ic|jin|iti| ri|u i|rik|wir|kaw|u k|yap|aya|kay|iaj|shi| ki|a p|ian|maj|iat|u t|nic|aji| pa|ti |ua |ish|ama|a r|ku |inu|i i|nis|ara| na|u n|ma |ati|pi |api|tia|aik|tsa|ait|tai|kan|jan|ira|a m| ji|ina|u a|ija| ti| wi|a w|a j|apu|aki| at|uju| ak|jic|pui|amu|its|wit|rak|upa|juk| ar|i n| ai|hak|uki|him|nim|kup|i k|ram|unu| ir|uji|i a|man|tam|uin|ika|mas|kuj| it|ki |u r|uch| pu|tin|u p|ash|naj|kun|ura|kir| mi|ats|jun|puc|iju|wij|taw|har|kat|una|taj|aku|aur|kau| an|nat|ui |hij|ran|muj| ma|ña |iña|miñ|suj|asu|kim|hik|kak|jia|raj|rai|u c|kas|uku|kam|sak|tim|sha|iam|au | pi| am|auk|ri |eir|mei|uir|mui|uta|uya|kuy|nak|tij|uma|tak|tau|sa |apa|tuk|sau|pia|ami|iji|kui|tik|san|tan| me|uak|jak|yaj|ra |hir|num|kit|u j|tar|i r|ham| in|iau|utu|kut|chi|i t|rij|sat|tat| ut|a u|aru|uat|mim|hat|kuk|iak|kai|jau|kij|iya|yan|tsu| ja|asa|haj|uik|nji|inj|saj|ach|ita|min|hit|sua|ras|mir|ari|uar|uja|mar|ruk|iai|ris|un |i c| sh|puk|ni |i p|riy|tiu|ai |tic|hin|wik|aun|ya |hic|ush|aus|auj|i u|hai| ya|a y|jit|i m|pak|rap| ra|pam|imi|jik|hau'
  },
 'Cyrillic': {
    'rus': ' пр| и |рав| на|пра|ств|го |ени|во |ове| ка|на |ть | по|ия |о н| об|ет | в |сво| св|аво|ани|ост|ого|ый |ажд|лов|т п| им|ния| че| со|ело|име| не|льн|ли |чел|каж|ест|век|ать|ова|или| ра|ек |й ч|дый|жды| до|ие |еет|мее|но | ил|ии |ся |его|обо|и п|ние|к и| бы|и с|и и|ми |бод|воб|ван| за|ой |ых |ом |лен|аци|енн|о с|о п|ьно|тва|тво|при|ног|аль|ако|ва |и н|сти|ных|то |бра|олж|дол|сто|и в|ным|ое | ег|нов|их |ель|тел|ти |нос|не |пол|раз| вс|и о| ли|и р|ыть|быт|вле|ред|ию |тор| ос|ься|тьс|оди|щес|я и|как|про|жен|ым |пре|а с|сно|е д|нно|о и|ий | ко|о в| ни| де|сту|лжн|сов|е в|ном|оль|ран|оже|иче|ей |аст|нны| от|туп|м и|одн|зов|рес| мо|осу|ля |осн|а о|вен| то|о б|шен|тве|общ|а и|е м|ьны|обр|вер|чен|я н|жно|чес|ак |лич|нии|е и|все|бще|ват|есп|мож|й и|ное|о д|бес| во|я в|ду | ст|дно|она|нац|ден|ежд|х и| бе|и д|ны |дос|для| дл| та|льс|ате|ции|я п|ую |ите|е о|ной|под|ото|стр|ста| ме|ели| ре|я к|тоя|ами|ен |ь в|ю и|азо|гос|м п|ь п|т б|жет|уча|суд|ьст|дст|щит|ащи|защ|кон|нию|ам |оду|ере|гра|печ|о о|оро|кот|и к|тра|ник|уще|циа|оци|соц|нал|еск|о р|ког|дру| др|ни |ава|нст|ем |авн|ыми|едс|дин|дов| го| вы|в к|ые |обе|му |я е|слу|уда|так|кой|ту |иту|зак|ход|вол|раб|кто|икт|ичн|нич|от |ина| к |тер|род|нар',
    'ukr': 'на | пр|пра| і |рав| на| по|ня |ння| за|ого|ти |во |го | ко|аво| ма|люд|о н| не| лю|юди|ожн|кож|льн|жна|дин|ати|ає |их |ина|пов|сво| св|анн|є п|має|або|а л| бу|не |енн|бо | аб|а м|ови|ні | ви| ос|аці|вин| та|без|обо| ві| як|ере| до|і п|ува|о п|аль|них|ом |ми |іль|ног|та |ий |при|ою |ть |ста| об|ван|инн|ті |ост| у |ся |ват|бут|ист| мо|езп|ути|нов|пер|ії |и п|бод|воб|ств| в |о в|від| бе|ако|під|тис|кон|но |ва |нні|і с|а п|сті| сп|ний|ду |ьно|она| ін|дно|ним|ій |а з|ну |мож|її | її|ля |соб|му |ої |яко| пе| ра|ід | де|і в|и і|чин|вно|ому|ном|у п|і н|а с| су|а о|нен|ися|ово|нан|одн|у в|і д|ава|ідн|рів| рі|і р|ими|віл|им |ції|о д|а в|сту|оду|буд|ова| пі| ні|я н|е п|нац|и с|нна| од| ро|нос|ьни|ють|и з|ки |і з|а б|спр|чен|же |оже|е м|овн|рим|е б|то |ніх|осо|удь|ві | ре| ст|рац|до | со|роз|лен|вни|івн|род| вс|спі|ков|зпе|ів |для| дл|ї о|хис|ахи|зах|‐як|ь‐я|дь‐|я і|так|зна|заб|сть|ту |ною|а н|тор|сно|о с|жен|ціа|оці|соц|інш|і м|кла|и в|тер| ді|іст|ові|у с|я в|аро|сі |віт|сві|осв|роб|піл|рес|за |печ|абе|ку |лив|ерж|дер|в і|авн|тав|ав |ами|ком|вле|о б|ь п| що|їх |тво|хто|іхт|ког| кр|ано|тан|іал|нал|нь |х п|жно|леж|але|про|тва|рат|о о|х в|нар|льс|цій|кор|час|ржа|ї с|ину|дст|о з|раз|мін|а р|зак',
    'bos': ' пр| и |рав|на |ма |пра| на|има| св|а с|да |а п|во |је |ко |ако|о и| по|аво|е с|а и|ти | им| да| у |сва|но | за|о н|ва |и п|или|вак|ли | ко|не | ил|кој| не| др|ост| сл|ња |им |и с|у с|и и|ава|ије|а у| би|ств|се |вањ|а д|ом |јед|бод|обо|лоб|сло| се| ра|их |сти|а н|ње | об| је|при|дру|у и|ју |о д|ити|вој|раз|ање|ова|дје| ос|е и|ло |е п|ања|ује|и д|бра|тре| тр| су|у з|а к|ог |у п|оје|циј|реб|а о|а б| ње|и у|миј|ни |нос|ба |едн|сво|њег| из|про|е д|жав|бит| ни|и о|ста|а з|авн|вје| ка|бил|ово|а ј|ају|ист|и н|них|јел|ту |ред|гов| од|е о|оји| см|ја |о к|ило|аци|е у|пре|о п|еба|у о|су |вим|ичн| са| дј|а т|ија|шти|чно|ржа|држ|сту|дна|одн|ени|за |ива|ном|ем |ду |ран|вно|сми|јер|е б|е н|де |пос|м и| до|у д|нак|а р|обр| мо|ним|его| кр|тит|кри|ве |ан |ико|ник|ну |и м|ног|ено|сно|е к|туп|руг|ка |ода|рив|вољ|алн|м с|иту|ашт|заш|ани|сам| ст|акв|ови|осн|род|аро| ми|ји |тва|дно|нст|ак |ите|љу |вич|рад|у н|у м| та|дст|тив|нац|рим|кон|ку |њу |оду|жив|амо|тво|тељ|под|еђу|г п|нов|ина|нар| вј|и б|ој | ов|аве|ву |анс|оја|зов|азо|уде|буд| бу|е т|и в|ења|еди|ниц|нап|мје| ис|слу|едс|о о|зак|и к|м п|тно|иво|ере|нич|как|ада|вни|уги| ро|мов|вен|о с|то |те | вр| бе|ара|кла| бр|у б|у у|и т|она| он|ави|јал|дни| ск',
    'srp': ' пр| и |рав|на |пра| на|ма | св|има|да |а п|во |ко |ти |аво| по|а и|ако|а с| за| у |о и| им|и п|ва |сва|вак| да|о н|е с|ост| ко|ња |ли |или|не |ом | не|а н| сл| ил|је | др|и с|но |кој|у с|ава| ра|ог |сло|ју |им |сти|бод|обо|лоб|ити|а о|ств|и у|а д|ни |јед|у п|при|едн| би|и и|а к|о д|ста|их |дру|а у| је|ања| ос| ни|нос|про|ају|и о| де| су|у и|се |ње |ја |ова|и д|циј| об|ује|ред|жав|е и|е п|а ј|дна| се| од|ве | ка|ени|ржа|држ|а з|авн|ења|аци|вој|ово|у у|м и|оја|вањ| из|ија|у з|ање|ран|е о|род|и н|е б|раз|за | ње|гов|ичн| ст|нов|сно|осн|ду |пре| тр|су |ву |одн|а б|сво|њег|ним|них|ту |тит|шти|ку |ном|бит|е д|ме |ико|чно|оји|ло |вно|ник|ика|без|ара|де |у о|вим|нак| са|рив|аве|ан |вољ| кр|о п|сме|е к|ног|ји | ов|е у|тва|бра|руг|реб|тре|у д|ода| мо| вр|ављ|у н|его|дел|м с|кри|о к|ашт|заш|њу | см|ани| ли|дно|еђу|алн|ла |акв|ој |ком|сту|уги|ави|а р|ка |рад|оди|вич|тав|иту|уде|буд| бу|пот|оду|жив|ере|тво|ило|бил|аро|е н|ови|пор|ено|штв|нац|ове|м п|туп|пос|рем|дни|ба |нст|а т|оју|аст|ива|е м|вре|вља|ну |беђ|ист|ен |те |дст|рот|зак|ао |као|и к|јућ|о с|ст |сам|м н|тер|нар| ме|и м|кол|е р|ушт|руш|вер|как| бе|и б|кла|ада|еба|ена|она| он|тву|анс| до|рак|слу|и в|ниц|у к|мен|врш|еме|едс|иви|о о|јав',
    'uzn': 'ан |лар|га |ир | би|ар | ва|да |ига| ҳу|ва |бир|уқу|қуқ|ҳуқ| ҳа|р б|ган|иш |ида| та|а э|ини|ади|нг |дир|иши|лик|лиш|ий |или|ари|уқи|ҳар|лан|инг|ши |дан|нин|инс|кин|сон|нсо| ин| му|қиг| ма|он |р и| бў|эга| эг| ўз|ни |бўл|гад|и б|ки |ила|ёки| ёк|а б|н б|ин |р ҳ|ала|эрк| эр|лга| қа|рки|ш ҳ|и ҳ|н м| бо| ба|ик |ара|иги|лиг|ри |қил|а т|бил| эт|ниш|нли|кла|и в|бош|эти|ани|им |и м|оли|қла|а ҳ|лаш|атл|тил|а қ| ол|оси|мас|қар|инл|лат| қи|таъ|ҳам|ги |иб |мла|ўз |н э|мум| да| бу|ат |ш в|ун |ати|мки|умк|тла|иро|ўли|бар|ири|риш|ият|али| бе| қо|а ш|аро| ке|и т|рла| те|ча |рча|арч|а ў| шу|тиш|н ҳ|тга| са|аси| ха|рак|лин|ола|имо|шқа|ли | ту|амл|лла|сид|н ў| ас|нид|а и| ки|н т|нда|к б|ера|ошқ|сиз|ор |а м|р в|енг|тен|мат|мда|амд|лим|й т|ят |и а|ино|илг| то|тни|ана|ас |эма| эм|а ё| ша|аш |а а|тар|кат|ака|ак | де|аза|илл|сий| си| со|уқл|н қ|ода|ъли|аъл|ник|ада| ни|тда|гин|уни|сит|ай |қон|н о| жа|ким|еч |ҳеч| ҳе|ўзи|лак|кер|икл|лли|ур |зар|шла|риг|ирл|дам|коҳ|ико|а д|ам |н в|рти|тиб|тал| иш|чун|учу| уч|сла|а у|рин|сос|асо| ун|на | ка|муҳ|диг|ч к|асл|лма|ра |бу |хал|ўлг|и к|екл|р д|қат|ага|и қ|оий|мил| ми|қа |и с|жин| жи|син|рор|а в|лад|а о|тли|мия|н и|аб |тир|з м|дав|рга|аги|а к|нла|ақт|вақ|арт|аёт|лаб',
    'azj': ' вә|вә |әр |ир | һә| би| һү| ол|үгу|һүг|гуг|на |ин |лар|һәр|дә | шә|бир|ләр|лик|мал|р б|лма|р һ| тә|әхс|шәх|ән |дир|угу|уна|ан |али|а м| ма|икд|ини|р ш|дән|ар |илә|гун|аг |асы| ја|мәк|јәт| мә| мү|кди|әси|әк |илм|нин|ндә|олм|әти|ә ј|син|хс |нда|лмә|јјә|и в| га| аз|олу|ијј|ја |инд|зад|гла|үн |ни |лә |тин|н м|аза|ары|әт |н т|маг|лун|лыг|ә б|ун |нун|г в|н һ|дан|ын | ет|тмә|әрә| өз|да |ә в| он|ә а|ына|ыны|бил|а б|сы |ил |әми|ара|си | ди|ә м|әри|рлә| ва|ә һ|етм|ығы|ама|длы|адл|рин|бәр|рын|н и|мүд|нын| һе|мас|ик |н а|дил|алы|ирл|әлә|үда|сын|ынд|хси|ли |ә д|нә | бә|әја| ин|ә и|ләт| сә|ны | иш|аны|еч |һеч|г һ|ејн|ә е|дыр| да|аси|ры |иш |ифа|лығ|и с|фиә|афи|даф| ед|мәз|у в|кил| һа|ола|н в|әни|ыр |уг |унм| бу| ас|сиа|оси|сос|или|ыды|лыд|нма|ыг |инә|әра|сил|хил|ахи|дах|адә|ман|а һ|ә о|ону|а г|әз | ки|сеч| се|ы һ|мин|лан|әдә|бу |раг|лы |ылы|ал |ә г|р в|нла|һси|әһс|тәһ|өз |ист| ис|мәс| әс|ина|ә т|әтл|а в|иә |н б|тәр| та| ҹә|еди|ала|ким|гу |и т|улм|мәһ|н о|аја|ы о|иал| со|илл|сиј| дә|вар|инс|ми |ғы |ник|р и|агл|к һ|тәм|там|чүн|үчү| үч|ғын|сас|әса|з һ|әмә|зам| за|сти|рәф|н е|р а|илд|һәм|ыгл|јан|мај|н ә|мән|мил| ми|әги|дин|н д|түн| дө|миј|каһ|ика| ни|фад|тиф|л о|сәр|јни| еј|ана|лән|ам |рил|ајә|ашы',
    'koi': 'ны |ӧн | бы|да | пр|лӧн|рав| мо|пра| да|быд| ве|орт|лӧ |ӧй |мор|ӧм |аво| не|во |ыд |ыс |нӧй|ын |м п|д м|ыны|тны| ас|тӧм|льн| эм|вер|сь |ьнӧ|эм |н э|тлӧ| кы|сӧ | по|ерм|сьӧ|ртл|аль| кӧ|эз | ӧт|ӧ в|то |ето|нет|ылӧ| ко|тшӧ| от| и |ы с|бы |ӧ б|ств|кӧр| вӧ|шӧм|кыт|та |на |з в| се| до|вол|ӧс | сы|ы а|ола|рмӧ|ас |оз | оз| сі|а с|тво|с о| вы|ліс|ӧ к|ытш|ӧ д|ис |ісь|ӧтн|ась| ол| на|аци| эт|а в|злӧ|сет| во| чу|лас|лан|мӧ |тыс|рты|ӧрт|ы п|ӧтл|о с|эта|дз |кӧт|ӧдн|вны| мы|н н|удж| уд|выл|ӧ м|рті|орй|ись| со|воэ|ыдӧ|й о|кол| го|с с|сси|сыл|ысл|йын|кин|олӧ|тӧн| сь|ана|ӧр |ция|а д|ӧмӧ| ви|з к| эз|ы б|тӧг|ӧт |мӧд|ест|ост|ӧны|тир|оти|укӧ|чук|н п|онд|пон|слӧ|кер| ке| об|сис|суд|а н|дор|кон|нек|н б|лӧт|с в|ті |ьӧр|тра| ст|нал|она|нац|н к|кӧд|ӧг |скӧ|ть |етӧ|дӧс|быт|рны|ӧ н|тсӧ|рре|а б|нда|с д|асс|ы к|асл| ло|ьны|сьн|ы м|еки|ы д| мӧ|ь м|ы н|ытӧ| ме|рйӧ|иал|й д|итӧ|а к|ӧсь|мӧс|овн|зын|а п|отс| ли|оля|ӧ а|осу|ӧя |нӧя|езл|рез|мед|с м| сэ|ь к|рйы|ако|зак| за|ьын|ннё|мӧл|умӧ| ум|ы у|н в|м д|н с| дз|н о|ран|стр|озь|поз|з п|о д|циа|оци|соц|ион|а м|еск|чес|нӧ |з д|тсь|бӧр| бӧ| ов|вес|кыд|ӧ с|воы|код|тко|ӧтк|оль|дбы|едб|сьы|чын|тчы|ӧтч|тла|мӧн|сла|йӧз| йӧ|т в|ы и|ез |о в|оны|йӧ |анн|ӧль| пы|ан |нӧс|нит| су|м с',
    'bel': ' пр|пра| і |ава|на |рав| на| па|ны |ва |або|ць | аб|ае | ма|аве|анн|ацы|сва| св|е п|льн| ча|не |ння|ала|а н|ай |лав|чал| ко| ад| не|га |ожн|кож|век|ня | як|жны|ы ч|мае|а п|ага|бо |ек |а а|ца |цца| ў | за|ых |пав|а с|го |він|дна|бод|мі |ваб|ван|ам | вы| са| да|ста|аві|нне|асц|най|цыя|наг|ара|і н|к м|яго| яг|ьна|пры|аць|і п|одн|ств|ама|ных| бы|тва|дзе|аль| ра|ні |і с|і а|ыць|а б|енн|лен|ці |оўн|ым |рац|інн|іх | ас| та|то |нас|які| дз|чын|оль|і д|аво|ад | ні|сці|ымі|ным|быц|я п|ьны|ыя |аро|ана|іна|і і|рад| гр|ля |ўле|о п|а ў|рым|пад|ыі | ін|амі|дзя|рам|цыі|аба|а і|ду |жна|ўна|нал|нац|ры |эта|гэт| гэ|нен|да |ах |гра|кац|ука|а з|кі |адс|ў і|нст|энн|я а|нні|оду|а р|нна|ход|нан|пер|х п| у |адз|і р|мад|м п|е м|аду|дст|для| дл|оў |нае|і м|ако| ка|ы ў|бар|е а|ацц|ую |ыцц|сам|яўл|але|род|раб| пе|што| ўс|адн| су|роў| ро|дук|люб|ь с| шл|раз|нав|зна|вол|удз|ада|жыц|чна|ве |а т|асн|сац|ера| рэ|яко|кла|аны| шт|ь у|аюц|нар| ус|соб|асо|пам|я ў|авя|чэн|воў|так|ну |ю а|ь п|зак|кар|е і|ь а|бес|ія |кія|х і|заб|аса|ім |жав|і з|леж|тан|ахо|яль|ыял|о с|яна|кан|ака|інш|алі|вы | мо|нах|я я|м н|ога| бе|й д|о а| ст|ены|і ў|а д|есп|шлю|цця|ы і|ыст|рыс|люч|клю|тац|уль|ынс|ачы|спр| сп|аў |ыма|ары|кам|е ў|і к|кон',
    'bul': ' на|на | пр|то | и |рав|да | да|пра|ств|ва |а с|а п|во |но |ите|та |о и|ени| за|не | не| вс|ван|аво|а н|ото|е н|о н|а и|ки |ие |те |ни |има| им|ли |или|ия | по|ове|ане|чов|ма | чо|и ч|а д|ние|ани|и д|ест| ил|век|все| об|ек |еки|сек|ава|тво|сво| св|вот|а в|и с|ост| ра|ова|а о|е и|ват|и н|е п|к и|а б| в |и п|лно|о д| се| бъ|при|раз|ето|ъде|бъд|ата| ко| тр| ос|аци| съ|бод|обо|воб|ат |за |тел| е |о с|де |о п|ен |и в| от|се |ния|ран|алн| де|бра|его|нег| из|от |ята|как|оди|е с|и и|ден|пре|бва|ябв|ряб|тря|нит| ка|ява|про|ст |а з|гов|вен|тве|о о|а р|акв|о в|и з|ред|нос|ият|е д|щес|нов| ни|ция| до|йст|о т|е т|ржа|ърж|дър|ено|пол| с |обр|тва|нот|рес|ейс|и о|е в|кой|общ|лен|она|нац|иче|ез |без| бе|ежд|ува|вит|ри |зак|и к| ли|а е|под|ели|ник|си |е о|а т|и р|т с|ка |оет|елн|нен|ой |гра|жен|дру| ре|а к|сно|осн|лич|зи | та|са |нст|авн|чки|ичк|сич|вси|люч|клю|дно| мо|еме|тъп|а у|изв|тви|дей|я н|кри|ато|о р|й н|ико|ичн|жав| дъ| то|бще| со|лит|т н| си|т и|вни|одн|жда|зов|азо|уча| гр|кое|стъ|вол|лни|сре| ср|ква|кон|тно|ака|и у|ко |ган|ода|чен|лст|елс|стр| къ|ста|род|нар|и м|иал|нал|руг| др|чес|ди | са| те|сто|дос|раж|рез|чре|гат|еоб|а м|о е|ине|аст|ово|чно|аве|му | му|ано|ита|ими|ако|нак|лаг|ови|ан ',
    'kaz': 'не | құ|ен |ұқы| ба| қа|құқ|ық |ға | жә|әне|жән| не| бо|де |дам|ада|а қ|тар|ына| ад|ылы| әр|ың |ан |ін |қыл|ар |еме|на |р а|лық|уға|ала|ықт| өз|мес|әр | жа|мен|ығы|лы | де|қта|ның|н қ|ған|іне|бас|ары| ме| қо|еке|ын |да |е қ|ды |асы|се |есе|ам |бол|анд|нем| бі|ара|ы б|ста|тан|нды|н б|ің |е б|ілі|тиі| ти|бар|ғы |нде|етт|иіс|қығ|іс |лар|ге |ы т|інд|ік |бір| бе| ке|алу|е а|алы|луы|а ж|ері|олы| те|қық|н к| та|н ж|ғын|тті|іні|тын| ер|нда|ім | са|е ж|аты| ар|рға|еті|ана|ы ә|уын|лға|өзі|ост|егі|тік|қа |сқа|рын|кін|луғ|ң қ|нің|уы |бос|асқ|қар|дық|нан|мыс|мны|амн|ы м|айд|ке | же|зін|рде|рін|е т|ген|ып |ры |ті |сын|қам|ден|і б|гіз|рал|е ө|лан|сы |ама|тта|тық|бер|ді |біл|ркі|өз |зде|кет|қор|дай|уге|ы е|ынд|нег|оны|ей |мет|аны|а т|жас|ауы|лге|аса|еге|дар|ру |ау |ерк|ы ж|рыл| то|н н|е н|тін|ір |сіз|тер|лма|і т|кім| ал|р м|лік| мү|е м|түр| тү|кел|лып|ең |тең|рлы|лім|рды|ард|атт|с б|ыры|сыз|ыс |елг|дал|йда|орғ|рқы|арқ| жү|тал|ылм|а б|ігі|лде|із |қты| еш|дей|ай |жағ|кті|ікт|гін| әл|тты|ұлт| ұл|е д|ыны|лін|р б|еле|кұқ| кұ|амд|м б| ет|оға|құр| кө|аға|тол|шін|айы| қы|қал|жек|і н|ес |ағы|е о|елі| ел|н е|зі |шкі|ешк|олу|ция|мас|ғда|ағд|лтт|імд|ным| да|а д|әсі|с ә|қат|ірі| со|ң б|аза|мда|айл| ас|ғам|қоғ',
    'tat': ' һә|лар|га |кук|оку|хок| хо|әм |рга|һәм| ке| бе|ар |еше|әр |ан |кеш|ләр|гә | ба|ең |нең| бу|кла|ргә|ырг|һәр| ти| то|р к|да |ене|бер|ән |дә | үз|а т|тор|ен | ка|нә | ал|ы б|на |ган|ара|ире|бул| дә|бар|енә|укл|тие|а х| ит|иеш|ары|кы |ка |ә т|н б|укы| ир|екл|еле|ына|ше |ала|н т|лык|ле |шен|еш |кар|лы |лан|лән|рын|ә к|елә|ерг|нда|рек|тел|ез |ите|а к|бел| та|лыр|ә б|ын | га|ел |сә | як|алы|әрг|а б|яис| яи|тә |дан|а а|үз |ә х|ш т|е б|ынд|сез|клә|исә|р б|улы| эш|чен|а һ|ем | са|н и|шка|тен|үзе|ы һ|әт |ять|гез|иге|аны|ә һ|орм| тү| ха| тә| ни|р һ| ту|мәт|кле|үлә|лу |ть |м а|лга|штә| ки|м и| мә|не |лек|мыш|рмы|гел|түг|лер|ди |зен|уга|сен|гән|акы|клы|ләт|алу|ны |ешт|веш|әве|рәв| рә|тәр|рлә|үге|а я|ль |рен|баш|ә д|ә и|илл|ер |р а|циа|оци|соц|айл|рдә| аш|рак|рда|ард|рне|әрн|якл|лә | җә|н м|ың |ның|кка|әре|орг|тан|мас|сын|нди|инд|нин|рел| би|ык |лем|аль|ни |ин |кер|м т|әүл|шла|н я|тын|ндә| оч|бу |кон|а д|арт|кем|рке|ылы|кта|кә | ил|р и|ерә| җи|ң т|ция|а и|ашк| сә| ди|асы|ый |мил| ми| мө|та |л һ|нна|гын|иал| со|змә|езм|хез| хе|ыят|гыя|мгы|шыр|ә я|ерл|нлы|ере| кы|ек |уры|тыр|н х|елү|ако|зак| за|итә| да|чар|ныр| ко| ан|иле|әсе|ыш |аци| де|аер| ае|ану|ина|ә с| тө|әте|ана|н һ|бир|нан|ры |йла|ә а|әлә',
    'tuk': ' би| ве|ве |да |лар|ир |бир| хе|ада|р б| ха|ер | ад|га |или|дыр|дам|ен |ыр |ара|ары|хер|лан|р а|ыды|р х|ам |кла|ага|ала|нда|бил|хак|клы|акл|лыд|лы | бо| өз|ың |ан |‐да|лен|ыны|маг|не |лер|ин |я‐д| я‐|ине|на | эд|а х|ына|ынд|дан|уку|хук| ху|ны |лма|е х|иле|ери| де|ге |иң |ли |атл|алы|ар |ден|ере| ба|дил|лиг| га|асы|лик|лыг|а г|кин|бол|кук|өз |е а|ама|де |эрк|рын| эр| хи|ини|гын|иги|айы|а д| ма|мак|п б|аны|эди|ни |ыгы|баш|лык|йда|рки|әге|ети|ич |хич| та|ак |шга|ашг|сын|мал| до|гда|ы б|ры |ги |мәг| җе|ыет|сас|эса| эс|лме|илм|мез|ип |ыкл|тлы|н э|дак|дай|ягд| яг|укл|хем|гал|ы в|чин|им |мек|рил|ян |рин| се|ал |ән |йән|ның|а б|дир|ола| ка|нде|ы д|сы |лин|е д|гин|зат|а в|екл|кы |акы|н м|кан|ылы| са| дә|хал|дол|чил| гө|тме| ге|н х|а а|айд|дең| ал|лет| дө| иш|н г|е б|уң | гу|дәл| го|ири|ик | он|ң д|сер|лип|ели| со|илл| ди|аза| аз|гар|и в|лим|ник|е в|еле|нли|үчи| үч|нме|з х|рап|тар|нуң|ону|мел|е г|кда|сиз|кле|ыз |сыз|ниң|дал|а я|циа|оци|соц|а с|мил| ми|кли|олм|и б| бе|н б|ра | дү|ең |еси|этм| эт|ы ө|ика| ни| ар|е м|дөв|ет |к э|тал|н а|гы |ез |инм|ып |олы|ора|гор|ч б|нун|ану|м х|алм|лйә| ки|ек |н я|анд|үни|рет|тла|гат|айл|ция|н д|ң х| ме|гые|мгы|емг|җем|ете|аха|мах|тле|тиң|а э|ң э|лам|пла|н в',
    'tgk': 'ар | ҳа| ба|ад | да| ва|он | та|ва | ин|ба | до|дар|ти |аро|дор| ки|ои | як|д ҳ| бо|бар|ҳар|як |ора|ки | на|нсо|инс| ма|сон|и м|р я|и о|ҳақ|рад|аи |к и|уқу|ард|и ҳ|қ д|ин |ни | му| аз|ии | ҳу| ша|аз |ҳои|ақ |яд |она| ка|и д| ё |и б|ояд|дан|анд|қуқ|ҳуқ|зод|озо| оз|ият|д б|а б|нд |да |ди |н б|амо| ху|уда|оди|гар|дон|и и|ат |моя|нам|и с|ст |ҳам|н ҳ|рда|худ|ан |боя|ода|ава|и т|оша|бош|қи |и х|а ш|аст|ӣ в|мил| ди| он| ме|шав|они|е к|ила|шад|имо|и н|оба|оми|кор|д к|кар|рои|ри |вад|уд |ро |ӣ ё|оти| бе|ани|яти|таҳ|мин|н д|ят |та |на |ати|оси|бо |и а|роб|а ҳ|таъ|и ҷ|а м|д а|р к|и ӯ|а в|лат|ист| фа|и к|шуд|р ҳ| ас|ида|ига| со|а д|ара|иҳо|д в|одо|н м|т б| ӯ |т ҳ|ама|тар|ор |фи | са|вар| шу|лӣ | ми|ли |рон|диг|ҳо |и ш|дав|бот| ҳи|иро|уна| ни|кас|еҷ |а т|або| ақ|нҳо|раф|мон|н в|авр|ино| ко| су| ҷа|оҳ | ҳе|д т|маҳ|сти|сар|а о|д д|диҳ|р а|уни|р б|уқ |а а|ми | во|н и|р в|тав|ори|н н|мум|ари|яи |ояи| қо| эъ|ҳеҷ|рии|дӣ |рдо|оли| ис|уди|р д|асо|фар|киш|ӣ ҳ|наи|даа|лом| иҷ|ран|ахс|шта|р м|ӣ б|ита|сит|вос|у о|о д|аҳр|нти|инт|ифо|тиф|ибо|тҳо|қу |а к|ир |рра|рат|ҳим|ону|қон|зди|ун |офи|и қ|нда|ла | гу|наб|гон|а н|қар|оят|шва|ишв|лал|ия |мия|ами|тим|ҷти|иҷт|сӣ | за|ошт|янд|оян|атҳ|а и|аъл|ник|ққи|аққ|ихо',
    'kir': ' жа|на |ана| би|жан|бир|уку|га | ук|ар |уу | ка|кук|укт|луу|ууг|тар|уга| ад|ан |ен |ык | ар|ада|ир |дам|олу|ган| бо|ам |р б| же| ме|туу|ын |ара|бол|мен|кту| ба|анд|нен|ене|ары|ына|р а|нда|н к|ин |үн |н б| өз|эрк| ко|а ж| ал| эр|да |кта|же | та|аны|а т|рки|а у|дык|ард|а к|кин|инд|иш |тий| ти|ийи|н ж|үү |гө |н а|ала|н э|алы|ук |или|н т|йиш|кыл|лар|рды|алу|нди|тер| ма|үгө|у а|кар|нын| кы|а а|баш|бар|лга|им |ун | эм| ээ|лык| ту|а б|а э| ан|нан|өз |тур|рүү|дай|алд|улу| са|рын|дар|тта|үүг|етт|рга| ки|кан|иги|н у|күн|ка |нды|у б| бе|м а|үчү|мес|эме|ры |дик|р м|ушу| мү| со|к ж|тук|үнө|не |ине|алг|кам|түү|үнү|эч |еке|ке |ес | эч|өзү|гин|икт|еги|лды|ө ж|ери|к м|уп |лим|бил|атт|кет|у м|чүн|тал|угу| ке|руу|к т|лук|ч к|е к|ээ |кте|у ж| де|ул | не|шка|дин| ди| тү|мда|амд|гон| иш|ы м|кал|к к| то|кор|рде|ыз |сыз|рго|орг|ай |уну| эл|е а|нүн|айд|зүн|ыгы|ге |ция|раб|ыкт|гиз|нег|ашк|ылу|е б|рин| те|ик |он |мкү|ү ж|ү ү|оо |н м|нуу|тык|ашт|уна|ей |дей|ирд|абы| мы|м ө|ерд|лоо|мсы|н н|ект|дыр|диг|акт|мак|ага|е э|лан|аци|тан|айы|циа|оци|соц|иле|рал|ынд|де |коо|ник|аты| өл|лго|олг|рди|амс|үмк|мүм|өсү|мду|н и|ш ж| үч|шты|гун|зги|бер|өн | бу|бын|сал|ким|у э|н с|өнү|ктө|а ө|дыг|ды |з к| кө|дан|ылы|рма| ай|иал',
    'mkd': ' на|на | пр| и |во | се|рав|пра|та |а с| не|то |да | да|а п|ува|ите|те |о н|ва |а н|ој |кој|и с|но |а и|ата|аво| им|еко|ма | за| со|ств|ни |има|от |ње | во| по|ли |ја |а д|ост|сек|е н|ова|се |или| ил|о с|е п|а о|ање|и п| сл|ат |е и|вањ|ија|о д|ото|ен |о и|сло|ред|и д|обо|при| од|бод|лоб|ј и|и н|вот|ста|ст |и и|его|нег| би|а в|нос| ра| ќе|гов|пре| ни| ко|т и| об|е с|ава|акв|ќе |бид| де| др|со |тво|ват|ако|аци|што|раз|едн|аат|про|бра|иде|ани|а з|а б|как|циј|ест|де | е |а е| шт| ка|е б|одн|од |и о|нит|т с|ј н|ран|е д|и з|ено|ди |кон|ени| ед| си|еме|сно|осн| ос|тит|ови|јат|о п|вен|лно|алн| ја|ед |дру|ваа|сто|дна|за |нот|дно|е о| до|ви |ове|еди|држ|о в|ние|нов|чно|ник|жив|ето|а к|иот| ст|нац|ели|вни|д н|без|ара|о о|и в|т н|руг|ден|дни|сит|обр|а р|луч|а г| вр|не |пор|шти|ичн|чув|ка |авн|тве|ко | бе| оп|бот|або|раб|а м|цел| це|тен|ело|олн|дел|нув|е в|ита|ашт|заш|кри|род|нио|т п|зем|ема|нем|оја|ез |им | ов|оди|пшт|опш|он |ие |нст|нак|аѓа|ште|чов| чо|ван|зов|азо|кот|слу|жав|ржа| из|о к|рем|ист|ење|вол|оре|ги |н и| то|ти |ико|ода| жи|лас|аро| ме| зе|ло |бед|лит| ре|ипа|рип|еде|о ќ|ово| мо|нап|т д|вре|јст|ејс|ора|иви|рив|ри |зво|век|лни|кво|вно| сп|о е|ква|н н|жен|дат|нет|ине|иво|под|али|ика',
    'khk': ' эр|эрх| хү|н б|эй |тэй|х э| бо|ах | бү|ний|ан |ийг|йн |хүн|бол| ба|эн |оло|ийн|уул|й х| ха|бүр|эх |бай| бу|гаа|рхт|хтэ|гүй|рх |үр |үн |аар|йг |ар |лах|он | хэ|ий |аа | за|н х|й б| ор|өлө|лэх|үй |лөө|ула| ху|ын |үнд|эл |эр | ул| ч | ёс|н э| ни|лон|хий| ту|р х|өөр| гэ|сан|чөл| чө|улс| үн|гээ|оро|ны |н т|юу |уюу|бую| ша|хан|эд |ох |ээ |нь | нь| тэ|сэн|н а|р э|ай |л х|хам|лаг| то|х ё| эд|ндэ|лга| тө|рол|ж б| ал|үлэ|х б|лий| хө|ол |л б|лс |эг |ээр|йгэ|ава|тай|гэм|гуу|д х|бус| өө|өтэ|өөт|төр|ыг |лго|луу|хуу|үүл|нд |хэн|сон|дэс| ял|лд |алд|хар|гий| нэ|лов|г б|рэг|эрэ|үйл|аал|н з|г х|х т|эни| ам|рла|гэр|үни|ой |той|ал | га|ад |рий|аан|й а| аж|вср| зо|ура|лла| ав| хи|эдэ|дсэ| үй|мга|амг|йх |айх|ч б| ол|рга|өрө|эс |ага| са|н д|оо |ана|ин |аг |н н|овс| со|олц|эгт|дэл|али|гөө|тэг|хээ|хэр|вах|арл|үү |хүү|лаа| дэ|с о| тү|мий|йгм| шү|н ш|арг|р ч|өр |аса|дил|ади| ад| мэ|сро| би|а х|илг|раа|й т|хүр| та|өх |ард|дээ|лох|лан|ваа|ива|лив|алу|тгэ|ори|лын| да| яв|л н|үрэ|айг|д б|огт|тог|айл|өри|аши|ялг|мар|лал|гла| эн|н ү|рон| хо|н г|н у|айд|х ч|длэ|р т|ата|бие|анг|й э|нэг| су|лцо|бүл|лж |д н|лөх|дах|рхи|лэл|г ү| ду|гох|тоо|эрг|олг|ас |эж |йлд|х а|гш |эгш|ули| ши|х ш|г н|игл|сгү|ёсг|дар|х х|амь|р а|о х',
    'kbd': 'гъэ|ыгъ| къ| ху|ыху|ныг| зы|ну |хуи|эм |ъэ |хуэ| и |уит|тын|гъу|э з|къы|эхэ|ӏых|э и|эр | зэ|ъэр|ым |хьэ|ъуэ|цӏы| цӏ|эху|ыны|иты|зы |нэ |хэм|агъ|уэ |къэ|эну| дэ|эу |эгъ|м и|энэ|хъу|эщ |рал|тхэ|этх|эра|хэн|дэт|м х|игъ|э х|ӏэ |щхь|ы ц|ыну|эны|у х| хэ|у з| гъ|зэх|кӏэ|ъэх|ум |хум|іэ |эдэ|рэ | ик|ъун| щы|щӏэ|уэд|и х|уэн|э к|хэт|уэф|иіэ| иі|хэр|э щ| е |ми |лъы|экӏ|іэщ|эти|ти |хуа|м к|эры|у д|щіэ|къу|р з|зэр|мрэ|экі|кіэ|ъым|уну| хъ|ӏи |ауэ| нэ|ъэм|лъэ|эмр|э г|уэх|езы|ншэ|ъэп|зых|алъ|у к|ащэ|фащ|кӏи|икӏ|ъых|укъ|алы|ал |у и|бзэ|ъэщ| мы|эфа| пс|іуэ|абз| ха|ӏуэ| гу| лъ|зым| щӏ| щх|псо|умэ|ъум|хаб|нук|иӏэ| иӏ|щыт|ӏэщ| я |ри |ху | ез|риг|и к|м щ|у щ|и ц|лым|шэу|ъыщ|ыхэ|эпэ|эщӏ|щэх|ыхь|эн |хъэ| ун|ъэк|ъэж|ъыт|м е|уу |эпс|щӏы|у п|сэн|мал|ама| ам|пхъ| щі|щіа|мэн|эхъ|ьэ |эжы|ылъ|э е|эщх|іых|ціы| ці|м з|ту |ьэх|эсэ|ьэн|апщ|эри|жьэ|ъэз|ъэу|дэ |пщӏ|псэ|и н|ынш|жын|уэщ|нэг|ьэп|н х|ъуа|ыкӏ|хур|лъх|дэу|э я|ъэс|псы|э п|эты|э д| ир|р и|эщі|нэх|зэг|ызэ|и л|и и|ней|уне|ыт | зи|уна|энш|хэг|гуп|ыщы|хуе|ыр |иту|и щ|сом|сэх|эзэ|ыкъ|эгу| те|апх|къе| за|лхэ|алх|и д|э л|и у|уэт|ам |мы |ын |и з|эжь|жьы|щ е|уэм|м д|зэ |ъэг|егъ| іу|щ з|л х|бгъ|ытэ| пщ|наг|р щ|сэу|м я|кэ |т х|имы|оми|э а|эмы|тэн|мыл|хэк|у е|хуб|уиг|уей',
    'oss': 'мӕ |ӕн |бар| ӕм| ба|ӕй |ӕмӕ|он |дӕр|ӕр |адӕ|ы а| дӕ| кӕ| йӕ| ис| ад|ар | хъ|дӕй|тӕ |ты |н ӕ|ды |гӕн|алы|лы | ал|йӕ |кӕн|ӕйм|ис |н д|над|маг|йма|агӕ|нӕн|хъу|ӕнӕ| ӕх|ӕ ӕ| уа|амӕ|уам|ъуа|хуы|уа |ынӕ|р и|ӕнд|ы б|ын |нын|с б|цы |ӕст|ӕны| па|ады| ма|онд|дон|ӕ б| ку|ы ӕ|р ӕ|ддз|адд|нӕ |гӕ |ӕ у|ӕ к|сты|арт| ра|уыс|стӕ| ах|хъӕ|ахъ|ӕ х|ӕцы|дза|ӕна|сӕн|аха|тӕй| хи|ӕ а|н а|ст | цӕ|кӕц|ад |зах|пад|н к|дӕм| ӕн|аци|ртӕ|дзи| уы|ӕ с|ыст|цӕу|ӕ й|ны |хад|хсӕ|ӕхс|зин|хиц|ара|ӕхх|зон|куы|йӕх|ӕхи|ӕрд|ицӕ|н и|ъӕн| фӕ|ӕ м|ина|д а| ца|н б|лон|ало|цӕн|нд |уыд|нӕй|й ӕ|арӕ|иба| сӕ|хъа|ард|хи |нды|фӕн|бын|адо| уӕ|рд |ӕ г|н х| ар|н у|нон|дзӕ|йы |ъах|ӕм |акӕ|вӕр|гон| гӕ|имӕ|ы д|ацы| ац|рад| ст|ы у|уыз|рӕй|ыны|ӕмб|р а|ино|ӕуы| рӕ|ӕг | ӕв|ций|раз|ы р|къо| за|ына|ынд| бы| нӕ|ндӕ|ытӕ|сгӕ|ӕсг|гӕс|р х|ы х| на|хӕс|ххӕ|уыр|хху|ӕнг|айд|мбӕ|уын|ыд |ы н|ы ф|рӕс|р й|й а|джы|тӕн|сын|ъон|акъ|зак|уы | ха|й х|кон|зӕр|циа|оци|соц|ист|ӕ и|ой |ызо|мху|ӕмх|рын|аху|тты|й к|рдӕ|ы к|йда|ӕ ф|рды|онт|бин| би|мад| фы|ндо|ийы|р к|а ӕ|ары|цар|чи |аг |ыл |уры|дур|нду|иал|она|аст|ӕмы|нӕд| де|риб|ӕри|сӕр|пӕт|ппӕ|ыра|мы |лтт|ӕлт|зӕл|адз|гӕй|хай|рон|нтӕ|ӕлг|й п|ӕ п| ин|хиб|ахӕ| ны| ӕр|ъхъ|хъх|рак|дра|ыдр|фыд|мӕн|стг|ӕуа|т ц| хӕ|ӕвӕ|й й|ттӕ|бах',
    'sah': 'ар |аах|таа| ки|ах |эр |ан | бы| ха|нна| бу|уон|раа|на |онн|лар|ыра| уо|быр|р б|иһи| су|ары| кө|ин |киһ|аап|уол| би|һи |иир|пта|апт|уох|с б| ту|ии |ас |суо|бии|хта|тар|дии|рди|эйэ|ын |ирд|н т|буо| бэ|тэр|а с|ай |и к|эн |тан|хас|бэй|най|тта|охт|а к| дь|н с|эри|н б|этэ|ара|нан|н к|х х| ба|эти|йэт|р к|аты|ына|тин|гэр|тын|оло| ол|игэ|х б|ана| да| са|га |и б|аҕа|ытт| кэ|ала|өҥү|ола|р у|гар|уга| со|аст|лэр|ллэ|р т|ны |ҥүл|көҥ|ох |уту|аци|анн|ахт|ста|ини|ств|уру| та|эх |улу|ык |олу|лла|ыыт|һин|ору|ция|тут|ыты|р с|бэт|нны| тө|тво|ни |көм|х к|ор |рын|аны| эб|аль|хан|н д|кин|ыга|а б|руй|нар|туһ|ээх|эбэ|ьна|льн|нык|да |тэн|ттэ|луо|наа|оһу|рыт| кы|н у|бур|эһи|көр| сы| ма|илл| на|уу | до|ыла|ыһы|быһ|үлл|абы|э с|бар|он |ьон|дьо|өрэ|үөр| үө|хтэ|во | тү|оҥо| оҥ|оро|лор|нэн|итэ|а т|ылл|аҕы|аһы| ку|н о|рар|рин|эҥ |ыта|тээ|үлэ|и о|кэм| хо|дьи|куо|уһа|нэр|лаа|ыба|тэ |аар|йду|эрэ|бил|айы|ити|һыы|өрү| тэ|та |эхт|рга|үн |үлү|ргэ|эни|аас|рор|т б|ллы|н а| си|ойд|дой|һын|тул|утт|оҕо|э б|тэҥ|ааб|ест| сө|эҕэ|тэҕ| ыл|баҕ|р о| ит|гэн|р а|р д|һан|эби|скэ| ин|н и|ҥор|или|ҕан|ат |р и|руо|бу |циа|оци|соц|к д|дьа| эр|элэ|төр|лта|йэ |рэх| үл|сөп|щес|бще|общ| об|у б|ойо|а о| ор|эми|эрг|сты|иэх|хол|тал|үнэ|й с|р х|инэ',
    'tyv': ' бо|лга|бол| эр|рге|эрг|га |гел|иг |ары|аш |олг|азы|нга| бү|гаш| ба| ки|ар |үрү|ижи|киж|лиг|ан | хо|ели|ге |и б| ту|ынг|аар|үзү|г к| ка|тур|жи |уг |лер|зы |бүр| ха|рын|за |аза|баз|иле|ажы|ың | чо|рүз|зү |г б|рин|анд|ери|даа|иң |ала|ган|лар|дыр|р б|ның|ура|ост|хос|нды|аа | да|да |олу| би|ыны|зын| аз|а б|лге|ниң|луг|урл|ын | кы|ин |рар|еле|р э|ыг |алг|рга|лды|зин| аж|гал|е б|рлу|жур|ужу| уж|алы|а а|ыр | де|ле |бил|ады|п т|алд|ези|ору|дыг|нда|ур |лур|н б|ыры|нде|ң б|ас |елд|тал|шкы|нге|кын|а э|н ч|ылг|маа|ен |бод|еди|уң | та|а к| оо|дар|ста|тты|аны|ышк|гаа|нуң|а х| чу|ыра|р к|ир |ып |чок|ы б| со|ал |ама|хам|аан|уну|оду| ал|ң ч|дун|газ|жыл|п б|ң х|оң |ооң|н х|лда|уру|ини|инг|ң к|ер |үгү|гла|а д|лаа|кан|ээр|аци| на|ити| чү|атт|рла|р у|ылд|хан|еп |н т|е к|лыр|иит|чур|ынд| кү|н а|дал|лде|үлг| хе| ча|улг|тта|туг|сту|инд|н к|өөр|лээ| са|урт|ааш|ара|р а|рни|рүн|ка |өре|ске|өск| өс|ени|а ч|ы х| ар|дең|ү к|гү |бүг|нии| ни|дил|еге|ург|ң э|с у|чор|ашк|ойл|кка|дан|ни |ада|рыл|бот|арг|ең |ү б|ред|е а|лел|ды |айы|н ү|рып|ыыш|ция|ден|мга|амг|кам|унг|е э|пас|г э|м д|лба|а т|лу |йлу|оой|хоо|еви|окк|она|дер|гез|эр |ш х|тын|гад|угу|ы к|кыл|рны|арн|илг| өө| че|е х| өг|де |ип |руу|лди|үнү|үнд| хү|ава|лал',
    'ady': 'гъэ|эу |ыгъ| къ|ъэ |рэ |ныг|нэу| хэ| зы|фит|тын|ъэр|эм |хэт| зэ|ыны|ъэу|эхэ|iыф|цiы|агъ| фи|къы|иты|хьэ| цi|эр |къэ|хъу|кiэ|хэм|энэ|э ц|э и|рал| фэ|ым |ъхь|эра|ыфи|ыкi|у з|э з|и ф|трэ|этр|эшъ|у х|ъэм|гъо|игъ|эны|шъх|фи |тэу|ынэ|эрэ|эдэ|iэ |эгъ|кіэ|у к|фэш|ми | щы|лъэ| гъ|м и|іэ |фэд|ъуа|шъу|лъы|жьы|э к|ти |ъэх|экi|экі| иі|хэр| ык|эти| е | хъ|э х| шъ|iи |нчъ|м к|мрэ|эмр|кiи|у щ|ыты|зэр|ыф |иі |э ш|мэ |ущт|ъэп|ылъ|ъэш|э а|уаш| пс|эп |щтэ|ъущ|зы |ал |бзэ|щыт|р з|ъыт|ыкі|умэ|тэп|у а|эмы| мы|зэх|стэ|пст|э г|ьэн|угъ|риг|ъум|унэ|алы|ъэк|чъэ|э ф|эшi|алъ|зэф|ытэ|ежь| еж|ухъ|абз| ха|и к| лъ| иi| нэ|э ы|шіэ|гъу|эфэ|э я|эжь|и а|хаб|и и|ъон|псэ|э л|уна|оу |зыф|іыф|ціы|эпс|къа|ашэ|ъуг|мал|ама|жьэ|мэн|ызэ| жъ|ъых|ыри|ыфэ|лым|хъэ|зын|ыхэ|у и|iэу|мык|фыг|ъо |ае |фаг|эфи|ыiэ|сэн| ам| ик|ъэг|ьэ |сэу|у п|ы х|фэу|ынч|нэм|ным|эпэ|и з|къо|дэу|эсэ|у ы|пхъ|афэ| ші|ъэз|н ф|ыфы|эн |дэ |имы|ъэн|у е|э е|нэ |шъо|асэ|ьэп|ыр |шэх|итэ|ьэф|ъэс|уми|эум|лэж|жъу|ф ж|эхь|iэн|шiэ|оты|щт |ыра|тыр|кіо|ырэ|шіа|эух|п х|зэг|уи |бгъ|лхэ|алх| иу|эдз|хэд|м е|мыл|кiы|пкъ|iыг|зэ | ці|мы |у ф|элъ|зыр|шiы|тэн|иi |ын |р к| гу| ар|э п|икъ|сэ |м ф|у г|эри|ъот|ьын|эфа|ыт |ьым|эры| аф|іэу|ухы|егъ|іоф|л х|лъх|апэ|къе|ъун| шi|э с|кэ | сы',
    'abk': 'ара|ра |ала|еи |а а|а и| иа|уп | ау|заа|ауа|оуп|аза| да| аз|зин|ы и|гьы|ақә|ьы |ак |лак|әа |зар|и а|реи|аал|уаҩ|атә|ыла|к а|арб|аҩы|рба|дар|ази|бан|ҩы |роу|ин |ла | им|лар|ы а|тә |моу| еи|нза|анз|у а|аар|қәа|оу | ма|иар|аро|н и|әеи|а р| ры|қәе|имо|и и|әар|ны |а д|аҭа|аре| их|шьа| ал| ах|п а|рат|аҵа|ила|и р|ҵар|а м|ахь|аха|аз |аны|әыл|ура|шәа| аи|ацә|ҳәа| ин|ма |цәа| аа|арг|тәы|рақ|п д|иҧш|әиҭ|қәи| из|ина|мза|ахә|хар|ана|еиҧ| ир|леи|а з|ы д| аҭ|сгь|асг|ан |акә|гыл|мам| ам|неи| зе|рра| ҳә|зы |әан|кәа|уа | на|ргь|ьар|хәа|хра|арр|мҭа|амз|әла|нқә|инқ|гь |егь|аац|ҭаа|азы|ашь|лаз| рз|әи |жәл|а у|хәы|рым|уаа|амҭ|з а| ид|ало|иал|ахы|ага|ы е|ҭаз|әыр|аӡә|раз|тәи| уб|аҧш| ха|има|ҭра| аб|ҟаз|агь|п и|ар |аам|аан|иҭа|иха|рхә|ҭах| ҟа|еил|нас|зак|арц|қәы| аӡ|ҧшы|уне|дун|рал|маз|иҭр|о а|аҳә| ад|ри |ыҟа|иҟа|зег|да |ажә|алх|аус|а ҟ| ан|хьа|ырш|әым|лаг| аҧ|бжь|ықә|куа|әал|хақ|аа |раа|наг|ә е|лах|әгь|м а|каа|иду|с и|ьақ|бар| ус|хьч|рц |ым |аҭы| ак|әра|рзи|хаҭ|аҧс|аҟа|гар|хьы|ас |бас|уаз| ды|әаҧ|нха|ҳәы|лаҭ|мил|рыл|ҧш |рҭ |хы |усу| рг| ил|иур|аиу|еид| ар|хь |лхр|қар|ҭқа|нҭқ|ынҭ|әын|аба|оур| иш|мҩа|ит | иу|ҟал|ы х|ӡба|ада|ьча|ьа |изи|ом |р а|аҳа|ам |ҟам|кгь|акг|ргы|ҭар| иҟ|ҧшр|зеи|ус |жьа|ә а| ат|уба|ихә',
    'alt': ' ја| та|ла | ка|тап|рик| ла|эри| ки|‐эр|п‐э|ап‐|а к|икт| бо|ыҥ |тӱ |ктӱ|ижи|киж|ажы|лу |ына|ныҥ|ы л| ке|жы |ле | ту|да |каж|а т|айы| он|жи |рга|бол|ар |ый |де |учу| уч| де|чур|лар|ери|эме| эм|ер |е к| би|арг|зе |езе|рлу|урл|нды|га |аҥ |мез|е ј|ан |ынд|ары|ӱ к|оны|ара|йын|оло|йым|јай|јар| ле|кер|р т|ере|наҥ|ула|а ј|анд|ала|ҥ к|кан|ган|лга|ык |на | ба| је|ок | јо|р у|нда|рын| те|ин |зын|ыны|тур| ай|ын |бой|лор|ири|ҥ т|дый| ко|кем| ор|бир|а б|аҥы|јаҥ|иҥ |у к|ойы|ор |ым |рек|е т|лан|ине|рин| ар|лык|тер|р а|до |алд|ик |ы ј|ный|рӱм|и ј|кте|ӱре|ана| ол|лер|о о|н т|дар|рул|кор|аны|ҥ ј|мин|ӱми|ция|аци|ай |тай|‐та|ств|ол |зин|нар| ал|ҥ б|ге |ыкт|ама|азы|ниҥ|ады|јӱр| кӧ|и к|ен |у б|к к|теҥ| иш|тво|едӱ|јет|иле| тӧ| бу|ӱ о|ект|ору|с у|алы|н ј|р л|ек |улу|лда|не |гал|а о|оно|е о|ард|ас |ҥын|нде|еҥ |к б|ыла|айа|тӧз|кал|ини| чы|кӧр|ире|кир|н к|ҥ‐т|еҥ‐| ул|нчо|онч|ред| ӱр|амы|е э|етк|тал|и о| ок|йдо|ойд|ной|ды |ада|й б|инд|ры |тар|а э|огы|ри |ир |ча |нча|зы |алг|ьны|льн|аль|соц|ӧзи| јӱ|е б| кӱ|ка |лус|вон|оон|роо|оро|лик|бил|кти|тки|еп |деп|аар|ди |ишт|ҥ а|сак|п т| то|аба|ӱрӱ|ду |р о|кта|к а|урт|јур|жин|јок|ынч|аай|ы а|йал|циа|оци| со|ӧрӱ|к э|и б|ы б|ылг|рер| бӱ|ест| ку|р ј|н э|лде|илд|кил| ээ|ӧзӧ',
    'kjh': ' па| по|а п|ай |аза|за |паз|ар |лар|пол|а к|ала|на |ың | тј|ға |ан |ған| кі|рға|лға|ның| ха| ки|арғ|тјр|ізі|јре|кіз|ің |е п|ара| на|аны|зын|нің|зін|іні|олғ| ал|кир|ире|н н|ң п|азы| ча| пр|ре |пар|р т|най|да | са|ын |ына|рге|рек|пра|а т|ге |р п| хо| чо|сха|лай|й п|ығ |ары|а а| пі|чар|ек |нда|ола|пос|ені| то|ыны|аци|ста| ар| ан|а ч|нар| ту|а х|ос |хай|ыра|асх|рын|сты|ерг|іг |ха |пір|лер|н п|ьна|льн|аль|ен |ция|ы п|ост|ң т|ынд|ны |рел|а с|озы|нын|не |ра |дай|ер |ген|н т|ңда|оңд| оң|урт|чур| чу|еле|зар|іне|хан|е а|айд|зы |рав|нча|пас|к п|рта|рай|ча |оғы|тоғ| сы|поз| та|ң а|зна|хаз|тыр|чон|айл|тар|ғыс|зі |та |ң ч|рер|ады|рад|іре|онн|нна|ох |чох| да|лан|тер| ти|ғла|тха|чат|езі|дыл|алы|ана|сте|азн|аво|бин|име|ним| ни|й к|ыс |ағы|а о|ері|нін|гре|хон|дыр| чи|сын|анд|е т|н с|е х|лығ|лын|раз|оос|хоо|н х|кен|она|нац|р а|аа |с о|лге|пу | пу|ард| ол|ін |еді|ред|дағ|ағ |ні |атх|айб|сай|ирг|лир|арн|ылб|аба|е ч|сан|инч| со|нал|й а|ли |иң |і п|діг|егр| ег|ых |ных|рга|аң |йзы|айз|пир| пи|н ч|чыл|ачы|рач|ң х|рны|лби|дее|рде|ірд|г п|туз|ліг|й ч|циа|оци|соц|ска|иче| ре| те| де|аст|де |с п|нны|лды|олд|тол|оны|ыст|вол|ығл|итк|н к|нҷа|ғы |анн|йли|ойл|пой|н а|йба|ылғ|уст|јст|тјс|ызы|ест|иал|й с|ион|ніс|кай',
    'evn': 'ин | ил|илэ| тэ|чин|тэд|кин|эде| би|ду |ыки|тык| та|эл | о̄|ачи|эты|н т|э̄н|лэт|н и|мач|ңи |тын|н э|ет |дет|э̄ |ын |на |вэл| вэ|̄н | мэ|ан |ава|ки | гу|чэ̄| эр|иты| дя|най|мчэ|ств|гу |тар| һа|нңи|эчи|о̄м|ви |мэ̄|элэ|ми |ай |н б|мэч|дяр|нма|бим|ун |нду|т б|н о|ама|а т|дян|упк|һав|имч|и д|дун|дук|̄ма|н д|̄нм|тво|н г|н а|ган|лэ |яри|э т|̄чи| да|ден|и т|инд|э̄т|ӣ |и в| ду|ция|аци| ая|уңа| ну|ди |ва |эру|лэ̄|а и|лду|ысу|дыс| ды|нэ |вки|и и|у и|н һ| ңи|нуң|рэ̄| ты|лэл|пка| уп|аты|ани|и г|и о|да |ир | дю|ңан|эвк|ен |н ң|вад|эдэ|сӣ| ит|ту | эв|у д|дер|т т|н у|иси|бис|и б|̄нң|урэ|мук|нму|ат |кат|чир|бин|рин|суд|ман|у т|а̄н|а̄ |дем|син|ады| ав|эду|рга|ар |гды| бу| һу|эн | дэ|а д|ма | де|р д|кит|эр |лды|ча̄| ур|уки|ыга|тыг|тат| си| га|эгэ| об| со|а б|рӯ|элд|эси|н с|эт |тыл|инм|учи|суч|уму| ум|рэ | эд| су|аду|тчэ|кэ̄|эгд|н м| бэ|ңту|уңт| эм|тки|а э|яна|си |яра|алд|ича| са|и м|там|ӣв|ал |ла |ула|дул| ку|ян |а̄ч| а̄|дин|анд|̄ т|у б|рст|арс|дар|уда|осу|гос| го|ук | ӣ|нӣ|дю̄|дыт|гэл|ңэ̄|еңэ|дең|ӣн|анң|н н|дэт|̄ты|илд|дан|лэд|л и|у с|̄ и|ит |вдя|дэ̄|ды |иде|бид|ннэ|р и| – |һэг| һэ|л б| ас|һуң|эма|уку|ри |эмэ|и у|ты̄|га̄|инэ|айд|мча|амч|гам|ьна|льн|аль|гэ̄|бэл|т г|во |ест|чӣ| на|нна|енн|̄ а',
    'gld': 'ни |й |ай|ани|наи| на|и м| та|эй|ми |и н|и г|чи | пр| му|аво|мут|ди |рав|пра|сал|тэи|ри |дё|они| го| би|тао|̆ т|ури|и б|и т|ой|и х|утэ| ха|аон|и п| тэ| мэ| де| гэ|нэ |̆ н|энэ|мэн| ба|элэ|алб|ку |гэл|гои|ва |нё| хэ|анд|бан|эни|и д|и а|ёа|си |лба|ами|уру| не|ств| да|би |иан|аси|̆ д| дэ|и о|ду |ачи|̆ п|ана|да |ими|и э|тво|ори|ова| ну|̈ан|хэм| об|ндо|ван|йв| гу|лди|эчи|ини|доа|оса| ос|нде|вок| ка|и к|дэ |ача|ба |бим|ава|мур| эм|диа|ту |оку|̈бо|ёб|оси|иди|эми|уй|улэ|и с|ция|гиа|аӈг|бод| бо|у б|эму|алд|э г|ал | бэ|ола|рун|рид|мбэ|нди|аци|̆ г|вэ |нду|эрэ|вос|у н|кан|эур|лэм|мба|эн |ну |ран|баи|ан |аса|учи|гуч|хаи|оло|гол|уту|ари| ги|а б|час|и у|амб| уи| ту|ала| ст|оан|̆ва|ода|эм |а д|у д|очи|лэч|дол|̆та|йт|ои |а т|хан| ач|бэ |унд|тур|йд|тра|стр|иги|гоа|эди| хо|онд| со|ест|общ|мби|ба̄|лан|иду|до |иур|ӈгэ|инд|э д|йн|дас|обо|воб|сво| св|ис |гис|а х|ӈги|а г|эсэ|̆ х|иу |миу|̆чи|йч|нчи|бал|эри|̆са|йс|мту|эмт|ьна|льн|аль|ние|и и|во |щес|бще|эӈг|хэӈ|бэл|гур| пу|̈й|ёи| ан|лэи|тэд|осу|лэу|дин|дул|̆ни|ии |вов|э т|̆ о|у п|са̄| са| эи|а э|̆ б|н б|син|ивэ|рив| эн|бон|бра|обр|вод|кул| эд|нна|умб|сид|рст|арс|дар|уда|суд|гос|элд|э м|лам|оми| чи|оач|пур|над|эде|вэн|чин|̆вэ|имб|эси|ива|эмб',
    'cjs': 'ын | ки| па|ижи|киж|да | по| қа|ға |зын|н к|а к|жи |пар|ин |а п|ге |н п| да| са|чын|рчы|арч|ана| ке|рге| ча|сан|пол|алы|за |қа |зин|арғ| чо|наз|азы|аны|ар |лер|лар|ығ |аза| те|ан |а а|н қ|қай|рға|ерг|а т|ың |ара|нға|қал|а ч|ере|кер|ери|ген|нар| ан| пи|аң |ған|ынғ|шқа|иле|ең | че|сын|лзы|н т|а с|айд|ашқ|жил| ал|де |ези|ыға|рбе|паш|чар|и п|ның|озу|поз|рин|нна|аба|ны |н а|аға| кӧ|пир|а қ|ер |ебе|нер|ӱрг|ы ч|н ч|нда|ғ п|ол |ола| то|кӧр|лық| иш|ынн|лығ|уны|зун|е с|сқа|чер|кир|ң к|кем|олз|ен |нын|қан| шы|ң п|тең| ту|ары| ӱр|неб| не|р п| тӧ|нге|инг|ноо| но|гин|еги|рег| аа|рзи|рын|ӧре|оза|чоз| ол|баз|и қ|е ч|қта|ықт|дығ|ала|ште|ишт|асқ|ла |алз|ң ч|нне|оо |н н|ааң|ция|аци|о д|жин|тсы|оол|тоо|йды|тар|рғы|е а|бе |ағы|а ӱ|р а|еле| ағ|тқа|иң |ени|тут|ы п|зақ|а д|е д|ас |ип | қу|ем |бен|ба |ғ д|ек |рек|ғ т|қты|тығ|ып |пал|бел|е к|и к|еге|аан|қаа|пас| ла|и т|қат|нде|инд|ерд|ынд|и а|ре |кла|л қ| қы|рба|тыр|с п|дер| эд|без|тег|чат|е т|рда|оқ |чоқ|ра |чон| ар|е п|ча |чад|ққа|по |нзи|енз|н и|тӧр| аб|шсы| пӱ|арз|нең|анд|ғын|атқ|инн|ығы|п а|ң қ|лаз|а ш|ле | ле|ирз|чығ|рац|екл|дек| де|лза|йда| эт|тты|атт|бас|раб|е қ|эде|л э|ни |ини|атс|ш ч|уғ |луғ|улу| ул|ирд|нан|шығ|яда|ияд| ти|он |ерб|р к|р с|ош |пош',
    'eve': 'эн | бэ|бэй|нэн|ан |да |‐да| би|эй |н б|ннэ|ян |нян| ня|н т|н н|чин|тэл|инн|мэн|л б|эл |өмэ| өм|кэн| та|ни |эсн| эс|мэт| мэ| ҥи|этэ|и‐д|а б|ин | но|элэ|ноҥ|сни|н ө|оҥа|эчи| тэ|дьи|ара|бин|ств|ҥан|н д|н г|нна| го| хо|н э|рав|ҥи‐|н ҥ|дук|суд|тар|тти|ргэ|икэ|дэн| пр|н х|йил|эйи|тво|этт|эгэ|тэг|а э|ьи |н м|ник|идэ|бид|и н|ур |ай |най|уда|бэл|иву|э б|н а|дар|ич |во | ху|нан|ти |ки | дь| эн| тө|ча |ург|гур| гу|рст|арс|осу|гос|й б|гэл|аль|нтэ|гэч|й н|н п|лэч|эйд|и т|пра| га|и э|ын |чим|кэт|ьна|льн|нат|куч|ун |н һ|ла |ач |лив|кон|тэ |та |тта|ир |йдь|гэн|энд|мэр|к‐д|тын| ач|дьэ|алд| ба| бо|аич| аи|лэн|мнэ|имн|лэ |онт|хон|ала|ав | һи|кан| һа| ку|й м|утт|снэ|илб|и б|и ҥ|нди|эрг|эни|нду|уку|бу |лбу|вал|ция|а а|рду|р б|чур|этч|окэ|бок|ил |й х| на|пку|упк|хуп|анн|ч т|гэв|инэ|эки|лгэ|лкэ|ми‐|ями| ям|а д|ман|ама|өгэ|төг|дял| дя| дю|тал|р г|унн|дьо|они|н к|айу|и и|энн| су|имэ|чэ |иһи|ако|зак| за|илэ| ил|и х| кэ|атт|гэт|он |идь|дэ |ҥии|ди |ээн|лни|ҥэл| ҥэ|төр|ача|иду|н‐д|н я|и а|йи |куй|ава|аци| де| эр|рэк|н и|ака|дол| до|ьэн|ми |ари|лда|бал| хи|тчу|ини|чэк|учэ|иал|циа|оци|соц| со|роф|про|ялн|аты|там|й г|ите|ынд|дюл|ган|‐та|лдэ|тэк|дун|элг|элк|дан|а г|ий |кий|тнэ|экэ|н о|буг| бу|тэн|аан|ски|и м|рид',
    'ykg': 'уол|раw|ньэ|дэ |ол |аwн|л м|эй | мо|ора|мор|йуо|ьэй|аҕа| та|эл |ҕа | эл|ьэ |көд| кө|тэ |wнь| па|дьэ|эҥ |өдэ|льэ|анэ|ҕан|даҕ|э к|атэ|даа|ада|тад|нэ |аат|пар| ту|эҕа|йаw| йа|wна|ара|э т|эйу|удэ|туд|элэ|нар|э й|wаа|аwа|ар | мэ| ча|э п|э w|ьэл|ньи| нь|wиэ|ги |аан|эк |дьи|аw |лҕа|лэ |эдэ|урэ|ндь| wи| ки|й т|лэк|ьил|эда|й к|лль|уйу|ань|w п|ҕат|кин|ури|уур| су|э ч|уон|энь|нэй| ҥо| уу|мэ |э м| тэ|адь|ҕад|ат |элк|ину|ри | кэ|тэт|э э|ьии|эдь|нь |инь|нул|нну| эн|бан|эн | wа|иэн|иэй|лк |дэл|аль| со|таҥ|нун|энн|рэҥ|итэ|чаҕ|э н| ха|нуо|ул |лги|одэ|ньа|л т|нуй|ҥ э|к э|эрэ|чии| чи|а э|имэ|пэд|ийу| эw|мэн|ҥол|и т|льи|уку| ль|э л| чу|анд|дит|дэҥ|пэҕ|нэҥ|олл|а к|куо|wэй|эwэ|э у|э х|ару|эт |нҕа|р т|ьуо|ҥдэ|уҥд|чуҥ|эги|аал|унҥ|эру|луо|маа| ма|ади|он |дэҕ|л л|лда|эwр|кэд|эйн| лэ|эмэ|льн|кун|мэд|ьэр|н н|ҥ т|раа|ура| ур|л ч|ола|рук|энд|чуо|й с|хад|ил |р э|аму|чам|эбэ|рэб|бур|нбу|йнб|лэw|и э| пр|ьнэ|олу|эль|аҥу|апэ|ҥи |ьэҥ| ди|пэ |нэм|и к|дьу| ба|нур| уо|а ч| нэ|ств|тэй|ним| ни|алл|ьал|э с|ай |най|амб|улҕ|ҥну|оҥн|чоҥ| чо|инҕ|олҕ|ан |оҕо|wрэ| эд|иий|иэ |й ч|аай|кэй|ану|йэ |рэл|пэл|аап|одь|ция|лпэ|н ч|ҥин|лдь|э б|ьид| на|мэл| ти|код|а м|ин |иин| пэ|ҥ м|унь|бун| бу|л б|суо|ууй|уул|иэл|ичу| ам|сэw| сэ|аар|т э',
    'nio': 'нә | ку| ӈи|мән|ә” | ӈа|әди|рәд|ӈан|ны |ти |са |аса|урә|кур| мә|ле |иле|ӈил|ты |ите|нас|ана|ту |әны|нту|онә| кә| ни| ӈо|те |рав|пра| пр| хо|ӈон|е м|дит|тән|әнә|е ӈ|хон|” ӈ|тү |ити|ы ӈ| тә|ынт|мын| мы|үтү|дя |во |аво| ӈә|нты|ә п|бся| ня|бит|әнд|ся |у” |тти|ә к|кәр|онт|ә ӈ|әтт| та|бса|нде|ы к|” к|и” |и м|уо |а х|хүт|” х|иби|тә |и ӈ|туо|сан| ху|ә т|няг|изи| ме| ӈу|тан|ягә|ыты| сы| хе|анә|рҫу|әрҫ|кәт|нә”| бә|елы|”тә|али|мәә| си|әтә|нсә|ә н|уни|ный|әә |” т|” с|ндя|нин|ый |ндә|гәт|ди | де|о” |ств|анд|мты|зә |тен|кун|я к|ә м|хун|ниб|лит|у к|ы н|хел|” н|бән|бәу| те|тәт|гуй|ены|тәр|гал|түо|итт|ӈуо|әә”|әй |ә х|ы” |әту|де”|йбә|әйб|ӈәй|ү м|әты|зи”|я ӈ|нил| ит| ка|ӈәз|е” |уом|тәб|тыә|мел|е н|ни |ини|унс|әән|ы с|аци|ану|у ӈ| их|а ӈ|әуз|уза|әбс|әмә| су|ӈиз|о ӈ|о н|” м|о т|ттү| хү|сиә|и н| сә|ы м|гәә|ыӈ |сыт|сы | не|уйс| об|у н|ыры|атә|кон|а к|ыгу|тыг|сыл|инт|ыбс|илы|я и|тум|уод|рә”|янд|нян|ихү|тыӈ|ава|иде|ели|уо”|йся|”сы|ы”с|лы”|ымт| на|й н|де |нии|сиб|лыг|ибс|и к|моу| мо|нтә|иәр|ы и|етә|ә с|вай|лид|ы х|ӈәт|ным|унә|сун| ма|дей|омт|у т|мту|ызә|суд|или|у х|ҫу |ру”|ыга|ылы|нти|лыб|унт|й ӈ|у с|анс|нис|айт|ү”т|й с|нен|” д| го|гәй|тво|нер|ерә|ы т| дя|дәт|ыә |ти”|әрә|”си|и”с|”дя|иси|убс|әру|а”т|адя|үо ',
    'oaa': 'ни |и б|ри |а̄ |̄ни| до|ама|и н|и д|дда|бū|дор|ари|че̄| ха|и х| на|оро|да̄|ми |ū |чи |ини| бu|ипа|чип|е̄д|ли |̄ли| чи|мач|а̄л|па̄|хам|̄дд| та|аче|ӡи |нар|о̄н|ūн| мэ|ури|е̄ |э̄ |ддэ|ду |̄ ч|мэ̄| гэ|и г|рон|они|э̄н| ба|и т|идд|дэ̄|и м|и с|̄нэ|̄ б| би|̄ г|али|нэ |до̄|удд| ху|̄ х| ан|нду|и к|ддо|гэв| уи|баи|и а|уру| гу|кку|и э|о̄ |вву|ӡӡи|лин|ачи|омо|гур|илэ|уил|уми|ими|ре̄| бо|нэи| ка|̄чи|но̄| но| да|буд|ита|эи |вур|ани| си|иӡи|о̄ч|тто|уӡӡ|элэ|таи|и о|иду|рре|̄ м|ӈуи| ӈу|ӡин| го|на̄|аит|аси|анд|ччи|урр|мал|эвв|ччу|экк|да |чче|иjа|лӡи|во̄|и у|̄нн|эчч|аи |эдд|̄ т|инэ|ачч|̄ э|пул|сиj|и ч|отт|эву|ичи| бэ|тач|буӡ|нū|ннu|вво|чим|чур|и ӈ|тар|дэ |эни|нӡи|мот| ом|не̄|лэч|бэл|ами|ули|акс|мū|а б|ла |уид|бо̄|̄ д|акк|там|сал|̄ с|сил|гои|нне|ибу|̄па|ūр|ӡū|ана|учи|лич|ге̄|ко̄|и п|биӡ|ула|аду|̄да|ӯп|хӯ|jū|jju|лма|илм| ну| эр|ӡӡu|лэк|нни|аин|сач| ак| са|̄ н|тта|тэи|рит|кам|са̄|ма |у г|э б| тэ| ре|а г|ои | хо|дап|лбэ|э д|вум|амм|̄ у|ств|чиб|икк|инн|ббu|дӯ|уни|эчи|ил |ӈга|дуч|кса|̄ а| ге| пр|аур|тау|олӡ|итэ|̄ду|е̄н|ру |кко|иса|оси|ума|рум|адд|дол|рол|а̄д|па |том| мu|би |сид|ата|ута|нум| ū|дду|̄рэ|эми|рас|дун|лил|ичч| бу|или|ӡил|эӡи|ивэ|мба|итт|ивв|бив| су|иха|̄ к| то| эв|алд|сиа|сос| со|рел'
  },
  'Arabic': {
    'arb': ' ال|ية |في | في|الح| أو|أو | وا|وال|حق |ة ا|لحق|الت|كل |الم|لكل| لك|لى |ق ف|ته |و ا|ة و|شخص|ة ل|ات |الأ|ي أ|ون | شخ|م ا|أي | أي|ان |أن |مة |ي ا|الا|لا |ها |اء | أن| عل|خص |ن ا| لل|د ا|من |فرد|ما |الع|ت ا|حري|على|ل ف|رد |ل ش| لا|رية| إل|ة أ|ا ا|ن ي| ول|ا ل|ا ي| فر| من|ة م|الق|جتم|ن أ|ق ا|الإ| حر|له |ه ل|اية|لك |ه ا| دو|دة |اً |ين |ه و|لة |ي ح| عن|ماع|ي ت|ذا | حق|قوق|حقو|، و|ن ت|مع |ص ا|ام |د أ| كا|هذا|الو| إن|مل |امة|ع ا|إلى|ة ع|ماي|حما|ن و|لتع| وي|ير |نون|ي و|اسي|الج| هذ|نسا|وق |ترا|عية|ه أ| له|سية| يج| با|دول|انو|قان|لقا|ة ب|ة ت|تما|الد|يات|ع ب|سان|إنس|هم |علي| مت|لمج|ذلك|عمل|لأس|وز |جوز|يجو|بال|غير|ك ا|كان|ساس|أسا|دم |لاد|اعي|الر|تمي|دون|تمت|لتم| يع|ليه|ساو|اجت|ي م|لعا|لجم|تعل|ر و|تمع|مجت| مع|يه |ى أ|فيه|ى ا| كل|لات|ملا|ود |انت|الف|يها|ي إ|تي |الب|لي |قدم|ال |اد |ل ا|يز |ييز|ميي| تم|لحر|تع |متع|ا ب|عام|ا و|ق و|رام|ل ل|لاج|را |الش| وإ|يم |ليم|شتر|ا ح|واج|لزو|ول |ا ف|ولة|لحم|أسر| ذل|ه ف|اته|مسا|لمس| تع|عن |ه ع|وله|يته|ن ل|رة | وس|اة |يد | تح| مس|ي ي|لتي|عة |ولي|لدو| أس| وف|ل و|أية|ني |الس|لان|لإع|ة ف|ريا|ل إ|م ب|امل|كرا|تسا|ميع|جمي| جم|أول|بية|عيش|تحق|ادة|س ا| مم|معي|جما|عات|اعا|ارس|مار|مما|م و|راك|اشت|الط|اج |زوا|الز| وم|حدة|تحد|لمت|مم |لأم|ده |بلا| بل|ار |يار|تيا|ختي|اخت|ن م| مر',
    'urd': 'ور | او|اور|کے | کے| کی| کا|یں | حق|کی |کا | کو|ئے |ے ک|یا |سے |کو |شخص| شخ|نے | اس| ہے|میں|حق | ہو| می|خص |ے ا| جا|اس | سے| یا|ہر |ی ا| کر| ہر|ے۔ |سی |ہیں|ا ح|ص ک|وں |ے م| ان|ر ش|۔ ہ|ائے|زاد|آزا| آز|ام |ر ا|ق ہ|ادی|جائ|ں ک|ہے۔|م ک| کس|ا ج|ی ک|س ک|کسی| پر|ے گ|ہے |ار |ت ک|دی |پر |و ا| حا| جو| ہی|ان |ی ج|ری | نہ| مع|جو |ل ک|ی ت|ن ک|کرن|ئی |ل ہ|تی |ہو |ہ ا| ای|صل |اصل|حاص|رنے|ی ش|نہ |۔ ا|ں۔ |یں۔|ر ک|ر م| مل|وہ |معا|رے |ں ا|نہی|ے ہ|ے ب|ایس|ے ل| تع| گا|یت |ی ح|ا ا|ی م|اپن| اپ|کیا|می |ی س| جس|ہ ک|نی |اشر|عاش| دو|لئے| لئ|انہ|وق |قوق|حقو|مل | قا|کہ | گی|ر ب|ہ م| وہ| بن|ی ب|ملک|جس |ا۔ |ریق|ر ن|ے ج|اد |ات |گی |د ک|ے ح|دار|ر ہ|گا۔|قوم| قو|ے، |ا س|دوس|ر پ| و | شا|ی آ|ں م|ق ح| پو| با|خلا|انے|یم |لیم|و ت|ون | کہ|ی، |۔ ک|ا پ|ن ا|لک |علا|ا م|ق ک|ائی|وسر|ی ہ|وئی|یر |ا ہ|علی|و گ|وری|دگی|ندگ|و ک|یسے| من|ائد|رائ| مر|پور| طر|ومی|ے خ|سب |نون|انو|قان| سک|وام|ین | رک|تعل|لاق|غیر|دان|، ا| بی| مس|یوں|نا | بھ| بر|رتی|ادا|امل|یہ | یہ|ہ و| عا|ی پ| بچ|اف |لاف| خل|ی۔ |گی۔| دی|ھی |بھی|دہ |جا |پنی|قوا|اقو|رکھ|ے ی| عل|کوئ|، م| چا|ے س|ر ع| پی|برا|ر س|ر ح|سان|م ا|کام|شرت| را|شام|من |زند| زن|ب ک|ت م|اہ |اری|س م|ر ج| مح|ورا|ے پ|طری|ہوں|ال |ں س|ی ن|کرے| مق|ت س|تحف| تح|و۔ |ہو۔|بند| اق|د ہ| ام|امی|الا|لت |شرے|ے ع|ا ک|فری',
    'pes': ' و | حق| با|ند |رد |دار| دا|که |هر | در| که|در | هر|ر ک|حق |د ه|از |یت | از|یا |کس |ود |ارد| یا| کس|ای |د و| بر| خو|ق د|باش|شد |د ک|ار |د ب| را|ه ب|ان |آزا| آز|را |اشد|ی و|ه ا|ین |ید |زاد|س ح|خود|ی ب| اس|ده |دی |ور |اید|ه د|ری |و ا|تما|ات | نم|ی ک|ادی|نه |رای|د ا| آن|است|ر ا|ر م| اج|مای|ون |قوق|حقو|و م| ان|انه| هم|وق |ایت| شو|ی ا| مو| بی|با | تا|ورد|انو|ست |وان|برا|ام |شود|آن |جتم|ی ی| کن|ر ب|کند| مر|ت م|های|ت ا| مس|ی، |ماع|اجت|توا|یگر|و ب|دان|ت و|ا م| بد|عی |کار| من|مور| مق|ی د| زن|ی م|ن ب|ر خ|اه |ا ب|اری|د آ|مل | به|اعی|د، |دیگ|ت ب|بای|این| می|ن و|ق م| عم| کا|ن ا|و آ| حم|نون|ه و|و د|د ش| ای|شور|کشو| کش|لی |نی |ه م|بعی|ر ش|یه | مل|میت|ی ر|رند| شر|می |وی |ساو|قان| قا|مقا|او | او|د م|گی |نمی| اح| مح|مین|ئی |ادا| آم|خوا|گرد| گر|مند| شد|ائی| دی|ز ح|هیچ| هی|اده| مت|نما|ت ک|ران| بم|ن ح|ر ت|حما|ارن|مسا|دگی|ومی|ن ت|ملل|بر |هد |واه|بهر| اع|‌ها|ق و|، ا|عیت|یتو|ا ر|ن م| عق|همه|ا ه|زش |وزش|موز|آمو|انت|تی |جام|موم|عمو|تخا| فر|طور|د د|ه ح|ردا|اوی|نوا|انی|رار| مج|ی ن|حدی|احد|ندگ|زند|شخص| شخ|‌من|ه‌م|ره‌|هره|شده|ع ا|و ه|اسی|هٔ |یده|عقی|ا ا|مه | بش|اد |دیه|ا د|دوا|ی ح|ابع|ی ت|خاب|نتخ|رور|و ر|شرا| خا|ٔمی|أم|تأ|اً |امل|له |د ر|اسا|خور|بل |ابل|قاب|یک |سان|قرا|ا ن|خصی| ام| بو|یر |الم|بین|اهد|تبع| تب',
    'zlm': ' دا|ان |دان| بر| او|ن س|رڠ |دال| ڤر|له |كن | كڤ|ن ا|ن ك|ن د|يڠ | يڠ|ڤد |حق |ورڠ|تيا|ياڤ|ارا|كڤد|اور|رحق|برح|اله|أن |ولي| ات|اتا|ڠن |تاو|اڤ |ستي|ليه|او | ست|ڤ ا|يه |را |ه ب|ه د|عدا| عد|ن ڤ|ن ب|ين | تر|ق ك|ن ي|يبس|بيب| تي| سو| كب| سا|ن م|ن ت|لم |الم|د س|ڠ ع| من|چار|د ڤ|رن |سام| ما|ڽ س|ن، | بو| اي|ندق| حق|ڬار|نڬا|بول|سبا| سب|اتو|ا س|قله| ڤم| مم|وان|سچا| سچ| كس|ا ب|سن | سم|ڤرل|اون|نڽ |تن | با|هن |سيا|ا ڤ|ارڠ|بار|ڤا |بسن|كبي|ام |يند|ي د|اڬي|ڠ ب|باڬ|ي ا|مان| لا| د |دقل|هند| هن|ت د|ادي|وين|يكن| نڬ|، ك|ن٢ | ڤو|بڠس|ق٢ |ات |اول|اكن|اڽ | سس|ون |اد | كو|اين|دڠن| دڠ|ائن|تو |تي |ن ه|ڬي |سي |ق م|وڠن|دوڠ|ندو|لين|رلي|نتو|ڤون|وات|ياد|تيك|ڠسا|ڤمب|ترم|٢ د|حق٢|وا |لوا|ماس|وق |ه م|ل د| مل|وند| ڤڠ|ا، |، ت|لائ|اي |مڤو|يك |ي ك|رات|مرا| بي|سمو|و ك|، د|سوا|ڠ م|ڠ س|ڠ٢ |ڤري|يري|دير|ا ا|اسا|ڤ٢ |تا |سوس|، س|جوا|ڠ ت|رأن| ان|سأن|ريك|يأن|ري | در|امر|كرج| ڤل|ا د|جرن|اجر|ارك|لاج|د ك|وار|برس|ونت|منو|سال|ينڠ|دڠ٢|ندڠ| مڠ|اڤا|سسي|ساس|نن |ڤول|اڬا| بڠ| سڤ|مبي| اڤ|ڠ ا|ارأ|ڤرا|ي س|بس | دل|ا م|موا|ڤلا|ملا|ڤرك|كور|وبو| كأ|وكن|أنڽ|كسا|ڠڬو|ادڤ|هاد|رها|تره|كوم|توق|م س|ڠ د|دي | دي|٢ س|ندي|اس |ادا|بوا| دب|ڠ ڤ|ڽ، |اڤ٢|رتا|ال |يال|وسي| كت|أن،|نڤا|تنڤ| تن|م ڤ|رسا|ممڤ| مر|ن ح| كم|نسي|جأن|ؤي |لؤي|الؤ|لال|كڤر|كت |ركت|شار|مشا| مش|جاد|رڬا',
    'skr': 'تے |اں |دی |دے | ۔ |وں | تے| دا| کو|کوں| حق|دا | دی|یاں| دے|یں |ے ا|شخص| شخ|ہر |ے ۔|اصل| حا|حق |خص | ہر|صل |حاص|ہے | ہے|ال |ق ح|ل ہ| نا| کی| وچ|۔ ہ|یا |سی |ے م| او|وچ |اتے|کیت|ا ح|ادی|نال|ص ک| ات|ر ش|ہیں| یا|ں د| ای|یسی| مل|وند|کہی| کہ|ی ت|زاد|ازا| از|ندے|ں ک|ار | وی|ے ک|ئے | ان|ڻ د|نہ | کر|اون|ے و|دیا|ی د|ں ا|ے ب|ویس|وڻ |ی ن| ہو|تی |ی ۔| نہ|ی ا|یند|و ڄ|آپڻ| آپ|ا و|ے ج| کن|ے ن|ندی|ت د|ے ح|ی ک|ئی |ملک|یتے|ن ۔|تھی| تھ|ون |ں م| بچ|۔ ا|نوں|کنو|ڻے |اری|ا ا|ے ہ|ل ت| ڄئ|وق |قوق|حقو|ل ک|خلا| جی|لک |دار|یت |کرڻ|انہ|کو |ہکو| ہک|ن ا|مل | وس|ں و|پڻے| تع|ی م|اف |ے خ|نون|قنو| قن| لو|۔ ک|ری |لے |تا |یتا| قو| چا|ہاں|ڄئے|ق ت|ایہ|رڻ |ے د|ر ک| و |لاف| خل| جو|ی و|او |ہو |ئو |چئو|بچئ|یر |ہوو|ا م|ی ج|الا|ین | جا|می |نہا|ان |ات |سڱد| سڱ|یب |سیب|وسی| شا|ب د|یوڻ|ام |اوڻ|ے ت|ڻ ک| مط|ں ت| ون| کم|ن د|رکھ| رک|ڻی |ں آ|ریا|ی ہ|اد |یاد|علا|ر ہ|ں س|ی ح|جھی|ائد|ہی |لوک| ڋو| سم| سا| من| مع|بق |ابق|طاب|مطا|ھیو|ں ف|ہن | ہن|جو |و ک|ں ش|ر ت|کار|م د|ھیا| ٻا|غیر|و ل|وئی|جیا|وام|قوا|ی س| جھ|ل ا|قوم| سی|ذہب|مذہ| مذ|اے | اے|دن |ا ت|سان|نسا|انس|رے |لیم|علی|تعل|امل|ہ د|ے ر|د ا|کم |یہو|فائ|چ ا| کھ|م ت|را |ورا|پور|ں ب|ق د|ے ق|وکو|کھی|ا ک|و د|ے ذ|پڻی|بند| فر|کوئ|امی|ی ی|ائی|لاق|ایں|ہ ا| نظ|سما|ومی|ی، |ے س|ت و|ھین|ے ع|یم |سہو| سہ',
    'pbu': ' د | او|او |په | په|ي۔ | حق|چې | چې|ره |ي ا|ې د| هر|نه |هر |حق | څو|وک |څوک|و ا|ه د|ه ا|۔ ه|ه و| شي| لر|ي چ|و د|ري |لري|ق ل| کښ|وي |ښې |کښې|ه ک|غه |لو |ر څ|سره| سر|ه پ| ټو|و پ|له |يت |ټول|يا |کړي| کو|خه |ي، |دي | له| از|د م| هي| وا| يا| څخ|ازا|د ا|ولو|ه ت|څخه| کړ|ول |هغه|ه ش|ي د| هغ|کول|زاد|نو | وي|و ي|ه ب|شي۔|دې |يو | دي|ته |خپل| پر|اد |د د|ک ح| تو|ه م|ګه |ه ه|قوق|حقو|و م|ه ح|د ه| تر| مس|شي | نه|ړي۔|ني |د پ|واد|ې پ|ادي|ولن| يو|د ت|ونو|وګه|ي و|لي | دا|يد | با|تون| خپ|ي پ|توګ|ار |اند|يوا|ې و|دان| بر|ړي | عم|انه| ده|يڅ |هيڅ|امي|لني|بعي|ډول| ډو|ه ل|ايد|باي|اتو|ه ګ| تا|پل | مل|ايت|وم |ون | لا|هيو| شو| دغ|م د|ده |ې ا|ان | ته|کار|تو |مي |اره|اوي|ساو|مسا|نون|دهغ|و ت|ي ش|انو| مح|ين |اخل| ګټ|شوي|دغه|و ح|وي،|نيز|سي |اسي|وند|قو |وقو|و ک|ونه|ومي| وک|ي ت| ان|قان|ندې|و ر|ک د|ه ي|مين|پر |ټه |لام|غو |هغو|د ټ|و ه|ل ت|لے |ولے|وون|کي |رو |ن ک|موم|وکړ|پار|ن ش|من | نو| وړ| قا|ې چ| وس|څ څ|شخص| شخ|ژون| ژو|تر |ګټه|و څ|هم |عقي|رته| ور|بل | بل|و ب|ه س|ښوو| ښو| کا|ې ک|و س|اده|ونک| غو|دو |و ن|ت ک|مل |عمو|ل ه| پي|وسي|ړان|وړا|يز |خصي|ي م|ا ب|ادا|ه ن|خلي|واخ|ديو|، د|د ق| هم|ا د| بي|تبع| تب|ه چ| عق|پلو|و ل| را|د ب|راي| دخ|نې |نکي|ت د|ابع| مق|د خ|وره|شرا| شر|ر م|رسر|تام|ه ټ| من|طه |سطه|اسط|واس|لې | اس|۔ د|برخ|ې ن',
    'uig': ' ئا| ھە|ە ئ|ىنى| بو|ىلى| ئى|بول| ۋە|ۋە |ىن |نىڭ|قۇق|وقۇ|ھوق| ھو|شقا|قىل|ىڭ |نى |قا |لىش|ن ب|ەن |ئاد|ھەم|لىك|دەم| قى|ادە| ئە|كى |ندا|دىن|قان|ى ئ|گە |ەم |ىش |ىي |ۇق | بى|غان|ىغا|اند|تىن|ىگە|ولۇ|ەت |ھەر|ىشى|كىن|ىدى|اق |ىتى|لۇق|ەرق|ىكى|مە |لەت| يا|لۇش|لىق|ممە|ەمم| ئۆ|داق|رقا| تە| قا| با|ىشق|اكى|غا |ۇقل|ا ھ|ياك|مەن|رىم| بە|ا ئ|دە |ئەر|قلۇ|دۇ |دۆل| دۆ|ىلە|ان |ق ھ|ركى|ەرك|ۇقى| مە|ى ب|ىمە|ەھر|نلى|ىق |ن ئ|ارا|ئۆز|ى ۋ|ۆلە|ھرى|ار |لار| ئې|بەھ|لەن|لغا|ش ھ|ىلا|ۇشق|شى |نىش|ق ئ|ئار|لىن|بىل| ئۇ|ا ب|ايد|ماي|كە |ولم|يدۇ|ئىي| كې|اسى| مۇ|ە ق|ەر |، ئ|ىنل|يەت|ىك |لما| ئو|م ئ|ېلى|مائ|ە ب|ئىگ|تنى|ا، |ش ئ|ۇ ھ|شكە|الى|ڭ ئ|ارى|ەك | قو|سىي|رلى|ى ك|بىر|ەمد|ە ھ|لەر|ۆزى|ئال|ىيە|منى|ەتت|ائى|شلى|مدە| تۇ|بار|ەشك|ەتل|لىد|كىل|ئىش|قىغ|چە |ۇشى|ىما|اشق| جى|رەك|ېرە|كېر|ر ئ|ر ب|راۋ|ن، |اۋا| ما|ايى|ادى|تۇر|نۇن|انۇ|ېتى|تىش|ىشل|دا |ىدا|ۇرۇ|قى | جە|باش|جىن|ى، | سا| خى|ېرى|ناي|ىنا|ى ھ|زىن|ە ت|ى ق|ەمن| بۇ|رنى|ن ق|تتى|تى |ىقى|ى ي|ك ھ|ىرى|ائا|ي ئ|تەش|شىش|لەش|دىل|تىد|دا،|ساس|اسا|ە م|سىت|پ ق|ئېل|نىي|ن ۋ|سىز|ىسى|ىل |اش |ي، |مىن|ۇنى|ىپ |تىم|ەلى|رىش|ىيا|ۇش |مۇش| خا|ىر |مەت| تا| پا|تلە|الغ|لىم|پال|اپا|كاپ| كا|انل|ڭ ھ|ۇند| تو|قتى|الە|ن ھ|ە د|جتى|ىجت|ئىج|رقى|ىيى|ارل|امى| ھۆ| بې|ەتن|اتن|ىكا|ي م|اتى|شكى|سى | ئۈ|ە، |ت ئ|گەن| دە|ق ق|ولغ|ق ب',
    'prs': ' و | حق|رد | با|ند |دار| دا| در|هر |که | هر|در | که|د ه| به|حق |ر ک| از|از |یت |به |کس |ود | کس|یا |ارد| یا| بر|د و|ق د|د ک| را|ار |ای | خو| اس|ه ب|باش|ید |آزا| آز|را |ین |ان |ه د|زاد|اشد|ی و|ه ا|اید|س ح|ده |د ب|ی ب|است|خود| آن|شد |ور | هم|تما|ی ا|ات |ر ا|ادی|نه |ری |رای|و ا|و م| نم|ی ک| مو| اج|د، |مای|ون |برا|قوق|حقو| شو| ان|انه| مس|ه م|ر ب|وق |ایت|آن |های|ر م|هیچ| هی| تا|ه و|ورد|شود|انو|ست | بی|ام |وان|یگر|با | مر|ن ا|ی د|دی |ی م|د آ|ر ش|ماع|جتم|اجت|ی ی|سی | کن|دیگ|بای|ت و|عی |کند|ت م|ت ا| من|مور| عم|و د|ر خ|اه |لی |ا ب|بر |نی | شد|ی، |اعی| دی|توا|ت ب|دان|کار|د ا|ن و| شر|می | کا|و آ| حم|ساو|مسا|نون| او| زن|د ش| مح|ن ب|ه ش|شور|کشو| کش|اری|مل |بعی|مند|یی | مل|ی ر|و ب|د م|وی |قان| قا| مق|او |انی|گی |این| ای|مین|ادا| آم|خوا|گرد| گر|ه ح|، ا|ز ح|میت|رند|ا ه|یل |اده|نما|ق م|ت ک|ران|ن ح|د د|حما|ارن|اوی|انت|شد،|چکس|یچک|دگی|ومی|ملل|هد |واه|‌من|ه‌م|ره‌|هره|بهر|، ب|یه | اع|دیه|ق و|عیت|هٔ |ا ر| عق|همه|ابر|راب| می|ا م|زش |وزش|موز|آمو|ا د|دوا|تی |جام|موم|عمو| مت| وس| فر|ق ا|ر ت|مقا|یک |نوا|رار|نمی|زند|شخص| شخ|ایی|ت، |و ه|اسی|یده|عقی|اً | بد|یتو|مه | تم|رش |طور|ازد|ی ح|ابع|ی ت|خاب|تخا|نتخ|رور|و ر|شرا| خا|اب |ٔمی|أم|تأ|‌ها|یرد|و ی|امل|له |اسا|ردا|خور|ا ا|سان|قرا| مج|ی ن|ا ن|کسی|خصی| ام|ندگ|دود',
    'pnb': ' ۔ |تے | تے|دا |وں |دے |دی |اے | اے| او|۔ ۔|ے ا| دا|اں |اوہ| حق|ئی |نوں|ے ۔| دی| دے|حق |شخص| شخ| جا| نو| ای|سے | کس|یا | وچ|خص |ہر |وچ |ل ا|ی ا|کسے| ہر|وہد|ے ن|صل |اصل| حا|حاص|ے م|ے و|یاں| کر|ال | تو|ا ا|ن د| یا|ادی|ر ش|ا ح|ص ن|توں| نا|ق ح| نہ|یں | وی|ا ج|نال|ی ت| کو|وی |وئی|ہدے|ں ا|ں د|۔ ہ|کرن|ایس|تی |کوئ|ئے |ں ت|ان |اپن| اپ|ے ج|وہن|ن ت| ہو|زاد|آزا| آز|ے ک|سکد|ے ب|ون | مع|ی د| ان|ے ت| مل|ی ش|ا ک|ا س|ے د|رن |ایہ|ں ک|ی ح|یس |۔ ا| سک|ام |تا |ہ ت|ملک|ی ک|ہیں|نہی| دو|نے |ت د|ں ب|م د|ہہ |یہہ|نہ |نی |ائے|کیت| کی|یت |معا|ے گ| شا|ت ت|پئی| پئ|ے پ|ی ج|ل ک|جائ|ی ن|لک |ا م|جے |ں ن| قا|جا |کدا|۔ ک|ار |یتا|ناں| من|پنے|ی م|ر د|انو|ی و|می |ق ا|ور |وہ | نی|سان|مل |امل|لے |ی ہ| با|ہدی|جان|یر |جیا|ین | تع| مر|ری |قوم| قو|ن، |دیا|ائی| اک|ہنا| رک|ہون|رے |علی|ہنو|لئی| لئ|ُتے|اُت| اُ|م ک|یم |لیم|ہ ح|ہ ا| بچ|ے ذ|غیر|ات |تعل|ی، |اشر|عاش|ے، |ر و|جھی|ہی | بھ|دوج|رکھ|ھان|نیں|ے ل|ے ع|وق |قوق|حقو|کم | کم|ریع|ذری| ذر|ہن |ں و|ر ک|نون| لو|پنی|کے |وام|ے س|اند|ومی|ذہب|مذہ| مذ|ھیڑ|اری|لوک|ک د| بر|نسا|انس| سا|وقت|شام|رتی|شاد|دہ |فائ|ے ہ|چ ا|ی ع|ر ا|ت ن|ر ت|قان|ی ق|ص د| ہی|ہ ہ|کدی|ا ۔|ا و|ھیا|ں ح| کے|گا | گا|ل د|ن ا| عو|امی|، ا|میت|، م|ا ت| بی| جھ|وک | سل|الا|بھا| وا| سم|ں ۔| پی|بر |ابر|راب|برا|ے ح|عے |یعے|منا|أ | را'
  },
  'Devanagari': {
    'hin': 'के |प्र| प्| का| के| । |और | और|का | को|कार|ार |ति |या |को |ने |ों |िका|्रत| है| कि|ं क|है |धिक|व्य|अधि| अध|्ति| सम|्यक|ि क|क्त|ा अ|की |ा क| व्|ें | हो|यक्|सी |से |े क| या| की|में|न्त| मे|त्य|ै ।|ता |रत्|क्ष|ेक |येक|्ये|िक |र ह|भी |किस| जा| स्|क व|ा ज|िसी|मान| वि|र स|त्र|ी स|। प| कर|्रा|गा |ित | अप| पर|स्व|ी क| से|ा स|्य | अन|्त्|िया|ा ह| सा|ना |्त |प्त|समा|ान |र क|ाप्|तन्| भी| उस|राप|वतन|्वत|रों|वार|े स|था |हो |े अ|ा ।|न क| न |देश| रा|षा |अन्|त ह|्षा|्वा|जाए|ी प|करन|ा प|अपन|ष्ट| सं|े व|होग|िवा|ट्र|्ट्|ाष्|राष|सके| मा|ओं |ाओं|री |क स|े प| नि|ीय |रक्|ो स|ाएग|रने| इस|व क|पर |रता|र अ| सभ|तथा| तथ| ऐस|रा |पने|्री|िक्|किय|ा व|माज|ं औ|र उ|द्ध|सभी|श्य| जि|ाने|ार्|ारा|द्व| द्|एगा|सम्|ेश |िए |ाव |र प| दे|्तर|ा औ|ारो|यों|परा|पूर|चित|्ध |रूप| रू| सु| लि|त क|ो प|ं स|े ल|शिक| शि|वाह|े औ|जो |राध|जिस|ूर्|ी भ|ूप |ोगा|स्थ|रीय|तिक|्र |। इ|इस | उन|ले |े म|लिए|म क|कता|े य| जो|न म|अपर| पू|ो क|ा उ|ाह |नून|ानू|गी |दी |ारी|ं म|। क|तर्|ी र|श क|परि|स्त|ोई |कोई|र्य|ी अ|हित|भाव| भा|ताओ|ास |साम|विक|विव|म्म| सक|कर |ाना|ध क|निक|य क|उसक|कृत| क़ा|न स|जीव|्या|रका|्रक|ाज |न्य|्म |र्ण|क़ ह|हक़ | हक़|ी म|जिक|ाजि|ामा|क औ|मिल|ेने|लेन| ले|ये |ो अ|े ज|रिव|मय |समय|वश्|आवश| आव|ऐसी|ाध |र द|र्व|सार|प स|बन्| सह|िधा|विध|ी न|ून |क़ान',
    'mar': '्या|या |त्य|याच|चा |ण्य|ाचा| व |कार|प्र| प्|िका|धिक|ार | अध|अधि|च्य|आहे| आह|ा अ|हे |ा क|ास |वा |्ये|्रत| स्|ता |ा स| अस| कर|स्व| का|ल्य|रत्|ाहि|कोण| को|िक |येक|्वा|ा व| त्|र आ|्य |त्र|ेका|क्ष|ा न| सं|ामा|ाच्|ंवा|िंव|किं| कि|ात |ष्ट|कास| या|यां|ांच|र्य|मिळ| मि| सा|व्य|ोणत|ने |े प|काम| सम|ंत्|ये | रा|समा|तंत|करण|ा आ|े क|हि |े स|ना |िळण|ून |ा प|ट्र|्ट्|ाष्|राष|ीय |व स|क्त|मान|र्व| आप|ळण्|्र्|ातं|वात|चे | वि|्षण|रण्| दे| व्|आपल|ही |ार्|नये| नय|मा |यास| जा|लेल| नि|े अ| पा|ा म|ले |ाही|बंध|े व|्यक| मा|शिक| शि|देश|ा द|माज|्री|ली |ान |ांन|पल्| हो|ा ह|षण |जे |िजे|हिज|पाह|ारा|यात|सर्| सर|रां|असल|ंबं|संब|िक्|ी प|ंच्|रक्|णत्| आण|ला |स्थ|रीय|ीत |ंना|त व|्व |क व|णे |ाचे|न क|त क|रता|्रा|याह|्त |ची |य क|द्ध|्वत|यक्|णि |आणि|स स|ंधा|क स|च्छ|य अ|त स|ीने|ोणा|करत|त्व|ील |ी अ|सार|र व|भाव|व त|थवा|अथव| अथ|े त|े ज|याय|ंचा|ेल्|ाने|ेण्|क आ|क्क|हक्| हक|ण म|ंरक|संर|न्य|ायद|ा त|त आ| उप|वस्|िवा|ेशा|साम|े य|े आ|ी व|व म|तीन|व आ|ध्य| अश|धात|कृत|्क |द्य|ित |सले|ेश |तो |ेल |ती |्ती|असे|इतर| इत|स्त|र्ण|ा ब|ेले| के|हीर|जाह|ा ज|ेत |ूर्|पूर|ेच | वा|ाजा|ी स|शा |य व| न्|याव|द्द|्ध |रून|यद्|काय|ा श|गण्|क क|राध| शा|यत्|ल अ|्यव|ी क|ाव |ा य|त्त|जिक|ाजि|रणा| धर|ा ध|भेद| बा|रका|्रक|केल|ि व|िष्|तील|योग|साध|ांत|विव|श्र| धे| मु|वतः',
    'mai': 'ाक |प्र|कार| प्|ार |िका|्यक|धिक|क अ|्रत|्ति|व्य| अध|ेँ |अधि|िक | व्|आʼ | आʼ|क्त|यक्|तिक|केँ|क व|बाक|क स|छैक| छै|त्य|मे |ेक | सम|क्ष|हि |रत्|र छ|येक|्ये|न्त|वा |िके|क। |ैक।|। प| अप| स्| वि| जा|ित |सँ | हो|कोन| को|त्र|स्व| वा|क आ|ष्ट| कर|अपन|मान| का| अन|ति |्त्|नो |नहि| पर|ट्र|्य | एह|ि क|्ट्|ाष्|राष| रा|समा|ोनो|ल ज| नह|ताक|ार्|पन |तन्|वतन|्वत|्षा| कए| सा|्री| नि|ा आ|िवा| सं| दे|जाए|ीय |करब|था |एबा|ा प|ना |्वा|देश|त। |रक |क ह|ँ अ| सभ| आ |त क|चित|्त |वार|ता |ारक|माज|ा स|रीय|न्य|रता|ान |्रा|्या|रक्|ारण|परि|एल |कएल|अन्|रबा|क प|ओर |आओर| आओ|अछि| अछ|िर्|ान्|नक |होए|कर |धार|स्थ|ा अ|िमे|र आ|एहि| एक|े स|तथा| तथ| मा|िक्|शिक| शि|प्त|र्व|निर|च्छ|र्य|ँ स|क क|हो |ाहि|एत।|र प|ामा|साम|षा |ʼ स|ँ ए|ैक |द्ध|र अ|क ज|स्त|ाप्|ँ क| सक|यक |कान|हन |एहन|ेल |ोएत|त आ|ा व|। क|्तर|ाएत|्रक|हु |क उ|पूर|विव|ʼ अ|छि | ले|न प|ास |राप|धक |पएब| पए|रा |यता|रूप|न व| के|षाक|य प|त ह|जाह| ओ |भाव|पर |थवा|अथव| अथ|सम्|जिक|ाजि|ूर्|रति| दो|सभक|। स| जन|सभ |बाध|अनु|िसँ| सह|ँ व|ए स|रिव|तु |ेतु|हेत| हे|ाध |ेबा|न स|िष्|राध| अव|ित्|वास|चार| उच|ारा|न क|वक |ा क|नून|ानू|एत |री |ेओ |केओ|रण |्रस|ि द|ओ व| भे|नहु|ोनह|्थि|पत्|म्प|राज| भा|हिम| हक|ामे|्ण |र्ण|हार|ि स|क द|न अ|त अ|लेब| अभ|िश्|जक |ाजक|न आ|वाह|काज|श्य|वस्|ओहि| ओह|योग|। ए|कए |े ओ|अपर',
    'bho': ' के|के |े क|ार |कार|िका|धिक|अधि| अध|ओर |आओर| आओ|े अ|े स|ा क| सं|िक |र ह|ा स| हो|र स|ें |में| मे| कर| से|नो |क्ष|से | का|। स|खे |ा। |रा | सम| सब|्रा| सक|र क|न क|वे |ौनो|कौन| कौ|चाह| चा| बा|प्र| प्|था |ि क|ति | जा| सा|े आ|पन |करे|ता |होख|त क|े। |े ब|तथा| तथ| आप|केल|सके| स्|रे |सबह|कर |आपन|े ओ|जा | पर|ष्ट| रा|ना |हवे| हव|ला |ेला|बहि| ओक|ोखे|र ब|ह। | ह।|न स|ाष्|राष|्त | और|े च|। क|संग|र आ|ट्र|्ट्|षा |मान|ा आ|ं क|ा प|्षा|रक्|हे |ाहे|ाति|ावे| जे|ही |ओकर|मिल|ित |ो स|ल ज|इखे|नइख| नइ|त्र|माज| बि|वे।|े ज|क स|िं |हिं|करा|और |े म|समा|हु | ओ |पर |े न|स्थ|रीय|्री|ला।|ाज |ान |कान|े त|िर |तिर|खात| खा|े उ|नून|ानू|ाम | सु| दे|ी क| मा|र म|प्त|िया|ाही|बा।|योग|ी स|ल ह|ून |व्य|ु क|ए क|े व|ंत्|स्व|केह|ीय |खल |साम|यता|तिक|े ह|ाप्|राप|र प|र अ| लो| सह|जे |ोग |म क|ले | नि|ेकर|ा ह|पूर|र न|ेहु|्य |या | या|देश|दी |ा म|ाव | दो|े द| पा|हि |िक्|शिक| शि|बा |िल | उप|्रत| वि| ही| ले|रो |े ख|ठन |गठन|ंगठ| मि|षण |्षण|ंरक|संर| आद| एक|ने | अप|तंत|वतं|्वत|्तर|्या|ेश |ादी|्ति|जिक|ाजि|क आ|्म |चार| उच| शा|री |ाह |याह|बिय|चित|क्त|पयो|उपय|रता|र व|न म|लोग|ह क|न प|काम| पू| इ |आदि|ईल | कई| व्|मी |ुरक|सुर| जी|धार|य स|तर्|भे |सभे| सभ|भाव|्थि|ामा|सर |र्म| को| बे|ोसर|दोस|ण क|ास |े प|जाद|आजा| आज|उचि|ग क|ारी| जर|गे |ज क|ी ब|सन |हो |ा त',
    'npi': 'को |ने | र |ार |क्त|कार|प्र| प्|्यक|व्य| गर|िका| व्|्रत|धिक|्ति|यक्|अधि| अध|ाई |मा |लाई|त्य|िक | । | सम|वा | वा|क व|्ने|र्न|गर्|न्त|छ ।|तिल|रत्|त्र|ेक |येक|्ये|िला|र स|ो स| स्|मान|क्ष| वि|हुन|ा स| हु| छ |र छ|्त्|समा|स्व|। प| सं|नेछ|ुने|हरु|तन्|वतन|े अ|िने|ो अ|्वत| का|े छ|गरि| रा|्र |ति |ाको| कु|ष्ट|ना |स्त|क स|ुनै|कुन|ट्र|ले | नि|ान |छैन| छै|्ट्|ाष्|राष|तिक|छ। |ार्|ता |ित |नै |ा अ| सा|ा व|रु | मा| अन|ा र|रता|र र|हरू|ेछ |ा प|रक्|्त | पर|था | ला|परि|देश|सको| यस|माज|ामा|्रा|िवा|ाहर|ो प|्य |वार|न स|। क|नि |्षा| त्|द्ध|र ह|तथा| तथ|यस्|्यस|री |र व|पनि|रिन|ंरक|संर|भाव|ै व|सबै| सब| शि| सह|ताक|े र|त र|लाग| सु|्षण|द्द| अप|ैन |ो व|िक्|ाव |धार|्या|्रि|ा भ|एको|र म|न अ|ो ल| उस|शिक|ात्|स्थ|वाह|ूर्|श्य|ित्|रको|ारक|ुद्|तो |्तो|ाउन|कान|िएक|ा न| पन|न। |ैन।|का |ेछ।| भे|र्य|सम्|त्प|साम|रिय|चार|निज|ुन |गि |ागि|उसक| मत| अभ|पूर|र त| सक|सार|राध|परा|अपर|ुक्|जको| उप|रा |ारा|्वा|विध|्न |ा त|न ग|णको| पा| दि|क र|र प|अन्|भेद|ारम|ो आ| अर|जिक|ाजि|िय |षा |ाट |बाट| बा|ि र| छ।|त्व|त स|रू |छ र|रका|विक|र उ|ोग |्दे|रिव|सकि|ै प|रति|अनु| आव|युक|ा ग|नमा|योग|ग ग|क अ|द्व|्ध |रुद| बि|। स|उने|ान्|ा म|िको|र्द|ारी|्तर|ो ह|हित| दे|रिक|ा क| आध|राज|र्म|्ण |र्ण|ि व|्यव|विच|बै |सहि|रोज|र्स|ई उ|्प |रात|निक|मिक|च्छ|्था|विव|कता|अभि|्धा',
    'mag': ' के|के |ार | हई|कार|ई। |हई।|िका|े अ|धिक|अधि| अध|र ह|े क|और | और|ा क|े स|सब | सब| कर|ें |था |में| मे|तथा| तथ|िक | हो| सम|क्ष|ना |ब क|र स| सं|ा स|कर | भी|। स| सा| से| का| अप|्रा|प्र| प्|से |भी | को|त क| पर|रा |क ह|पन |अपन| सक|या |ति |र क|ी क| या|करे| जा|रे | ओक|्त |सक |नो |ान |मान|ओकर|ा प|न क|ेल | ना|। क|रक्| स्|ही |होए| एक|पर |दी |ट्र|ता |व्य|हई | शा|े उ| दे|त्र|ादी| रा| ही|कान|ित |म क|ल ज|ाम |ी स|े भ|न स|माज|ष्ट|षा | ले|क स|बे |वे |ावे|मिल|र म|्य |ा ह|ला |प्त|नून|ानू|जा |ेकर|्षा|्रत|ंत्|र औ|ोई |कोई|्ट्|ाष्|राष| मा|रो | जे|करा|ोए |ाप्|राप|समा|ून |ो स|स्व|्ति|साम|ोनो|कोन| व्|र अ|्म | वि| सह|े म|क्त|योग|र व|काम|ल ह| नि|देश|पूर|वार| इ |ंरक|संर|ए क|र प| सु|तंत|वतं|्वत|ा म|व क|े व|ाथ |साथ| दो|होब| पा|ो क|े ब|ोग | उप|स्त|परि|न प|े त|्तर|लेल|े ओ|चाह| चा|य क|वा |ेश |य स|न ह|षण |ा ब|। त|एक |एल |ीय |केक|े ह|र आ|ि क|स्थ|जिक|ाजि|ामा|रीय|्री|तिक|ाति| बि|चार|े आ|ास | उच|ा त|यक्|्यक|िल |मय |समय|शाद|पयो|उपय|े ख|रिव| पू|े ल|े च|ौनो|कौन| कौ|ं क|संग|न द|ं स|ण प|्षण|र न|े न|ो भ|करो|ा औ|रता|ाव |भाव|क औ|र्म|ोसर|दोस|ण क|े प|न औ|ब ह|िक्|शिक| शि|ाबे|निय|चित|उचि|ित्|ग क|े। |त स|ी श|ं श|एकर|। ए|तन | ओ |री |्र |जे |क क| सी|सन |िवा| अन|ूरा| बच|ए। | बे|त ह| तक| मि|धार|थवा|अथव| अथ|िला|्वा|ि म| आद|ने |कएल| कए|्या',
    'san': 'प्र| प्|पि |स्य|्य |ां |्या|न्त|िका|कार|स्व| स्|धिक| सं|ं स|्रत| वि| च |क्ष|त्य|ुं |तुं|ार्|रत्|्ये| सम|र्व|्वा|ं व|्ति|ते।|्त्| जन|ष्ट|ं अ|े। |येक|स्त|र्य|ति।|ाना|ः स|मपि|ि। |त्र| वा| नि|अधि| अध|तन्|नां|वा |रं |मान|्यत|वर्|धार|ट्र|्ट्|ाष्|राष|िष्|व्य|ाः |सर्|ेकम|कमप|त्त|नः |जनः|्तु| सर|िता|वीय|ाधि|ारं| सा|र्त|ितु|ऽपि|यित| रा|ारा|ाया|ि च|ते |्ते|। प|्वी|ं प|रक्|य स|ान्|ि ज|ाणा|ष्य|ेन |संध| न |कस्|ोऽप|त्व|क्त|च स|्वे|वस्|र्थ|ं च|कृत|णां| अन|ारय|नं |यते|विध|न्य|्रि|िक |निर|ं न|या | वर|ि स|ा स| का|यति|म् |वात|िर्|। अ|यां|िवा|्यक|थं |्थं|ित्|संर|न क|माज|साम|यं |ातन|चित|तान|्षण|ंरक|कं |धत्|श्च|ामा|ति |याण|्र्|रस्|समा| अप|षु |वित|भवि|तित|ं ध|ऽस्|र्ह|रति|ंधत|्षा|। स|क स|िक्| व्|े स| एत|अपि|समु|्रा|्वस|शिक| शि|संघ|ेषु|ा। | भव|्रम|रयत|ोऽस|राण|पूर|ेण |राध|ास्|्रस|्च |जिक|ाजि|रिय|तिक|र्ण|ैव | पर| सह|विव|परि|यता|च प|ानि|यक्|ता।|ीय |े प|य च|च्छ|योग|ृते| कृ|य क|च व|ात्|ध्य|विर|द्ध|ूर्|्ञा|ज्ञ| धा|न व|परा|कोऽ| को|देश|यस्|् स|याः|ताय|्ता| कस|ः प|्तर|षा |नैव|ि व|षणा|्तन|ं ज|ेकं|िश्|न् |अन्|नि |रिव|त् |श्य|तं |ं क|ने |प्त|ाप्|ुल्|्रव|स्थ| पू|याप|। न|न स|जीव|ारे|य प|ा व|य व|नस्|नान|ि प|रिक|्वो|गन्|र्म|विन| अभ| अस|्यव|ा अ| मा|मिक|्यम| वै|वाह|ष्ठ|वेत|विक|तोऽ|ानं|िके|वार|्मि|दान|िकस|सार|्धा|दाय|याध|ापि'
  },
  'Myanmar': {
    'mya': 'င့်|င်း|ိုင|ုင်|သည်|့် |ွင့|ခွင|ကို|ည်း|ောင|သော|ာင်|ြစ်|တို|နို|်းက|ို |င် | အခ|ြင်|ဖြစ|လည်| လူ|် အ|ရှိ|ျား|မျာ|်ခွ|်။ |ည်။|ကော|းကေ|နှင|ှင့|ို့|ရေး|်း |င်ခ|း၊ |် လ|ော |ခြင|ွင်|မှု|်စေ|တွင|်း၊|ှိသ|ောက|ိသည|းကိ|ည့်|ော်|ာက်|တ်လ|စ်စ|လပ်|ွတ်|လွတ| မိ|လူတ|်လပ|ူတိ|်လည|်းမ| ဖြ|စွာ| လွ|င်ရ|ွာ |ုပ်|်၊ |့် |ထို|်သေ|းတွ|။ လ|ြား|အရေ|့်အ|အခွ|ိမိ|ွက်|ာ်လ|ေ၊ |ား |မည်| သေ|က် |ိုး|်ရှ|ည် |မိမ|်စွ|စေ၊|့်ရ| ထိ|်အရ|ြင့|န် |းနှ|်းတ|မ်း|ဖြင|် မ|အား|်သည| ပြ|န်း|အခြ|်ငံ|င်င|ပို|ာ အ|်မှ|ပ်စ|ရန်| နိ|ဆို|းမျ|ားက| ရှ|စေရ|ွယ်|းသည|လုပ|် ပ|တစ်|၊ အ|း အ|် ဖ|ုံး|ခြာ|ဝင်|ရမည|် ရ|ြည်|ုတ်|သို|းခြ|းဖြ|းမှ|အပြ|်ခြ|စား| လည|်းသ|်နိ|အတွ|ပြု|ပြည|်းပ|ခံစ| ခံ|း မ|ေးမ|ပြင|င်သ|ဟုတ|မဟု|ပ်ခ|့ အ|ားသ|ကြေ|တ် |က်မ|တွက|ားန|ပဒေ|ဥပဒ|ု အ|သား|် သ|်းခ|၊ မ|ပညာ|ိုက|မှ |မျှ|ည်သ|ြော|ရ။ |စည်|်ဖြ|တည်|ျက်|ကွယ| အာ|ေး | သိ|ားဖ| အလ|်မျ|သင်|ွဲ့|ဖွဲ|ရား|တရာ|်ကိ| ဥပ|ေးခ|ပြစ|တ်ခ|်ရန|က်သ|်ချ|ု့တ|၊ လ|ားလ|်ရွ|မိ၏|ု သ|ုက်|သက်| အက|ားရ|ခြေ|် န|်မြ|စ်မ|်းန|၊ န| ကိ|၊ သ|ျို|လူမ|းချ|်နှ|ူမျ|ူညီ|တူည| တူ|လို|ားစ| အတ|းသေ|ဆော|င်၊|ဒေအ|ပေး|ှု |ာ လ|်သူ|ှော|ိမ်|ားခ|ံစာ|် ခ|ျင်|ွေး|အလု|ါဝင|ပါဝ| နှ|ားတ|ပ် |း န|းစွ|ု လ|ေအရ| အပ|ားမ|်ရေ|ာ သ|ေးက|။ မ| လု|် ထ|်ရာ|ေရ။| အဆ|းမဟ|့တည|၊ က|ထား|် က|ိုသ|ပ်သ|် တ| ပါ|အဖွ|ရွက|အခါ|ေးရ|် စ|ခံရ|၏ အ|က်ခ|်းအ|းအဖ|အဖြ|ွန်|ျှ |ုမျ|ှင်|ုယ်|ိုယ|ာင့| တိ',
    'shn': 'င်ႈ|ၼ်း|လႆႈ|င်း|်း |ူၼ်|ုၼ်|ၼ်ႉ|ူင်|ဝ်း|ွင်|ၼၼ်|ိူင|်ႇလ|မ်ႇ|ူဝ်|်ႈလ|ၼ်ႇ|ႇလႆ|်းၵ|တႃႇ|မိူ|ဢမ်|ၵူၼ|မီး|တ်ႈ|တ်း|သုၼ|ဝ်ႈ|လွင|လႄႈ|င်ႇ|ုင်|ၼႆႉ|ၢင်|ဢၼ်|ၵေႃ|်ႈ | လွ|ႆႉ |ႈ တ|ိူဝ|မ်း|ႆႈ | တႃ|ႄႈ |ၼ် |ွတ်|်းၼ| ၵူ|ိုင|းသု|ယူႇ|်းလ|ၢၼ်|ဵၼ်|ီးသ|ၵ်း|ႅဝ်|လႅဝ|လွတ|ုၵ်| မီ|ေႃႉ| ဢၼ|ၵ်ႇ| လႄ|ဵင်|ႈ လ|ၵၼ်|်ႈၵ|ပိူ|ၵူႊ|်းပ|ွၼ်|်းတ|်ႈတ|ႃႉၼ|်ႉ |်ႈမ|။ ၵ|်းသ|ႇ။ | တေ|ၸႂ်|်းမ|ူႇ။|ၵ်ႈ|သေ |်ႇ |ႉၼႆ|ႊၵေ|ူႊၵ|းၵူ|ႉ မ|ႈလႅ|်ႈပ|်ႇၼ|ပဵၼ|တီႈ|ႈမိ|ၵၢၼ|ေဢမ|ဝ်ႇ|ိုၼ|ၶဝ်|ဵတ်|ႁဵတ|လႂ်|ုမ်|းၼၼ|ၸို|ိင်|ႂ်ႈ|ၼ်ႈ|ပ်ႉ|မ်ႈ|ိူၼ|ၢႆး|်၊ |်းၶ|ႈလွ|င် |် လ|်ႇမ|်းၸ|်းယ|ႃႈ |တင်|တေႃ|ုဝ်|ိုဝ|ၼ်လ|်ႇၵ|ပၼ်|း လ|်ႉလ|ၾိင|်ႇပ|တ်ႇ|းပိ|ႁႂ်|မၼ်|ႃႇ |ေႃႈ|ၼႃႈ|်ၼၼ|်းႁ|ႈတႃ|ထုၵ|်ႈၼ| ဢမ|်ႉတ|်ႈႁ|တၢင|တေဢ|ေႃႇ|ူၺ်|ၼ်ၵ|ၵဝ်|ႉ တ|ႇၼၼ|းမိ|ၢမ်|ၢႆႇ|း ဢ|ပၢႆ|်ႈၸ|ႈ ဢ|ႃႇၶ|ႆႈတ|ွမ်|ေလႆ|တေလ|ူမ်|်ႈဢ|ၢဝ်|ၼ်ပ|သၢင|ၼ်ၼ|်ႈယ|လိူ|ဝ် |်သေ|ၽဵင|ၼ်ဢ|ၸွမ|ပ်း|ႈလႆ|ဢဝ်|သင်|ႉယူ|်ႉယ|်ႉၵ|်းဢ| မိ|် ဢ|ထို|ၶွင|ၼ်တ|ၾၢႆ|ႁပ်|ႂ်း|ၼႂ်|်ႉႁ|ၺ်ႈ|းလႅ|းသေ|်ႇၶ|ၼင်|ႂ်ႉ|်ႇၽ|ပို|ွၵ်|ၼ်မ|်ၼႆ|ပဵင|လူၺ| ပိ|ူပ်|လုၵ|ႇ လ|ႈသင|တူဝ|ႈ ပ|ႅင်|် တ|ႁူမ|်ႇႁ|ႃႇလ|ႇၶဝ| ၾၢ|်ႇၸ|်ႇတ|းလွ|ႆႈမ|ၼ်ၽ|ႃႇၵ|တို|းသၢ|ဝ်ၼ|ႇပဵ|ူၵ်|ၵ်ႉ|ႄႈသ|ယဵၼ|ႈထု|ႆႈထ|းၵၢ|ပၵ်|ႆႈပ|ႅတ်|ႉ လ|ၽူႈ|ဝႃႈ|်ၵူ|င်ၸ|ႉ။ |းၼႆ|ႈ မ|ႈမီ|ႁၼ်|းတေ|ၼ်သ|ဝႆႉ| သု|ူတ်|ၵိူ|်ဢၼ|မ်ႉ|ၸုမ| တီ|ႃႇႁ|ႉၼၼ|ၺ်း|်ႉသ|းၵေ|်ၸိ|ဝ်ႉ|၊ လ|ၼ်ႊ|း၊ |ိၵ်| ၼႂ|ႉႁၼ|ိတ်|ႇၵၼ|်။ |ႃႇၸ|င်သ|။ ပ|သွၼ|ၵတ်|ၸဝ်|်ၸႂ|င်ပ|ႂ်၊|ႅၼ်|သေဢ|်ဢမ',
    'mnw': 'ုၚ်| အခ|ါၚ်|ေါၚ|ခေါ|အခေ|ကဵု|ိဟ်|ၞိဟ|မၞိ|ေၚ်|မွဲ|ာန်|ိုၚ|ဟွံ|ၚ် |ှ် |ရေၚ|နွံ| ကေ|ောန|ဒုၚ|ရ။ |ာံ |်မၞ|ဟ် |ဂှ်|် အ|ွံရ|ုာံ|ေုာ|ကေု|ၚ်မ|ံၚ်|ပရေ|ဒှ်|ၚ်က|ကီု|ဂွံ|ံရ။|ၚ်စ|ဍုၚ| ဟွ| ပရ|ပ်မ|ုပ်|ၚ်အ|ာပ်|ၟာပ|ဇၟာ| ဇၟ|အရာ| ဒး|္ဍဲ|ပ္ဍ|ၚ်သ|်၊ |။ ဇ|ာၚ်|ကော|ံ အ|် န|ဝ် |ၚ်တ|တုဲ|ၚ်ပ|ဇကု|ုဲ |ောၚ|ဵု |် က|ၠော|ွဲမ|ၚ်ဒ|ောံ|ုဒှ|်မွ|် သ|ီုဒ|် ပ|်ဂှ|သၠး|ွံ |ရော|်အရ|ပွး|ုက်|် ဒ|်ကဵ|ုဟ်|းပွ|ၠးပ|်။ |ၚ်။|်ကီ| ပ္|လဝ်|ၚ်ဂ|်ဒု|ုတ်|တံ |်တံ|န်တ|ၞော|သို|စသိ|်စသ|န် |ှ်ေ| နွ|တ် |ဝွံ|သၞေ|ဗွဲ|သ္ပ|် ဟ|ဒးဒ|ပညာ|ပ်သ|းဒု|ာဝ်|ောဝ|နကဵ| နက|ံဂွ|ွံဂ|ိက်|်ဍု|ေဝ်|၊ အ|်တု|မၠေ|ကမၠ|ဵုဒ|းနွ|ု၊ |လဵု|ှ်၊|်သ္|ွံမ|ဂး |္ဂး|မ္ဂ|တုပ|ကု |ွက်|သွက|က်ပ|ဒးန|တို|ံမွ|ုန်|ာတ်| သ္|ၟဟ်|သၟဟ| သွ|နူက|ဵုပ|်သၟ|န်က|အလဵ|န်ဍ|်ကေ| မၞ|်ဇက|ၚ်ဇ|လုပ|ံရေ|ၚ်လ|ွံဒ|ိုက|စဵု|ုမွ|ဵုမ|ဂဵု|ူဂဵ|ပူဂ|ီု |်သၞ| ဗွ|ဵုအ|ကၟိ|ိၚ်|ဟ်တ|်သၠ| နူ|ဂကေ|ၠုၚ|ူကဵ|ၚ်န|တန်|်ပတ|ိုန|်ဂွ|ံ ပ|န်သ|ီု၊|ိန်|ၟိန|ု က|ဇို| ညး|်ခြ|ရာ |တအ်|ၠို|ံကီ|ွး |ဲအရ|ကၠေ|ွဲက|မံၚ|ဲမွ|ဟ်မ|ဆံၚ|်မ္|ွံသ|၊ ပ|က်က|ိုဟ|ပါ်|ဓရ်|ိုတ|်ပည|ပို|်အာ|် ဗ|ံ ဒ|န်ဂ|က်ဂ|်ဟွ|ဍဲအ|ပဒေ|ဥပဒ|ၚ်ရ|အာ |ဒၞာ|ုဒၞ|မၚ်|သဇိ|ံက်|သာ်|် ဂ|ကဆံ|သေၚ|ံသေ|ဲ က|ံ သ|မၠိ|ဂမၠ|။ ပ|ါလု|ပါလ|သီု| သီ|ခိၚ|အခိ|။ အ|က်မ|်နွ|အပ္|် မ|ာံမ| ဂွ|်တဴ|်ဂၠ|ု ဒ|ဵုဇ|ဝ်က|ွဲလ|လေဝ| အတ|ာ် |ဲသာ|ခြာ|ံ က|်ကွ|သှ်|က် |ွဲ |ံတု|ွံတ|်ပါ|်တအ|ာ က|်ကၠ|တ်ပ|ံဂှ|တံဂ|္ၚိ|သ္ၚ|ပ်တ| အပ|ု အ|်မံ|ဗုတ|ဂဗု|ဒုဟ|ျို'
  },
  'Ethiopic': {
    'amh': '፡መብ|ሰው፡|ት፡አ|ብት፡|፡ሰው|መብት|፡አለ|ይም፡|ወይም|፡ወይ|ነት፡|ለው።|አለው|ንዱ፡|ዳንዱ|ንዳን|ያንዳ|እያን|ዱ፡ሰ|፡እን|ት፡መ|ው። | እያ|፡የመ|። እ|እንዲ|፡ነጻ|፡የተ|ም፡በ|ው፡የ|ም፡የ|፡የሚ|ን፡የ|ና፡በ|ና፡የ|፡አይ|፡የማ|ነጻነ|ው፡በ|ሆነ፡|ቶች፡|ት፡የ|ው።፡|፡በሚ|ትና፡|ኀብረ|፡መን|ትን፡|ውም፡|ብቻ፡|፡ለመ|ም፡ሰ|ም። |ኛውም|ንኛው|ማንኛ|ንም፡|፡አገ|መብቶ|፡ያለ|እኩል|ረት፡|መንግ|፡ለማ|ት፡በ|ሆን፡|በት፡|፡በተ|ለት፡|፡እኩ|ጋብቻ|ዎች፡|ወንጀ|ህንነ|ደህን|ኩል፡|ማንም| ማን|። ማ|ጠበቅ|ጻነት|ብቶች|፡ልዩ|ራዊ፡|ሰብ፡|ም፡እ|ግኘት|ማግኘ|ች፡በ|ሥራ፡|ነጻ፡|ርድ፡|ፍርድ|፡በሆ|፡ድር|ል፡መ|፡ደህ|ተግባ|፡የሆ|ት፡ወ|በትም|ፈጸም|ር፡ወ|ይነት|ትም፡|፡በመ|፡ሁሉ|ቸው፡|ኘት፡|ማኀበ|የማግ|በር፡|ም፡መ|በኀብ|፡በኀ|ችና፡|፡ኑሮ|፡ሥራ|፡ጊዜ|፡ወን|መሠረ|፡መሠ|ቱን፡|ሕግ፡|ባር፡|ግባር|ነትና|ነቶች|ጻነቶ|ንና፡|ዩነት|ልዩነ|ደረጃ|፡ደረ|ብ፡የ|ዓይነ|፡ዓይ|ይማኖ|ሃይማ|ል። |ነው።|፡ነው|ሁሉ፡|ርት፡|ህርት|ምህር|ትምህ|ንነት|ና፡ለ|በት።|ለበት|አለበ|መሆን|ን፡አ|ን፡ወ|፡መሰ|ብረ፡|፡ብቻ|፡አላ|ርጅት|ድርጅ|ንግሥ|ተባበ|ሎች፡|ሌሎች|የሚያ|ቤተሰ|እንደ|ት፡ድ|፡መሆ|ች፡የ|ትክክ|፡ማን|በሆነ|ሆኑ፡|ን፡መ|።፡ |ት፡ለ|ረግ፡|፡ይህ|ዲጠበ|ንዲጠ|ት፡እ|ነቱ፡|፡በሕ|የሆነ|ጸም፡|በቅ፡|የመኖ|ትም።|ገር፡|፡ከሚ|ው፡ከ|ሩት፡|የኀብ|፡የኀ|ሔራዊ|ብሔራ|፡አስ|ር፡የ|ይገባ|ውን፡|ጥ፡የ|ንስ፡|፡ትም|ኑሮ፡|ን፡ለ|ች፡እ|ሁኔታ|፡ሁኔ|ስት፡|፡በአ|፡ማኀ|ብረሰ|መሰረ|ረ፡ሰ|የሚፈ|ላቸው|አላቸ|መፈጸ|፡ጋብ|ር፡በ|ዜግነ|ችን፡|ጅት፡|የተባ|ነትን|ዚህ፡|ብነት|ገብነ|፡ገብ|ስጥ፡|ውስጥ|፡ውስ|ሰቡ፡|መው፡|ፈጸመ|ጊዜ፡|ት፡ጊ|ሆኖ፡|፡ሆኖ|ፈላጊ|ው፡ለ|ሙሉ፡|ክለኛ|ክክለ|ጀል፡|ንጀል|ሁም፡|ዲሁም|ንዲሁ|፡በግ|ው፡ያ|ታዊ፡|ረታዊ|ንግስ|፡ እ|ደረግ|።፡ይ|ነ፡መ|ነቱን|ንነቱ|ሉ፡በ|በሕግ|፡ተግ|ዓዊ፡|ብዓዊ|ሰብዓ|ም፡ከ|ቅ፡መ|መጠበ|፡መጠ|በነጻ|፡በነ|መኖር|ምበት|አይፈ|ም፡ዓ|፡በማ|ቢሆን|፡ቢሆ|ር፡አ|ገሩ፡|አገሩ|ናል፡|ሽናል|ናሽና|ርናሽ|ተርና|ንተር|ኢንተ|፡የአ|አገር|ንድ፡|አንድ|ህም፡|ና፡ነ|፡ውሳ|ረጃ፡|ኖት፡',
    'tir': '፡፡ | መሰ|ሰብ | ሰብ| ኦለ|ኦለዎ|ናይ | ናይ|ዎ፡፡|ለዎ፡|መሰል|ሰል |ሕድሕ|ሕድ |ድሕድ| ሕድ|ይ ም|ል ኦ| ኦብ|ድ ሰ|ትን |ውን |፡ ሕ|ካብ |ኦብ |ወይ | ወይ|ን መ|ብ ዝ| ካብ| መን| ነፃ|ነት |ብ መ|ዝኾነ|ብ ብ| እን|ኾነ | ዝኾ|ን ነ| ምር|ን፡፡|ኹን | እዚ|ርካብ|ምርካ| ኦይ|ይኹን| ይኹ|ታትን|ነፃነ|እዚ |ን ኦ|ሕጊ |ነ ይ|ታት |ት ኦ|ይ ብ|ን ም| ከም|ብ ኦ| ብሕ| ፣ |ንግስ|መንግ| ሃገ|፣ ብ|ዊ መ|ማዕሪ|ስራሕ|ን ን| ንም|ዕሪ | ንክ|ኦዊ |ን ብ|’ውን|መሰላ|ራዊ |ማሕበ|ኦት | ዝተ| ማዕ|ሎም |ርን | ስራ|ተሰብ|ዓት |ነቱ |ብኦዊ|ሰብኦ|ት ወ|ነታት|ላትን|ሕበራ|ልኦት|ካልኦ| ብዘ|ን ዝ|ም፡፡|ርቲ |ህርቲ|ምህር|ትምህ| ትም|ራሕ | ማሕ|ኸውን| ገበ|ብሕጊ|ቱ ን| ብዝ|ፃነታ|ሰላት|ዚ ድ| ኦድ|ዎም፡|ለዎም|ታዊ |እንት|ሪተሰ|ብሪተ|ሕብሪ| ሕብ|ብን |ራት |ን ሰ|ዋን |ኡ’ው|ምኡ’|ከምኡ|፣ ኦ|ርዓት|ስርዓ| ስር|ዕሊ |ን ና|ነትን|ት ና|ይ ኦ|ነፃ |ገሩ |ሃገሩ|ም መ|ንጋገ|ድንጋ| ድን|እንተ|በራዊ| ብማ|ይማኖ|ሃይማ|ኩሎም| ኩሎ|ልን |ክኸው| ክኸ|ት ስ|ን ሓ| ሃይ|ት መ|፡ እ| ካል|እን |ቤተሰ| ቤተ|እዋን| እዋ|በን |ን ዘ|ተደን|መሰሪ|ግስቲ|ን ካ|ሓለዋ| ሓለ|ብዘይ| ምዃ| ሕጊ|ን፣ |ዊ ወ|ፃነት| ዘይ|ሓደ |ን ተ|ት፣ |ናን | ምስ|ፃን |ነፃን| ክብ|፡ ት|ብማዕ|ት ብ|ታውን|ብነፃ| ብነ|ብ ና|ዜግነ| ዜግ|ስታት|ግስታ|ብ ሕ|ዊ ኦ|ብ ን|ባርን|፡ ዝ| ብሓ|ነቲ | ነቲ|ሪጋገ|ገበን|ፍትሓ|ላውን|፣ ከ|ፃኢ |ወፃኢ| ወፃ|ገ ስ|ገገ |ንገገ|ደንገ|ዝተደ|ጊ ካ|ሃገራ|ሰሪታ|ሉ መ|ስቲ |ዚ ብ|ለዋ |ዘይ |ልዕሊ| ልዕ|ድ ኦ|ክብሩ|ዊ ክ|ል እ|ት ክ| ድሕ| ምን|ህይወ|ይፍፀ|ዓለም|፣ ሕ|ብ እ| ምም|ር፣ | ሓደ|፡ ብ|ገ እ|ጋገ |ልዎ |ድልዎ|ኦድል| ብሃ| ብም|ም ብ|ት እ|ባት |ባለ |ዕባለ|ምዕባ| ምዕ| ብር|ድሕነ|ብ ሰ|ሪ ክ|ን ስ|ቱን |ቲ ብ|ዊ ው| ምጥ| መሪ|፣ ም| ምግ|ቱ ወ| ንብ|ር ን|ባር |ምስ |ጉጅለ| ጉጅ|ሕን | ፍት|ን ፍ|ሓዳር| ሓዳ|ንን |ቱ ክ|ገልግ|ተግባ| ተግ|ቡራት|ሕቡራ| ሕቡ|ድብ |ውድብ| ውድ|ዚ መ|ሕታት'
  },
  'Tibetan': {
    'bod': 'འི་|་དང|གས་|ྱི་|ོབ་|༌། |ང༌།|་ཐོ|་ཡོ|ོད་|དང༌|་བྱ|ཐོབ|ི་ཐ|་ཀྱ|་པ་|ོས་|ད་པ|ཀྱི|ང་ཡ|པའི|་པའ|ེད་|ས་ས|ུང་|ས་ཀ|ཡོད|བ་ཐ|ང་བ|བྱེ|ཐང་|རང་|་ཐང|ང་ད|ས་པ|་འད|་དབ|སྐྱ|མས་|ོན་|ས་འ|་སྐ|ྱེད|་རེ|ནས་|་དག|དབང|རྒྱ|ི་ར|་སྤ|ིག་|་འག|་རང|སྤྱ|ིན་|ེ་བ|བང་|་ལ་|ོགས|་ཡི|ང་ག|ས་ལ|་བཅ|་གི|་མི|ཡིན|ས་བ|་རྒ|བཅས|ྱེ་|གོས|ས་ད|སུ་|ོག་|གང་|ཅས་|དགོ|གི་|རིག|་རི|་གང|གྱི|་གྱ|དེ་|ོང་|ྐྱེ|ིགས|ཡང་|། ར|མི་|ལ་བ|ེས་|ང་ས|ེར་|ན་ག|་བས|་ནས|ངས་|། ས|་ཚོ|ང་འ|པ་ད|་ཞི|ེ་ར|ི་ས|ང་མ|ང་ར|་བོ|ོ་ར|ལས་|ི་ག|་གཞ|བོ་| སྐ|ེན་|་ཡང|ྱལ་|ྒྱལ|ལ་ག|མ། |ྱོད|ྤྱོ|། ད|བས་|་བ་|ིམས|ྲིམ|བ་ད|ུགས|རེ་|༎ ས|ད། |དོན|ུལ་|དང་|་བའ|ཁྲི|ཚོག|ིས་|ོད།|ི་བ|་དུ|ས་ར|ེལ་|བའི|ས་མ|་ལས|ན་ར|ན་ད|ད༎ |ོད༎|་རུ|་འབ|ལ་ཁ|་དོ|ས་ག|དུ་|འདྲ|ན་ས|་བར|ད་ད|རེར|ན་བ|དྲ་|ོངས|ི་མ|་ཁྲ|ི་ད|ཞིག|་གན|ང་ལ|ག་ག|ན་པ|ུ་ཡ|ཉམ་|མཉམ|་སྒ|་སུ|་ཆོ|ི་ཆ|ུས་|རུང|་ཁབ| དེ|ི་འ|བྱུ|ར་ར|འགྲ|ར་བ|་གཏ|་དེ|གནས|ྤྱི|ནང་|་ནང|ར་ད|ལེན|་འཛ|ུན་|་ཚུ|་མཉ|ིད་|་སྦ|ྲེལ|ང་ན|གལ་|ས་ཡ|ཆོག| སུ|ྐྱོ|་ལེ|་སྡ|འགལ|ཐོག| རང|བ་བ|ི་ཚ|ཁབ་|ག་ད|ི་ན|སྒྲ|བྱ་|་ཤེ|ག་ལ|ྱུང|ྲ་མ|་མཐ|ོ་བ|གྲོ|བ་ས|ུག་|ན་འ|ཚང་|་འཚ|དག་|་ལུ|་སྟ|ར་ག|པ་ཡ|ད་ཀ|ཤེས|ལ་ད|་རྩ|ལ་ས|ྱིས|ི་ཁ|ག་ན|ར་འ|། ཡ|ག་པ|འཚོ|་པར|པ་བ|། ག|གཞུ|པ། |་པ།|མེད|་མེ|ུ་ས|ྱང་|འདོ|ང་ཚ|་ཆེ|་སླ|ོ་ན|ན་ལ|ད་བ|་ན་|ཞི་|གཞི|པར་|། ཚ|། བ|ྐུང|སྐུ|ི་ལ|ད་འ|་བད|་མ་|ྱོང|། ལ|ེ་འ|གཞན|། མ|་བཀ|འདི|སལ་|་གས|ྟར་|ཚུལ|ོར་|། ཁ|མ་ད|ཡོང|ིའི|ྲོ་|ློབ|སློ|་ཡུ',
    'dzo': 'འི་|་དང|དང་|་ལུ|ལུ་|མི་|་དབ|བང་|དབང|གས་|་ཡོ|་ཐོ|་ར་|་མི|བ་ད|ོབ་|་འབ|པའི|་པའ|ཐོབ|ཡོད|ག་ར|་གི|ི་ད|ུང་|ི་ཐ|ྱི་|ོད་|་ཚུ|་ནི|ང་ |ལས་|ང་ད|་ལས|གི་|དེ་|ཚུ་|བད་|འབད|ང་ག|ིན་|ི་ག|ུ་ |དགོ|་དག|་ག་|ེན་|་འད|ང་འ|་རི|ོག་|རང་|རྒྱ|ི་ར|ད། |ར་ལ|ང་ཡ|ོགས|ེས་|ིའི|ས་འ|ོན་| མི|ོད།|མས་|་ ར|་སོ|ས་ས|ཨིན|་ཨི|ད་ད|ི་ས|་ཆོ|་སྐ|ག་ལ| ག་|ེལ་|ང་ས|ཀྱི|་ཀྱ|ནང་|རུང|་རུ|ང་ལ|ོང་|ཁྲི|ཆོག|་། |ང་།|ི་ |ད་པ|་ནང|བའི|་བའ|ལ་ད|ི་བ|། ག| དེ|་ ད|ང་བ|ན་ད|ིག་|་གྱ|་ཉེ|ངན་|ཡངན|ས་པ|ུགས|ན་ར|ི་མ|་ ག|་སྡ|གྱི|ངས་|ན་ |ྱལ་|ྒྱལ|་ཡང|ནི་|་གཞ|ོས་|དི་|འདི|་བས|ས་ག|གོ་|དལ་|་བ་|ོ་བ|ནིའ|མ་ག|ིམས|ྲིམ|ང་ར|བས་|་ཅི|ས་ལ|་བར|་བཟ|་མེ| རང|་སྲ|་པ་|་བཀ|རིག|ིས་|ན་ག|སྐྱ|ོའི|་རྒ|ས་མ|་ངོ|ི་ང|ཉེན|་ མ|མེད|ེད་|ས་ད|་དལ|སྡེ|སོའ|ལ་ཁ|ས་ཀ|་དེ|་སྤ|དོན|་དོ|ས་ |་འག|ཉེས|ལ་ག|་ཚོ|ན་ས|་རང|ར་ཨ|སྤྱ|་མ་|ལ་བ|ས་བ|ལཱ་|བ་མ|ོམ་|ཚོག|ད་མ|། ད|ོག | ཡང| རྒ|ེ་བ|ང་ཚ|ོ། |གོ།|ཅིག|ུ་ག|ི་ཚ|གྲོ|ངོམ|ཞི་|ོ་པ|ི་ཉ|ྲུང|སྲུ|ས་ར|ཁབ་|་ཁབ|ཡང་|ིགས|ི་འ|་སྦ|ཐོག|ྲོ་|འགྲ|་འཐ|ས་ཡ|ྡེ་|ས་ཚ|་ཆ་|་འཛ|་ཁྲ|མ་འ|ྲེལ|འབྲ|་ བ|ི་ཆ|ད་བ|་གཏ|པར་|་པར|ི་ལ|་སྟ|ི་ཁ|་གན|་གོ|། མ|དཔ་|ྐབས|སྐབ|ང་མ|ུས་|གཞི|ན་པ|བྲེ|ན་ལ|ེ་ལ|ོ་ས|་ འ|ི་ན|ཤེས| འག|ིང་|ུ་འ|ཡོག|གཡོ|་གཡ|ོར་|་ཚད|ུ་ཡ|ུལ་|ཅི་|་ལཱ|ུ་བ|ཏེ་|་ཏེ|སྦྱ|ེ་ད|མ་ཚ|་བད|ན་འ|ད་ན|ས་ན|་གྲ|ག་འ|་ ས|ེ་ཚ|སྟེ|ག་ས|ྱོང|ྤྱི|ག་པ|ངོས|ལུག|ས། |ཉམ་|མཉམ|་མཉ|དྲ་|འདྲ|བརྩ|ར་ད|་འཕ|རྐྱ|་རྐ|སྡོ|་ཕོ|ང་ན|ཏང་|ེ་ |ྟེན|ས་ཆ|་བྱ'
  },
  'Hebrew': {
    'heb': 'ות |ים |כל | כל|דם |אדם| זכ|ל א|יות| אד|ת ה|י ל|כאי|אי |זכא| של|לא | ול|ל ה|ית |של |רות|או | או|ת ו|ם ז| לא|ויו|ין |ירו|זכו|רה | לה|ת ל|ת ש|ם ל| המ|ון |ו ב| וה|ה ש| הח|ו ל|ותי|חיר|תו |יים|ת ב|נה |את |ת א| וב| במ|וך |ת כ|ה ה|על |א י|לה |ה א|יה | את|דה | על|ם ו|ם ב|ני |ו כ| שו| שה|כות|כוי| לב|בוד|בות|ם ה|בחי| בי|נות|ה ל| הא|אומ|ה ב|ה כ|ה ו|החי|לית|ירה|ת מ|ינו| לע|ן ש|ה מ|לאו|מי |פלי|וה |שוו|ן ו|חינ|ו א|ו ו| הכ|חוק|החו|י ה|ם א|דות|לו |בין|עה | אח|ליה| לפ|ן ל| חו| בנ|נוך|ופש|חופ|ור |וד |הגנ|וק | בכ|ילי| יה| הז|י ו| הי|וא |אלי|ו ה|פי |ולה|ומי|ל מ| הפ|וצי|ך ה|ן ב|ואי|רך |חות|אין|רצו|רבו|ם ש|ליל|יו |שוא| למ|ר א|ן ה| הד| בח|ווה|להג|פני|היה| לח| לו|יבו|לת |נתו| הו|מדי|לל |אחר|ה פ|יא |היא|ללא|זו | בה|רוי| אי|נו |תיה|דו |בני|ל ב|עבו|יאל|ציא|סוצ| סו|ודה| חי|שית|פשי|דרך| דר|הן | הע|חה | בש|וי |תוך|מעש|גנה|הכל|שיו|משפ| עב|יהי|לחי|גבל|שרי| שר|מנו|י ש|דינ| יו| מע|חבר|שהי| זו|זש |הכר|איש|לפי|הם |ם נ|י א|כלל|עות|נשו|ותו|יהן|גוד|יפו|א ב|ארצ| אר|כבו| בז|שה |שות|ק ב| פל|תיו|ריר|והח|סוד|יסו|ת ז|רים|עם |ל ז|אים|ום |ולא| לכ|ישי|ן א|הזכ|ם י|הגב| הג|ונו|ובי|הוא|תה |המד|ד א|ידה| לי|תי |א ל|פול| לש|הפל|א ה| לל| שנ|חרו| בת|ם כ| בע| וש|שר |ובח|השת|ידי| הר|בור|ציב| אמ|ברה|עית|ה ח|הנש| הנ|רחו|זרח|אזר|וחד|מות|ד ל',
    'ydd': ' פֿ|ער |ון |ט א|דער| אַ|ן א| או|אַר|און| אױ|ען |ן פ| אי|פֿו|רעכ| רע|עכט|ֿון|ױף |אױף|פֿא| דע|כט |אַ | זײ|זײַ| גע|אָס|ונג|ֿאַ| הא|האָ|ן ד| אָ|ַן | די|אַל|װאָ| װא|נג |אַנ|ניט|אָט|די |ײַן|ָט |אָל|יט |עדע|יעד| יע|ן ז|אָר|רײַ|ָס |מען|באַ| מע| בא|נאַ|טן |זאָ|ַ ר|אָד|ר א|ין |אין|פֿר|ן ג|ר ה|ן װ|ֿרײ|ָדע|יז | זא| צו|ע א|אַצ|איז|ַצי|ַנד|ײַנ|לעכ| פּ|ַפֿ|אַפ| ני| װע|ײט |עזע|געז|טער|ראַ|ָל |אָנ|לאַ|פֿט|מיט|רן |דיק|לן |ן נ|ט ד|בן |ַלע|קט |טיק|שאַ| מי|ענט|ר מ|טלע|אַק|נען|ף א|כער|טאָ|ערע|יע |ַנע|רונ|עכע|יק | דא|יקע|ַרב|יט־|סער|הײט|ַהײ|ײַה|לע |ן ב| זי|ן מ|פּר|גן |עם |ר ג| קײ|ָר | טא|יאָ|ציא|ישע|ע פ|־אי|ט־א|־ני|טאַ|מענ|נגע|אױס|פֿע|דאָ|ן ק|ר פ|עט |ָנא|ר־נ|ער־|ָסע|ציע|ט פ|צו |ג א|ט צ|יקט|יך |זיך|נד |קן |לײַ| גל|װער|זעל|קײט|אָב|קע |כע |יקן| צי|ײנע|ענע|ערן| נא|נדע|נטע|ר ד|ֿט |ן י|ף פ|גען|דור|ס א|ן ל|ן ה|ט װ| שו|עס |ס ז|פּע| לא|קער|אַט|יטע|רע |שע |ונט|ַרא|ל ז|גלײ|לשא|עלש|בעט| דו|עפֿ|כן |שן |ים |שטע|ן ש|נעם|קײנ|אָפ|נט |טעט|ליט| שט|ײטן|ר װ|נטש|רבע|יונ|רך |ורך|ערצ|י פ|רעס| גר|ײַכ|ראָ|ג פ|צי |ם ט|רענ|ק א|ָפּ|לער|אינ|רעל|ֿאָ|ע ר|י א|ַרע|ר ז| כּ|ך א|ציו|רצי|ג ז|ר ב| מא|עמע|צן |נעמ|שפּ|אַן|נטל|ָבן|ַקט|ן צ|גער|ערי| קע|ן ע|עץ |זעץ|לױט| לױ| װי|ם א|אים|ום |טרא|פֿן|ַרז|אומ|מאָ| קו|ַלי|פּא|ליג|ז א|קלא|ף ד|ערש|פֿי|אַש'
  },
  'Canadian_Aboriginal': {
    'csw': 'ᑭᒋ | ᑭᒋ|ᐢᑕ |ᓀᐢᑕ| ᓀᐢ| ᑲ | ᐱᑯ|ᐱᑯ |ᓯᐟ |ᒥᓯᐌ| ᒥᓯ|ᐌᓇ |ᐊᐌᓇ| ᐊᐌ|ᓂᐠ |ᑕ ᐱ|ᓯᐌ |ᐎᐣ |ᐠ ᓀ|ᐟ ᓀ|ᐎᓂᐠ|ᐅᐟ |ᐁᑲ | ᐁᑲ|ᑯᐎᓯ|᙮ ᒥ| ᐃᔑ| ᐅᐟ|ᐌ ᐊ| ᐁ | ᑎᐯ|ᐎᓇ |ᒋ ᐃ| ᐅᒋ|ᐃᔑ |ᓂᐤ |ᑕᑯᓯ|ᒥᓂᑯ|ᐠ᙮ |ᓂᑯᐎ|ᐟ ᐃ| ᒥᓂ|ᐟ ᑭ| ᐊᐸ|ᒋ ᐊ| ᐊᐢ|ᐟ ᐅ| ᑲᓇ|ᐠ ᐅ|ᐅᒋ |ᐊᐢᑭ|ᑲ ᑭ|ᐟ ᐊ|ᓂᓂᐤ|ᐗᐠ |ᓇ ᐁ|ᑯᓯᐟ| ᐃᐢ|ᓂᑕᑯ|ᑲ ᐅ|ᐎᓯᐟ| ᐁᔑ|ᑌᓂᑕ|ᐃᐢᐱ|ᑕᒧᐎ|ᓂᑕᒧ|ᔑ ᑲ| ᐯᔭ|ᐁᔑ | ᐃᓂ|ᐢᐱ |ᑕ ᑭ|ᑕᐟ |ᑲ ᐊ|ᑲ ᐱ| ᐃᑕ|ᐠ ᑭ|ᐠ ᑲ|᙮ ᐁ|ᐣ ᑭ|ᐯᔭᑾ|ᓂᒥᑎ|ᐯᓂᒥ|ᑎᐯᓂ|ᐃᓂᓂ|ᓯᐎᐣ|ᓯᐎᓂ|ᐱ ᑲ|ᐤ ᑭ| ᐃᑌ| ᑎᐸ|ᐎᓂᓂ|ᓇᐗᐸ|ᑲᓇᐗ|ᐸᑎᓯ|ᐊᐸᑎ|ᑎᓯᐎ|ᑲᐠ |ᐟ᙮ |ᒥᐟ |ᐃᑌᓂ|ᑕ ᑲ| ᐎᒋ|ᐗᐸᒥ|ᒧᐎᐣ|ᒋ ᒥ|ᑯᓯᐎ|ᓂᐗᐠ|ᐢᑭᐠ| ᐅᓇ|ᑯ ᑭ|ᒋ ᐅ|ᓂᐠ᙮|ᑕᐠ | ᐅᑭ|ᑕᐢᑲ| ᐊᓂ|ᓯᐎᓇ|ᐎᓯᐎ|ᒥᑯᐎ|ᑾᐣ |ᓇᐌ |ᓂᔑᒋ|ᑕ ᐅ|ᑭᐠ |ᒪᐟ |ᒪᑲᐠ|ᐢᑯᓂ| ᓇᑕ|ᐣ ᓀ|ᓂᒥᑯ|ᔓᐌᐎ|ᓇᔓᐌ|ᑎᓯᐟ|ᑲ ᑎ|ᑕ ᐁ|ᑫᐎᓂ|ᐣ᙮ | ᐅᑎ|ᐊᔭᒥ| ᐊᔭ|ᐢᑲᓀ|ᑐᐎᓂ|ᑕᐌᓂ|ᒋᐠ | ᑭᐢ|ᒥᑎᓱ|ᓂᓂᐠ|ᒋᑕᐟ|ᐸᒋᑕ|ᐊᐸᒋ|ᐁ ᒥ| ᑲᑕ|ᐎᑭᑐ|ᐯᓇᐌ|ᑎᐯᓇ| ᐎᑭ| ᐱᒋ| ᑕᐺ|ᔑᒋᑫ|ᐗᓂᔑ| ᐗᓂ|ᓇ ᑲ|ᐠ ᐊ|ᑯᐟ |ᐎᐣ᙮| ᐅᒪ|ᐌᐎᓂ|ᐅᓇᔓ|ᐌᓂᒥ|ᒋ ᓂ| ᑐᑕ|ᐃᐟ |ᒋ ᑲ|ᐠ ᐃ|ᓇ ᑭ|ᒋ ᓇ|ᒋ ᐱ|ᐣ ᐁ|ᒋᑫᐎ|ᐸᒥᐟ|ᐤ ᑲ| ᑫᑾ| ᑯᑕ|ᐟ ᐁ|ᑲᓀᓯ|ᓇ ᓀ|ᓯᐤ |ᐤ ᓀ|ᐌᓂᑕ|ᔭᑾᐣ|ᐠ ᐁ|ᓀᓯᐎ|ᐃᑕᐢ| ᐊᔑ| ᑫ | ᐱᒧ|ᐱᒋ |ᑐᑕᒧ| ᐎᓇ|ᑲ ᐗ|ᒋ ᑭ|ᓇᒪᐟ|ᑯᓂᑫ|ᐸᐢᑯ|ᐢᑲᒥ|ᓇᑕᒪ|ᐅᒪ |ᓇᐌᓂ|ᑲᓇᐌ|ᒋ ᒪ|ᑲᐤ |ᒋᐃᐟ|ᑲᒋᐃ|ᑕᐤ |ᒪᑎᓯ|ᐱᒪᑎ| ᐱᒪ|ᔑ ᒥ|ᑯ ᐊ|ᒋ ᑎ|ᐱᓇᐌ|ᐤ ᐁ|ᐎᐎᓂ|ᒪᐎᐎ|ᑭᒪᐎ|ᐅᑭᒪ|ᐣ ᐅ|ᑲ ᐃ| ᐅᑕ|ᑎᓱᐎ|ᓄᐠ |ᐎᒋᐃ|ᔦᓂᑕ|ᐺᔦᓂ|ᑕᐺᔦ|ᑲᑕ |ᐌ ᐅ|ᒪᐎ |ᒪᒪᐎ| ᒪᒪ|ᑕ ᐃ|ᑭᐠ᙮|ᐡᑲᒋ|ᑯᐡᑲ|ᒥᑯᐡ| ᒥᑯ|ᐠ ᐱ|ᑕᒧᑴ|ᑎᐸᐢ|ᔭᑾᓄ|ᐎᒪᑲ|ᐸᐎᒪ|ᓂᐸᐎ| ᓂᐸ|ᑕᒪᑫ|ᓂᑫᐎ|ᑕᒪᑯ|ᑲ ᐎ|ᑯᓂᑲ|ᐟ ᐱ|ᐟ ᐯ|ᐁ ᐃ|ᐁ ᑎ|ᒋ ᑐ| ᐊᐗ|ᒥᑎᓯ|ᐢᑭᓂ|ᓂᑴ |ᑲ ᐁ|ᒪᑲ | ᒪᑲ|ᑯᑕᑭ|ᐌᐎᓯ|ᑎᐱᓇ|ᑯ ᑯ|ᑎᐯᐣ|ᐊᐎᐣ|ᒥᐊᐎ|ᔭᒥᐊ|ᑯ ᑲ|ᐨ ᑲ|ᐟ ᑕ|ᓇ ᐃ|ᑕ ᑎ|ᓂᐃ |ᐊᓂᐃ|ᓇ ᑎ|ᑐᒋᐠ|ᑕ ᐎ|ᑎᓇᒪ|ᐸᑭᑎ| ᐸᑭ|ᐢᑌᓂ|ᑭᐢᑌ|ᑭᐟ |ᑕᐎᑭ|ᓂᑕᐎ| ᓂᑕ|ᑫᐎᐣ',
    'ojb': 'ᐎᓐ |ᓐ ᑲ| ᑲᐃ|ᓂᒃ |ᑲᐃᔑ|ᓯᐎᓐ|ᒃ ᑲ| ᐅᑕ|ᑕᑯᓯ| ᒥᓇ|ᓐ ᐅ| ᑲᑭ|ᑫᑕᑯ|ᐎᓂᒃ|ᑯᓯᐎ|ᑲᔦ | ᑲᔦ|ᐸᑫᑕ|ᑌᐸᑫ| ᑌᐸ|ᒥᓇ |ᐅᒋ |ᐗᒃ |ᑦ ᑲ|ᑲᑭᓇ|ᐅᑕᔭ|ᓐ ᑌ|ᓂᐗᒃ|ᓀᓐ |ᐌᓀᓐ|ᓇᐌᓀ|ᑦ ᐅ|ᑭᓇᐌ|ᔭᓐ |ᑕᔭᓐ|ᑫᐎᓐ|ᒃ ᒋ|ᓐ ᒥ| ᒋᐅ|ᐃᔑ |ᒃ ᒥ|ᐗᑦ |ᑯᓂᑫ|ᒃ ᐅ|ᓇᓐ |ᓇᓂᐗ| ᐅᒋ| ᑲᐎ|ᓐ ᐊ|ᑲᐎᓐ|ᓇᐗ |ᑭᓐ |ᓂᑫᐎ| ᐃᔑ|ᐃᔑᓇ|ᑕᒃ |ᒋᐅᒋ| ᑲᐅ|ᓐ ᒋ|ᒃ ᐊ|ᒥᓯᐌ|ᐎᑦ | ᒋᐃ|ᑲᓇᐌ|ᓐ ᐃ|ᒋᑲᑌ|ᑎᐸᑯ| ᐅᒪ|ᑫᐎᓂ| ᐊᑭ|ᐎᔭ |ᐊᐎᔭ| ᐊᐎ| ᒥᓯ|ᑫᒪ | ᑫᒪ|ᒋᐃᔑ|ᑭᒃ | ᐱᑯ|ᓐ ᑫ|ᑌᒃ |ᑾᒃ | ᒋᐊ|ᓇ ᑲ|ᒃ ᑫ|ᐌᓂ |ᓄᓐ |ᐸᓐ |ᒥᓇᐗ| ᑎᐯ|ᐊᑭᒃ|ᐸᑯᓂ| ᑲᓇ|ᑲᓂᐎ| ᒋᑭ| ᑫᑯ| ᐊᓂ|ᓯᑦ |ᐃᔑᐊ|ᐃᑯ | ᐃᑯ| ᐅᑎ| ᑎᐸ|ᐅᒪ |ᑲᐅᒋ|ᔭ ᑕ|ᐊᓄᑭ|ᑲᑌᒃ| ᑕᐃ|ᓐ ᑕ|ᐎᓇᓐ|ᓱᐎᓂ|ᑎᓱᐎ|ᓂᒥᑎ|ᑎᐯᓂ|ᒪᑎᓯ|ᐱᒪᑎ|ᔦ ᒋ|ᒋᑫᐎ|ᑎᓇᓂ|ᓇᐌᑕ|ᓐ ᐁ|ᒋ ᑲ|ᐱᑯ |ᑐᒋᑲ|ᓂᑲᑌ|ᓇ ᒋ|ᑕᐃᔑ|ᔭᒃ |ᐅᑭᒪ|ᒪ ᑲ|ᓇᑯᓯ|ᒃ ᐃ|ᑲᓀᓯ|ᑕᑲᓀ|ᔑᓇᑯ|ᑫᑦ | ᑲᑎ| ᐅᐌ|ᑌᓂᒃ|ᒋᐎᑎ|ᑕᔥ | ᑭᒋ| ᑕᐱ|ᒥᑎᓱ|ᐯᓂᒥ| ᑫᐎ|ᐎᑎᑫ| ᐱᓴ|ᓐ ᑭ|ᓂ ᐅ|ᒪ ᐊ|ᒪᒪᔑ|ᑲᑌᓂ|ᑾᔭᒃ| ᑾᔭ|ᑲᓐ |ᓂᐎᑦ|ᑲᓂᐗ|ᐌᓂᒥ|ᓇᑯᓂ|ᑯᓯᑦ|ᓯᐌ |ᐗᓐ | ᐊᓄ|ᐃᔑᒋ|ᒃ ᑭ|ᔑᓇᑾ| ᑎᐱ|ᑦ ᐊ|ᐅᑕᑭ|ᑎᐯᑕ| ᑲᐊ|ᓯᓄᓐ|ᑭᑫᑕ|ᑲᐃᓇ|ᐗ ᑲ|ᑎᐎᓂ|ᐱᑕ |ᑕᐱᑕ|ᑯᓇᓐ|ᑫᑯᓇ|ᓱᐎᓐ|ᑕᑾᑭ| ᑲᑕ| ᐁᔑ|ᓀᓯᐎ|ᑯ ᒋ|ᓴᓐ |ᐱᓴᓐ|ᑦ ᑫ|ᐱᓐ |ᔥᐱᓐ|ᑭᔥᐱ| ᑭᔥ|ᑕᑾᒃ|ᓐ ᐱ|ᓂᓐ |ᐃᒪ | ᐃᒪ|ᓐ ᑎ|ᐃᔑᑕ|ᐸᑲᓐ| ᐸᑲ| ᐁᑕ|ᑯ ᑲ|ᑫᐎᓇ|ᑌᑭᓐ|ᑲᑌᑭ|ᑲᑭ |ᐱᑯᓂ|ᓇᐌᓂ|ᐃᓇᑯ| ᐃᓇ|ᒋᐃᑎ|ᓂᐎᓯ|ᒋᑲᓂ| ᐊᔭ|ᑦ ᒥ|ᑯᓯ |ᔕ ᑲ|ᑭᔕ |ᒪᑭᔕ| ᒪᑭ|ᑭᒪᐅ| ᐅᑭ|ᐱᓇᐌ|ᑎᐱᓇ|ᑯᑦ |ᒥᒃ |ᑲᒥᒃ|ᐌᑲᒥ|ᓯᐌᑲ|ᓯᒃ |ᐃᔑᑭ| ᑯᑕ|ᓐ ᒣ|ᑐᐎᓐ|ᑭᑐᐎ|ᐅᐌᓂ|ᑭᓇ |ᐎᒋᐎ|ᓇᐗᐸ|ᐅᑕᔦ|ᐃᓀᑕ| ᑲᐱ|ᑭᑲᓇ|ᑭᑦ |ᓄᑭᑦ|ᑡ ᑲ|ᒥᑡ |ᔑ ᐊ|ᐃᔑᐅ| ᒋᑕ|ᐗᐎᒋ| ᐗᐎ|ᔑ ᐗ|ᐊᐎᓐ|ᒥᐊᐎ|ᐌᑕᑾ|ᓐ ᐎ|ᑎᑫᐎ| ᐎᑎ|ᔭᒥᐊ|ᔑᐊᔭ|ᑐᑦ | ᐅᑐ|ᐅᑕᑲ| ᒪᒪ|ᐸᑕᒃ|ᐗᐸᑕ|ᒃ ᐱ|ᒋᑎᐸ|ᐅᑌᐺ| ᐅᑌ|ᒋ ᒪ|ᐌᑦ |ᑕᑦ |ᐯᒋᑫ|ᑎᐯᒋ|ᐃᑲᓂ|ᑲᒃ |ᐊᓇᐌ|ᐅᐌ |ᑦ ᒋ|ᔭᓇᐗ|ᑕᔭᓇ|ᒪᔑᐎ|ᐅᒪᒪ|ᔦ ᑭ|ᓐ ᒪ|ᐊᓂᓐ|ᔑᒋᑲ|ᐌᐌᓂ| ᐌᐌ|ᓇᑲᓂ|ᑭᒋᐎ| ᐎᓐ|ᑭ ᐃ|ᓂᑫᑦ',
    'ike': 'ᐃᓐᓇ|ᑦ ᐊ|ᑐᐃᓐ|ᒃᑯᑦ|ᑯᑦ |ᒪᓗ |ᒻᒪᓗ|ᐊᒻᒪ| ᐊᒻ|ᑦᑎᐊ|ᓂᒃᑯ|ᔪᓐᓇ|ᐅᑎᖃ|ᑦ ᐃ|ᓐᓇᐅ|ᒃᓴᐅ|ᒍᑦ |ᒧᑦ |ᑎᖃᕐ|ᑦ ᐱ|ᓄᑦ | ᐱᔪ|ᓇᐅᑎ|ᐅᕝᕙ| ᐅᕝ| ᑭᓇ|ᐱᔪᓐ|ᒥᒃ |ᓃᑦ |ᓐᓃᑦ|ᓘᓐᓃ|ᓂᒃ |ᖃᖅᑐ|ᑦ ᐅ|ᑐᒃᓴ|ᑦ ᑭ|ᓂᕐᒥ|ᓇᒃᑯ|ᐳᑦ |ᖅᑐᒃ|ᓐᓇᕐ|ᕙᓘᓐ|ᕝᕙᓘ|ᑭᓇᒃ|ᒃ ᐊ| ᐃᓱ| ᐃᓅ|ᕐᓂᕐ|ᓐᓇᖅ|ᐃᓱᒪ|ᕐᒧᑦ|ᖃᕐᐳ|ᐊᑦ |ᑎᐊᑦ|ᑯᑐᐃ|ᒃᑯᑐ|ᕐᐳᑦ|ᓴᐅᙱ|ᓇᖅ |ᓗᓂ |ᖅᑕᐅ|ᓂᕐᒧ| ᓄᓇ|ᓇᑦᑎ|ᑎᒍᑦ|ᑎᒃ |ᓗᒍ |ᓇᕐᓂ|ᕈᓐᓇ|ᓐᓇᑦ|ᑎᑕᐅ|ᐅᙱᓚ|ᑦ ᓴ|ᓗ ᐃ|ᖃᕐᓂ| ᑕᒪ|ᕐᓂᒃ|ᔾᔪᑎ|ᓂ ᐊ|ᓚᖅ |ᐱᖁᔭ| ᐱᖁ|ᑎᑦᑎ|ᕐᒥᒃ|ᖅ ᐊ|ᐅᑉ |ᙱᓚᖅ|ᓯᒪᔪ|ᑦ ᓇ|ᐅᓯᒪ|ᕆᐊᖃ|ᐊᔾᔨ| ᐊᔾ|ᐊᖑᑎ| ᐊᖑ|ᖅᑐᐃ|ᐊᕐᓂ|ᑎᐊᖅ|ᑐᑦ |ᑕᐅᓯ|ᑦ ᑕ|ᖃᑎᒌ|ᓕᒫᑦ|ᓪᓗᒍ|ᓂᑐᐃ|ᒋᑦ |ᓂᖅ |ᓗᑎᒃ|ᒪᖅᓱ|ᓱᒪᖅ|ᒥᓂᒃ|ᕐᓗᓂ|ᔪᖃᖅ|ᐃᓅᖃ|ᕐᔪᐊ|ᖕᒥᓂ|ᕐᓯᒪ| ᓴᓇ|ᑦ ᓄ| ᓇᓂ|ᓪᓕᐊ|ᖅ ᐱ|ᒫᑦᑎ|ᓗ ᐊ|ᖑᑎᐅ|ᑎᓪᓗ|ᑕᐅᔪ|ᖅ ᐃ|ᒻᒥᔭ|ᐳᒻᒥ|ᓴᐳᒻ| ᓴᐳ|ᒃ ᐱ|ᓇᖕᒥ| ᓇᖕ|ᑦ ᑲ|ᑦᑎᔪ|ᓇᓂᑐ| ᐊᕐ|ᑕᐅᓂ|ᓗ ᓇ|ᓇᓪᓕ| ᓇᓪ|ᔭᐅᑎ| ᐃᓕ|ᒃ ᐃ|ᓱᕈᓐ|ᖅᓱᕈ|ᔾᔨᐅ|ᓂᕈᐊ| ᓂᕈ|ᒥᒍᑦ|ᔭᒥᓂ| ᐃᓚ|ᑎᓄᑦ|ᐊᖅᑐ|ᖓᒍᑦ|ᐅᓂᒃ| ᐃᓄ|ᖓᓄᑦ| ᒪᓕ|ᔭᐅᔪ|ᒋᔭᐅ| ᐊᓯ|ᐊᕐᓇ|ᓇᓕᒫ|ᓐᓇᓕ|ᐊᖃᕐ|ᓐᓇᐃ|ᖢᑎᒃ|ᕐᖢᑎ|ᑐᔾᔨ| ᑲᑐ|ᔪᖅ |ᐃᔾᔪ|ᖅᑎᑦ|ᖅᑲᖅ|ᑎᔪᖃ|ᓗᒋᑦ| ᐊᑭ|ᓂ ᐱ|ᒥᔭᐅ|ᐊᖅ |ᓪᓗᓂ|ᖓᓂᒃ|ᖅ ᑭ|ᕕᖃᖅ|ᓐᓂᐊ|ᖃᓄᐃ| ᖃᓄ|ᓇᑐᐃ|ᓯᐅᑎ|ᐃᓅᓯ| ᑭᒡ| ᐊᖏ|ᓂᐊᕐ|ᔪᐊᕐ|ᕈᑕᐅ|ᓯᒪᓂ|ᓇᒋᔭ|ᓄᓇᒋ| ᒐᕙ|ᕐᕕᖃ|ᒍ ᐊ|ᕐᓇᐅ|ᕐᒥᐅ|ᙱᓪᓗ|ᓕᐅᖅ|ᔪᒃᓴ|ᓗ ᐱ|ᔨᖃᑎ|ᔾᔨᖃ|ᓇᐅᑉ|ᑎᐅᑉ|ᕐᒥᒍ|ᑲᑐᔾ|ᐅᔪᓐ|ᑐᐃᔾ|ᓪᓚᕆ|ᖅᑎᑕ| ᓈᓚ|ᑲᖅᑐ|ᐃᖅᑲ| ᐃᖅ|ᓂᑦ |ᑲᔪᖅ|ᐃᑲᔪ| ᐃᑲ|ᖃᕐᖢ|ᓗ ᑕ|ᕈᓂ |ᖃᓪᓚ|ᓱᐊᕐ|ᓇᓱᐊ|ᙱᑦᑐ|ᑭᓇᑐ|ᓂ ᐃ|ᐃᑦ |ᒥᓂᖅ|ᓪᓚᑦ| ᐊᑕ|ᑦ ᑖ|ᑦ ᑎ|ᐊᕐᒥ|ᑦ ᒪ|ᖃᖅᓂ|ᒥᑦ |ᐅᔪᒥ|ᖁᑎᒋ|ᑦ ᓯ|ᕙᓗ |ᕝᕙᓗ|ᒐᕙᒪ|ᐊᕐᕕ|ᒃᓯᐊ| ᐅᖃ|ᓱᒪᒋ|ᕐᓗ |ᖃᑦᑎ|ᓯᒪᔭ|ᑦ ᖃ|ᑕᐅᕙ|ᓴᓇᕕ|ᒪᔭᒥ|ᐅᔪᖅ|ᐅᑎᐅ|ᕕᖃᕈ| ᑲᑎ|ᑦ ᑐ|ᑉ ᐅ|ᑭᓲᓂ| ᑭᓲ|ᓅᖃᑎ|ᓂᐊᖅ|ᓂᕐᓴ|ᒋᔭᒥ|ᐅᔪᓂ|ᔪᖅᑐ|ᓂᖓᒍ|ᐅᑦ |ᓚᕐᔪ|ᓯᓚᕐ| ᓯᓚ|ᓇᐃᑦ|ᒃ ᑭ|ᓂᖓᓂ|ᖅᑐᕐ|ᒥᓂ |ᓈᓚᒃ|ᑦ ᓈ|ᔭᒃᓴ|ᑎᒧᑦ|ᓴᖅᑕ|ᓄᓇᒥ|ᐅᑎᓄ|ᓗ ᑐ|ᑎᐊᕐ|ᐊᑭᕋ|ᓴᐅᓂ|ᖃᓐᓂ'
  }
}
